/* Generated by Nim Compiler v2.2.10 */
#define NIM_INTBITS 64

#include "nimbase.h"
#include <string.h>
#include <math.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix
typedef struct tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ;
typedef struct tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw;
typedef struct tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg;
typedef struct tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug;
typedef struct RootObj RootObj;
typedef struct TNimTypeV2 TNimTypeV2;
typedef struct tyObject_TJSGen__eMRdF9b1ev54YKlmk5BuCUA tyObject_TJSGen__eMRdF9b1ev54YKlmk5BuCUA;
typedef struct tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg;
typedef struct tyObject_CountTable__C4iAvBZYBHUgGQV1J30IiA tyObject_CountTable__C4iAvBZYBHUgGQV1J30IiA;
typedef struct tySequence__9bRXJy1JXrQ4hWpStaKBpXg tySequence__9bRXJy1JXrQ4hWpStaKBpXg;
typedef struct tySequence__9bRXJy1JXrQ4hWpStaKBpXg_Content tySequence__9bRXJy1JXrQ4hWpStaKBpXg_Content;
typedef struct tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw;
typedef struct tySequence__TfHJycarvNts8E4mVG4Mfg tySequence__TfHJycarvNts8E4mVG4Mfg;
typedef struct tySequence__TfHJycarvNts8E4mVG4Mfg_Content tySequence__TfHJycarvNts8E4mVG4Mfg_Content;
typedef struct tyObject_PackedModuleGraph__vzv9a6xTiz616FotDgUeo9bg tyObject_PackedModuleGraph__vzv9a6xTiz616FotDgUeo9bg;
typedef struct tySequence__5reviU45axUMPQgL9aoENrg tySequence__5reviU45axUMPQgL9aoENrg;
typedef struct tySequence__5reviU45axUMPQgL9aoENrg_Content tySequence__5reviU45axUMPQgL9aoENrg_Content;
typedef struct tySequence__dtr79aXjHrgHuH79ac55I2aw tySequence__dtr79aXjHrgHuH79ac55I2aw;
typedef struct tySequence__dtr79aXjHrgHuH79ac55I2aw_Content tySequence__dtr79aXjHrgHuH79ac55I2aw_Content;
typedef struct tyObject_Table__EBJpp1hXwvFl9cyekUv4qHg tyObject_Table__EBJpp1hXwvFl9cyekUv4qHg;
typedef struct tySequence__8y0Gi4GwtXi2wk2mK1IOzw tySequence__8y0Gi4GwtXi2wk2mK1IOzw;
typedef struct tySequence__8y0Gi4GwtXi2wk2mK1IOzw_Content tySequence__8y0Gi4GwtXi2wk2mK1IOzw_Content;
typedef struct tyObject_Table__nn0jq9adRZXGGj9assM9c9bR0w tyObject_Table__nn0jq9adRZXGGj9assM9c9bR0w;
typedef struct tySequence__C2ivDnhTZ6IxAdui1rfuqw tySequence__C2ivDnhTZ6IxAdui1rfuqw;
typedef struct tySequence__C2ivDnhTZ6IxAdui1rfuqw_Content tySequence__C2ivDnhTZ6IxAdui1rfuqw_Content;
typedef struct tyObject_Table__ChMwcRY3QzpOEBWbGAfvcA tyObject_Table__ChMwcRY3QzpOEBWbGAfvcA;
typedef struct tySequence__3vEEVfBECLN6NIRA3FIp5g tySequence__3vEEVfBECLN6NIRA3FIp5g;
typedef struct tySequence__3vEEVfBECLN6NIRA3FIp5g_Content tySequence__3vEEVfBECLN6NIRA3FIp5g_Content;
typedef struct tyObject_Table__tEqt8LkShErhjQ9acvGyE7g tyObject_Table__tEqt8LkShErhjQ9acvGyE7g;
typedef struct tySequence__9aSa87aKMiolq9a7z3kC0jTw tySequence__9aSa87aKMiolq9a7z3kC0jTw;
typedef struct tySequence__9aSa87aKMiolq9a7z3kC0jTw_Content tySequence__9aSa87aKMiolq9a7z3kC0jTw_Content;
typedef struct tyObject_Table__QS2Z9cQjmvkp1aaFGq4ippw tyObject_Table__QS2Z9cQjmvkp1aaFGq4ippw;
typedef struct tySequence__N589c2UsUgqqOITU2JfIuAQ tySequence__N589c2UsUgqqOITU2JfIuAQ;
typedef struct tySequence__N589c2UsUgqqOITU2JfIuAQ_Content tySequence__N589c2UsUgqqOITU2JfIuAQ_Content;
typedef struct tyObject_Table__bnfVX2VJ9aUicVujDM0GIhw tyObject_Table__bnfVX2VJ9aUicVujDM0GIhw;
typedef struct tySequence__GYDW6wGgERshoSd16jJ3eQ tySequence__GYDW6wGgERshoSd16jJ3eQ;
typedef struct tySequence__GYDW6wGgERshoSd16jJ3eQ_Content tySequence__GYDW6wGgERshoSd16jJ3eQ_Content;
typedef struct tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw tySequence__7lEisrXlQEzwtUKW5pzRCw;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw_Content tySequence__7lEisrXlQEzwtUKW5pzRCw_Content;
typedef struct tyObject_PackedConfig__Hpn673wkKPDorr1HY9bOaDQ tyObject_PackedConfig__Hpn673wkKPDorr1HY9bOaDQ;
typedef struct tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg;
typedef struct tySequence__ZCZaCk14bTmSb6LMW9aWPVA tySequence__ZCZaCk14bTmSb6LMW9aWPVA;
typedef struct tySequence__ZCZaCk14bTmSb6LMW9aWPVA_Content tySequence__ZCZaCk14bTmSb6LMW9aWPVA_Content;
typedef struct tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA;
typedef struct tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA;
typedef struct tySequence__ZeWVlH6DqG79b1pTDhrrUYA tySequence__ZeWVlH6DqG79b1pTDhrrUYA;
typedef struct tySequence__ZeWVlH6DqG79b1pTDhrrUYA_Content tySequence__ZeWVlH6DqG79b1pTDhrrUYA_Content;
typedef struct tyObject_Table__79b4rr6WWQqgRr9b4NH4UF9cw tyObject_Table__79b4rr6WWQqgRr9b4NH4UF9cw;
typedef struct tySequence__fdmz6VkIf1ewwrssKYqRFg tySequence__fdmz6VkIf1ewwrssKYqRFg;
typedef struct tySequence__fdmz6VkIf1ewwrssKYqRFg_Content tySequence__fdmz6VkIf1ewwrssKYqRFg_Content;
typedef struct tyObject_Table__AC9bec2JdoOuC3xQePGWgmA tyObject_Table__AC9bec2JdoOuC3xQePGWgmA;
typedef struct tySequence__kxu4GK0onha2t9bo86mdVAg tySequence__kxu4GK0onha2t9bo86mdVAg;
typedef struct tySequence__kxu4GK0onha2t9bo86mdVAg_Content tySequence__kxu4GK0onha2t9bo86mdVAg_Content;
typedef struct tySequence__48JTohSgTy339bRxHzUD8KA tySequence__48JTohSgTy339bRxHzUD8KA;
typedef struct tySequence__48JTohSgTy339bRxHzUD8KA_Content tySequence__48JTohSgTy339bRxHzUD8KA_Content;
typedef struct tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA;
typedef struct tyObject_Table__bHTcQUCehDW9clHfFZXI7lQ tyObject_Table__bHTcQUCehDW9clHfFZXI7lQ;
typedef struct tySequence__fz0REU1l0nYmKHXgMLRrIg tySequence__fz0REU1l0nYmKHXgMLRrIg;
typedef struct tySequence__fz0REU1l0nYmKHXgMLRrIg_Content tySequence__fz0REU1l0nYmKHXgMLRrIg_Content;
typedef struct tyObject_Table__w2vCG1OPnHmNolvQVT168g tyObject_Table__w2vCG1OPnHmNolvQVT168g;
typedef struct tySequence__Ip9aV1IKO2gVdheNOM31DCQ tySequence__Ip9aV1IKO2gVdheNOM31DCQ;
typedef struct tySequence__Ip9aV1IKO2gVdheNOM31DCQ_Content tySequence__Ip9aV1IKO2gVdheNOM31DCQ_Content;
typedef struct tySequence__kHjIdgrpmuSn9cUIIKpSiDg tySequence__kHjIdgrpmuSn9cUIIKpSiDg;
typedef struct tySequence__kHjIdgrpmuSn9cUIIKpSiDg_Content tySequence__kHjIdgrpmuSn9cUIIKpSiDg_Content;
typedef struct tyObject_CountTable__qvMelb9coODdwoghoAPc9c9aA tyObject_CountTable__qvMelb9coODdwoghoAPc9c9aA;
typedef struct tySequence__Wd0Vle6gxRCPPoSlNEvfTA tySequence__Wd0Vle6gxRCPPoSlNEvfTA;
typedef struct tySequence__Wd0Vle6gxRCPPoSlNEvfTA_Content tySequence__Wd0Vle6gxRCPPoSlNEvfTA_Content;
typedef struct tyObject_Table__fZyCWkMwhdvr3pauCNDaag tyObject_Table__fZyCWkMwhdvr3pauCNDaag;
typedef struct tySequence__T7nNEWoEbKBa0G5Htr45Xw tySequence__T7nNEWoEbKBa0G5Htr45Xw;
typedef struct tySequence__T7nNEWoEbKBa0G5Htr45Xw_Content tySequence__T7nNEWoEbKBa0G5Htr45Xw_Content;
typedef struct tyObject_Table__5vmBY49areSIlgIs4A1LLKQ tyObject_Table__5vmBY49areSIlgIs4A1LLKQ;
typedef struct tySequence__q9cHvMDDxYU1hSCdG4YwIhA tySequence__q9cHvMDDxYU1hSCdG4YwIhA;
typedef struct tySequence__q9cHvMDDxYU1hSCdG4YwIhA_Content tySequence__q9cHvMDDxYU1hSCdG4YwIhA_Content;
typedef struct tySequence__olFOFaYzOJN9aV5BWqK4b9bA tySequence__olFOFaYzOJN9aV5BWqK4b9bA;
typedef struct tySequence__olFOFaYzOJN9aV5BWqK4b9bA_Content tySequence__olFOFaYzOJN9aV5BWqK4b9bA_Content;
typedef struct tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg;
typedef struct tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ;
typedef struct tyObject_Table__9bmd0cvHWe1s4FTDn5BPmfw tyObject_Table__9bmd0cvHWe1s4FTDn5BPmfw;
typedef struct tySequence__vJcM7B74R2U5db9cxyXT9coA tySequence__vJcM7B74R2U5db9cxyXT9coA;
typedef struct tySequence__vJcM7B74R2U5db9cxyXT9coA_Content tySequence__vJcM7B74R2U5db9cxyXT9coA_Content;
typedef struct tyObject_Table__GhjCMuklnRqwdX9bZo9bCoNg tyObject_Table__GhjCMuklnRqwdX9bZo9bCoNg;
typedef struct tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg;
typedef struct tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg_Content tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg_Content;
typedef struct tyObject_Table__pI3mJh4Ap2XujSCfcSeUvQ tyObject_Table__pI3mJh4Ap2XujSCfcSeUvQ;
typedef struct tySequence__R9c39btP6BwOBBPnbaNUtMQg tySequence__R9c39btP6BwOBBPnbaNUtMQg;
typedef struct tySequence__R9c39btP6BwOBBPnbaNUtMQg_Content tySequence__R9c39btP6BwOBBPnbaNUtMQg_Content;
typedef struct tyObject_Table__MsPmCuYz1KcEw6lr7P9cGkw tyObject_Table__MsPmCuYz1KcEw6lr7P9cGkw;
typedef struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA tySequence__squ9b9bUH4OLHf6cEMrt6hVA;
typedef struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA_Content tySequence__squ9b9bUH4OLHf6cEMrt6hVA_Content;
typedef struct tyObject_Table__1HJsK7ponJ4Vb1lJgVFVTQ tyObject_Table__1HJsK7ponJ4Vb1lJgVFVTQ;
typedef struct tySequence__3nALyQgqjnfK2Qjc6ny2Uw tySequence__3nALyQgqjnfK2Qjc6ny2Uw;
typedef struct tySequence__3nALyQgqjnfK2Qjc6ny2Uw_Content tySequence__3nALyQgqjnfK2Qjc6ny2Uw_Content;
typedef struct tySequence__WbW5Q8QVks0bQpUJSGmuVg tySequence__WbW5Q8QVks0bQpUJSGmuVg;
typedef struct tySequence__WbW5Q8QVks0bQpUJSGmuVg_Content tySequence__WbW5Q8QVks0bQpUJSGmuVg_Content;
typedef struct tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA;
typedef struct tySequence__9ahcSjIErJohSBBFLwuF56Q tySequence__9ahcSjIErJohSBBFLwuF56Q;
typedef struct tySequence__9ahcSjIErJohSBBFLwuF56Q_Content tySequence__9ahcSjIErJohSBBFLwuF56Q_Content;
typedef struct tyObject_Operators__yrAfvKhiysDamJlcGNgVfQ tyObject_Operators__yrAfvKhiysDamJlcGNgVfQ;
typedef struct tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg;
typedef struct tyObject_PGlobalscolonObjectType___5ylNBaUZgofS9cIrLp09cbRA tyObject_PGlobalscolonObjectType___5ylNBaUZgofS9cIrLp09cbRA;
typedef struct NimStrPayload NimStrPayload;
typedef struct NimStringV2 NimStringV2;
typedef struct tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A;
typedef struct tySequence__bdNIx7Bah2llfuqeoTJEWQ tySequence__bdNIx7Bah2llfuqeoTJEWQ;
typedef struct tySequence__bdNIx7Bah2llfuqeoTJEWQ_Content tySequence__bdNIx7Bah2llfuqeoTJEWQ_Content;
typedef struct tySequence__P9aymq2R2Xa8At0XKJ6Bh1A tySequence__P9aymq2R2Xa8At0XKJ6Bh1A;
typedef struct tySequence__P9aymq2R2Xa8At0XKJ6Bh1A_Content tySequence__P9aymq2R2Xa8At0XKJ6Bh1A_Content;
typedef struct tyObject_TBlock__e4aohBvIZbqlrYGhrE9cgpw tyObject_TBlock__e4aohBvIZbqlrYGhrE9cgpw;
typedef struct tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA;
typedef struct tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA;
typedef struct tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw;
typedef struct tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig;
typedef struct tyObject_GcEnv__HccVszwojlCZRN46BE9cG8w tyObject_GcEnv__HccVszwojlCZRN46BE9cG8w;
typedef struct tyObject_CellSeq__gW9aeWLFbrNaeUKXqxYBXhg tyObject_CellSeq__gW9aeWLFbrNaeUKXqxYBXhg;
typedef struct tyTuple__N4J9cV4JZGem3ljqqj5rT0Q tyTuple__N4J9cV4JZGem3ljqqj5rT0Q;
typedef struct tyObject_CellSeq__IHvIqxITv1yMjJj8lwLrhg tyObject_CellSeq__IHvIqxITv1yMjJj8lwLrhg;
typedef struct tyTuple__DTRsWi2kgTewbhN2TT5mbA tyTuple__DTRsWi2kgTewbhN2TT5mbA;
typedef struct tyObject_Target__GzbDkV2u8Pgzlf9azvC43FA tyObject_Target__GzbDkV2u8Pgzlf9azvC43FA;
typedef struct tyObject_MsgConfig__E1VAUnnaNIOngCdEgTI2Dw tyObject_MsgConfig__E1VAUnnaNIOngCdEgTI2Dw;
typedef struct tySequence__E0kio2ZnplNTuln9bsnljSA tySequence__E0kio2ZnplNTuln9bsnljSA;
typedef struct tySequence__E0kio2ZnplNTuln9bsnljSA_Content tySequence__E0kio2ZnplNTuln9bsnljSA_Content;
typedef struct tySequence__hTEiKNj3evQAjIXUI21elA tySequence__hTEiKNj3evQAjIXUI21elA;
typedef struct tySequence__hTEiKNj3evQAjIXUI21elA_Content tySequence__hTEiKNj3evQAjIXUI21elA_Content;
typedef struct tyObject_HashSet__8IGL0eIK5PYDsNGVA78Wmw tyObject_HashSet__8IGL0eIK5PYDsNGVA78Wmw;
typedef struct tySequence__4eRCaZmrYLLw2k30GPTiMw tySequence__4eRCaZmrYLLw2k30GPTiMw;
typedef struct tySequence__4eRCaZmrYLLw2k30GPTiMw_Content tySequence__4eRCaZmrYLLw2k30GPTiMw_Content;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ tySequence__sM4lkSb7zS6F7OVMvW9cffQ;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content;
typedef struct tySequence__xOJ2kx2lq9bBfIm3IXnde3Q tySequence__xOJ2kx2lq9bBfIm3IXnde3Q;
typedef struct tySequence__xOJ2kx2lq9bBfIm3IXnde3Q_Content tySequence__xOJ2kx2lq9bBfIm3IXnde3Q_Content;
typedef struct tyObject_SuggestcolonObjectType___UyASNXAqAMRY5zJmcRD9ccA tyObject_SuggestcolonObjectType___UyASNXAqAMRY5zJmcRD9ccA;
typedef struct tyObject_ProfileDatacolonObjectType___R9cEb9cNTzPRldVmD9bCDO0xQ tyObject_ProfileDatacolonObjectType___R9cEb9cNTzPRldVmD9bCDO0xQ;
typedef struct tyObject_CountTable__5N9carAoH8U5E301UN9ccEmQ tyObject_CountTable__5N9carAoH8U5E301UN9ccEmQ;
typedef struct tySequence__hRbbzIynOoxrYjHTIKZ3Gw tySequence__hRbbzIynOoxrYjHTIKZ3Gw;
typedef struct tySequence__hRbbzIynOoxrYjHTIKZ3Gw_Content tySequence__hRbbzIynOoxrYjHTIKZ3Gw_Content;
typedef struct tyTuple__kN8up2W6YKc5YA9avn5mV5w tyTuple__kN8up2W6YKc5YA9avn5mV5w;
typedef struct tyTuple__kIcKc1aSJCixG4QCidyBAg tyTuple__kIcKc1aSJCixG4QCidyBAg;
typedef struct tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ;
typedef struct tySequence__d8ZV4IMgHt9biik9cS9a0hrmg tySequence__d8ZV4IMgHt9biik9cS9a0hrmg;
typedef struct tySequence__d8ZV4IMgHt9biik9cS9a0hrmg_Content tySequence__d8ZV4IMgHt9biik9cS9a0hrmg_Content;
typedef struct tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg;
typedef struct tyObject_TFileInfo__xPdjmgevOVG8T0Aq8BK7jw tyObject_TFileInfo__xPdjmgevOVG8T0Aq8BK7jw;
typedef struct tyTuple__UV3llMMYFckfui8YMBuUZA tyTuple__UV3llMMYFckfui8YMBuUZA;
typedef struct tyObject_HSlice__Td0KDtM8kU0p7CVwrbJeww tyObject_HSlice__Td0KDtM8kU0p7CVwrbJeww;
typedef struct tyTuple__RICk09aVWvF6a15iJKyZfFQ tyTuple__RICk09aVWvF6a15iJKyZfFQ;
typedef struct tyTuple__axVdnKAd4XGmBNrMsqQ7kw tyTuple__axVdnKAd4XGmBNrMsqQ7kw;
typedef struct tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA;
typedef struct tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ;
typedef struct tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig;
typedef struct tyObject_SourceMap__WQjtp9aU0iILpTcFCDzWLTA tyObject_SourceMap__WQjtp9aU0iILpTcFCDzWLTA;
typedef struct tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g;
typedef struct tyObject_OrderedTable__ASIVNBCKpz8qGZwzYCCBFQ tyObject_OrderedTable__ASIVNBCKpz8qGZwzYCCBFQ;
typedef struct tySequence__m9axZwxFfhSNLcoofvKZJYA tySequence__m9axZwxFfhSNLcoofvKZJYA;
typedef struct tySequence__m9axZwxFfhSNLcoofvKZJYA_Content tySequence__m9axZwxFfhSNLcoofvKZJYA_Content;
typedef struct tySequence__fXWXs2NlFKREhy9cn6vokJw tySequence__fXWXs2NlFKREhy9cn6vokJw;
typedef struct tySequence__fXWXs2NlFKREhy9cn6vokJw_Content tySequence__fXWXs2NlFKREhy9cn6vokJw_Content;
typedef struct tyTuple__9agFg9cuYsNvckAbTfHAsTSA tyTuple__9agFg9cuYsNvckAbTfHAsTSA;
typedef struct tyObject_Iface__j1FkQxwEAKMJy1o9bap1xow tyObject_Iface__j1FkQxwEAKMJy1o9bap1xow;
typedef struct tyObject_LoadedModule__7NEKRkz5hkiOxQy5guqIHA tyObject_LoadedModule__7NEKRkz5hkiOxQy5guqIHA;
typedef struct tyObject_PackedModule__sRHd9aQ2ZMII76xRsfAbE9aQ tyObject_PackedModule__sRHd9aQ2ZMII76xRsfAbE9aQ;
typedef struct tySequence__PXIzfWocnrafGz5p3CP5LA tySequence__PXIzfWocnrafGz5p3CP5LA;
typedef struct tySequence__PXIzfWocnrafGz5p3CP5LA_Content tySequence__PXIzfWocnrafGz5p3CP5LA_Content;
typedef struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA tySequence__9bAGqSvkAaFL9bWjsEPslrFA;
typedef struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA_Content tySequence__9bAGqSvkAaFL9bWjsEPslrFA_Content;
typedef struct tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w;
typedef struct tySequence__OxRbUT0qZaZN5UjnqQjGPA tySequence__OxRbUT0qZaZN5UjnqQjGPA;
typedef struct tySequence__OxRbUT0qZaZN5UjnqQjGPA_Content tySequence__OxRbUT0qZaZN5UjnqQjGPA_Content;
typedef struct tySequence__ezS5mGPcRfBURJyMgqYVzA tySequence__ezS5mGPcRfBURJyMgqYVzA;
typedef struct tySequence__ezS5mGPcRfBURJyMgqYVzA_Content tySequence__ezS5mGPcRfBURJyMgqYVzA_Content;
typedef struct tySequence__wW7xkohjuUKO9aMaB0nt9cqA tySequence__wW7xkohjuUKO9aMaB0nt9cqA;
typedef struct tySequence__wW7xkohjuUKO9aMaB0nt9cqA_Content tySequence__wW7xkohjuUKO9aMaB0nt9cqA_Content;
typedef struct tySequence__b89aLriiJnVTD186H6zNIgg tySequence__b89aLriiJnVTD186H6zNIgg;
typedef struct tySequence__b89aLriiJnVTD186H6zNIgg_Content tySequence__b89aLriiJnVTD186H6zNIgg_Content;
typedef struct tySequence__hIPTk9aFdaMMVAOzEbnPyqg tySequence__hIPTk9aFdaMMVAOzEbnPyqg;
typedef struct tySequence__hIPTk9aFdaMMVAOzEbnPyqg_Content tySequence__hIPTk9aFdaMMVAOzEbnPyqg_Content;
typedef struct tySequence__YYy1721YAuPF0ajBYHd8Wg tySequence__YYy1721YAuPF0ajBYHd8Wg;
typedef struct tySequence__YYy1721YAuPF0ajBYHd8Wg_Content tySequence__YYy1721YAuPF0ajBYHd8Wg_Content;
typedef struct tySequence__UODJbvzmu39c3Ho9cqhSk9agQ tySequence__UODJbvzmu39c3Ho9cqhSk9agQ;
typedef struct tySequence__UODJbvzmu39c3Ho9cqhSk9agQ_Content tySequence__UODJbvzmu39c3Ho9cqhSk9agQ_Content;
typedef struct tySequence__F1qNdU7m0Czu7Y2q0eksXw tySequence__F1qNdU7m0Czu7Y2q0eksXw;
typedef struct tySequence__F1qNdU7m0Czu7Y2q0eksXw_Content tySequence__F1qNdU7m0Czu7Y2q0eksXw_Content;
typedef struct tySequence__r3Kz9breImOXyFFoJ29aBM8Q tySequence__r3Kz9breImOXyFFoJ29aBM8Q;
typedef struct tySequence__r3Kz9breImOXyFFoJ29aBM8Q_Content tySequence__r3Kz9breImOXyFFoJ29aBM8Q_Content;
typedef struct tySequence__qBes3XzcQQ9cyia9bRwnmbJw tySequence__qBes3XzcQQ9cyia9bRwnmbJw;
typedef struct tySequence__qBes3XzcQQ9cyia9bRwnmbJw_Content tySequence__qBes3XzcQQ9cyia9bRwnmbJw_Content;
typedef struct tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw;
typedef struct tySequence__Vl1abU3gfp0RqCb1KKfmDA tySequence__Vl1abU3gfp0RqCb1KKfmDA;
typedef struct tySequence__Vl1abU3gfp0RqCb1KKfmDA_Content tySequence__Vl1abU3gfp0RqCb1KKfmDA_Content;
typedef struct tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw;
typedef struct tySequence__qyyNkmlc4fzOzelC8spUkQ tySequence__qyyNkmlc4fzOzelC8spUkQ;
typedef struct tySequence__qyyNkmlc4fzOzelC8spUkQ_Content tySequence__qyyNkmlc4fzOzelC8spUkQ_Content;
typedef struct tyObject_BiTable__KR9c7QZguPO3OKZOIcphgcA tyObject_BiTable__KR9c7QZguPO3OKZOIcphgcA;
typedef struct tyObject_BiTable__9aUXwPoJbNPqj9a249c0iSmlg tyObject_BiTable__9aUXwPoJbNPqj9a249c0iSmlg;
typedef struct tySequence__IHUFRsFxZNv7YydiUO2esQ tySequence__IHUFRsFxZNv7YydiUO2esQ;
typedef struct tySequence__IHUFRsFxZNv7YydiUO2esQ_Content tySequence__IHUFRsFxZNv7YydiUO2esQ_Content;
typedef struct tyObject_LineInfoManager__TTy646Kfh1cVyXU9aSMasUQ tyObject_LineInfoManager__TTy646Kfh1cVyXU9aSMasUQ;
typedef struct tySequence__orxtl6CusdjXleqrxi67gw tySequence__orxtl6CusdjXleqrxi67gw;
typedef struct tySequence__orxtl6CusdjXleqrxi67gw_Content tySequence__orxtl6CusdjXleqrxi67gw_Content;
typedef struct tyObject_OrderedTable__h8mIUVGY8LJXF9cakgvB9bqQ tyObject_OrderedTable__h8mIUVGY8LJXF9cakgvB9bqQ;
typedef struct tySequence__K0j67V58u5FW0dCC534FQw tySequence__K0j67V58u5FW0dCC534FQw;
typedef struct tySequence__K0j67V58u5FW0dCC534FQw_Content tySequence__K0j67V58u5FW0dCC534FQw_Content;
typedef struct tyObject_OrderedTable__DED9c7j9bI3Lh5w4GQakK8yQ tyObject_OrderedTable__DED9c7j9bI3Lh5w4GQakK8yQ;
typedef struct tySequence__UE4b6iUkm1b3zTPamTTkDw tySequence__UE4b6iUkm1b3zTPamTTkDw;
typedef struct tySequence__UE4b6iUkm1b3zTPamTTkDw_Content tySequence__UE4b6iUkm1b3zTPamTTkDw_Content;
typedef struct tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg;
typedef struct tySequence__FmsTQiIcS9arxHxs3QY48vA tySequence__FmsTQiIcS9arxHxs3QY48vA;
typedef struct tySequence__FmsTQiIcS9arxHxs3QY48vA_Content tySequence__FmsTQiIcS9arxHxs3QY48vA_Content;
typedef struct tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ;
typedef struct tyObject_Table__uaQEKxLZNO5fpFluyxnhTg tyObject_Table__uaQEKxLZNO5fpFluyxnhTg;
typedef struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ tySequence__9cnx3zXnWzeclW8Ko4oUgAQ;
typedef struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ_Content tySequence__9cnx3zXnWzeclW8Ko4oUgAQ_Content;
typedef struct tyTuple__7TXOq9czx9cn1FWKG5gXNK8Q tyTuple__7TXOq9czx9cn1FWKG5gXNK8Q;
typedef struct tySequence__vb3AGHvMJTxdOSSwMmBmTQ tySequence__vb3AGHvMJTxdOSSwMmBmTQ;
typedef struct tySequence__vb3AGHvMJTxdOSSwMmBmTQ_Content tySequence__vb3AGHvMJTxdOSSwMmBmTQ_Content;
typedef struct tyTuple__F1mMODXmKFMNQ5rLCtcv0Q tyTuple__F1mMODXmKFMNQ5rLCtcv0Q;
typedef struct tySequence__apM9bRAO19cVjhWlxqd1PGeA tySequence__apM9bRAO19cVjhWlxqd1PGeA;
typedef struct tySequence__apM9bRAO19cVjhWlxqd1PGeA_Content tySequence__apM9bRAO19cVjhWlxqd1PGeA_Content;
typedef struct tyTuple__vHfXSpEC1R9b9cKgfFB9a58gw tyTuple__vHfXSpEC1R9b9cKgfFB9a58gw;
typedef struct tyTuple__4iq9bD09amB7Ah0r9cBB0nSPQ tyTuple__4iq9bD09amB7Ah0r9cBB0nSPQ;
typedef struct tySequence__9bW2eTK9b7vXE70Sx5VPH1mw tySequence__9bW2eTK9b7vXE70Sx5VPH1mw;
typedef struct tySequence__9bW2eTK9b7vXE70Sx5VPH1mw_Content tySequence__9bW2eTK9b7vXE70Sx5VPH1mw_Content;
typedef struct tyTuple__bnJwOH0eJlAwCAMbr1inhw tyTuple__bnJwOH0eJlAwCAMbr1inhw;
typedef struct tyTuple__YG7h1OUHzgfgTeH9cl0U0dw tyTuple__YG7h1OUHzgfgTeH9cl0U0dw;
typedef struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw tyTuple__xYhUhS7X82rKTqbT9bRfCnw;
typedef struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q;
typedef struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ tyTuple__xDU9bZmv1ZbZkJDaATBekIQ;
typedef struct tyTuple__tG5yYi8DnD7bl00aT9cgctQ tyTuple__tG5yYi8DnD7bl00aT9cgctQ;
typedef struct tyObject_SuggestFileSymbolDatabase__o0ahEzaLn5a7TdNqH4OVqQ tyObject_SuggestFileSymbolDatabase__o0ahEzaLn5a7TdNqH4OVqQ;
typedef struct tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg;
typedef struct tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg_Content tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg_Content;
typedef struct tySequence__yUWoZehF86MIc40opFgacw tySequence__yUWoZehF86MIc40opFgacw;
typedef struct tySequence__yUWoZehF86MIc40opFgacw_Content tySequence__yUWoZehF86MIc40opFgacw_Content;
typedef struct tyObject_PackedBoolArray__1pk9boftqWMNDE1oh5HcIhw tyObject_PackedBoolArray__1pk9boftqWMNDE1oh5HcIhw;
typedef struct tyTuple__gnRkA1L4XiR4uByriyHW8Q tyTuple__gnRkA1L4XiR4uByriyHW8Q;
typedef struct tySequence__nSO1ltijM4vhc0UrrXKEqA tySequence__nSO1ltijM4vhc0UrrXKEqA;
typedef struct tySequence__nSO1ltijM4vhc0UrrXKEqA_Content tySequence__nSO1ltijM4vhc0UrrXKEqA_Content;
typedef struct tyTuple__CvjVmQeIfivirDme2r5MRw tyTuple__CvjVmQeIfivirDme2r5MRw;
typedef struct tyTuple__2QDyOgS51ZMPO0W1pWCY6g tyTuple__2QDyOgS51ZMPO0W1pWCY6g;
typedef struct tyTuple__UbCNQED4XJUgxOgPHJUcAQ tyTuple__UbCNQED4XJUgxOgPHJUcAQ;
typedef struct tySequence__juxPMVNF1FoR2ltzeQu8NQ tySequence__juxPMVNF1FoR2ltzeQu8NQ;
typedef struct tySequence__juxPMVNF1FoR2ltzeQu8NQ_Content tySequence__juxPMVNF1FoR2ltzeQu8NQ_Content;
typedef struct tyTuple__zExIg9bDTcVf2FHROUpzoow tyTuple__zExIg9bDTcVf2FHROUpzoow;
typedef struct tyTuple__XrHNJHOzS3O7uwF9bvCySiA tyTuple__XrHNJHOzS3O7uwF9bvCySiA;
typedef struct tyTuple__EdLY4EJQ37VFgbAn5g5rXQ tyTuple__EdLY4EJQ37VFgbAn5g5rXQ;
typedef struct tyTuple__OtlgAx3kBps9cOSMNDZSzBA tyTuple__OtlgAx3kBps9cOSMNDZSzBA;
typedef struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg tyTuple__F3gkSrMB1qp2Tvf9bixVXwg;
typedef struct tyTuple__RFOJ4fF7D9bpvmh9birH1JhQ tyTuple__RFOJ4fF7D9bpvmh9birH1JhQ;
typedef struct tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw;
typedef struct tyObject_NodecolonObjectType___U4ON6JZL9cIHezBQjmQzJ8Q tyObject_NodecolonObjectType___U4ON6JZL9cIHezBQjmQzJ8Q;
typedef struct tyTuple__O3g9a8zTXSX36ljWponcAoA tyTuple__O3g9a8zTXSX36ljWponcAoA;
typedef struct tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ;
typedef struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw tyTuple__QeWl6B6ffS4pU6WWrtcrDw;
typedef struct tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg;
typedef struct tyTuple__Oubp8LPEu86EPyDuc56AXg tyTuple__Oubp8LPEu86EPyDuc56AXg;
typedef struct tyTuple__eR5B9b9c9coYBbO09chTvuMqNQ tyTuple__eR5B9b9c9coYBbO09chTvuMqNQ;
typedef struct tyTuple__0q9cmhneJEKnQERTpXXdz6Q tyTuple__0q9cmhneJEKnQERTpXXdz6Q;
typedef struct tyObject_PackedNode__YxKk4C732K04CNgtMhmc0w tyObject_PackedNode__YxKk4C732K04CNgtMhmc0w;
typedef struct tyTuple__48iPM3yLBKU5nyEuYwJvuQ tyTuple__48iPM3yLBKU5nyEuYwJvuQ;
typedef struct tyTuple__R3ddFrA0G9buJY57Qhf9cTpg tyTuple__R3ddFrA0G9buJY57Qhf9cTpg;
typedef struct tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ;
typedef struct tyTuple__7rmdAMLZ8fDd79brQn2ixZA tyTuple__7rmdAMLZ8fDd79brQn2ixZA;
typedef struct tyTuple__qPXRCRNQuZLLKto7CIIEzw tyTuple__qPXRCRNQuZLLKto7CIIEzw;
typedef struct tyObject_PackedInstantiation__C3FSePJFY8gUIMObsjT2dg tyObject_PackedInstantiation__C3FSePJFY8gUIMObsjT2dg;
typedef struct tyTuple__6kG8KAxm9aXPdLdlxcxqJJw tyTuple__6kG8KAxm9aXPdLdlxcxqJJw;
typedef struct tyTuple__TRK7rrwoha9bbDAdPWsqJMw tyTuple__TRK7rrwoha9bbDAdPWsqJMw;
typedef struct tyTuple__V1VWX9bHapuzCjpMfFfys5Q tyTuple__V1VWX9bHapuzCjpMfFfys5Q;
typedef struct tyObject_PackedSym__KKnx6w8Cc9aaVsaPOpaqxbw tyObject_PackedSym__KKnx6w8Cc9aaVsaPOpaqxbw;
typedef struct tyObject_PackedLib__EpwVLk0Fuc5Q9agKLMWedbg tyObject_PackedLib__EpwVLk0Fuc5Q9agKLMWedbg;
typedef struct tyTuple__anemVmHCFglLFt6LiEhFvg tyTuple__anemVmHCFglLFt6LiEhFvg;
typedef struct tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ;
typedef struct tyTuple__MaWaKZwaGUqCXKsSK12rVg tyTuple__MaWaKZwaGUqCXKsSK12rVg;
typedef struct tyTuple__nL9cBxaIV4ZA9b9ceY79coA5eA tyTuple__nL9cBxaIV4ZA9b9ceY79coA5eA;
typedef struct tyTuple__1xWeGeoNoZxaLhTUDDWYyA tyTuple__1xWeGeoNoZxaLhTUDDWYyA;
typedef struct tyTuple__MZVSn3SE3XUBJOaMu7ofRQ tyTuple__MZVSn3SE3XUBJOaMu7ofRQ;
typedef struct tyTuple__UvldbCB6B9ayi9bGYW7vJNLA tyTuple__UvldbCB6B9ayi9bGYW7vJNLA;
typedef struct tyObject_LazyType__dsEGDq9cOhnzsRvTUTwwwuA tyObject_LazyType__dsEGDq9cOhnzsRvTUTwwwuA;
typedef struct tyObject_LazyInstantiation__n72c7MnOoHWBy9c9akgwGqEA tyObject_LazyInstantiation__n72c7MnOoHWBy9c9akgwGqEA;
typedef struct tySequence__YxH9cgSorHRI8ZPzHf47NNQ tySequence__YxH9cgSorHRI8ZPzHf47NNQ;
typedef struct tySequence__YxH9cgSorHRI8ZPzHf47NNQ_Content tySequence__YxH9cgSorHRI8ZPzHf47NNQ_Content;
typedef struct tyObject_TInstantiation__jr8MibvPn2sQBnO7XCoZRQ tyObject_TInstantiation__jr8MibvPn2sQBnO7XCoZRQ;
typedef struct tyTuple__lGHLhAAUpxgfrnQkIzNrMw tyTuple__lGHLhAAUpxgfrnQkIzNrMw;
typedef struct tyObject_TinyLineInfo__qW2GTIPjeOQ42q9c2MPWLLA tyObject_TinyLineInfo__qW2GTIPjeOQ42q9c2MPWLLA;
typedef struct tyTuple__V6P73hvHy70PBBwharKjig tyTuple__V6P73hvHy70PBBwharKjig;
struct TNimTypeV2 {
	void* destructor;
	NI size;
	NI16 align;
	NI16 depth;
	NU32* display;
	void* traceImpl;
	void* typeInfoV1;
	NI flags;
	void* vTable[SEQ_DECL_SIZE];
};
struct RootObj {
	TNimTypeV2* m_type;
};
struct tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ {
	RootObj Sup;
	tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen;
};
struct tySequence__9bRXJy1JXrQ4hWpStaKBpXg {
  NI len; tySequence__9bRXJy1JXrQ4hWpStaKBpXg_Content* p;
};
struct tyObject_CountTable__C4iAvBZYBHUgGQV1J30IiA {
	tySequence__9bRXJy1JXrQ4hWpStaKBpXg data;
	NI counter;
	NIM_BOOL isSorted;
};
struct tyObject_TJSGen__eMRdF9b1ev54YKlmk5BuCUA {
	tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ Sup;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module;
	tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph;
	tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* config;
	tyObject_CountTable__C4iAvBZYBHUgGQV1J30IiA sigConflicts;
	tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* initProc;
};
struct tySequence__TfHJycarvNts8E4mVG4Mfg {
  NI len; tySequence__TfHJycarvNts8E4mVG4Mfg_Content* p;
};
struct tySequence__5reviU45axUMPQgL9aoENrg {
  NI len; tySequence__5reviU45axUMPQgL9aoENrg_Content* p;
};
struct tyObject_PackedModuleGraph__vzv9a6xTiz616FotDgUeo9bg {
	tySequence__5reviU45axUMPQgL9aoENrg pm;
};
struct tySequence__dtr79aXjHrgHuH79ac55I2aw {
  NI len; tySequence__dtr79aXjHrgHuH79ac55I2aw_Content* p;
};
struct tySequence__8y0Gi4GwtXi2wk2mK1IOzw {
  NI len; tySequence__8y0Gi4GwtXi2wk2mK1IOzw_Content* p;
};
struct tyObject_Table__EBJpp1hXwvFl9cyekUv4qHg {
	tySequence__8y0Gi4GwtXi2wk2mK1IOzw data;
	NI counter;
};
struct tySequence__C2ivDnhTZ6IxAdui1rfuqw {
  NI len; tySequence__C2ivDnhTZ6IxAdui1rfuqw_Content* p;
};
struct tyObject_Table__nn0jq9adRZXGGj9assM9c9bR0w {
	tySequence__C2ivDnhTZ6IxAdui1rfuqw data;
	NI counter;
};
struct tySequence__3vEEVfBECLN6NIRA3FIp5g {
  NI len; tySequence__3vEEVfBECLN6NIRA3FIp5g_Content* p;
};
struct tyObject_Table__ChMwcRY3QzpOEBWbGAfvcA {
	tySequence__3vEEVfBECLN6NIRA3FIp5g data;
	NI counter;
};
typedef tyObject_Table__ChMwcRY3QzpOEBWbGAfvcA tyArray__HTPiakF26bUQGH9bgtmrtkA[7];
struct tySequence__9aSa87aKMiolq9a7z3kC0jTw {
  NI len; tySequence__9aSa87aKMiolq9a7z3kC0jTw_Content* p;
};
struct tyObject_Table__tEqt8LkShErhjQ9acvGyE7g {
	tySequence__9aSa87aKMiolq9a7z3kC0jTw data;
	NI counter;
};
struct tySequence__N589c2UsUgqqOITU2JfIuAQ {
  NI len; tySequence__N589c2UsUgqqOITU2JfIuAQ_Content* p;
};
struct tyObject_Table__QS2Z9cQjmvkp1aaFGq4ippw {
	tySequence__N589c2UsUgqqOITU2JfIuAQ data;
	NI counter;
};
struct tySequence__GYDW6wGgERshoSd16jJ3eQ {
  NI len; tySequence__GYDW6wGgERshoSd16jJ3eQ_Content* p;
};
struct tyObject_Table__bnfVX2VJ9aUicVujDM0GIhw {
	tySequence__GYDW6wGgERshoSd16jJ3eQ data;
	NI counter;
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw {
  NI len; tySequence__7lEisrXlQEzwtUKW5pzRCw_Content* p;
};
struct tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A {
	tySequence__7lEisrXlQEzwtUKW5pzRCw data;
	NI counter;
};
typedef NU8 tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw;
typedef NU8 tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg;
typedef NU8 tyEnum_TSystemCC__A5wZwpTXF1SiKGvwgH1wrA;
typedef NU32 tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ;
typedef NU64 tySet_tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A;
struct tyObject_PackedConfig__Hpn673wkKPDorr1HY9bOaDQ {
	tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw backend;
	tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg selectedGC;
	tyEnum_TSystemCC__A5wZwpTXF1SiKGvwgH1wrA cCompiler;
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ options;
	tySet_tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A globalOptions;
};
struct tySequence__ZCZaCk14bTmSb6LMW9aWPVA {
  NI len; tySequence__ZCZaCk14bTmSb6LMW9aWPVA_Content* p;
};
struct tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg {
	NI counter;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA data;
};
struct tySequence__ZeWVlH6DqG79b1pTDhrrUYA {
  NI len; tySequence__ZeWVlH6DqG79b1pTDhrrUYA_Content* p;
};
typedef NI tyArray__k7D0lwfLmYccbQxUd49bbcQ[34];
struct tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA {
	NI elems;
	NI counter;
	NI max;
	tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA* head;
	tySequence__ZeWVlH6DqG79b1pTDhrrUYA data;
	tyArray__k7D0lwfLmYccbQxUd49bbcQ a;
};
struct tySequence__fdmz6VkIf1ewwrssKYqRFg {
  NI len; tySequence__fdmz6VkIf1ewwrssKYqRFg_Content* p;
};
struct tyObject_Table__79b4rr6WWQqgRr9b4NH4UF9cw {
	tySequence__fdmz6VkIf1ewwrssKYqRFg data;
	NI counter;
};
struct tySequence__kxu4GK0onha2t9bo86mdVAg {
  NI len; tySequence__kxu4GK0onha2t9bo86mdVAg_Content* p;
};
struct tyObject_Table__AC9bec2JdoOuC3xQePGWgmA {
	tySequence__kxu4GK0onha2t9bo86mdVAg data;
	NI counter;
};
struct tySequence__48JTohSgTy339bRxHzUD8KA {
  NI len; tySequence__48JTohSgTy339bRxHzUD8KA_Content* p;
};
typedef struct {
N_NIMCALL_PTR(NIM_BOOL, ClP_0) (void* ClE_0);
void* ClE_0;
} tyProc__In3g79a0qTcRmbTbJp9ba9ctg;
struct tySequence__fz0REU1l0nYmKHXgMLRrIg {
  NI len; tySequence__fz0REU1l0nYmKHXgMLRrIg_Content* p;
};
struct tyObject_Table__bHTcQUCehDW9clHfFZXI7lQ {
	tySequence__fz0REU1l0nYmKHXgMLRrIg data;
	NI counter;
};
struct tySequence__Ip9aV1IKO2gVdheNOM31DCQ {
  NI len; tySequence__Ip9aV1IKO2gVdheNOM31DCQ_Content* p;
};
struct tyObject_Table__w2vCG1OPnHmNolvQVT168g {
	tySequence__Ip9aV1IKO2gVdheNOM31DCQ data;
	NI counter;
};
struct tySequence__kHjIdgrpmuSn9cUIIKpSiDg {
  NI len; tySequence__kHjIdgrpmuSn9cUIIKpSiDg_Content* p;
};
struct tySequence__Wd0Vle6gxRCPPoSlNEvfTA {
  NI len; tySequence__Wd0Vle6gxRCPPoSlNEvfTA_Content* p;
};
struct tyObject_CountTable__qvMelb9coODdwoghoAPc9c9aA {
	tySequence__Wd0Vle6gxRCPPoSlNEvfTA data;
	NI counter;
	NIM_BOOL isSorted;
};
struct tySequence__T7nNEWoEbKBa0G5Htr45Xw {
  NI len; tySequence__T7nNEWoEbKBa0G5Htr45Xw_Content* p;
};
struct tyObject_Table__fZyCWkMwhdvr3pauCNDaag {
	tySequence__T7nNEWoEbKBa0G5Htr45Xw data;
	NI counter;
};
struct tySequence__q9cHvMDDxYU1hSCdG4YwIhA {
  NI len; tySequence__q9cHvMDDxYU1hSCdG4YwIhA_Content* p;
};
struct tyObject_Table__5vmBY49areSIlgIs4A1LLKQ {
	tySequence__q9cHvMDDxYU1hSCdG4YwIhA data;
	NI counter;
};
struct tySequence__olFOFaYzOJN9aV5BWqK4b9bA {
  NI len; tySequence__olFOFaYzOJN9aV5BWqK4b9bA_Content* p;
};
typedef tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* tyArray__EOkbZZXacNOZHC8p7xc7hw[65];
struct tySequence__vJcM7B74R2U5db9cxyXT9coA {
  NI len; tySequence__vJcM7B74R2U5db9cxyXT9coA_Content* p;
};
struct tyObject_Table__9bmd0cvHWe1s4FTDn5BPmfw {
	tySequence__vJcM7B74R2U5db9cxyXT9coA data;
	NI counter;
};
struct tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg {
  NI len; tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg_Content* p;
};
struct tyObject_Table__GhjCMuklnRqwdX9bZo9bCoNg {
	tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg data;
	NI counter;
};
typedef N_NIMCALL_PTR(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, tyProc__QieBhPPkGvcmpFg89a4ftcA) (tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* m_p1, NI32 fileIdx_p2);
typedef N_NIMCALL_PTR(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, tyProc__F2ahyGAjs3aNLJYEXzu07g) (tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* m_p1, NI32 fileIdx_p2);
struct tySequence__R9c39btP6BwOBBPnbaNUtMQg {
  NI len; tySequence__R9c39btP6BwOBBPnbaNUtMQg_Content* p;
};
struct tyObject_Table__pI3mJh4Ap2XujSCfcSeUvQ {
	tySequence__R9c39btP6BwOBBPnbaNUtMQg data;
	NI counter;
};
struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA {
  NI len; tySequence__squ9b9bUH4OLHf6cEMrt6hVA_Content* p;
};
struct tyObject_Table__MsPmCuYz1KcEw6lr7P9cGkw {
	tySequence__squ9b9bUH4OLHf6cEMrt6hVA data;
	NI counter;
};
struct tySequence__3nALyQgqjnfK2Qjc6ny2Uw {
  NI len; tySequence__3nALyQgqjnfK2Qjc6ny2Uw_Content* p;
};
struct tyObject_Table__1HJsK7ponJ4Vb1lJgVFVTQ {
	tySequence__3nALyQgqjnfK2Qjc6ny2Uw data;
	NI counter;
};
struct tySequence__WbW5Q8QVks0bQpUJSGmuVg {
  NI len; tySequence__WbW5Q8QVks0bQpUJSGmuVg_Content* p;
};
typedef NU8 tyEnum_PipelinePass__kO50VlNfBJZtrNuD4VL9aTg;
typedef N_NIMCALL_PTR(void, tyProc__c9a5q9aZQWYYOu1vHoRoq9bVQ) (tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p2);
struct tySequence__9ahcSjIErJohSBBFLwuF56Q {
  NI len; tySequence__9ahcSjIErJohSBBFLwuF56Q_Content* p;
};
typedef N_NIMCALL_PTR(void, tyProc__kj3TYePLaHBuXxhRznQQNQ) (tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* owner_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* body_p2);
typedef N_NIMCALL_PTR(NIM_BOOL, tyProc__D3Q9bYoPIpHZVLfEIxpBssA) (tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* formal_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* actual_p2);
struct tyObject_Operators__yrAfvKhiysDamJlcGNgVfQ {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opNot;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opContains;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opLe;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opLt;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opAnd;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opOr;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opIsNil;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opEq;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opAdd;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opSub;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opMul;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opDiv;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opLen;
};
struct tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw {
	tySequence__TfHJycarvNts8E4mVG4Mfg ifaces;
	tyObject_PackedModuleGraph__vzv9a6xTiz616FotDgUeo9bg packed_0;
	tySequence__dtr79aXjHrgHuH79ac55I2aw encoders;
	tyObject_Table__EBJpp1hXwvFl9cyekUv4qHg typeInstCache;
	tyObject_Table__nn0jq9adRZXGGj9assM9c9bR0w procInstCache;
	tyArray__HTPiakF26bUQGH9bgtmrtkA attachedOps;
	tyObject_Table__tEqt8LkShErhjQ9acvGyE7g methodsPerGenericType;
	tyObject_Table__QS2Z9cQjmvkp1aaFGq4ippw memberProcsPerType;
	tyObject_Table__bnfVX2VJ9aUicVujDM0GIhw initializersPerType;
	tyObject_Table__ChMwcRY3QzpOEBWbGAfvcA enumToStringProcs;
	tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A emittedTypeInfo;
	tyObject_PackedConfig__Hpn673wkKPDorr1HY9bOaDQ startupPackedConfig;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg packageSyms;
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA deps;
	tyObject_Table__79b4rr6WWQqgRr9b4NH4UF9cw importDeps;
	NIM_BOOL suggestMode;
	NIM_BOOL invalidTransitiveClosure;
	NIM_BOOL interactive;
	NIM_BOOL withinSystem;
	tyObject_Table__AC9bec2JdoOuC3xQePGWgmA inclToMod;
	tySequence__48JTohSgTy339bRxHzUD8KA importStack;
	RootObj* backend;
	tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* config;
	tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* cache;
	RootObj* vm;
	RootObj* repl;
	tyProc__In3g79a0qTcRmbTbJp9ba9ctg doStopCompile;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* usageSym;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA owners;
	tyObject_Table__bHTcQUCehDW9clHfFZXI7lQ suggestSymbols;
	tyObject_Table__w2vCG1OPnHmNolvQVT168g suggestErrors;
	tySequence__kHjIdgrpmuSn9cUIIKpSiDg methods;
	tyObject_CountTable__qvMelb9coODdwoghoAPc9c9aA bucketTable;
	tyObject_Table__fZyCWkMwhdvr3pauCNDaag objectTree;
	tyObject_Table__5vmBY49areSIlgIs4A1LLKQ methodsPerType;
	tySequence__olFOFaYzOJN9aV5BWqK4b9bA dispatchers;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* systemModule;
	tyArray__EOkbZZXacNOZHC8p7xc7hw sysTypes;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg compilerprocs;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg exposed;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg packageTypes;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* emptyNode;
	tyObject_Table__9bmd0cvHWe1s4FTDn5BPmfw canonTypes;
	tyObject_Table__GhjCMuklnRqwdX9bZo9bCoNg symBodyHashes;
	tyProc__QieBhPPkGvcmpFg89a4ftcA importModuleCallback;
	tyProc__F2ahyGAjs3aNLJYEXzu07g includeFileCallback;
	tyObject_Table__pI3mJh4Ap2XujSCfcSeUvQ cacheSeqs;
	tyObject_Table__MsPmCuYz1KcEw6lr7P9cGkw cacheCounters;
	tyObject_Table__1HJsK7ponJ4Vb1lJgVFVTQ cacheTables;
	tySequence__WbW5Q8QVks0bQpUJSGmuVg passes;
	tyEnum_PipelinePass__kO50VlNfBJZtrNuD4VL9aTg pipelinePass;
	tyProc__c9a5q9aZQWYYOu1vHoRoq9bVQ onDefinition;
	tyProc__c9a5q9aZQWYYOu1vHoRoq9bVQ onDefinitionResolveForward;
	tyProc__c9a5q9aZQWYYOu1vHoRoq9bVQ onUsage;
	tySequence__9ahcSjIErJohSBBFLwuF56Q globalDestructors;
	tyProc__kj3TYePLaHBuXxhRznQQNQ strongSemCheck;
	tyProc__D3Q9bYoPIpHZVLfEIxpBssA compatibleProps;
	tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen;
	tyObject_Operators__yrAfvKhiysDamJlcGNgVfQ operators;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* cachedFiles;
	tySequence__9ahcSjIErJohSBBFLwuF56Q procGlobals;
};
struct NimStrPayload {
	NI cap;
	NIM_CHAR data[SEQ_DECL_SIZE];
};
struct NimStringV2 {
	NI len;
	NimStrPayload* p;
};
struct tyObject_PGlobalscolonObjectType___5ylNBaUZgofS9cIrLp09cbRA {
	RootObj Sup;
	NimStringV2 typeInfo;
	NimStringV2 constants;
	NimStringV2 code;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA forwarded;
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA generatedSyms;
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA typeInfoGenerated;
	NI unique;
	NIM_BOOL inSystem;
};
struct tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A {
	NI rc;
	NI rootIdx;
};
typedef NU tyArray__KznKlIbW0OmA9ckg0NfmHVQ[8];
struct tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA {
	tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA* next;
	NI key;
	tyArray__KznKlIbW0OmA9ckg0NfmHVQ bits;
};
struct tySequence__bdNIx7Bah2llfuqeoTJEWQ {
  NI len; tySequence__bdNIx7Bah2llfuqeoTJEWQ_Content* p;
};
struct tySequence__P9aymq2R2Xa8At0XKJ6Bh1A {
  NI len; tySequence__P9aymq2R2Xa8At0XKJ6Bh1A_Content* p;
};
struct tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* procDef;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* prc;
	NimStringV2 globals;
	NimStringV2 locals;
	NimStringV2 body;
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ options;
	tySequence__bdNIx7Bah2llfuqeoTJEWQ optionsStack;
	tyObject_TJSGen__eMRdF9b1ev54YKlmk5BuCUA* module;
	tyObject_PGlobalscolonObjectType___5ylNBaUZgofS9cIrLp09cbRA* g;
	NIM_BOOL beforeRetNeeded;
	NI unique;
	tySequence__P9aymq2R2Xa8At0XKJ6Bh1A blocks;
	NI extraIndent;
	NimStringV2 previousFileName;
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA generatedParamCopies;
	tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* up;
};
struct tyObject_TBlock__e4aohBvIZbqlrYGhrE9cgpw {
	NI id;
	NIM_BOOL isLoop;
};
struct tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA {
	NI32 module;
	NI32 item;
};
typedef NU8 tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q;
typedef NU16 tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg;
struct tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA {
	NU16 line;
	NI16 col;
	NI32 fileIndex;
};
typedef NU64 tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg;
typedef NU8 tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ;
typedef NU8 tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg;
typedef NU16 tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg;
struct tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw {
	tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ k;
	tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg storage;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg flags;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* lode;
	NimStringV2 snippet;
};
struct tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg {
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA itemId;
	tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q kind;
union{
	struct {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* gcUnsafetyReason;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* transformedBody;
} _kind_1;
	struct {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* guard;
	NI bitsize;
	NI alignment;
} _kind_2;
};
	tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg magic;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ;
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* name;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* ownerField;
	tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg flags;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* ast;
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ options;
	NI position;
	NI32 offset;
	NI32 disamb;
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw loc;
	tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig* annex;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* constraint;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* instantiatedFrom;
};
typedef NU32 tySet_tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw;
typedef NU8 tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw;
struct tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typField;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info;
	tySet_tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw flags;
	tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw kind;
union{
	struct {
	NI64 intVal;
} _kind_1;
	struct {
	NF floatVal;
} _kind_2;
	struct {
	NimStringV2 strVal;
} _kind_3;
	struct {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym;
} _kind_4;
	struct {
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* ident;
} _kind_5;
	struct {
	tySequence__9ahcSjIErJohSBBFLwuF56Q sons;
} _kind_6;
};
};
struct tyObject_CellSeq__gW9aeWLFbrNaeUKXqxYBXhg {
	NI len;
	NI cap;
	tyTuple__N4J9cV4JZGem3ljqqj5rT0Q* d;
};
struct tyObject_CellSeq__IHvIqxITv1yMjJj8lwLrhg {
	NI len;
	NI cap;
	tyTuple__DTRsWi2kgTewbhN2TT5mbA* d;
};
struct tyObject_GcEnv__HccVszwojlCZRN46BE9cG8w {
	tyObject_CellSeq__gW9aeWLFbrNaeUKXqxYBXhg traceStack;
	tyObject_CellSeq__IHvIqxITv1yMjJj8lwLrhg toFree;
	NI freed;
	NI touched;
	NI edges;
	NI rcSum;
	NIM_BOOL keepThreshold;
};
struct tyTuple__N4J9cV4JZGem3ljqqj5rT0Q {
	void** Field0;
	TNimTypeV2* Field1;
};
typedef NU8 tyEnum_TSystemCPU__3f9cinURS2hpZEHtBX69bm9cw;
typedef NU8 tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw;
struct tyObject_Target__GzbDkV2u8Pgzlf9azvC43FA {
	tyEnum_TSystemCPU__3f9cinURS2hpZEHtBX69bm9cw targetCPU;
	tyEnum_TSystemCPU__3f9cinURS2hpZEHtBX69bm9cw hostCPU;
	tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw targetOS;
	tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw hostOS;
	NI intSize;
	NI floatSize;
	NI ptrSize;
	NimStringV2 tnl;
};
typedef NU8 tySet_tyEnum_TErrorOutput__wGgqZXVnY1wkKEe8EL9cL9aw;
struct tySequence__E0kio2ZnplNTuln9bsnljSA {
  NI len; tySequence__E0kio2ZnplNTuln9bsnljSA_Content* p;
};
struct tySequence__hTEiKNj3evQAjIXUI21elA {
  NI len; tySequence__hTEiKNj3evQAjIXUI21elA_Content* p;
};
struct tyObject_MsgConfig__E1VAUnnaNIOngCdEgTI2Dw {
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA trackPos;
	NIM_BOOL trackPosAttached;
	tySet_tyEnum_TErrorOutput__wGgqZXVnY1wkKEe8EL9cL9aw errorOutputs;
	tySequence__E0kio2ZnplNTuln9bsnljSA msgContext;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA lastError;
	tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A filenameToIndexTbl;
	tySequence__hTEiKNj3evQAjIXUI21elA fileInfos;
	NI32 systemFileIdx;
};
typedef NU8 tyEnum_FilenameOption__o3jmnnVs6HdBg5KcNAzYiQ;
typedef NU8 tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ;
typedef NU8 tyEnum_ExceptionSystem__dJ6sXW7k8NDYNNBUjVZmnw;
typedef NU8 tyEnum_SymbolFilesOption__2eyIIreuRXhYT9buPPZbBYA;
struct tySequence__4eRCaZmrYLLw2k30GPTiMw {
  NI len; tySequence__4eRCaZmrYLLw2k30GPTiMw_Content* p;
};
struct tyObject_HashSet__8IGL0eIK5PYDsNGVA78Wmw {
	tySequence__4eRCaZmrYLLw2k30GPTiMw data;
	NI counter;
};
typedef NU32 tySet_tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ;
typedef NU8 tySet_tyEnum_LegacyFeature__yvNVqOQTgcxHpvo1MvfBfA;
typedef NU8 tyEnum_IdeCmd__mZiSMTDWSAKKDbZfXDQwng;
typedef NU8 tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw[13];
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ {
  NI len; tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content* p;
};
typedef NU8 tySet_tyEnum_StdOrrKind__so1PI9cHP1cN622ePtqa0yw;
struct tySequence__xOJ2kx2lq9bBfIm3IXnde3Q {
  NI len; tySequence__xOJ2kx2lq9bBfIm3IXnde3Q_Content* p;
};
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_SuggestcolonObjectType___UyASNXAqAMRY5zJmcRD9ccA* result_p0, void* ClE_0);
void* ClE_0;
} tyProc__QQyR5yGA47tr5TwLxcC4Gw;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (NimStringV2 output_p0, void* ClE_0);
void* ClE_0;
} tyProc__k2HFjxisIgDALbEUFojxaQ;
typedef NU8 tyEnum_Severity__mHEDvws7FmOtnFhcQsM8UA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* config_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, NimStringV2 msg_p2, tyEnum_Severity__mHEDvws7FmOtnFhcQsM8UA severity_p3, void* ClE_0);
void* ClE_0;
} tyProc__DA9aR62IikoxFqfC5rIT9cuw;
struct tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg {
	tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw backend;
	tyObject_Target__GzbDkV2u8Pgzlf9azvC43FA target;
	NI linesCompiled;
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ options;
	tySet_tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A globalOptions;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* macrosToExpand;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* arcToExpand;
	tyObject_MsgConfig__E1VAUnnaNIOngCdEgTI2Dw m;
	tyEnum_FilenameOption__o3jmnnVs6HdBg5KcNAzYiQ filenameOption;
	NimStringV2 unitSep;
	NI evalTemplateCounter;
	NI evalMacroCounter;
	NI8 exitcode;
	tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ cmd;
	NimStringV2 cmdInput;
	NIM_BOOL projectIsCmd;
	NIM_BOOL implicitCmd;
	tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg selectedGC;
	tyEnum_ExceptionSystem__dJ6sXW7k8NDYNNBUjVZmnw exc;
	NIM_BOOL hintProcessingDots;
	NI verbosity;
	NI numberOfProcessors;
	NF lastCmdTime;
	tyEnum_SymbolFilesOption__2eyIIreuRXhYT9buPPZbBYA symbolFiles;
	NI spellSuggestMax;
	tyObject_HashSet__8IGL0eIK5PYDsNGVA78Wmw cppDefines;
	NimStringV2 headerFile;
	NimStringV2 nimbasePattern;
	tySet_tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ features;
	tySet_tyEnum_LegacyFeature__yvNVqOQTgcxHpvo1MvfBfA legacyFeatures;
	NimStringV2 arguments;
	tyEnum_IdeCmd__mZiSMTDWSAKKDbZfXDQwng ideCmd;
	tyEnum_TSystemCC__A5wZwpTXF1SiKGvwgH1wrA cCompiler;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw modifiedyNotes;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw cmdlineNotes;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw foreignPackageNotes;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw notes;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw warningAsErrors;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw mainPackageNotes;
	NI mainPackageId;
	NI errorCounter;
	NI hintCounter;
	NI warnCounter;
	NI errorMax;
	NI maxLoopIterationsVM;
	NI maxCallDepthVM;
	NIM_BOOL isVmTrace;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* configVars;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* symbols;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* packageCache;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ nimblePaths;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ searchPaths;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ lazyPaths;
	NimStringV2 outFile;
	NimStringV2 outDir;
	NimStringV2 jsonBuildFile;
	NimStringV2 prefixDir;
	NimStringV2 libpath;
	NimStringV2 nimcacheDir;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* dllOverrides;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* moduleOverrides;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* cfileSpecificOptions;
	NimStringV2 projectName;
	NimStringV2 projectPath;
	NimStringV2 projectFull;
	NIM_BOOL projectIsStdin;
	NimStringV2 stdinFile;
	tySet_tyEnum_StdOrrKind__so1PI9cHP1cN622ePtqa0yw lastMsgWasDot;
	NI32 projectMainIdx;
	NI32 projectMainIdx2;
	NimStringV2 command;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ commandArgs;
	NimStringV2 commandLine;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ extraCmds;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ implicitImports;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ implicitIncludes;
	NimStringV2 docSeeSrcUrl;
	NimStringV2 docRoot;
	NimStringV2 docCmd;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ configFiles;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ cIncludes;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ cLibs;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ cLinkedLibs;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ externalToLink;
	NimStringV2 linkOptionsCmd;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ compileOptionsCmd;
	NimStringV2 linkOptions;
	NimStringV2 compileOptions;
	NimStringV2 cCompilerPath;
	tySequence__xOJ2kx2lq9bBfIm3IXnde3Q toCompile;
	tyProc__QQyR5yGA47tr5TwLxcC4Gw suggestionResultHook;
	NI suggestVersion;
	NI suggestMaxResults;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA lastLineInfo;
	tyProc__k2HFjxisIgDALbEUFojxaQ writelnHook;
	tyProc__DA9aR62IikoxFqfC5rIT9cuw structuredErrorHook;
	NimStringV2 cppCustomNamespace;
	NimStringV2 nimMainPrefix;
	tyObject_ProfileDatacolonObjectType___R9cEb9cNTzPRldVmD9bCDO0xQ* vmProfileData;
	NIM_BOOL expandProgress;
	NI expandLevels;
	NimStringV2 expandNodeResult;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA expandPosition;
	NimStringV2 currentConfigDir;
	NI clientProcessId;
};
struct tySequence__hRbbzIynOoxrYjHTIKZ3Gw {
  NI len; tySequence__hRbbzIynOoxrYjHTIKZ3Gw_Content* p;
};
struct tyObject_CountTable__5N9carAoH8U5E301UN9ccEmQ {
	tySequence__hRbbzIynOoxrYjHTIKZ3Gw data;
	NI counter;
	NIM_BOOL isSorted;
};
struct tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug {
	NI32 module;
	NI32 symId;
	NI32 typeId_0;
	NIM_BOOL sealed;
	tyObject_CountTable__5N9carAoH8U5E301UN9ccEmQ disambTable;
};
typedef NU8 tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg;
struct tyTuple__kN8up2W6YKc5YA9avn5mV5w {
	NimStringV2 Field0;
	NI Field1;
	NI Field2;
};
struct tyTuple__kIcKc1aSJCixG4QCidyBAg {
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ Field0;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw Field1;
};
typedef NU8 tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ;
typedef NU8 tyEnum_LegacyFeature__yvNVqOQTgcxHpvo1MvfBfA;
typedef NimStringV2 tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ[2];
typedef NimStringV2 tyArray__TonP9cxJgj8gXu71dWIyNlA[1];
struct tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA {
	NI id;
	NimStringV2 s;
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* next;
	NI h;
};
typedef NU8 tySet_tyEnum_TransformFlag__CzUOfRCXpoYcP43GAlt9cnA;
typedef NimStringV2 tyArray__YgExxhfgKcesA5EOUj1MOA[1];
typedef NU8 tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw;
typedef NU8 tyEnum_TResKind__UiCSai1lX4RMkJ9bHo9aP2HA;
typedef NU8 tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg;
struct tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ {
	tyEnum_TResKind__UiCSai1lX4RMkJ9bHo9aP2HA kind;
	tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg typ;
	NimStringV2 res;
	NimStringV2 address;
	NimStringV2 tmpLoc;
};
typedef NU8 tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg;
typedef NU8 tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ;
typedef NU64 tySet_tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A;
struct tySequence__d8ZV4IMgHt9biik9cS9a0hrmg {
  NI len; tySequence__d8ZV4IMgHt9biik9cS9a0hrmg_Content* p;
};
struct tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg {
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA itemId;
	tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg kind;
	tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ callConv;
	tySet_tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A flags;
	tySequence__d8ZV4IMgHt9biik9cS9a0hrmg sons;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* ownerField;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym;
	NI64 size;
	NI16 align;
	NI16 paddingAtEnd;
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw loc;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typeInst;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA uniqueId;
};
typedef NU8 tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg[9];
typedef NimStringV2 tyArray__dyW7vpmfeTYw8kX3EXuaJA[3];
typedef NU8 tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A;
typedef NU32 tyArray__PPSU5X9aizf5OJq0lL4Og7A[4];
struct tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg {
	tyArray__PPSU5X9aizf5OJq0lL4Og7A udata;
};
typedef NimStringV2 tyArray__hSrJSIaqyFxuH67Wd7apZQ[8];
typedef NimStringV2 tyArray__hFPV9bffMpPjoz9bsO9crekNg[7];
typedef NU8 tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA;
typedef NU8 tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w;
typedef NU8 tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A;
typedef NimStringV2 tyArray__awn6UrBeChh9cVy9ccoluuYg[5];
typedef NU8 tySet_tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw[21];
typedef NimStringV2 tyArray__Seu7uK9aaOSN0BK3EAjjSHw[4];
typedef NU8 tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg;
typedef NU8 tyEnum_FloatClass__gfrWEZTSUZU5OWgwK4wTYw;
struct tyObject_TFileInfo__xPdjmgevOVG8T0Aq8BK7jw {
	NimStringV2 fullPath;
	NimStringV2 projPath;
	NimStringV2 shortName;
	NimStringV2 quotedName;
	NimStringV2 quotedFullName;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ lines;
	NimStringV2 dirtyFile;
	NimStringV2 hash;
	NIM_BOOL dirty;
};
typedef tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ tyArray__nZzcix4CWuRF8YzR69agPRw[59];
struct tyTuple__UV3llMMYFckfui8YMBuUZA {
	NimStringV2 Field0;
	NimStringV2 Field1;
};
typedef NU8 tySet_tyChar__nmiMWKVIe46vacnhAFrQvw[32];
struct tyObject_HSlice__Td0KDtM8kU0p7CVwrbJeww {
	tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg a;
	tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg b;
};
struct tyTuple__RICk09aVWvF6a15iJKyZfFQ {
	NimStringV2 Field0;
	tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q Field1;
};
typedef NimStringV2 tyArray__A2YC0h9cZydgH7zGAndH9bLg[6];
struct tyTuple__axVdnKAd4XGmBNrMsqQ7kw {
	NimStringV2 Field0;
	tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg Field1;
	tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg Field2;
};
typedef NU16 tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw;
struct tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig {
	NU32 module;
	NI32 item;
};
struct tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ {
	NI module;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig packed_0;
};
struct tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA {
	tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ id;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym;
};
struct tyObject_SourceMap__WQjtp9aU0iILpTcFCDzWLTA {
	NI version;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ sources;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ names;
	NimStringV2 mappings;
	NimStringV2 file;
};
typedef NU8 tyEnum_JsonNodeKind__qvXp5fGPKV9a8zGGwjrKjDA;
struct tySequence__m9axZwxFfhSNLcoofvKZJYA {
  NI len; tySequence__m9axZwxFfhSNLcoofvKZJYA_Content* p;
};
struct tyObject_OrderedTable__ASIVNBCKpz8qGZwzYCCBFQ {
	tySequence__m9axZwxFfhSNLcoofvKZJYA data;
	NI counter;
	NI first;
	NI last;
};
struct tySequence__fXWXs2NlFKREhy9cn6vokJw {
  NI len; tySequence__fXWXs2NlFKREhy9cn6vokJw_Content* p;
};
struct tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g {
	NIM_BOOL isUnquoted;
	tyEnum_JsonNodeKind__qvXp5fGPKV9a8zGGwjrKjDA kind;
union{
	struct {
	NimStringV2 str;
} _kind_1;
	struct {
	NI64 num;
} _kind_2;
	struct {
	NF fnum;
} _kind_3;
	struct {
	NIM_BOOL bval;
} _kind_4;
	struct {
	tyObject_OrderedTable__ASIVNBCKpz8qGZwzYCCBFQ fields;
} _kind_6;
	struct {
	tySequence__fXWXs2NlFKREhy9cn6vokJw elems;
} _kind_7;
};
};
typedef NU8 tyArray__dnD8kjh6rJ1Yy5jHvid0Ow[16];
struct tyTuple__9agFg9cuYsNvckAbTfHAsTSA {
	tyArray__dnD8kjh6rJ1Yy5jHvid0Ow Field0;
	NI Field1;
};
struct tySequence__9bRXJy1JXrQ4hWpStaKBpXg_Content { NI cap; tyTuple__9agFg9cuYsNvckAbTfHAsTSA data[SEQ_DECL_SIZE]; };
struct tyObject_Iface__j1FkQxwEAKMJy1o9bap1xow {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module;
	tySequence__olFOFaYzOJN9aV5BWqK4b9bA converters;
	tySequence__olFOFaYzOJN9aV5BWqK4b9bA patterns;
	tySequence__olFOFaYzOJN9aV5BWqK4b9bA pureEnums;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg interf;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg interfHidden;
	NimStringV2 uniqueName;
};
struct tySequence__TfHJycarvNts8E4mVG4Mfg_Content { NI cap; tyObject_Iface__j1FkQxwEAKMJy1o9bap1xow data[SEQ_DECL_SIZE]; };
typedef NU8 tyEnum_ModuleStatus__uT4B39a2dNaG9a9aunVdyhQtQ;
struct tySequence__PXIzfWocnrafGz5p3CP5LA {
  NI len; tySequence__PXIzfWocnrafGz5p3CP5LA_Content* p;
};
struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA {
  NI len; tySequence__9bAGqSvkAaFL9bWjsEPslrFA_Content* p;
};
struct tySequence__OxRbUT0qZaZN5UjnqQjGPA {
  NI len; tySequence__OxRbUT0qZaZN5UjnqQjGPA_Content* p;
};
struct tySequence__ezS5mGPcRfBURJyMgqYVzA {
  NI len; tySequence__ezS5mGPcRfBURJyMgqYVzA_Content* p;
};
struct tySequence__wW7xkohjuUKO9aMaB0nt9cqA {
  NI len; tySequence__wW7xkohjuUKO9aMaB0nt9cqA_Content* p;
};
struct tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w {
	tySequence__OxRbUT0qZaZN5UjnqQjGPA nodes;
	tySequence__ezS5mGPcRfBURJyMgqYVzA withFlags;
	tySequence__wW7xkohjuUKO9aMaB0nt9cqA withTypes;
};
struct tySequence__b89aLriiJnVTD186H6zNIgg {
  NI len; tySequence__b89aLriiJnVTD186H6zNIgg_Content* p;
};
struct tySequence__hIPTk9aFdaMMVAOzEbnPyqg {
  NI len; tySequence__hIPTk9aFdaMMVAOzEbnPyqg_Content* p;
};
struct tySequence__YYy1721YAuPF0ajBYHd8Wg {
  NI len; tySequence__YYy1721YAuPF0ajBYHd8Wg_Content* p;
};
struct tySequence__UODJbvzmu39c3Ho9cqhSk9agQ {
  NI len; tySequence__UODJbvzmu39c3Ho9cqhSk9agQ_Content* p;
};
struct tySequence__F1qNdU7m0Czu7Y2q0eksXw {
  NI len; tySequence__F1qNdU7m0Czu7Y2q0eksXw_Content* p;
};
struct tySequence__r3Kz9breImOXyFFoJ29aBM8Q {
  NI len; tySequence__r3Kz9breImOXyFFoJ29aBM8Q_Content* p;
};
struct tySequence__qBes3XzcQQ9cyia9bRwnmbJw {
  NI len; tySequence__qBes3XzcQQ9cyia9bRwnmbJw_Content* p;
};
typedef NU8 tySet_tyEnum_ModuleBackendFlag__5FvIlwIIbpcHU0ZRU9a5hrQ;
struct tySequence__Vl1abU3gfp0RqCb1KKfmDA {
  NI len; tySequence__Vl1abU3gfp0RqCb1KKfmDA_Content* p;
};
struct tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw {
	tySequence__Vl1abU3gfp0RqCb1KKfmDA data;
	NI counter;
	NI first;
	NI last;
};
struct tySequence__qyyNkmlc4fzOzelC8spUkQ {
  NI len; tySequence__qyyNkmlc4fzOzelC8spUkQ_Content* p;
};
struct tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw {
	tySequence__qyyNkmlc4fzOzelC8spUkQ data;
	NI counter;
	NI first;
	NI last;
};
struct tyObject_BiTable__KR9c7QZguPO3OKZOIcphgcA {
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ vals;
	tySequence__9bAGqSvkAaFL9bWjsEPslrFA keys;
};
struct tySequence__IHUFRsFxZNv7YydiUO2esQ {
  NI len; tySequence__IHUFRsFxZNv7YydiUO2esQ_Content* p;
};
struct tyObject_BiTable__9aUXwPoJbNPqj9a249c0iSmlg {
	tySequence__IHUFRsFxZNv7YydiUO2esQ vals;
	tySequence__9bAGqSvkAaFL9bWjsEPslrFA keys;
};
struct tySequence__orxtl6CusdjXleqrxi67gw {
  NI len; tySequence__orxtl6CusdjXleqrxi67gw_Content* p;
};
struct tyObject_LineInfoManager__TTy646Kfh1cVyXU9aSMasUQ {
	tySequence__orxtl6CusdjXleqrxi67gw aside;
};
struct tyObject_PackedModule__sRHd9aQ2ZMII76xRsfAbE9aQ {
	NimStringV2 definedSymbols;
	tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg moduleFlags;
	tySequence__PXIzfWocnrafGz5p3CP5LA includes;
	tySequence__9bAGqSvkAaFL9bWjsEPslrFA imports;
	tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w toReplay;
	tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w topLevel;
	tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w bodies;
	tySequence__b89aLriiJnVTD186H6zNIgg exports;
	tySequence__b89aLriiJnVTD186H6zNIgg hidden;
	tySequence__hIPTk9aFdaMMVAOzEbnPyqg reexports;
	tySequence__b89aLriiJnVTD186H6zNIgg compilerProcs;
	tySequence__48JTohSgTy339bRxHzUD8KA converters;
	tySequence__48JTohSgTy339bRxHzUD8KA methods;
	tySequence__48JTohSgTy339bRxHzUD8KA trmacros;
	tySequence__48JTohSgTy339bRxHzUD8KA pureEnums;
	tySequence__YYy1721YAuPF0ajBYHd8Wg typeInstCache;
	tySequence__UODJbvzmu39c3Ho9cqhSk9agQ procInstCache;
	tySequence__F1qNdU7m0Czu7Y2q0eksXw attachedOps;
	tySequence__r3Kz9breImOXyFFoJ29aBM8Q methodsPerGenericType;
	tySequence__YYy1721YAuPF0ajBYHd8Wg enumToStringProcs;
	tySequence__YYy1721YAuPF0ajBYHd8Wg methodsPerType;
	tySequence__qBes3XzcQQ9cyia9bRwnmbJw dispatchers;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ emittedTypeInfo;
	tySet_tyEnum_ModuleBackendFlag__5FvIlwIIbpcHU0ZRU9a5hrQ backendFlags;
	tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw syms;
	tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw types;
	tyObject_BiTable__KR9c7QZguPO3OKZOIcphgcA strings;
	tyObject_BiTable__9aUXwPoJbNPqj9a249c0iSmlg numbers;
	tyObject_LineInfoManager__TTy646Kfh1cVyXU9aSMasUQ man;
	tyObject_PackedConfig__Hpn673wkKPDorr1HY9bOaDQ cfg;
};
struct tySequence__K0j67V58u5FW0dCC534FQw {
  NI len; tySequence__K0j67V58u5FW0dCC534FQw_Content* p;
};
struct tyObject_OrderedTable__h8mIUVGY8LJXF9cakgvB9bqQ {
	tySequence__K0j67V58u5FW0dCC534FQw data;
	NI counter;
	NI first;
	NI last;
};
struct tySequence__UE4b6iUkm1b3zTPamTTkDw {
  NI len; tySequence__UE4b6iUkm1b3zTPamTTkDw_Content* p;
};
struct tyObject_OrderedTable__DED9c7j9bI3Lh5w4GQakK8yQ {
	tySequence__UE4b6iUkm1b3zTPamTTkDw data;
	NI counter;
	NI first;
	NI last;
};
struct tySequence__FmsTQiIcS9arxHxs3QY48vA {
  NI len; tySequence__FmsTQiIcS9arxHxs3QY48vA_Content* p;
};
struct tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg {
	tySequence__FmsTQiIcS9arxHxs3QY48vA data;
	NI counter;
};
struct tyObject_LoadedModule__7NEKRkz5hkiOxQy5guqIHA {
	tyEnum_ModuleStatus__uT4B39a2dNaG9a9aunVdyhQtQ status;
	NIM_BOOL symsInit;
	NIM_BOOL typesInit;
	NIM_BOOL loadedButAliveSetChanged;
	tyObject_PackedModule__sRHd9aQ2ZMII76xRsfAbE9aQ fromDisk;
	tyObject_OrderedTable__h8mIUVGY8LJXF9cakgvB9bqQ syms;
	tyObject_OrderedTable__DED9c7j9bI3Lh5w4GQakK8yQ types;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module;
	tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg iface;
	tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg ifaceHidden;
};
struct tySequence__5reviU45axUMPQgL9aoENrg_Content { NI cap; tyObject_LoadedModule__7NEKRkz5hkiOxQy5guqIHA data[SEQ_DECL_SIZE]; };
struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ {
  NI len; tySequence__9cnx3zXnWzeclW8Ko4oUgAQ_Content* p;
};
struct tyObject_Table__uaQEKxLZNO5fpFluyxnhTg {
	tySequence__9cnx3zXnWzeclW8Ko4oUgAQ data;
	NI counter;
};
struct tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ {
	NI32 thisModule;
	NI32 lastFile;
	NU32 lastLit;
	tyObject_Table__uaQEKxLZNO5fpFluyxnhTg filenames;
	tySequence__d8ZV4IMgHt9biik9cS9a0hrmg pendingTypes;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA pendingSyms;
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA typeMarker;
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA symMarker;
	tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* config;
};
struct tySequence__dtr79aXjHrgHuH79ac55I2aw_Content { NI cap; tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ data[SEQ_DECL_SIZE]; };
struct tySequence__vb3AGHvMJTxdOSSwMmBmTQ {
  NI len; tySequence__vb3AGHvMJTxdOSSwMmBmTQ_Content* p;
};
struct tyTuple__7TXOq9czx9cn1FWKG5gXNK8Q {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tySequence__vb3AGHvMJTxdOSSwMmBmTQ Field2;
};
struct tySequence__8y0Gi4GwtXi2wk2mK1IOzw_Content { NI cap; tyTuple__7TXOq9czx9cn1FWKG5gXNK8Q data[SEQ_DECL_SIZE]; };
struct tySequence__apM9bRAO19cVjhWlxqd1PGeA {
  NI len; tySequence__apM9bRAO19cVjhWlxqd1PGeA_Content* p;
};
struct tyTuple__F1mMODXmKFMNQ5rLCtcv0Q {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tySequence__apM9bRAO19cVjhWlxqd1PGeA Field2;
};
struct tySequence__C2ivDnhTZ6IxAdui1rfuqw_Content { NI cap; tyTuple__F1mMODXmKFMNQ5rLCtcv0Q data[SEQ_DECL_SIZE]; };
struct tyTuple__vHfXSpEC1R9b9cKgfFB9a58gw {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA Field2;
};
struct tySequence__3vEEVfBECLN6NIRA3FIp5g_Content { NI cap; tyTuple__vHfXSpEC1R9b9cKgfFB9a58gw data[SEQ_DECL_SIZE]; };
struct tySequence__9bW2eTK9b7vXE70Sx5VPH1mw {
  NI len; tySequence__9bW2eTK9b7vXE70Sx5VPH1mw_Content* p;
};
struct tyTuple__4iq9bD09amB7Ah0r9cBB0nSPQ {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tySequence__9bW2eTK9b7vXE70Sx5VPH1mw Field2;
};
struct tySequence__9aSa87aKMiolq9a7z3kC0jTw_Content { NI cap; tyTuple__4iq9bD09amB7Ah0r9cBB0nSPQ data[SEQ_DECL_SIZE]; };
struct tyTuple__bnJwOH0eJlAwCAMbr1inhw {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA Field2;
};
struct tySequence__N589c2UsUgqqOITU2JfIuAQ_Content { NI cap; tyTuple__bnJwOH0eJlAwCAMbr1inhw data[SEQ_DECL_SIZE]; };
struct tyTuple__YG7h1OUHzgfgTeH9cl0U0dw {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* Field2;
};
struct tySequence__GYDW6wGgERshoSd16jJ3eQ_Content { NI cap; tyTuple__YG7h1OUHzgfgTeH9cl0U0dw data[SEQ_DECL_SIZE]; };
struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw {
	NI Field0;
	NimStringV2 Field1;
	NI32 Field2;
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw_Content { NI cap; tyTuple__xYhUhS7X82rKTqbT9bRfCnw data[SEQ_DECL_SIZE]; };
struct tySequence__ZCZaCk14bTmSb6LMW9aWPVA_Content { NI cap; tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* data[SEQ_DECL_SIZE]; };
struct tySequence__ZeWVlH6DqG79b1pTDhrrUYA_Content { NI cap; tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA* data[SEQ_DECL_SIZE]; };
struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q {
	NI Field0;
	NI32 Field1;
	tySequence__48JTohSgTy339bRxHzUD8KA Field2;
};
struct tySequence__fdmz6VkIf1ewwrssKYqRFg_Content { NI cap; tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q data[SEQ_DECL_SIZE]; };
struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ {
	NI Field0;
	NI32 Field1;
	NI32 Field2;
};
struct tySequence__kxu4GK0onha2t9bo86mdVAg_Content { NI cap; tyTuple__xDU9bZmv1ZbZkJDaATBekIQ data[SEQ_DECL_SIZE]; };
struct tySequence__48JTohSgTy339bRxHzUD8KA_Content { NI cap; NI32 data[SEQ_DECL_SIZE]; };
struct tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg {
  NI len; tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg_Content* p;
};
struct tySequence__yUWoZehF86MIc40opFgacw {
  NI len; tySequence__yUWoZehF86MIc40opFgacw_Content* p;
};
struct tyObject_PackedBoolArray__1pk9boftqWMNDE1oh5HcIhw {
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA s;
	NI len;
};
struct tyObject_SuggestFileSymbolDatabase__o0ahEzaLn5a7TdNqH4OVqQ {
	tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg lineInfo;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA sym;
	tySequence__yUWoZehF86MIc40opFgacw caughtExceptions;
	tyObject_PackedBoolArray__1pk9boftqWMNDE1oh5HcIhw caughtExceptionsSet;
	tyObject_PackedBoolArray__1pk9boftqWMNDE1oh5HcIhw isDecl;
	tyObject_PackedBoolArray__1pk9boftqWMNDE1oh5HcIhw isGenericInstance;
	NI32 fileIndex;
	NIM_BOOL trackCaughtExceptions;
	NIM_BOOL isSorted;
};
struct tyTuple__tG5yYi8DnD7bl00aT9cgctQ {
	NI Field0;
	NI32 Field1;
	tyObject_SuggestFileSymbolDatabase__o0ahEzaLn5a7TdNqH4OVqQ Field2;
};
struct tySequence__fz0REU1l0nYmKHXgMLRrIg_Content { NI cap; tyTuple__tG5yYi8DnD7bl00aT9cgctQ data[SEQ_DECL_SIZE]; };
struct tySequence__nSO1ltijM4vhc0UrrXKEqA {
  NI len; tySequence__nSO1ltijM4vhc0UrrXKEqA_Content* p;
};
struct tyTuple__gnRkA1L4XiR4uByriyHW8Q {
	NI Field0;
	NI32 Field1;
	tySequence__nSO1ltijM4vhc0UrrXKEqA Field2;
};
struct tySequence__Ip9aV1IKO2gVdheNOM31DCQ_Content { NI cap; tyTuple__gnRkA1L4XiR4uByriyHW8Q data[SEQ_DECL_SIZE]; };
struct tyTuple__CvjVmQeIfivirDme2r5MRw {
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA Field0;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* Field1;
};
struct tySequence__kHjIdgrpmuSn9cUIIKpSiDg_Content { NI cap; tyTuple__CvjVmQeIfivirDme2r5MRw data[SEQ_DECL_SIZE]; };
struct tyTuple__2QDyOgS51ZMPO0W1pWCY6g {
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field0;
	NI Field1;
};
struct tySequence__Wd0Vle6gxRCPPoSlNEvfTA_Content { NI cap; tyTuple__2QDyOgS51ZMPO0W1pWCY6g data[SEQ_DECL_SIZE]; };
struct tySequence__juxPMVNF1FoR2ltzeQu8NQ {
  NI len; tySequence__juxPMVNF1FoR2ltzeQu8NQ_Content* p;
};
struct tyTuple__UbCNQED4XJUgxOgPHJUcAQ {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tySequence__juxPMVNF1FoR2ltzeQu8NQ Field2;
};
struct tySequence__T7nNEWoEbKBa0G5Htr45Xw_Content { NI cap; tyTuple__UbCNQED4XJUgxOgPHJUcAQ data[SEQ_DECL_SIZE]; };
struct tyTuple__zExIg9bDTcVf2FHROUpzoow {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tySequence__olFOFaYzOJN9aV5BWqK4b9bA Field2;
};
struct tySequence__q9cHvMDDxYU1hSCdG4YwIhA_Content { NI cap; tyTuple__zExIg9bDTcVf2FHROUpzoow data[SEQ_DECL_SIZE]; };
struct tySequence__olFOFaYzOJN9aV5BWqK4b9bA_Content { NI cap; tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA data[SEQ_DECL_SIZE]; };
struct tyTuple__XrHNJHOzS3O7uwF9bvCySiA {
	NI Field0;
	tyArray__dnD8kjh6rJ1Yy5jHvid0Ow Field1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* Field2;
};
struct tySequence__vJcM7B74R2U5db9cxyXT9coA_Content { NI cap; tyTuple__XrHNJHOzS3O7uwF9bvCySiA data[SEQ_DECL_SIZE]; };
struct tyTuple__EdLY4EJQ37VFgbAn5g5rXQ {
	NI Field0;
	NI Field1;
	tyArray__dnD8kjh6rJ1Yy5jHvid0Ow Field2;
};
struct tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg_Content { NI cap; tyTuple__EdLY4EJQ37VFgbAn5g5rXQ data[SEQ_DECL_SIZE]; };
struct tyTuple__OtlgAx3kBps9cOSMNDZSzBA {
	NI Field0;
	NimStringV2 Field1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* Field2;
};
struct tySequence__R9c39btP6BwOBBPnbaNUtMQg_Content { NI cap; tyTuple__OtlgAx3kBps9cOSMNDZSzBA data[SEQ_DECL_SIZE]; };
struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg {
	NI Field0;
	NimStringV2 Field1;
	NI64 Field2;
};
struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA_Content { NI cap; tyTuple__F3gkSrMB1qp2Tvf9bixVXwg data[SEQ_DECL_SIZE]; };
struct tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw {
	tyObject_NodecolonObjectType___U4ON6JZL9cIHezBQjmQzJ8Q* root;
	NI entries;
};
struct tyTuple__RFOJ4fF7D9bpvmh9birH1JhQ {
	NI Field0;
	NimStringV2 Field1;
	tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw Field2;
};
struct tySequence__3nALyQgqjnfK2Qjc6ny2Uw_Content { NI cap; tyTuple__RFOJ4fF7D9bpvmh9birH1JhQ data[SEQ_DECL_SIZE]; };
typedef N_NIMCALL_PTR(tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ*, tyProc__TVHQTM3bKm4Mi6Ul6zgzuQ) (tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module_p1, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p2);
typedef N_NIMCALL_PTR(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, tyProc__74nHWc2UIRu3iSR9akqDDBg) (tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* topLevelStmt_p1);
typedef N_NIMCALL_PTR(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, tyProc__S9bLWKf8jgjzoiotAmEyFSw) (tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ* p_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p2);
struct tyTuple__O3g9a8zTXSX36ljWponcAoA {
	tyProc__TVHQTM3bKm4Mi6Ul6zgzuQ Field0;
	tyProc__74nHWc2UIRu3iSR9akqDDBg Field1;
	tyProc__S9bLWKf8jgjzoiotAmEyFSw Field2;
	NIM_BOOL Field3;
};
struct tySequence__WbW5Q8QVks0bQpUJSGmuVg_Content { NI cap; tyTuple__O3g9a8zTXSX36ljWponcAoA data[SEQ_DECL_SIZE]; };
struct tySequence__9ahcSjIErJohSBBFLwuF56Q_Content { NI cap; tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* data[SEQ_DECL_SIZE]; };
struct tySequence__bdNIx7Bah2llfuqeoTJEWQ_Content { NI cap; tyTuple__kIcKc1aSJCixG4QCidyBAg data[SEQ_DECL_SIZE]; };
struct tySequence__P9aymq2R2Xa8At0XKJ6Bh1A_Content { NI cap; tyObject_TBlock__e4aohBvIZbqlrYGhrE9cgpw data[SEQ_DECL_SIZE]; };
struct tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ {
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA Field0;
	NimStringV2 Field1;
};
struct tySequence__E0kio2ZnplNTuln9bsnljSA_Content { NI cap; tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ data[SEQ_DECL_SIZE]; };
struct tySequence__hTEiKNj3evQAjIXUI21elA_Content { NI cap; tyObject_TFileInfo__xPdjmgevOVG8T0Aq8BK7jw data[SEQ_DECL_SIZE]; };
struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw {
	NI Field0;
	NimStringV2 Field1;
};
struct tySequence__4eRCaZmrYLLw2k30GPTiMw_Content { NI cap; tyTuple__QeWl6B6ffS4pU6WWrtcrDw data[SEQ_DECL_SIZE]; };
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content { NI cap; NimStringV2 data[SEQ_DECL_SIZE]; };
typedef NU8 tySet_tyEnum_CfileFlag__qhMBL5cBz484papsb5WgFQ;
struct tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg {
	NimStringV2 nimname;
	NimStringV2 cname;
	NimStringV2 obj;
	tySet_tyEnum_CfileFlag__qhMBL5cBz484papsb5WgFQ flags;
	NimStringV2 customArgs;
};
struct tySequence__xOJ2kx2lq9bBfIm3IXnde3Q_Content { NI cap; tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg data[SEQ_DECL_SIZE]; };
struct tyTuple__Oubp8LPEu86EPyDuc56AXg {
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* Field0;
	NI Field1;
};
struct tySequence__hRbbzIynOoxrYjHTIKZ3Gw_Content { NI cap; tyTuple__Oubp8LPEu86EPyDuc56AXg data[SEQ_DECL_SIZE]; };
struct tySequence__d8ZV4IMgHt9biik9cS9a0hrmg_Content { NI cap; tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* data[SEQ_DECL_SIZE]; };
struct tyTuple__eR5B9b9c9coYBbO09chTvuMqNQ {
	NI Field0;
	NI Field1;
	NimStringV2 Field2;
	tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* Field3;
};
struct tySequence__m9axZwxFfhSNLcoofvKZJYA_Content { NI cap; tyTuple__eR5B9b9c9coYBbO09chTvuMqNQ data[SEQ_DECL_SIZE]; };
struct tySequence__fXWXs2NlFKREhy9cn6vokJw_Content { NI cap; tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* data[SEQ_DECL_SIZE]; };
struct tyTuple__0q9cmhneJEKnQERTpXXdz6Q {
	NU32 Field0;
	NimStringV2 Field1;
};
struct tySequence__PXIzfWocnrafGz5p3CP5LA_Content { NI cap; tyTuple__0q9cmhneJEKnQERTpXXdz6Q data[SEQ_DECL_SIZE]; };
struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA_Content { NI cap; NU32 data[SEQ_DECL_SIZE]; };
struct tyObject_PackedNode__YxKk4C732K04CNgtMhmc0w {
	NU32 x;
	NU32 info;
};
struct tySequence__OxRbUT0qZaZN5UjnqQjGPA_Content { NI cap; tyObject_PackedNode__YxKk4C732K04CNgtMhmc0w data[SEQ_DECL_SIZE]; };
struct tyTuple__48iPM3yLBKU5nyEuYwJvuQ {
	NI32 Field0;
	tySet_tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw Field1;
};
struct tySequence__ezS5mGPcRfBURJyMgqYVzA_Content { NI cap; tyTuple__48iPM3yLBKU5nyEuYwJvuQ data[SEQ_DECL_SIZE]; };
struct tyTuple__R3ddFrA0G9buJY57Qhf9cTpg {
	NI32 Field0;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field1;
};
struct tySequence__wW7xkohjuUKO9aMaB0nt9cqA_Content { NI cap; tyTuple__R3ddFrA0G9buJY57Qhf9cTpg data[SEQ_DECL_SIZE]; };
struct tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ {
	NU32 Field0;
	NI32 Field1;
};
struct tySequence__b89aLriiJnVTD186H6zNIgg_Content { NI cap; tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ data[SEQ_DECL_SIZE]; };
struct tyTuple__7rmdAMLZ8fDd79brQn2ixZA {
	NU32 Field0;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field1;
};
struct tySequence__hIPTk9aFdaMMVAOzEbnPyqg_Content { NI cap; tyTuple__7rmdAMLZ8fDd79brQn2ixZA data[SEQ_DECL_SIZE]; };
struct tyTuple__qPXRCRNQuZLLKto7CIIEzw {
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field0;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field1;
};
struct tySequence__YYy1721YAuPF0ajBYHd8Wg_Content { NI cap; tyTuple__qPXRCRNQuZLLKto7CIIEzw data[SEQ_DECL_SIZE]; };
struct tyObject_PackedInstantiation__C3FSePJFY8gUIMObsjT2dg {
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig key;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig sym;
	tySequence__qBes3XzcQQ9cyia9bRwnmbJw concreteTypes;
};
struct tySequence__UODJbvzmu39c3Ho9cqhSk9agQ_Content { NI cap; tyObject_PackedInstantiation__C3FSePJFY8gUIMObsjT2dg data[SEQ_DECL_SIZE]; };
typedef NU8 tyEnum_TTypeAttachedOp__RefHoBI5deIfxIZqo3dS5Q;
struct tyTuple__6kG8KAxm9aXPdLdlxcxqJJw {
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field0;
	tyEnum_TTypeAttachedOp__RefHoBI5deIfxIZqo3dS5Q Field1;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field2;
};
struct tySequence__F1qNdU7m0Czu7Y2q0eksXw_Content { NI cap; tyTuple__6kG8KAxm9aXPdLdlxcxqJJw data[SEQ_DECL_SIZE]; };
struct tyTuple__TRK7rrwoha9bbDAdPWsqJMw {
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field0;
	NI Field1;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field2;
};
struct tySequence__r3Kz9breImOXyFFoJ29aBM8Q_Content { NI cap; tyTuple__TRK7rrwoha9bbDAdPWsqJMw data[SEQ_DECL_SIZE]; };
struct tySequence__qBes3XzcQQ9cyia9bRwnmbJw_Content { NI cap; tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig data[SEQ_DECL_SIZE]; };
typedef NU8 tyEnum_TLibKind__BkKL8ReLoyYDI7of9aQPV0A;
struct tyObject_PackedLib__EpwVLk0Fuc5Q9agKLMWedbg {
	tyEnum_TLibKind__BkKL8ReLoyYDI7of9aQPV0A kind;
	NIM_BOOL generated;
	NIM_BOOL isOverridden;
	NU32 name;
	NI32 path;
};
struct tyObject_PackedSym__KKnx6w8Cc9aaVsaPOpaqxbw {
	NI32 id;
	tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q kind;
	NU32 name;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig typ;
	tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg flags;
	tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg magic;
	NU32 info;
	NI32 ast;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig owner;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig guard;
	NI bitsize;
	NI alignment;
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ options;
	NI position;
	NI32 offset;
	NI32 disamb;
	NU32 externalName;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg locFlags;
	tyObject_PackedLib__EpwVLk0Fuc5Q9agKLMWedbg annex;
	NI32 constraint;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig instantiatedFrom;
};
struct tyTuple__V1VWX9bHapuzCjpMfFfys5Q {
	NI Field0;
	NI Field1;
	NI32 Field2;
	tyObject_PackedSym__KKnx6w8Cc9aaVsaPOpaqxbw Field3;
};
struct tySequence__Vl1abU3gfp0RqCb1KKfmDA_Content { NI cap; tyTuple__V1VWX9bHapuzCjpMfFfys5Q data[SEQ_DECL_SIZE]; };
struct tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ {
	NI32 id;
	tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg kind;
	tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ callConv;
	tySet_tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A flags;
	tySequence__qBes3XzcQQ9cyia9bRwnmbJw types;
	NI32 n;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig sym;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig owner;
	NI64 size;
	NI16 align;
	NI16 paddingAtEnd;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig typeInst;
	NI32 nonUniqueId;
};
struct tyTuple__anemVmHCFglLFt6LiEhFvg {
	NI Field0;
	NI Field1;
	NI32 Field2;
	tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ Field3;
};
struct tySequence__qyyNkmlc4fzOzelC8spUkQ_Content { NI cap; tyTuple__anemVmHCFglLFt6LiEhFvg data[SEQ_DECL_SIZE]; };
struct tySequence__IHUFRsFxZNv7YydiUO2esQ_Content { NI cap; NI64 data[SEQ_DECL_SIZE]; };
struct tyTuple__MaWaKZwaGUqCXKsSK12rVg {
	NU32 Field0;
	NI32 Field1;
	NI32 Field2;
};
struct tySequence__orxtl6CusdjXleqrxi67gw_Content { NI cap; tyTuple__MaWaKZwaGUqCXKsSK12rVg data[SEQ_DECL_SIZE]; };
struct tyTuple__nL9cBxaIV4ZA9b9ceY79coA5eA {
	NI Field0;
	NI Field1;
	NI32 Field2;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* Field3;
};
struct tySequence__K0j67V58u5FW0dCC534FQw_Content { NI cap; tyTuple__nL9cBxaIV4ZA9b9ceY79coA5eA data[SEQ_DECL_SIZE]; };
struct tyTuple__1xWeGeoNoZxaLhTUDDWYyA {
	NI Field0;
	NI Field1;
	NI32 Field2;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* Field3;
};
struct tySequence__UE4b6iUkm1b3zTPamTTkDw_Content { NI cap; tyTuple__1xWeGeoNoZxaLhTUDDWYyA data[SEQ_DECL_SIZE]; };
struct tyTuple__MZVSn3SE3XUBJOaMu7ofRQ {
	NI Field0;
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* Field1;
	tySequence__qBes3XzcQQ9cyia9bRwnmbJw Field2;
};
struct tySequence__FmsTQiIcS9arxHxs3QY48vA_Content { NI cap; tyTuple__MZVSn3SE3XUBJOaMu7ofRQ data[SEQ_DECL_SIZE]; };
struct tyTuple__UvldbCB6B9ayi9bGYW7vJNLA {
	NI Field0;
	NI32 Field1;
	NU32 Field2;
};
struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ_Content { NI cap; tyTuple__UvldbCB6B9ayi9bGYW7vJNLA data[SEQ_DECL_SIZE]; };
struct tyObject_LazyType__dsEGDq9cOhnzsRvTUTwwwuA {
	tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ id;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ;
};
struct tySequence__vb3AGHvMJTxdOSSwMmBmTQ_Content { NI cap; tyObject_LazyType__dsEGDq9cOhnzsRvTUTwwwuA data[SEQ_DECL_SIZE]; };
struct tySequence__YxH9cgSorHRI8ZPzHf47NNQ {
  NI len; tySequence__YxH9cgSorHRI8ZPzHf47NNQ_Content* p;
};
struct tyObject_LazyInstantiation__n72c7MnOoHWBy9c9akgwGqEA {
	NI module;
	tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ sym;
	tySequence__YxH9cgSorHRI8ZPzHf47NNQ concreteTypes;
	tyObject_TInstantiation__jr8MibvPn2sQBnO7XCoZRQ* inst;
};
struct tySequence__apM9bRAO19cVjhWlxqd1PGeA_Content { NI cap; tyObject_LazyInstantiation__n72c7MnOoHWBy9c9akgwGqEA data[SEQ_DECL_SIZE]; };
struct tyTuple__lGHLhAAUpxgfrnQkIzNrMw {
	NI Field0;
	tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA Field1;
};
struct tySequence__9bW2eTK9b7vXE70Sx5VPH1mw_Content { NI cap; tyTuple__lGHLhAAUpxgfrnQkIzNrMw data[SEQ_DECL_SIZE]; };
struct tyObject_TinyLineInfo__qW2GTIPjeOQ42q9c2MPWLLA {
	NU16 line;
	NI16 col;
};
struct tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg_Content { NI cap; tyObject_TinyLineInfo__qW2GTIPjeOQ42q9c2MPWLLA data[SEQ_DECL_SIZE]; };
struct tySequence__yUWoZehF86MIc40opFgacw_Content { NI cap; tySequence__d8ZV4IMgHt9biik9cS9a0hrmg data[SEQ_DECL_SIZE]; };
struct tySequence__nSO1ltijM4vhc0UrrXKEqA_Content { NI cap; tyObject_SuggestcolonObjectType___UyASNXAqAMRY5zJmcRD9ccA* data[SEQ_DECL_SIZE]; };
struct tyTuple__V6P73hvHy70PBBwharKjig {
	NI Field0;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* Field1;
};
struct tySequence__juxPMVNF1FoR2ltzeQu8NQ_Content { NI cap; tyTuple__V6P73hvHy70PBBwharKjig data[SEQ_DECL_SIZE]; };
struct tySequence__YxH9cgSorHRI8ZPzHf47NNQ_Content { NI cap; tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ data[SEQ_DECL_SIZE]; };
N_LIB_PRIVATE N_NIMCALL(tyObject_TJSGen__eMRdF9b1ev54YKlmk5BuCUA*, newModule__jsgen_u8125)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___ast_u4955)(RootObj** dest_p0, RootObj* src_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_PGlobalscolonObjectType___5ylNBaUZgofS9cIrLp09cbRA*, newGlobals__jsgen_u497)(void);
N_LIB_PRIVATE N_NIMCALL(void*, nimNewObj)(NI size_p0, NI alignment_p1);
N_LIB_PRIVATE N_NIMCALL(void, rttiDestroy__jsgen_u8420)(void* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___jsgen_u260)(tyObject_PGlobalscolonObjectType___5ylNBaUZgofS9cIrLp09cbRA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___pureZcollectionsZintsets_u100)(tySequence__ZeWVlH6DqG79b1pTDhrrUYA dest_p0);
static N_INLINE(NIM_BOOL, nimDecRefIsLastDyn)(void* p_p0);
static N_INLINE(NI, minuspercent___system_u805)(NI x_p0, NI y_p1);
N_LIB_PRIVATE N_NIMCALL(void, unregisterCycle__system_u3130)(tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* s_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___pureZcollectionsZintsets_u66)(tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, nimRawDispose)(void* p_p0, NI alignment_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u4848)(tySequence__ZCZaCk14bTmSb6LMW9aWPVA dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___system_u2691)(NimStringV2 dest_p0);
static N_INLINE(NIM_BOOL*, nimErrorFlag)(void);
N_LIB_PRIVATE N_NIMCALL(void*, newSeqPayload)(NI cap_p0, NI elemSize_p1, NI elemAlign_p2);
static N_INLINE(void, initIntSet__pureZcollectionsZintsets_u598)(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* Result);
static N_INLINE(void, nimZeroMem)(void* p_p0, NI size_p1);
static N_INLINE(void, nimSetMem__system_u2172)(void* a_p0, int v_p1, NI size_p2);
N_LIB_PRIVATE N_NIMCALL(void, initPackedSet__pureZcollectionsZintsets_u37)(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* Result);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___jsgen_u506)(tyObject_PGlobalscolonObjectType___5ylNBaUZgofS9cIrLp09cbRA* dest_p0);
static N_INLINE(NIM_BOOL, nimDecRefIsLastCyclicDyn)(void* p_p0);
N_LIB_PRIVATE N_NOINLINE(void, rememberCycle__system_u3500)(NIM_BOOL isDestroyAction_p0, tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* s_p1, TNimTypeV2* desc_p2);
N_LIB_PRIVATE N_NIMCALL(void, nimDestroyAndDispose)(void* p_p0);
N_LIB_PRIVATE N_NIMCALL(void, rttiDestroy__jsgen_u8422)(void* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___jsgen_u186)(tyObject_TJSGen__eMRdF9b1ev54YKlmk5BuCUA* dest_p0);
static N_INLINE(NIM_BOOL, nimDecRefIsLastCyclicStatic)(void* p_p0, TNimTypeV2* desc_p1);
N_LIB_PRIVATE N_NIMCALL(void, rttiDestroy__jsgen_u8424)(void* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___jsgen_u159)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___jsgen_u319)(tySequence__P9aymq2R2Xa8At0XKJ6Bh1A dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, alignedDealloc)(void* p_p0, NI align_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___cgendata_u1265)(tySequence__bdNIx7Bah2llfuqeoTJEWQ dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u3469)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u3270)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqtrace___jsgen_u171)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* dest_p0, void* env_p1);
static N_INLINE(void, nimTraceRefDyn)(void* q_p0, void* env_p1);
static N_INLINE(void, add__system_u3021)(tyObject_CellSeq__gW9aeWLFbrNaeUKXqxYBXhg* s_p0, void** c_p1, TNimTypeV2* t_p2);
N_LIB_PRIVATE N_NIMCALL(void, resize__system_u3029)(tyObject_CellSeq__gW9aeWLFbrNaeUKXqxYBXhg* s_p0);
static N_INLINE(NI, pluspercent___system_u785)(NI x_p0, NI y_p1);
static N_INLINE(void, nimTraceRef)(void* q_p0, TNimTypeV2* desc_p1, void* env_p2);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___cgendata_u1411)(tySequence__9bRXJy1JXrQ4hWpStaKBpXg dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___options_u1751)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u13532)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* dest_p0);
static N_INLINE(NIM_BOOL, nimDecRefIsLast)(void* p_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u3074)(tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqtrace___jsgen_u198)(tyObject_TJSGen__eMRdF9b1ev54YKlmk5BuCUA* dest_p0, void* env_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, eqdup___ast_u4580)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* src_p0);
N_LIB_PRIVATE N_NIMCALL(void, initCountTable__cgen_u30860)(NI initialSize_p0, tyObject_CountTable__C4iAvBZYBHUgGQV1J30IiA* Result);
N_LIB_PRIVATE N_NIMCALL(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw*, eqdup___modulegraphs_u14759)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* src_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg*, eqdup___options_u2141)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* src_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___jsgen_u653)(tyObject_TJSGen__eMRdF9b1ev54YKlmk5BuCUA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___ast_u3103)(tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug** dest_p0, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* src_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___ast_u3255)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** dest_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* src_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ*, eqdup___cgen_u30982)(tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ* src_p0, NIM_BOOL cyclic_p1);
static N_INLINE(NIM_BOOL, skipCodegen__pipelineutils_u8)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* config_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___jsgen_u139)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, internalErrorImpl__msgs_u1598)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, NimStringV2 errMsg_p2, tyTuple__kN8up2W6YKc5YA9avn5mV5w* info2_p3);
N_LIB_PRIVATE N_NIMCALL(RootObj*, eqdup___ast_u4951)(RootObj* src_p0, NIM_BOOL cyclic_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw*, newInitProc__jsgen_u681)(tyObject_PGlobalscolonObjectType___5ylNBaUZgofS9cIrLp09cbRA* globals_p0, tyObject_TJSGen__eMRdF9b1ev54YKlmk5BuCUA* module_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw*, newProc__jsgen_u605)(tyObject_PGlobalscolonObjectType___5ylNBaUZgofS9cIrLp09cbRA* globals_p0, tyObject_TJSGen__eMRdF9b1ev54YKlmk5BuCUA* module_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* procDef_p2, tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ options_p3);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___cgendata_u1268)(tySequence__bdNIx7Bah2llfuqeoTJEWQ* dest_p0, tySequence__bdNIx7Bah2llfuqeoTJEWQ src_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___cgendata_u1262)(tySequence__bdNIx7Bah2llfuqeoTJEWQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TJSGen__eMRdF9b1ev54YKlmk5BuCUA*, eqdup___jsgen_u660)(tyObject_TJSGen__eMRdF9b1ev54YKlmk5BuCUA* src_p0, NIM_BOOL cyclic_p1);
static N_INLINE(void, nimIncRefCyclic)(void* p_p0, NIM_BOOL cyclic_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, eqdup___ast_u3258)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* src_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_PGlobalscolonObjectType___5ylNBaUZgofS9cIrLp09cbRA*, eqdup___jsgen_u513)(tyObject_PGlobalscolonObjectType___5ylNBaUZgofS9cIrLp09cbRA* src_p0, NIM_BOOL cyclic_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___ast_u4577)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg** dest_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* src_p1);
N_LIB_PRIVATE N_NIMCALL(tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ, initProcOptions__jsgen_u674)(tyObject_TJSGen__eMRdF9b1ev54YKlmk5BuCUA* module_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___jsgen_u142)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw** dest_p0, tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* src_p1, NIM_BOOL cyclic_p2);
N_LIB_PRIVATE N_NIMCALL(void, genModule__jsgen_u8185)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, frameCreate__jsgen_u7273)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, NimStringV2 procname_p1, NimStringV2 filename_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, indentLine__jsgen_u102)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, NimStringV2 r_p1);
static N_INLINE(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, owner__ast_u6254)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u4574)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nsuRepeatChar)(NIM_CHAR c_p0, NI count_p1);
static N_INLINE(void, appendString)(NimStringV2* dest_p0, NimStringV2 src_p1);
static N_INLINE(void, copyMem__system_u1742)(void* dest_p0, void* source_p1, NI size_p2);
static N_INLINE(void, nimCopyMem)(void* dest_p0, void* source_p1, NI size_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, rawNewString)(NI space_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u7279)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u7284)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, prepareAdd)(NimStringV2* s_p0, NI addLen_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, makeJSString__jsgen_u806)(NimStringV2 s_p0, NIM_BOOL escapeNonAscii_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nsuEscape)(NimStringV2 s_p0, NimStringV2 prefix_p1, NimStringV2 suffix_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, escapeJSString__jsgen_u798)(NimStringV2 s_p0);
N_NIMCALL(NimStringV2, rawNewString)(NI cap_p0);
static N_INLINE(void, nimAddCharV1)(NimStringV2* s_p0, NIM_CHAR c_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, toFilenameOption__msgs_u676)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NI32 fileIdx_p1, tyEnum_FilenameOption__o3jmnnVs6HdBg5KcNAzYiQ opt_p2);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, transformStmt__transf_u3500)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module_p2, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p3, tySet_tyEnum_TransformFlag__CzUOfRCXpoYcP43GAlt9cnA flags_p4);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___ast_u3261)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** dest_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* src_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, injectDestructorCalls__injectdestructors_u3431)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* owner_p2, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p3);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u3252)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hcrOn__options_u629)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, idOrSig__sighashes_u2002)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p0, NimStringV2 currentModule_p1, tyObject_CountTable__C4iAvBZYBHUgGQV1J30IiA* sigCollisions_p2, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p3);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u1249)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, addHcrInitGuards__jsgen_u8151)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, NimStringV2 moduleLoadedVar_p2, NIM_BOOL* inInitGuard_p3);
static N_INLINE(NI, safeLen__ast_u3197)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0);
static N_INLINE(NI, len__ast_u3190)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u8175)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, genStmt__jsgen_u1163)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
N_LIB_PRIVATE N_NIMCALL(void, gen__jsgen_u1159)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* r_p2);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___system_u2700)(NimStringV2* dest_p0, NimStringV2 src_p1);
N_LIB_PRIVATE N_NIMCALL(void, genSym__jsgen_u4197)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* r_p2);
N_LIB_PRIVATE N_NIMCALL(void, genVarInit__jsgen_u4193)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* v_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, mangleName__jsgen_u702)(tyObject_TJSGen__eMRdF9b1ev54YKlmk5BuCUA* m_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___system_u2694)(NimStringV2* dest_p0, NimStringV2 src_p1);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, validJsName__jsgen_u706)(NimStringV2 name_p0);
static N_INLINE(NIM_BOOL, eqStrings)(NimStringV2 a_p0, NimStringV2 b_p1);
static N_INLINE(NIM_BOOL, equalMem__system_u1750)(void* a_p0, void* b_p1, NI size_p2);
static N_INLINE(int, nimCmpMem)(void* a_p0, void* b_p1, NI size_p2);
N_LIB_PRIVATE N_NIMCALL(NI, hashString)(NimStringV2 s_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, mangle__mangleutils_u4)(NimStringV2 name_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, toHex__pureZstrutils_u2114)(NI x_p0, NI len_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, mangleParamExt__mangleutils_u32)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, mangleProcNameExt__mangleutils_u35)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, rope__ropes_u15)(NI64 i_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u4931)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u4941)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg, mapType__jsgen_u698)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p1);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg, mapType__jsgen_u686)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, skipTypes__ast_u5379)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p0, tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg kinds_p1);
static N_INLINE(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, elementType__ast_u5331)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* n_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___ast_u3381)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg** dest_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* src_p1);
static N_INLINE(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg**, X5BX5D___ast_u5281)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg** s_p0, NI s_p0Len_0, NI i_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u3378)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* dest_p0);
static N_INLINE(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, skipModifier__ast_u5338)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* n_p0);
N_LIB_PRIVATE N_NOINLINE(void, raiseAssert__stdZassertions_u15)(NimStringV2 msg_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u4985)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u4990)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, runtimeFormat__ropes_u39)(NimStringV2 frmt_p0, NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, createVar__jsgen_u4648)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p1, NIM_BOOL indirect_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, putToSeq__jsgen_u4639)(NimStringV2 s_p0, NIM_BOOL indirect_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u4643)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NI, toInt__int128_u257)(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg arg_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg, lengthOrd__types_u1505)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, elemType__types_u254)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, arrayTypeForElemType__jsgen_u4808)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u4834)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, useMagic__jsgen_u1172)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, NimStringV2 name_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, getCompilerProc__magicsys_u150)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, NimStringV2 name_p1);
static N_INLINE(NimStringV2, toFileLineCol__msgs_u701)(tyTuple__kN8up2W6YKc5YA9avn5mV5w* info_p0);
static N_INLINE(void, addInt__stdZprivateZdigitsutils_u204)(NimStringV2* result_p0, NI x_p1);
N_LIB_PRIVATE N_NIMCALL(void, addInt__stdZprivateZdigitsutils_u187)(NimStringV2* result_p0, NI64 x_p1);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, containsOrIncl__astyaml_u223)(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* s_p0, NI key_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, genProc__jsgen_u1166)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* oldProc_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* prc_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, generateHeader__jsgen_u3304)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* prc_p1);
static N_INLINE(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, lastSon__ast_u5208)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0);
static N_INLINE(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ**, X5BX5D___ast_u5211)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** s_p0, NI s_p0Len_0, NI i_p1);
static N_INLINE(NIM_BOOL, isCompileTimeOnly__types_u3655)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p0);
static N_INLINE(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, returnType__ast_u5354)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* n_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u7366)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u7371)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u7399)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u7408)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u7413)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, transformBody__transf_u26)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* prc_p2, tySet_tyEnum_TransformFlag__CzUOfRCXpoYcP43GAlt9cnA flags_p3);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, lineDir__jsgen_u2636)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* config_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, NI line_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u2641)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, toFullPath__msgs_u624)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NI32 fileIdx_p1);
static N_INLINE(NI, toColumn__msgs_u698)(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p0);
static N_INLINE(NI, toLinenumber__msgs_u695)(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, optionalLine__jsgen_u7308)(NimStringV2 p_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, genProcBody__jsgen_u7292)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* prc_p1);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasFrameInfo__jsgen_u2617)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0);
static N_INLINE(void, appendChar)(NimStringV2* dest_p0, NIM_CHAR c_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u7303)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, frameDestroy__jsgen_u7289)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u7442)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u7447)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___jsgen_u570)(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* dest_p0);
N_LIB_PRIVATE N_NOINLINE(void, liMessage__msgs_u1227)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA msg_p2, NimStringV2 arg_p3, tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w eh_p4, tyTuple__kN8up2W6YKc5YA9avn5mV5w* info2_p5, NIM_BOOL isRaw_p6, NIM_BOOL ignoreError_p7);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u4839)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, genTypeInfo__jsgen_u828)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u1083)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u1119)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, prepend__ropes_u36)(NimStringV2* a_p0, NimStringV2 b_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u907)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u945)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, genEnumInfo__jsgen_u1003)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p1, NimStringV2 name_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u1023)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u1035)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u932)(NimStringV2* args_p1, NI args_p1Len_0);
static N_INLINE(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, baseClass__ast_u5348)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* n_p0);
N_LIB_PRIVATE N_NIMCALL(void, genObjectInfo__jsgen_u899)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p1, NimStringV2 name_p2);
static N_INLINE(NIM_BOOL, objHasTypeField__jsgen_u888)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u920)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, genObjectFields__jsgen_u831)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u845)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u850)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u873)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, rope__jsgen_u825)(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg arg_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___int128_u36)(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg a_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg, getOrdValue__types_u167)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u878)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u883)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, genTupleInfo__jsgen_u969)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p1, NimStringV2 name_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, genTupleFields__jsgen_u950)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p1);
static N_INLINE(NI, len__ast_u5502)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* n_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u960)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___ast_u182)(tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg e_p0);
static N_INLINE(NIM_BOOL, isEmptyType__ast_u7234)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u4860)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, createObjInitList__jsgen_u4793)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p1, tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* excludedFieldIDs_p2, NimStringV2* output_p3);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u4799)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___ast_u3387)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg** dest_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* src_p1);
N_LIB_PRIVATE N_NIMCALL(void, createRecordVarAux__jsgen_u4652)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* rec_p1, tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* excludedFieldIDs_p2, NimStringV2* output_p3);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, contains__astalgo_u2846)(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* s_p0, NI key_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u4788)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u4870)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___pureZcollectionsZintsets_u230)(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, needsNoCopy__jsgen_u3374)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* y_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___system_u2688)(NimStringV2* dest_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u5021)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getTemp__jsgen_u1235)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, NIM_BOOL defineInLocals_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u1244)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u5062)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u9681)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, astdef__ast_u4596)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, newNodeI__ast_u4091)(tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw kind_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1);
N_LIB_PRIVATE N_NIMCALL(void, genCopyForParamIfNeeded__jsgen_u4136)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u4187)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u4253)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u4258)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u3725)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u3720)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, genConstant__jsgen_u1169)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* c_p1);
static N_INLINE(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, getBody__modulegraphs_u17880)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, loadProcBody__icZic_u21187)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* config_p0, tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* cache_p1, tyObject_PackedModuleGraph__vzv9a6xTiz616FotDgUeo9bg* g_p2, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p3);
N_LIB_PRIVATE N_NIMCALL(void, add__renderer_u83)(tySequence__ZCZaCk14bTmSb6LMW9aWPVA* x_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* y_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___ast_u4571)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg** dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, genProcForSymIfNeeded__jsgen_u4084)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___ast_u4583)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg** dest_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* src_p1);
N_LIB_PRIVATE N_NIMCALL(void, attachProc__jsgen_u4076)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, NimStringV2 content_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p2);
N_LIB_PRIVATE N_NIMCALL(void, attachProc__jsgen_u4080)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___systemZdollars_u54)(NU64 xX60gensym9__p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, makeJsNimStrLit__jsgen_u810)(NimStringV2 s_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u7998)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(tyEnum_FloatClass__gfrWEZTSUZU5OWgwK4wTYw, classify__pureZmath_u211)(NF x_p0);
static N_INLINE(NIM_BOOL, signbit__astyaml_u680)(NF x_p0);
N_LIB_PRIVATE N_NIMCALL(void, addFloatRoundtrip__systemZrepr95v2_u97)(NimStringV2* result_p0, NF32 x_p1);
N_LIB_PRIVATE N_NIMCALL(void, addFloatRoundtrip__system_u4742)(NimStringV2* result_p0, NF x_p1);
N_LIB_PRIVATE N_NIMCALL(void, genLineDir__jsgen_u2646)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u2654)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, sourceLine__msgs_u1210)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA i_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u21793)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u2671)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u2681)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, genMagic__jsgen_u5466)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* r_p2);
N_LIB_PRIVATE N_NIMCALL(void, genOr__jsgen_u1303)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* b_p2, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* r_p3);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isSimpleExpr__jsgen_u1221)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
static N_INLINE(NIM_BOOL, isAtom__ast_u7223)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u1325)(NimStringV2* args_p1, NI args_p1Len_0);
static N_INLINE(NimStringV2, rdLoc__jsgen_u593)(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* a_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u9083)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u1330)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u1293)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, genAnd__jsgen_u1254)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* b_p2, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* r_p3);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u1278)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u1283)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, arith__jsgen_u2527)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* r_p2, tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg op_p3);
N_LIB_PRIVATE N_NIMCALL(void, binaryUintExpr__jsgen_u1698)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* r_p2, NimStringV2 op_p3);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u1720)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, unsignedTrimmer__jsgen_u1494)(NI64 size_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u1726)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u2564)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, arithAux__jsgen_u1559)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* r_p2, tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg op_p3);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u1596)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u1601)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u1606)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u1615)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u1620)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u1625)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u1634)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u1639)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u1644)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u1653)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u1658)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u1663)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u1668)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u1677)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u1682)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u1687)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u1692)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u1735)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u1759)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u1784)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u1793)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u1834)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u1858)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u1883)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u1892)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u1945)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u1963)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u1976)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, signedTrimmer__jsgen_u1497)(NI64 size_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u1500)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___systemZdollars_u29)(NI64 xX60gensym4__p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u1988)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u1993)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u2007)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u2020)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u2025)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u2036)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u2055)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u2065)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u2070)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u2081)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u2086)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u2119)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u2128)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u2137)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u2170)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u21605)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u21610)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u21615)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u21693)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u2363)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u21479)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u2372)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u2390)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u2399)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u2404)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u21788)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u2417)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u2435)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u2441)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u2446)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u2467)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u2476)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u2485)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u2583)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u2612)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, genRepr__jsgen_u5348)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* r_p2);
N_LIB_PRIVATE N_NIMCALL(void, genReprAux__jsgen_u5333)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* r_p2, NimStringV2 magic_p3, NimStringV2 typ_p4);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u14643)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, genSwap__jsgen_u3634)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, lowerSwap__lowerings_u156)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p2, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* owner_p3);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u5494)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, maybeMakeTemp__jsgen_u1365)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* x_p2, tyTuple__UV3llMMYFckfui8YMBuUZA* Result);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, needsTemp__jsgen_u1352)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u1382)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___stdZprivateZospaths2_u303)(tyTuple__UV3llMMYFckfui8YMBuUZA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u1390)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___stdZprivateZospaths2_u306)(tyTuple__UV3llMMYFckfui8YMBuUZA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u5516)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u5521)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u5545)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u5555)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, genConStrStr__jsgen_u5277)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* r_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u5290)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u5295)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u5309)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u5314)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u5323)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u5328)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u5584)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u5609)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u5634)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, contains__pureZstrutils_u1833)(NimStringV2 s_p0, NimStringV2 sub_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u5648)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u5658)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, genNew__jsgen_u5195)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u2814)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u5216)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u5221)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, genJSArrayConstr__jsgen_u5439)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* r_p2);
N_LIB_PRIVATE N_NIMCALL(void, genCall__jsgen_u4598)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* r_p2);
N_LIB_PRIVATE N_NIMCALL(void, genArgs__jsgen_u4449)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* r_p2, NI start_p3);
N_LIB_PRIVATE N_NIMCALL(void, genArgNoParam__jsgen_u4373)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* r_p2);
N_LIB_PRIVATE N_NIMCALL(void, genArg__jsgen_u4386)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* param_p2, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* r_p3, NI* emitted_p4);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u4435)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u3715)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, genOrd__jsgen_u5245)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* r_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u5262)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u5272)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u5688)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u5693)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u5710)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u5715)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, binaryUintExpr__jsgen_u5721)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* r_p2, NimStringV2 op_p3);
N_LIB_PRIVATE N_NIMCALL(void, maybeMakeTempAssignable__jsgen_u1399)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* x_p2, tyTuple__UV3llMMYFckfui8YMBuUZA* Result);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg, firstOrd__types_u1182)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p1);
static N_INLINE(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, indexType__ast_u5345)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* n_p0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, eqeq___int128_u980)(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg a_p0, NI64 b_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u1449)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u1454)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u1459)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u5746)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u5752)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u5782)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u5827)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u5853)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u5882)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u5908)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u5946)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u5991)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u6017)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u6046)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u6072)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u6099)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u6121)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u6131)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u6156)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u6181)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u6206)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u6231)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u6256)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u6281)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u6306)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u6331)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u6356)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u6381)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, genNewSeq__jsgen_u5226)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u5240)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u6391)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, genOf__jsgen_u5353)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* r_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u5371)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u5376)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, genDefault__jsgen_u5381)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* r_p2);
N_LIB_PRIVATE N_NIMCALL(void, genWasMoved__jsgen_u5385)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u5397)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, genEcho__jsgen_u4620)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* r_p2);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, skipConv__types_u3729)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nsuFormatSingleElem)(NimStringV2 formatstr_p0, NimStringV2 a_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u6401)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u6411)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u6431)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, genMove__jsgen_u5413)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* r_p2);
N_LIB_PRIVATE N_NIMCALL(void, genDup__jsgen_u5426)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* r_p2);
N_LIB_PRIVATE N_NIMCALL(void, genInfixCall__jsgen_u4563)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* r_p2);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, contains__pureZstrutils_u1837)(NimStringV2 s_p0, tySet_tyChar__nmiMWKVIe46vacnhAFrQvw chars_p1);
N_LIB_PRIVATE N_NIMCALL(void, genPatternCall__jsgen_u4513)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, NimStringV2 pat_p2, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p3, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* r_p4);
N_LIB_PRIVATE N_NIMCALL(void, genOtherArg__jsgen_u4489)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, NI i_p2, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p3, NI* generated_p4, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* r_p5);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___systemZdollars_u9)(NI xX60gensym0__p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, substr__system_u8654)(NimStringV2 s_p0, NI first_p1, NI last_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u8050)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, genSetConstr__jsgen_u6436)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* r_p2);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isDeepConstExpr__trees_u153)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0, NIM_BOOL preventInheritance_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u3818)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, genArrayConstr__jsgen_u6482)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* r_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u6498)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, genTupleConstr__jsgen_u6508)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* r_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u6532)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u6541)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, genObjConstr__jsgen_u6546)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* r_p2);
N_LIB_PRIVATE N_NIMCALL(void, incl__pureZcollectionsZintsets_u366)(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* s_p0, NI key_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, lookupFieldAgain__types_u4208)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* ty_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* field_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u6646)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u6655)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u6665)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, genConv__jsgen_u6670)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* r_p2);
static N_INLINE(NIM_BOOL, contains__semfold_u1019)(tyObject_HSlice__Td0KDtM8kU0p7CVwrbJeww s_p0, tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg value_p1);
static N_INLINE(tyObject_HSlice__Td0KDtM8kU0p7CVwrbJeww, dotdot___semfold_u987)(tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg a_p0, tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg b_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u6949)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u6958)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u6975)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u6992)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u7001)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u7010)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u7031)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u7040)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u7049)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, genAddr__jsgen_u3765)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* r_p2);
N_LIB_PRIVATE N_NIMCALL(void, genSymAddr__jsgen_u3939)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p2, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* r_p3);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___jsgen_u3987)(tyTuple__RICk09aVWvF6a15iJKyZfFQ x_p0);
N_LIB_PRIVATE N_NIMCALL(void, genCheckedFieldOp__jsgen_u3769)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* addrTyp_p2, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* r_p3);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, genFieldDefect__astmsgs_u68)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 field_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* disc_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u3824)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u9620)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, genFieldAddr__jsgen_u3658)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* r_p2);
N_LIB_PRIVATE N_NIMCALL(NI, getFieldPosition__jsgen_u3654)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* f_p1);
N_LIB_PRIVATE N_NIMCALL(void, genFieldAccess__jsgen_u3693)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* r_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u15846)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, genArrayAddr__jsgen_u3841)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* r_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___nodekinds_u168)(tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw e_p0);
N_LIB_PRIVATE N_NIMCALL(void, genDeref__jsgen_u4337)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* r_p2);
N_LIB_PRIVATE N_NIMCALL(void, genArrayAccess__jsgen_u3885)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* r_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u3905)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, upConv__jsgen_u7132)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* r_p2);
N_LIB_PRIVATE N_NIMCALL(void, genCast__jsgen_u7479)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* r_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u7757)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u7770)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u7775)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u7788)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u7943)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, genRangeChck__jsgen_u7136)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* r_p2, NimStringV2 magic_p3);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u7189)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u7194)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u7227)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, convStrToCStr__jsgen_u7232)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* r_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u7240)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, convCStrToStr__jsgen_u7245)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* r_p2);
N_LIB_PRIVATE N_NIMCALL(void, genBlock__jsgen_u3130)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* r_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u3153)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, setLen__jsgen_u339)(tySequence__P9aymq2R2Xa8At0XKJ6Bh1A* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u3166)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, genIf__jsgen_u3241)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* r_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u2864)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u3281)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, moveInto__jsgen_u2802)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* src_p1, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* dest_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u5386)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, genWhileStmt__jsgen_u2686)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
static N_INLINE(tyObject_TBlock__e4aohBvIZbqlrYGhrE9cgpw*, X5BX5D___jsgen_u2710)(tyObject_TBlock__e4aohBvIZbqlrYGhrE9cgpw* s_p0, NI s_p0Len_0, NI i_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u2743)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u2758)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, genVarStmt__jsgen_u5110)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, lowerTupleUnpacking__lowerings_u56)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p2, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* owner_p3);
N_LIB_PRIVATE N_NIMCALL(void, genClosureVar__jsgen_u5098)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
N_LIB_PRIVATE N_NIMCALL(void, genAsgnAux__jsgen_u3406)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* x_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* y_p2, NIM_BOOL noCopyNeeded_p3);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u3442)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u3463)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u3468)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u3486)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u3495)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u3508)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u3537)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___jsgen_u3546)(tyTuple__axVdnKAd4XGmBNrMsqQ7kw x_p0);
N_LIB_PRIVATE N_NIMCALL(void, genCaseJS__jsgen_u2955)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* r_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u2990)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u16453)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u3006)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u3011)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u3026)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u24580)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, copyNode__ast_u6736)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* src_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u18073)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u3049)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u3054)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u24585)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u3067)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u9601)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u3094)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u3099)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, genReturnStmt__jsgen_u7257)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u7268)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, genBreakStmt__jsgen_u3171)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u3202)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, genAsgn__jsgen_u3623)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
N_LIB_PRIVATE N_NIMCALL(void, genFastAsgn__jsgen_u3626)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
static N_INLINE(void, warningDeprecated__msgs_u1572)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, NimStringV2 msg_p2);
N_LIB_PRIVATE N_NIMCALL(void, genAsmOrEmitStmt__jsgen_u3207)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, NIM_BOOL isAsmStmt_p2);
N_LIB_PRIVATE N_NIMCALL(void, genTry__jsgen_u2823)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* r_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u2839)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u2850)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u2855)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isInfixAs__ast_u7333)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0);
N_LIB_PRIVATE N_NIMCALL(void, failedAssertImpl__stdZassertions_u79)(NimStringV2 msg_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___ast_u3249)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** dest_p0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isImportedException__ast_u7302)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p0, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u2891)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u2896)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u2901)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u2910)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u2924)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, genRaiseStmt__jsgen_u2937)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u2950)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, genPragma__jsgen_u7470)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw, whichPragma__trees_u218)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0);
N_LIB_PRIVATE N_NIMCALL(void, processPushBackendOption__pushpoppragmas_u288)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* config_p0, tySequence__bdNIx7Bah2llfuqeoTJEWQ* optionsStack_p1, tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ* options_p2, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p3, NI start_p4);
N_LIB_PRIVATE N_NIMCALL(void, popBackendOption__pushpoppragmas_u230)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* config_p0, tySequence__bdNIx7Bah2llfuqeoTJEWQ* optionsStack_p1, tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ* options_p2);
N_LIB_PRIVATE N_NIMCALL(void, genBreakState__jsgen_u1536)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* r_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u1549)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u1554)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u7465)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u8213)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, add__ast_u3215)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* father_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* son_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, processJSCodeGen__jsgen_u8222)(tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ* b_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, genHeader__jsgen_u8149)(void);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nsuFormatVarargs)(NimStringV2 formatstr_p0, NimStringV2* a_p1, NI a_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nsuUnindent)(NimStringV2 s_p0, NI count_p1, NimStringV2 padding_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, wholeCode__jsgen_u8233)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TJSGen__eMRdF9b1ev54YKlmk5BuCUA* m_p1);
N_LIB_PRIVATE N_NIMCALL(void, generateIfMethodDispatchers__cgmeth_u1019)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, resolveSym__modulegraphs_u3497)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA* t_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, prepareToWriteOutput__options_u3642)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0);
N_LIB_PRIVATE N_NIMCALL(void, genSourceMap__sourcemap_u801)(NimStringV2 source_p0, NimStringV2 outFile_p1, tyObject_SourceMap__WQjtp9aU0iILpTcFCDzWLTA* Result);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___jsgen_u8335)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, writeFile__stdZsyncio_u532)(NimStringV2 filename_p0, NimStringV2 content_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___pureZjson_u4831)(tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* node_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g*, percent___jsgen_u8340)(tyObject_SourceMap__WQjtp9aU0iILpTcFCDzWLTA* o_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___pureZjson_u324)(tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___sourcemap_u720)(tyObject_SourceMap__WQjtp9aU0iILpTcFCDzWLTA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, equalsFile__ropes_u230)(NimStringV2 r_p0, NimStringV2 filename_p1);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, writeRope__ropes_u27)(NimStringV2 head_p0, NimStringV2 filename_p1);
N_LIB_PRIVATE TNimTypeV2 NTIv2__5ylNBaUZgofS9cIrLp09cbRA_;
N_LIB_PRIVATE TNimTypeV2 NTIv2__eMRdF9b1ev54YKlmk5BuCUA_;
N_LIB_PRIVATE TNimTypeV2 NTIv2__k9cVsoDH6xQeAkEiVEPoauw_;
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_5 = { 9 | NIM_STRLIT_FLAG, "myProcess" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_6 = {9, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_5};
static const struct {
  NI cap; NIM_CHAR data[60+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_8 = { 60 | NIM_STRLIT_FLAG, "/home/runner/work/nightlies/nightlies/nim/compiler/jsgen.nim" };
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_9 = { 1 | NIM_STRLIT_FLAG, "\"" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_10 = {1, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_9};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_11 = {1, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_9};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_12 = {1, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_9};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_13 = { 2 | NIM_STRLIT_FLAG, "\\n" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_14 = {2, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_13};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_15 = { 2 | NIM_STRLIT_FLAG, "\\r" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_16 = {2, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_15};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_17 = { 2 | NIM_STRLIT_FLAG, "\\t" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_18 = {2, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_17};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_19 = { 2 | NIM_STRLIT_FLAG, "\\b" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_20 = {2, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_19};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_21 = { 2 | NIM_STRLIT_FLAG, "\\a" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_22 = {2, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_21};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_23 = { 2 | NIM_STRLIT_FLAG, "\\e" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_24 = {2, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_23};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_25 = { 2 | NIM_STRLIT_FLAG, "\\v" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_26 = {2, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_25};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_27 = { 2 | NIM_STRLIT_FLAG, "\\\\" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_28 = {2, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_27};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_29 = { 2 | NIM_STRLIT_FLAG, "\\\"" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_30 = {2, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_29};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_31 = {1, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_9};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_32 = { 7 | NIM_STRLIT_FLAG, "module " };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_33 = {7, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_32};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_34 = { 7 | NIM_STRLIT_FLAG, "_loaded" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_35 = {7, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_34};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_36 = { 2 | NIM_STRLIT_FLAG, "}\012" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_37 = {2, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_36};
static const struct {
  NI cap; NIM_CHAR data[0+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_38 = { 0 | NIM_STRLIT_FLAG, "" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_39 = {0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38};
static const struct {
  NI cap; NIM_CHAR data[30+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_40 = { 30 | NIM_STRLIT_FLAG, "symbol has no generated name: " };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_41 = {30, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_40};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_43 = { 8 | NIM_STRLIT_FLAG, "abstract" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_44 = {8, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_43};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_45 = { 5 | NIM_STRLIT_FLAG, "await" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_46 = {5, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_45};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_47 = { 7 | NIM_STRLIT_FLAG, "boolean" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_48 = {7, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_47};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_49 = { 5 | NIM_STRLIT_FLAG, "break" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_50 = {5, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_49};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_51 = { 4 | NIM_STRLIT_FLAG, "byte" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_52 = {4, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_51};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_53 = { 4 | NIM_STRLIT_FLAG, "case" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_54 = {4, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_53};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_55 = { 5 | NIM_STRLIT_FLAG, "catch" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_56 = {5, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_55};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_57 = { 4 | NIM_STRLIT_FLAG, "char" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_58 = {4, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_57};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_59 = { 5 | NIM_STRLIT_FLAG, "class" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_60 = {5, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_59};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_61 = { 5 | NIM_STRLIT_FLAG, "const" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_62 = {5, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_61};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_63 = { 8 | NIM_STRLIT_FLAG, "continue" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_64 = {8, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_63};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_65 = { 8 | NIM_STRLIT_FLAG, "debugger" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_66 = {8, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_65};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_67 = { 7 | NIM_STRLIT_FLAG, "default" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_68 = {7, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_67};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_69 = { 6 | NIM_STRLIT_FLAG, "delete" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_70 = {6, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_69};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_71 = { 2 | NIM_STRLIT_FLAG, "do" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_72 = {2, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_71};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_73 = { 6 | NIM_STRLIT_FLAG, "double" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_74 = {6, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_73};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_75 = { 4 | NIM_STRLIT_FLAG, "else" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_76 = {4, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_75};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_77 = { 4 | NIM_STRLIT_FLAG, "enum" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_78 = {4, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_77};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_79 = { 6 | NIM_STRLIT_FLAG, "export" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_80 = {6, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_79};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_81 = { 7 | NIM_STRLIT_FLAG, "extends" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_82 = {7, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_81};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_83 = { 5 | NIM_STRLIT_FLAG, "false" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_84 = {5, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_83};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_85 = { 5 | NIM_STRLIT_FLAG, "final" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_86 = {5, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_85};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_87 = { 7 | NIM_STRLIT_FLAG, "finally" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_88 = {7, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_87};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_89 = { 5 | NIM_STRLIT_FLAG, "float" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_90 = {5, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_89};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_91 = { 3 | NIM_STRLIT_FLAG, "for" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_92 = {3, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_91};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_93 = { 8 | NIM_STRLIT_FLAG, "function" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_94 = {8, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_93};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_95 = { 4 | NIM_STRLIT_FLAG, "goto" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_96 = {4, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_95};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_97 = { 2 | NIM_STRLIT_FLAG, "if" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_98 = {2, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_97};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_99 = { 10 | NIM_STRLIT_FLAG, "implements" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_100 = {10, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_99};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_101 = { 6 | NIM_STRLIT_FLAG, "import" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_102 = {6, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_101};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_103 = { 2 | NIM_STRLIT_FLAG, "in" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_104 = {2, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_103};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_105 = { 10 | NIM_STRLIT_FLAG, "instanceof" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_106 = {10, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_105};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_107 = { 3 | NIM_STRLIT_FLAG, "int" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_108 = {3, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_107};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_109 = { 9 | NIM_STRLIT_FLAG, "interface" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_110 = {9, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_109};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_111 = { 3 | NIM_STRLIT_FLAG, "let" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_112 = {3, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_111};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_113 = { 4 | NIM_STRLIT_FLAG, "long" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_114 = {4, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_113};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_115 = { 6 | NIM_STRLIT_FLAG, "native" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_116 = {6, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_115};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_117 = { 3 | NIM_STRLIT_FLAG, "new" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_118 = {3, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_117};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_119 = { 4 | NIM_STRLIT_FLAG, "null" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_120 = {4, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_119};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_121 = { 7 | NIM_STRLIT_FLAG, "package" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_122 = {7, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_121};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_123 = { 7 | NIM_STRLIT_FLAG, "private" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_124 = {7, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_123};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_125 = { 9 | NIM_STRLIT_FLAG, "protected" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_126 = {9, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_125};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_127 = { 6 | NIM_STRLIT_FLAG, "public" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_128 = {6, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_127};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_129 = { 6 | NIM_STRLIT_FLAG, "return" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_130 = {6, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_129};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_131 = { 5 | NIM_STRLIT_FLAG, "short" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_132 = {5, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_131};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_133 = { 6 | NIM_STRLIT_FLAG, "static" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_134 = {6, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_133};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_135 = { 5 | NIM_STRLIT_FLAG, "super" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_136 = {5, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_135};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_137 = { 6 | NIM_STRLIT_FLAG, "switch" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_138 = {6, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_137};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_139 = { 12 | NIM_STRLIT_FLAG, "synchronized" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_140 = {12, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_139};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_141 = { 4 | NIM_STRLIT_FLAG, "this" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_142 = {4, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_141};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_143 = { 5 | NIM_STRLIT_FLAG, "throw" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_144 = {5, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_143};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_145 = { 6 | NIM_STRLIT_FLAG, "throws" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_146 = {6, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_145};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_147 = { 9 | NIM_STRLIT_FLAG, "transient" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_148 = {9, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_147};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_149 = { 4 | NIM_STRLIT_FLAG, "true" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_150 = {4, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_149};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_151 = { 3 | NIM_STRLIT_FLAG, "try" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_152 = {3, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_151};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_153 = { 6 | NIM_STRLIT_FLAG, "typeof" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_154 = {6, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_153};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_155 = { 3 | NIM_STRLIT_FLAG, "var" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_156 = {3, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_155};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_157 = { 4 | NIM_STRLIT_FLAG, "void" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_158 = {4, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_157};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_159 = { 8 | NIM_STRLIT_FLAG, "volatile" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_160 = {8, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_159};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_161 = { 5 | NIM_STRLIT_FLAG, "while" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_162 = {5, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_161};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_163 = { 4 | NIM_STRLIT_FLAG, "with" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_164 = {4, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_163};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_165 = { 5 | NIM_STRLIT_FLAG, "yield" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_166 = {5, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_165};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_167 = { 3 | NIM_STRLIT_FLAG, "HEX" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_168 = {3, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_167};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_169 = { 1 | NIM_STRLIT_FLAG, "_" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_170 = {1, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_169};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_171 = { 11 | NIM_STRLIT_FLAG, "globalThis." };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_172 = {11, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_171};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_173 = { 6 | NIM_STRLIT_FLAG, "var $2" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_174 = {6, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_173};
static NIM_CONST tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg TM__BxLwT0mhrtgTPodf1v3xjg_175 = {
0x10, 0xa9, 0x00, 0x00, 0x00, 0x60, 0x80, 0x00,
0x00}
;
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_176 = { 11 | NIM_STRLIT_FLAG, "unreachable" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_177 = {11, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_176};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_178 = { 8 | NIM_STRLIT_FLAG, " = $3;$n" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_179 = {8, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_178};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_180 = {0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_181 = { 1 | NIM_STRLIT_FLAG, "0" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_182 = {1, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_181};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_183 = { 6 | NIM_STRLIT_FLAG, "bigint" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_184 = {6, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_183};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_185 = { 2 | NIM_STRLIT_FLAG, "0n" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_186 = {2, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_185};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_187 = {1, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_181};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_188 = {2, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_185};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_189 = {1, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_181};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_190 = { 3 | NIM_STRLIT_FLAG, "0.0" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_191 = {3, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_190};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_192 = { 2 | NIM_STRLIT_FLAG, "{}" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_193 = {2, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_192};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_194 = {5, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_83};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_195 = {4, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_119};
static NIM_CONST tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg TM__BxLwT0mhrtgTPodf1v3xjg_196 = {
0x10, 0xa9, 0x10, 0x00, 0x00, 0x60, 0x80, 0x00,
0x00}
;
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_197 = { 10 | NIM_STRLIT_FLAG, "Int32Array" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_198 = {10, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_197};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_199 = { 10 | NIM_STRLIT_FLAG, "Int16Array" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_200 = {10, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_199};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_201 = { 9 | NIM_STRLIT_FLAG, "Int8Array" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_202 = {9, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_201};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_203 = { 13 | NIM_STRLIT_FLAG, "BigInt64Array" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_204 = {13, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_203};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_205 = {0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_206 = { 11 | NIM_STRLIT_FLAG, "Uint32Array" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_207 = {11, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_206};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_208 = { 11 | NIM_STRLIT_FLAG, "Uint16Array" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_209 = {11, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_208};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_210 = { 10 | NIM_STRLIT_FLAG, "Uint8Array" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_211 = {10, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_210};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_212 = { 14 | NIM_STRLIT_FLAG, "BigUint64Array" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_213 = {14, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_212};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_214 = {0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_215 = { 12 | NIM_STRLIT_FLAG, "Float32Array" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_216 = {12, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_215};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_217 = { 12 | NIM_STRLIT_FLAG, "Float64Array" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_218 = {12, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_217};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_219 = {10, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_210};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_220 = {11, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_208};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_221 = {11, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_206};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_222 = {0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_223 = {0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_224 = {0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_225 = { 1 | NIM_STRLIT_FLAG, "(" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_226 = {1, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_225};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_227 = { 2 | NIM_STRLIT_FLAG, ", " };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_228 = {2, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_227};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_229 = { 1 | NIM_STRLIT_FLAG, ")" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_230 = {1, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_229};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_232 = {0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_233 = {0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_234 = {0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_235 = {0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_236 = {4, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_141};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_237 = {2, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_227};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_238 = {2, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_227};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_239 = { 4 | NIM_STRLIT_FLAG, "_Idx" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_240 = {4, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_239};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_241 = { 14 | NIM_STRLIT_FLAG, " {$n$#$#$#$#$#" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_242 = {14, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_241};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_243 = {0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_244 = {0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_245 = { 1 | NIM_STRLIT_FLAG, "\012" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_246 = {1, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_245};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_247 = {0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_248 = { 13 | NIM_STRLIT_FLAG, "BeforeRet: {\012" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_249 = {13, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_248};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_250 = { 3 | NIM_STRLIT_FLAG, "};\012" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_251 = {3, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_250};
static const struct {
  NI cap; NIM_CHAR data[19+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_252 = { 19 | NIM_STRLIT_FLAG, "framePtr = F.prev;\012" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_253 = {19, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_252};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_254 = { 4 | NIM_STRLIT_FLAG, "IMLP" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_255 = {4, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_254};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_256 = {2, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_36};
static const struct {
  NI cap; NIM_CHAR data[21+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_257 = { 21 | NIM_STRLIT_FLAG, "system module needs: " };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_258 = {21, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_257};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_260 = {21, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_257};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_262 = { 11 | NIM_STRLIT_FLAG, "arrayConstr" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_263 = {11, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_262};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_264 = { 7 | NIM_STRLIT_FLAG, "nimCopy" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_265 = {7, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_264};
static NIM_CONST tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg TM__BxLwT0mhrtgTPodf1v3xjg_266 = {
0x10, 0x28, 0x00, 0x00, 0x00, 0x60, 0x30, 0x00,
0x00}
;
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_267 = {0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_268 = { 11 | NIM_STRLIT_FLAG, "genEnumInfo" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_269 = {11, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_268};
static const struct {
  NI cap; NIM_CHAR data[62+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_271 = { 62 | NIM_STRLIT_FLAG, "/home/runner/work/nightlies/nightlies/nim/compiler/jstypes.nim" };
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_272 = { 3 | NIM_STRLIT_FLAG, ", \012" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_273 = {3, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_272};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_274 = {0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_275 = {0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_276 = {3, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_272};
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_277 = { 15 | NIM_STRLIT_FLAG, "genObjectFields" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_278 = {15, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_277};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_280 = {0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38};
static const struct {
  NI cap; NIM_CHAR data[34+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_281 = { 34 | NIM_STRLIT_FLAG, "genObjectFields; nkOfBranch broken" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_282 = {34, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_281};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_284 = {2, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_227};
static const struct {
  NI cap; NIM_CHAR data[26+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_285 = { 26 | NIM_STRLIT_FLAG, "genObjectFields(nkRecCase)" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_286 = {26, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_285};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_288 = {3, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_272};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_289 = {15, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_277};
static NIM_CONST tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg TM__BxLwT0mhrtgTPodf1v3xjg_291 = {
0x10, 0x09, 0xe0, 0x00, 0x00, 0xe0, 0x80, 0x00,
0x00}
;
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_292 = {0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_293 = {3, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_272};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_294 = { 12 | NIM_STRLIT_FLAG, "genTypeInfo(" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_295 = {12, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_294};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_297 = {12, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_294};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_299 = { 1 | NIM_STRLIT_FLAG, "[" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_300 = {1, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_299};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_301 = {2, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_227};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_302 = { 1 | NIM_STRLIT_FLAG, "]" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_303 = {1, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_302};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_304 = { 1 | NIM_STRLIT_FLAG, "{" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_305 = {1, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_304};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_306 = {2, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_227};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_307 = { 1 | NIM_STRLIT_FLAG, "}" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_308 = {1, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_307};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_309 = {0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_310 = {2, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_227};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_311 = {2, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_227};
static const struct {
  NI cap; NIM_CHAR data[18+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_312 = { 18 | NIM_STRLIT_FLAG, "createRecordVarAux" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_313 = {18, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_312};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_315 = { 9 | NIM_STRLIT_FLAG, "[null, 0]" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_316 = {9, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_315};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_317 = {4, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_119};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_318 = { 2 | NIM_STRLIT_FLAG, "[]" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_319 = {2, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_318};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_320 = {4, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_119};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_321 = { 11 | NIM_STRLIT_FLAG, "createVar: " };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_322 = {11, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_321};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_324 = {0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_325 = {11, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_321};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_327 = {0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38};
static NIM_CONST tySet_tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw TM__BxLwT0mhrtgTPodf1v3xjg_328 = {
0xe0, 0x07, 0x77, 0xfc, 0x61, 0x02, 0x00, 0x00,
0x80, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x01}
;
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_329 = {7, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_264};
static const struct {
  NI cap; NIM_CHAR data[21+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_330 = { 21 | NIM_STRLIT_FLAG, " = $3, $2_Idx = $4;$n" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_331 = {21, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_330};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_332 = {0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38};
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_333 = { 16 | NIM_STRLIT_FLAG, " = [[$3, $4]];$n" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_334 = {16, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_333};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_335 = {0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_336 = { 14 | NIM_STRLIT_FLAG, " = [$3, $4];$n" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_337 = {14, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_336};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_338 = {0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_339 = {8, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_178};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_340 = {0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_341 = { 10 | NIM_STRLIT_FLAG, " = [$3];$n" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_342 = {10, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_341};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_343 = {0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_344 = {8, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_178};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_345 = {0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38};
static const struct {
  NI cap; NIM_CHAR data[55+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_346 = { 55 | NIM_STRLIT_FLAG, "couldn\'t find the owner proc of the closed over param: " };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_347 = {55, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_346};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_349 = {4, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_239};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_350 = {30, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_40};
static const struct {
  NI cap; NIM_CHAR data[48+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_352 = { 48 | NIM_STRLIT_FLAG, "request to generate code for .compileTime proc: " };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_353 = {48, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_352};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_355 = {30, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_40};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_357 = {4, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_239};
static NIM_CONST tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg TM__BxLwT0mhrtgTPodf1v3xjg_358 = {
0x10, 0xa9, 0x90, 0x00, 0x00, 0x60, 0x80, 0x00,
0x00}
;
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_359 = { 5 | NIM_STRLIT_FLAG, "false" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_360 = {5, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_359};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_361 = { 4 | NIM_STRLIT_FLAG, "true" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_362 = {4, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_361};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_363 = { 4 | NIM_STRLIT_FLAG, "null" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_364 = {4, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_363};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_365 = { 1 | NIM_STRLIT_FLAG, "0" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_366 = {1, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_365};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_367 = {4, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_363};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_368 = {1, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_299};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_369 = { 1 | NIM_STRLIT_FLAG, "," };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_370 = {1, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_369};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_371 = {1, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_302};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_372 = { 13 | NIM_STRLIT_FLAG, "makeNimstrLit" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_373 = {13, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_372};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_374 = { 4 | NIM_STRLIT_FLAG, "-NaN" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_375 = {4, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_374};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_376 = { 3 | NIM_STRLIT_FLAG, "NaN" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_377 = {3, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_376};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_378 = { 4 | NIM_STRLIT_FLAG, "-0.0" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_379 = {4, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_378};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_380 = { 3 | NIM_STRLIT_FLAG, "0.0" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_381 = {3, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_380};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_382 = { 8 | NIM_STRLIT_FLAG, "Infinity" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_383 = {8, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_382};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_384 = { 9 | NIM_STRLIT_FLAG, "-Infinity" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_385 = {9, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_384};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_386 = { 12 | NIM_STRLIT_FLAG, "command line" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_387 = {12, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_386};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_388 = { 3 | NIM_STRLIT_FLAG, "\?\?\?" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_389 = {3, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_388};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_390 = {1, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_307};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_391 = {1, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_307};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_392 = { 6 | NIM_STRLIT_FLAG, "& 0xff" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_393 = {6, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_392};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_394 = { 8 | NIM_STRLIT_FLAG, "& 0xffff" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_395 = {8, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_394};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_396 = { 5 | NIM_STRLIT_FLAG, ">>> 0" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_397 = {5, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_396};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_398 = {0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_399 = { 1 | NIM_STRLIT_FLAG, "+" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_400 = {1, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_399};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_401 = { 1 | NIM_STRLIT_FLAG, "-" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_402 = {1, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_401};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_403 = { 1 | NIM_STRLIT_FLAG, "*" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_404 = {1, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_403};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_405 = { 1 | NIM_STRLIT_FLAG, "/" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_406 = {1, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_405};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_407 = {0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_408 = {0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_409 = { 6 | NIM_STRLIT_FLAG, "addInt" };
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_410 = { 6 | NIM_STRLIT_FLAG, "subInt" };
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_411 = { 6 | NIM_STRLIT_FLAG, "mulInt" };
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_412 = { 6 | NIM_STRLIT_FLAG, "divInt" };
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_413 = { 6 | NIM_STRLIT_FLAG, "modInt" };
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_414 = { 6 | NIM_STRLIT_FLAG, "nimMin" };
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_415 = { 6 | NIM_STRLIT_FLAG, "nimMax" };
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_416 = { 6 | NIM_STRLIT_FLAG, "negInt" };
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_417 = { 8 | NIM_STRLIT_FLAG, "negInt64" };
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_418 = { 6 | NIM_STRLIT_FLAG, "absInt" };
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_419 = { 12 | NIM_STRLIT_FLAG, "nimCharToStr" };
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_420 = { 12 | NIM_STRLIT_FLAG, "nimBoolToStr" };
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_421 = { 12 | NIM_STRLIT_FLAG, "cstrToNimstr" };
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_422 = { 8 | NIM_STRLIT_FLAG, "addInt64" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_423 = {8, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_422};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_424 = { 8 | NIM_STRLIT_FLAG, "subInt64" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_425 = {8, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_424};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_426 = { 8 | NIM_STRLIT_FLAG, "mulInt64" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_427 = {8, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_426};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_428 = { 8 | NIM_STRLIT_FLAG, "divInt64" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_429 = {8, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_428};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_430 = { 8 | NIM_STRLIT_FLAG, "modInt64" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_431 = {8, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_430};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_432 = {1, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_399};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_433 = {1, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_399};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_434 = {8, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_422};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_435 = {6, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_409};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_436 = {1, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_401};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_437 = {1, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_401};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_438 = {8, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_424};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_439 = {6, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_410};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_440 = { 1 | NIM_STRLIT_FLAG, "&" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_441 = {1, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_440};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_442 = {1, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_440};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_443 = { 1 | NIM_STRLIT_FLAG, "|" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_444 = {1, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_443};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_445 = {1, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_443};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_446 = { 1 | NIM_STRLIT_FLAG, "^" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_447 = {1, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_446};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_448 = {1, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_446};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_449 = { 8 | NIM_STRLIT_FLAG, "absInt64" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_450 = {8, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_449};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_451 = { 11 | NIM_STRLIT_FLAG, "cmpClosures" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_452 = {11, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_451};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_453 = {1, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_225};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_454 = { 7 | NIM_STRLIT_FLAG, "reprAny" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_455 = {7, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_454};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_456 = { 6 | NIM_STRLIT_FLAG, ", null" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_457 = {6, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_456};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_458 = {2, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_227};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_459 = {1, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_229};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_460 = { 7 | NIM_STRLIT_FLAG, "reprInt" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_461 = {7, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_460};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_462 = {0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_463 = { 8 | NIM_STRLIT_FLAG, "reprChar" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_464 = {8, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_463};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_465 = {0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_466 = { 8 | NIM_STRLIT_FLAG, "reprBool" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_467 = {8, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_466};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_468 = {0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_469 = { 9 | NIM_STRLIT_FLAG, "reprFloat" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_470 = {9, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_469};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_471 = {0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_472 = { 7 | NIM_STRLIT_FLAG, "reprStr" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_473 = {7, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_472};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_474 = {0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_475 = { 8 | NIM_STRLIT_FLAG, "reprEnum" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_476 = {8, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_475};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_477 = { 7 | NIM_STRLIT_FLAG, "reprSet" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_478 = {7, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_477};
static const struct {
  NI cap; NIM_CHAR data[34+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_479 = { 34 | NIM_STRLIT_FLAG, "\'repr\' doesn\'t support \'void\' type" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_480 = {34, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_479};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_482 = { 11 | NIM_STRLIT_FLAG, "reprPointer" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_483 = {11, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_482};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_484 = {0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38};
static const struct {
  NI cap; NIM_CHAR data[17+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_485 = { 17 | NIM_STRLIT_FLAG, "reprJSONStringify" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_486 = {17, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_485};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_487 = {0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_488 = {7, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_454};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_489 = { 7 | NIM_STRLIT_FLAG, "addChar" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_490 = {7, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_489};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_491 = { 12 | NIM_STRLIT_FLAG, "nimAddStrStr" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_492 = {12, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_491};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_493 = {7, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_264};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_494 = { 9 | NIM_STRLIT_FLAG, "eqStrings" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_495 = {9, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_494};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_496 = { 10 | NIM_STRLIT_FLAG, "cmpStrings" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_497 = {10, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_496};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_498 = {10, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_496};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_499 = {0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_500 = { 12 | NIM_STRLIT_FLAG, "($1 == null)" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_501 = {12, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_500};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_502 = { 2 | NIM_STRLIT_FLAG, "$2" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_503 = {2, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_502};
static NIM_CONST tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg TM__BxLwT0mhrtgTPodf1v3xjg_504 = {
0x10, 0xa9, 0x80, 0x00, 0x00, 0xe0, 0x80, 0x00,
0x00}
;
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_505 = {1, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_299};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_506 = {2, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_227};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_507 = {7, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_264};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_508 = {1, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_302};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_509 = {7, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_264};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_510 = {1, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_225};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_511 = {2, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_227};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_512 = {2, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_227};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_513 = {2, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_227};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_514 = {1, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_229};
static NIM_CONST tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg TM__BxLwT0mhrtgTPodf1v3xjg_515 = {
0x10, 0xa9, 0x90, 0x00, 0x00, 0xe0, 0x80, 0x00,
0x00}
;
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_516 = {0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_517 = { 10 | NIM_STRLIT_FLAG, "Number($1)" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_518 = {10, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_517};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_519 = {2, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_502};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_520 = {0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_521 = { 12 | NIM_STRLIT_FLAG, "($1 \? 1 : 0)" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_522 = {12, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_521};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_523 = {2, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_502};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_524 = { 6 | NIM_STRLIT_FLAG, "genOrd" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_525 = {6, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_524};
static NIM_CONST tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg TM__BxLwT0mhrtgTPodf1v3xjg_527 = {
0x10, 0xa9, 0xe0, 0x00, 0x00, 0xe0, 0x80, 0x00,
0x00}
;
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_528 = { 8 | NIM_STRLIT_FLAG, "chckIndx" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_529 = {8, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_528};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_530 = {1, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_399};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_531 = {0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_532 = {1, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_399};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_533 = {0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_534 = {8, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_422};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_535 = {0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_536 = {6, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_409};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_537 = {1, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_401};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_538 = {0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_539 = {1, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_401};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_540 = {0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_541 = {8, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_424};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_542 = {0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_543 = {6, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_410};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_544 = { 10 | NIM_STRLIT_FLAG, "mnewString" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_545 = {10, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_544};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_546 = { 7 | NIM_STRLIT_FLAG, "SetCard" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_547 = {7, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_546};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_548 = { 11 | NIM_STRLIT_FLAG, "SetCard($1)" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_549 = {11, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_548};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_550 = {2, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_502};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_551 = { 5 | NIM_STRLIT_FLAG, "SetLt" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_552 = {5, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_551};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_553 = { 5 | NIM_STRLIT_FLAG, "SetLe" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_554 = {5, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_553};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_555 = { 5 | NIM_STRLIT_FLAG, "SetEq" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_556 = {5, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_555};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_557 = { 6 | NIM_STRLIT_FLAG, "SetMul" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_558 = {6, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_557};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_559 = { 7 | NIM_STRLIT_FLAG, "SetPlus" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_560 = {7, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_559};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_561 = { 8 | NIM_STRLIT_FLAG, "SetMinus" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_562 = {8, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_561};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_563 = { 6 | NIM_STRLIT_FLAG, "SetXor" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_564 = {6, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_563};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_565 = {0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_566 = {0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_567 = {0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_568 = {0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_569 = {2, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_318};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_570 = {2, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_502};
static NIM_CONST tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg TM__BxLwT0mhrtgTPodf1v3xjg_571 = {
0x10, 0xa9, 0xf0, 0x00, 0x00, 0xe0, 0x80, 0x00,
0x00}
;
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_572 = { 5 | NIM_STRLIT_FLAG, "isObj" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_573 = {5, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_572};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_575 = { 7 | NIM_STRLIT_FLAG, "toJSStr" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_576 = {7, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_575};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_577 = { 7 | NIM_STRLIT_FLAG, "rawEcho" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_578 = {7, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_577};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_579 = { 8 | NIM_STRLIT_FLAG, "rawEcho(" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_580 = {8, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_579};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_581 = {2, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_227};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_582 = {1, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_229};
static const struct {
  NI cap; NIM_CHAR data[45+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_583 = { 45 | NIM_STRLIT_FLAG, "\'$1\' can only be used in compile-time context" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_584 = {45, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_583};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_586 = {10, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_544};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_587 = { 14 | NIM_STRLIT_FLAG, "mnewString($1)" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_588 = {14, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_587};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_589 = {2, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_502};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_590 = {10, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_544};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_591 = { 13 | NIM_STRLIT_FLAG, "mnewString(0)" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_592 = {13, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_591};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_593 = {2, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_502};
static const struct {
  NI cap; NIM_CHAR data[20+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_594 = { 20 | NIM_STRLIT_FLAG, "nimParseBiggestFloat" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_595 = {20, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_594};
static NIM_CONST tySet_tyChar__nmiMWKVIe46vacnhAFrQvw TM__BxLwT0mhrtgTPodf1v3xjg_597 = {
0x00, 0x00, 0x00, 0x00, 0x08, 0x01, 0x00, 0x00,
0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00}
;
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_598 = {2, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_227};
static const struct {
  NI cap; NIM_CHAR data[56+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_599 = { 56 | NIM_STRLIT_FLAG, "wrong importcpp pattern; expected parameter at position " };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_600 = {56, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_599};
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_601 = { 15 | NIM_STRLIT_FLAG, " but got only: " };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_602 = {15, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_601};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_604 = { 1 | NIM_STRLIT_FLAG, "#" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_605 = {1, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_604};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_606 = { 1 | NIM_STRLIT_FLAG, "@" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_607 = {1, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_606};
static const struct {
  NI cap; NIM_CHAR data[31+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_608 = { 31 | NIM_STRLIT_FLAG, "cannot invoke with infix syntax" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_609 = {31, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_608};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_611 = {0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_612 = { 1 | NIM_STRLIT_FLAG, "." };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_613 = {1, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_612};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_614 = { 9 | NIM_STRLIT_FLAG, "setConstr" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_615 = {9, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_614};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_616 = { 10 | NIM_STRLIT_FLAG, "setConstr(" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_617 = {10, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_616};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_618 = {2, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_227};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_619 = {1, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_229};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_620 = { 8 | NIM_STRLIT_FLAG, "ConstSet" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_621 = {8, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_620};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_622 = {2, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_227};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_623 = { 2 | NIM_STRLIT_FLAG, "])" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_624 = {2, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_623};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_625 = {1, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_304};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_626 = {2, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_227};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_627 = {7, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_264};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_628 = {1, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_307};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_629 = {0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_630 = {2, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_227};
static NIM_CONST tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg TM__BxLwT0mhrtgTPodf1v3xjg_632 = {
0x00, 0x20, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00}
;
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_633 = {7, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_264};
static NIM_CONST tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg TM__BxLwT0mhrtgTPodf1v3xjg_634 = {
0x10, 0xa9, 0xe0, 0x00, 0x00, 0xe0, 0x80, 0x00,
0x00}
;
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_635 = { 10 | NIM_STRLIT_FLAG, "genAddr: 3" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_636 = {10, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_635};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_638 = {0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_639 = { 3 | NIM_STRLIT_FLAG, "[0]" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_640 = {3, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_639};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_641 = {0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_642 = {1, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_181};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_643 = { 10 | NIM_STRLIT_FLAG, "genAddr: 2" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_644 = {10, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_643};
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_649 = { 16 | NIM_STRLIT_FLAG, "raiseFieldError2" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_650 = {16, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_649};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_651 = {13, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_372};
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_652 = { 16 | NIM_STRLIT_FLAG, "reprDiscriminant" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_653 = {16, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_652};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_654 = { 3 | NIM_STRLIT_FLAG, "!==" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_655 = {3, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_654};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_656 = { 3 | NIM_STRLIT_FLAG, "===" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_657 = {3, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_656};
static NIM_CONST tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg TM__BxLwT0mhrtgTPodf1v3xjg_658 = {
0x10, 0xa9, 0x90, 0x00, 0x00, 0x60, 0xf8, 0x4f,
0x00}
;
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_659 = { 5 | NIM_STRLIT_FLAG, "Field" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_660 = {5, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_659};
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_661 = { 16 | NIM_STRLIT_FLAG, "genFieldPosition" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_662 = {16, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_661};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_664 = { 12 | NIM_STRLIT_FLAG, "genFieldAddr" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_665 = {12, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_664};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_668 = { 14 | NIM_STRLIT_FLAG, "genFieldAccess" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_669 = {14, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_668};
static NIM_CONST tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg TM__BxLwT0mhrtgTPodf1v3xjg_671 = {
0x10, 0xa9, 0x90, 0x00, 0x00, 0x60, 0xb0, 0x00,
0x00}
;
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_672 = {8, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_528};
static const struct {
  NI cap; NIM_CHAR data[20+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_673 = { 20 | NIM_STRLIT_FLAG, "expr(nkBracketExpr, " };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_674 = {20, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_673};
static const struct {
  NI cap; NIM_CHAR data[34+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_676 = { 34 | NIM_STRLIT_FLAG, "genAddr for complex nkStmtListExpr" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_677 = {34, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_676};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_679 = { 9 | NIM_STRLIT_FLAG, "genAddr: " };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_680 = {9, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_679};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_682 = {9, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_679};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_684 = { 8 | NIM_STRLIT_FLAG, "genDeref" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_685 = {8, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_684};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_687 = {20, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_673};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_689 = { 14 | NIM_STRLIT_FLAG, "genArrayAccess" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_690 = {14, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_689};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_692 = {4, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_119};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_693 = { 9 | NIM_STRLIT_FLAG, "chckRange" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_694 = {9, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_693};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_695 = { 10 | NIM_STRLIT_FLAG, "chckRangeF" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_696 = {10, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_695};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_697 = { 11 | NIM_STRLIT_FLAG, "chckRange64" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_698 = {11, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_697};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_699 = {9, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_693};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_700 = { 13 | NIM_STRLIT_FLAG, "convStrToCStr" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_701 = {13, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_700};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_703 = {7, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_575};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_704 = { 13 | NIM_STRLIT_FLAG, "convCStrToStr" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_705 = {13, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_704};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_707 = {12, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_421};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_708 = { 8 | NIM_STRLIT_FLAG, "genBlock" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_709 = {8, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_708};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_711 = {0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_712 = {1, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_245};
static const struct {
  NI cap; NIM_CHAR data[38+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_714 = { 38 | NIM_STRLIT_FLAG, "cstring doesn\'t support `[]=` operator" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_715 = {38, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_714};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_717 = {7, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_264};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_718 = {7, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_264};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_720 = { 7 | NIM_STRLIT_FLAG, "etyNone" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_721 = {7, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_720};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_722 = { 7 | NIM_STRLIT_FLAG, "etyNull" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_723 = {7, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_722};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_724 = { 7 | NIM_STRLIT_FLAG, "etyProc" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_725 = {7, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_724};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_726 = { 7 | NIM_STRLIT_FLAG, "etyBool" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_727 = {7, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_726};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_728 = { 6 | NIM_STRLIT_FLAG, "etySeq" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_729 = {6, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_728};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_730 = { 6 | NIM_STRLIT_FLAG, "etyInt" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_731 = {6, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_730};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_732 = { 8 | NIM_STRLIT_FLAG, "etyFloat" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_733 = {8, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_732};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_734 = { 9 | NIM_STRLIT_FLAG, "etyString" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_735 = {9, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_734};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_736 = { 9 | NIM_STRLIT_FLAG, "etyObject" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_737 = {9, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_736};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_738 = { 12 | NIM_STRLIT_FLAG, "etyBaseIndex" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_739 = {12, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_738};
static const struct {
  NI cap; NIM_CHAR data[0+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_740 = { 0 | NIM_STRLIT_FLAG, "" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_741 = {0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_740};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_742 = { 7 | NIM_STRLIT_FLAG, "genAsgn" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_743 = {7, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_742};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_745 = { 10 | NIM_STRLIT_FLAG, "$1 = $2;$n" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_746 = {10, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_745};
static const struct {
  NI cap; NIM_CHAR data[28+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_747 = { 28 | NIM_STRLIT_FLAG, "for statement not eliminated" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_748 = {28, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_747};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_750 = {7, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_575};
static const struct {
  NI cap; NIM_CHAR data[20+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_751 = { 20 | NIM_STRLIT_FLAG, "jsgen.genCaseStmt: 2" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_752 = {20, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_751};
static const struct {
  NI cap; NIM_CHAR data[17+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_754 = { 17 | NIM_STRLIT_FLAG, "jsgen.genCaseStmt" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_755 = {17, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_754};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_757 = { 13 | NIM_STRLIT_FLAG, "genReturnStmt" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_758 = {13, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_757};
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_760 = { 16 | NIM_STRLIT_FLAG, "no loop to break" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_761 = {16, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_760};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_763 = {1, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_225};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_764 = {1, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_229};
static const struct {
  NI cap; NIM_CHAR data[59+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_766 = { 59 | NIM_STRLIT_FLAG, "/home/runner/work/nightlies/nightlies/nim/compiler/msgs.nim" };
static const struct {
  NI cap; NIM_CHAR data[60+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_767 = { 60 | NIM_STRLIT_FLAG, "\'asm\' for the JS target is deprecated, use the \'emit\' pragma" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_768 = {60, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_767};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_769 = {0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_770 = {0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_771 = {0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_772 = {1, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_245};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_773 = { 14 | NIM_STRLIT_FLAG, "++excHandler;\012" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_774 = {14, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_773};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_775 = { 1 | NIM_STRLIT_FLAG, "F" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_776 = {1, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_775};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_777 = {0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_778 = {5, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_572};
static const struct {
  NI cap; NIM_CHAR data[34+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_779 = { 34 | NIM_STRLIT_FLAG, "jsgen.nim(985, 11) `orExpr == \"\"` " };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_780 = {34, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_779};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_781 = { 10 | NIM_STRLIT_FLAG, "genTryStmt" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_782 = {10, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_781};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_784 = { 2 | NIM_STRLIT_FLAG, "||" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_785 = {2, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_784};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_786 = { 5 | NIM_STRLIT_FLAG, "else " };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_787 = {5, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_786};
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_788 = { 16 | NIM_STRLIT_FLAG, "reraiseException" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_789 = {16, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_788};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_790 = { 7 | NIM_STRLIT_FLAG, "else {\012" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_791 = {7, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_790};
static const struct {
  NI cap; NIM_CHAR data[21+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_792 = { 21 | NIM_STRLIT_FLAG, "\011reraiseException();\012" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_793 = {21, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_792};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_794 = {2, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_36};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_795 = { 12 | NIM_STRLIT_FLAG, "} finally {\012" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_796 = {12, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_795};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_797 = {2, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_36};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_798 = { 14 | NIM_STRLIT_FLAG, "raiseException" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_799 = {14, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_798};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_800 = {16, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_788};
static const struct {
  NI cap; NIM_CHAR data[20+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_801 = { 20 | NIM_STRLIT_FLAG, "reraiseException();\012" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_802 = {20, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_801};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_803 = {0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38};
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_804 = { 15 | NIM_STRLIT_FLAG, "not implemented" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_805 = {15, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_804};
static const struct {
  NI cap; NIM_CHAR data[24+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_807 = { 24 | NIM_STRLIT_FLAG, "gen: unknown node type: " };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_808 = {24, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_807};
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_810 = {2, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_36};
static const struct {
  NI cap; NIM_CHAR data[119+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_811 = { 119 | NIM_STRLIT_FLAG, "/* Generated by the Nim Compiler v$1 */\012    var framePtr = null;\012    var excHandler = 0;\012    var lastJSError = null;\012  " };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_812 = {119, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_811};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_813 = { 1 | NIM_STRLIT_FLAG, " " };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_814 = {1, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_813};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_816 = { 6 | NIM_STRLIT_FLAG, "2.2.10" };
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__BxLwT0mhrtgTPodf1v3xjg_817 = { 4 | NIM_STRLIT_FLAG, ".map" };
static const NimStringV2 TM__BxLwT0mhrtgTPodf1v3xjg_818 = {4, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_817};
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_7 = {{60, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_8},
((NI)3158),
((NI)35)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_42 = {{60, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_8},
((NI)1656),
((NI)19)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_231 = {{60, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_8},
((NI)331),
((NI)4)}
;
extern NIM_CONST tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA unknownLineInfo__lineinfos_u364;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_259 = {{60, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_8},
((NI)337),
((NI)17)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_261 = {{60, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_8},
((NI)339),
((NI)16)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_270 = {{62, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_271},
((NI)107),
((NI)46)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_279 = {{62, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_271},
((NI)42),
((NI)42)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_283 = {{62, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_271},
((NI)51),
((NI)23)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_287 = {{62, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_271},
((NI)61),
((NI)25)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_290 = {{62, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_271},
((NI)69),
((NI)21)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_296 = {{62, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_271},
((NI)155),
((NI)23)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_298 = {{62, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_271},
((NI)156),
((NI)21)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_314 = {{60, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_8},
((NI)1918),
((NI)21)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_323 = {{60, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_8},
((NI)2035),
((NI)19)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_326 = {{60, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_8},
((NI)2038),
((NI)17)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_348 = {{60, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_8},
((NI)1641),
((NI)19)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_351 = {{60, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_8},
((NI)1681),
((NI)19)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_354 = {{60, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_8},
((NI)1685),
((NI)16)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_356 = {{60, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_8},
((NI)1701),
((NI)19)}
;
extern NIM_CONST tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg abstractRange__types_u92;
N_LIB_PRIVATE NIM_CONST tyArray__nZzcix4CWuRF8YzR69agPRw jsMagics__jsgen_u1351 = {{{6, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_409},
{0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38}}
,
{{6, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_410},
{0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38}}
,
{{6, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_411},
{0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38}}
,
{{6, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_412},
{0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38}}
,
{{6, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_413},
{0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38}}
,
{{6, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_409},
{0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38}}
,
{{6, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_410},
{0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38}}
,
{{0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38},
{0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38}}
,
{{0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38},
{0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38}}
,
{{0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38},
{0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38}}
,
{{0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38},
{0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38}}
,
{{0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38},
{0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38}}
,
{{0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38},
{0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38}}
,
{{0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38},
{0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38}}
,
{{0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38},
{0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38}}
,
{{0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38},
{0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38}}
,
{{0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38},
{0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38}}
,
{{6, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_414},
{6, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_414}}
,
{{6, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_415},
{6, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_415}}
,
{{0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38},
{0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38}}
,
{{0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38},
{0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38}}
,
{{0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38},
{0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38}}
,
{{0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38},
{0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38}}
,
{{0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38},
{0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38}}
,
{{0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38},
{0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38}}
,
{{0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38},
{0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38}}
,
{{0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38},
{0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38}}
,
{{0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38},
{0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38}}
,
{{0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38},
{0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38}}
,
{{0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38},
{0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38}}
,
{{0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38},
{0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38}}
,
{{0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38},
{0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38}}
,
{{0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38},
{0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38}}
,
{{0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38},
{0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38}}
,
{{0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38},
{0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38}}
,
{{0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38},
{0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38}}
,
{{0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38},
{0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38}}
,
{{0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38},
{0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38}}
,
{{0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38},
{0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38}}
,
{{0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38},
{0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38}}
,
{{0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38},
{0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38}}
,
{{0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38},
{0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38}}
,
{{0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38},
{0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38}}
,
{{0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38},
{0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38}}
,
{{0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38},
{0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38}}
,
{{0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38},
{0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38}}
,
{{0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38},
{0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38}}
,
{{6, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_416},
{0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38}}
,
{{8, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_417},
{0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38}}
,
{{6, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_418},
{0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38}}
,
{{0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38},
{0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38}}
,
{{0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38},
{0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38}}
,
{{0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38},
{0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38}}
,
{{0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38},
{0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38}}
,
{{0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38},
{0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38}}
,
{{12, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_419},
{12, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_419}}
,
{{12, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_420},
{12, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_420}}
,
{{12, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_421},
{12, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_421}}
,
{{0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38},
{0, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_38}}
}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_481 = {{60, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_8},
((NI)2250),
((NI)14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_526 = {{60, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_8},
((NI)2185),
((NI)21)}
;
extern NIM_CONST tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg Zero__int128_u8;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_574 = {{60, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_8},
((NI)1885),
((NI)2)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_585 = {{60, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_8},
((NI)2478),
((NI)14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_596 = {{60, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_8},
((NI)1851),
((NI)4)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_603 = {{60, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_8},
((NI)1797),
((NI)15)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_610 = {{60, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_8},
((NI)1861),
((NI)19)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_631 = {{60, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_8},
((NI)2584),
((NI)4)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_637 = {{60, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_8},
((NI)1529),
((NI)39)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_645 = {{60, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_8},
((NI)1560),
((NI)21)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_646 = {{60, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_8},
((NI)1419),
((NI)2)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_647 = {{60, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_8},
((NI)1431),
((NI)2)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_648 = {{60, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_8},
((NI)1435),
((NI)2)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_663 = {{60, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_8},
((NI)1370),
((NI)17)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_666 = {{60, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_8},
((NI)1381),
((NI)40)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_667 = {{60, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_8},
((NI)1385),
((NI)2)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_670 = {{60, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_8},
((NI)1409),
((NI)40)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_675 = {{60, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_8},
((NI)1589),
((NI)27)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_678 = {{60, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_8},
((NI)1604),
((NI)25)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_681 = {{60, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_8},
((NI)1611),
((NI)21)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_683 = {{60, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_8},
((NI)1613),
((NI)19)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_686 = {{60, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_8},
((NI)1729),
((NI)19)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_688 = {{60, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_8},
((NI)1500),
((NI)21)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_691 = {{60, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_8},
((NI)1502),
((NI)31)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_702 = {{60, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_8},
((NI)2688),
((NI)33)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_706 = {{60, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_8},
((NI)2700),
((NI)33)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_710 = {{60, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_8},
((NI)1139),
((NI)42)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_713 = {{60, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_8},
((NI)895),
((NI)2)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_716 = {{60, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_8},
((NI)1285),
((NI)14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_719 = {{60, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_8},
((NI)1323),
((NI)8)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_744 = {{60, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_8},
((NI)1336),
((NI)21)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_749 = {{60, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_8},
((NI)3047),
((NI)17)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_753 = {{60, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_8},
((NI)1093),
((NI)31)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_756 = {{60, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_8},
((NI)1130),
((NI)23)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_759 = {{60, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_8},
((NI)2706),
((NI)36)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_762 = {{60, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_8},
((NI)1165),
((NI)19)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_765 = {{59, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_766},
((NI)629),
((NI)9)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_783 = {{60, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_8},
((NI)990),
((NI)23)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_806 = {{60, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_8},
((NI)3074),
((NI)15)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_809 = {{60, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_8},
((NI)3080),
((NI)21)}
;
static NIM_CONST tyArray__YgExxhfgKcesA5EOUj1MOA TM__BxLwT0mhrtgTPodf1v3xjg_815 = {{6, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_816}}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_819 = {{60, (NimStrPayload*)&TM__BxLwT0mhrtgTPodf1v3xjg_8},
((NI)3216),
((NI)18)}
;
extern NIM_BOOL nimInErrorMode__system_u4146;
static NIM_CONST NU32 TM__BxLwT0mhrtgTPodf1v3xjg_2[2] = {3701606400, 692913408};
N_LIB_PRIVATE TNimTypeV2 NTIv2__5ylNBaUZgofS9cIrLp09cbRA_ = {.destructor = (void*)rttiDestroy__jsgen_u8420, .size = sizeof(tyObject_PGlobalscolonObjectType___5ylNBaUZgofS9cIrLp09cbRA), .align = (NI16) NIM_ALIGNOF(tyObject_PGlobalscolonObjectType___5ylNBaUZgofS9cIrLp09cbRA), .depth = 1, .display = TM__BxLwT0mhrtgTPodf1v3xjg_2, .traceImpl = (void*)NIM_NIL, .flags = 0};
static NIM_CONST NU32 TM__BxLwT0mhrtgTPodf1v3xjg_3[1] = {4117536768};
N_LIB_PRIVATE TNimTypeV2 NTIv2__k9cVsoDH6xQeAkEiVEPoauw_ = {.destructor = (void*)rttiDestroy__jsgen_u8424, .size = sizeof(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw), .align = (NI16) NIM_ALIGNOF(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw), .depth = 0, .display = TM__BxLwT0mhrtgTPodf1v3xjg_3, .traceImpl = (void*)eqtrace___jsgen_u171, .flags = 0};
static NIM_CONST NU32 TM__BxLwT0mhrtgTPodf1v3xjg_4[3] = {3701606400, 62025216, 3294435072};
N_LIB_PRIVATE TNimTypeV2 NTIv2__eMRdF9b1ev54YKlmk5BuCUA_ = {.destructor = (void*)rttiDestroy__jsgen_u8422, .size = sizeof(tyObject_TJSGen__eMRdF9b1ev54YKlmk5BuCUA), .align = (NI16) NIM_ALIGNOF(tyObject_TJSGen__eMRdF9b1ev54YKlmk5BuCUA), .depth = 2, .display = TM__BxLwT0mhrtgTPodf1v3xjg_4, .traceImpl = (void*)eqtrace___jsgen_u198, .flags = 0};
static N_INLINE(NI, minuspercent___system_u805)(NI x_p0, NI y_p1) {
	NI result;
	result = ((NI) ((NU)((NU64)(((NU) (x_p0))) - (NU64)(((NU) (y_p1))))));
	return result;
}
static N_INLINE(NIM_BOOL, nimDecRefIsLastDyn)(void* p_p0) {
	NIM_BOOL result;
	result = NIM_FALSE;
	{
		tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* cell_1;
		NI T5_;
		if (!!((p_p0 == NIM_NIL))) goto LA3_;
		T5_ = (NI)0;
		T5_ = minuspercent___system_u805(((NI) (ptrdiff_t) (p_p0)), ((NI)16));
		cell_1 = ((tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A*) (T5_));
		{
			if (!((NI)((*cell_1).rc & ((NI)-16)) == ((NI)0))) goto LA8_;
			result = NIM_TRUE;
		}
		goto LA6_;
LA8_: ;
		{
			(*cell_1).rc = minuspercent___system_u805((*cell_1).rc, ((NI)16));
		}
LA6_: ;
		{
			if (!result) goto LA13_;
			{
				if (!(((NI)0) < (*cell_1).rootIdx)) goto LA17_;
				unregisterCycle__system_u3130(cell_1);
			}
LA17_: ;
		}
LA13_: ;
	}
LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___jsgen_u260)(tyObject_PGlobalscolonObjectType___5ylNBaUZgofS9cIrLp09cbRA* dest_p0) {
	eqdestroy___pureZcollectionsZintsets_u100((*dest_p0).typeInfoGenerated.data);
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastDyn((*dest_p0).typeInfoGenerated.head);
		if (!T3_) goto LA4_;
		eqdestroy___pureZcollectionsZintsets_u66((&(*(*dest_p0).typeInfoGenerated.head)));
		nimRawDispose((*dest_p0).typeInfoGenerated.head, ((NI)8));
	}
LA4_: ;
	eqdestroy___pureZcollectionsZintsets_u100((*dest_p0).generatedSyms.data);
	{
		NIM_BOOL T8_;
		T8_ = (NIM_BOOL)0;
		T8_ = nimDecRefIsLastDyn((*dest_p0).generatedSyms.head);
		if (!T8_) goto LA9_;
		eqdestroy___pureZcollectionsZintsets_u66((&(*(*dest_p0).generatedSyms.head)));
		nimRawDispose((*dest_p0).generatedSyms.head, ((NI)8));
	}
LA9_: ;
	eqdestroy___ast_u4848((*dest_p0).forwarded);
	eqdestroy___system_u2691((*dest_p0).code);
	eqdestroy___system_u2691((*dest_p0).constants);
	eqdestroy___system_u2691((*dest_p0).typeInfo);
}
static N_INLINE(NIM_BOOL*, nimErrorFlag)(void) {
	NIM_BOOL* result;
	result = (&nimInErrorMode__system_u4146);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, rttiDestroy__jsgen_u8420)(void* dest_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqdestroy___jsgen_u260((&(*((tyObject_PGlobalscolonObjectType___5ylNBaUZgofS9cIrLp09cbRA*) (dest_p0)))));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(void, nimSetMem__system_u2172)(void* a_p0, int v_p1, NI size_p2) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a_p0, v_p1, ((size_t) (size_p2)));
}
static N_INLINE(void, nimZeroMem)(void* p_p0, NI size_p1) {
	nimSetMem__system_u2172(p_p0, ((int)0), size_p1);
}
static N_INLINE(void, initIntSet__pureZcollectionsZintsets_u598)(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* Result) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)Result, sizeof(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA));
	initPackedSet__pureZcollectionsZintsets_u37(Result);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_PGlobalscolonObjectType___5ylNBaUZgofS9cIrLp09cbRA*, newGlobals__jsgen_u497)(void) {
	tyObject_PGlobalscolonObjectType___5ylNBaUZgofS9cIrLp09cbRA* result;
	tyObject_PGlobalscolonObjectType___5ylNBaUZgofS9cIrLp09cbRA* T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	T1_ = NIM_NIL;
	T1_ = (tyObject_PGlobalscolonObjectType___5ylNBaUZgofS9cIrLp09cbRA*) nimNewObj(sizeof(tyObject_PGlobalscolonObjectType___5ylNBaUZgofS9cIrLp09cbRA), NIM_ALIGNOF(tyObject_PGlobalscolonObjectType___5ylNBaUZgofS9cIrLp09cbRA));
	(*T1_).Sup.m_type = (&NTIv2__5ylNBaUZgofS9cIrLp09cbRA_);
	(*T1_).forwarded.len = 0; (*T1_).forwarded.p = (tySequence__ZCZaCk14bTmSb6LMW9aWPVA_Content*) newSeqPayload(0, sizeof(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*), NIM_ALIGNOF(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*));
	initIntSet__pureZcollectionsZintsets_u598((&(*T1_).generatedSyms));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	initIntSet__pureZcollectionsZintsets_u598((&(*T1_).typeInfoGenerated));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	result = T1_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, nimDecRefIsLastCyclicDyn)(void* p_p0) {
	NIM_BOOL result;
	result = NIM_FALSE;
	{
		tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* cell_1;
		NI T5_;
		if (!!((p_p0 == NIM_NIL))) goto LA3_;
		T5_ = (NI)0;
		T5_ = minuspercent___system_u805(((NI) (ptrdiff_t) (p_p0)), ((NI)16));
		cell_1 = ((tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A*) (T5_));
		{
			if (!((NI)((*cell_1).rc & ((NI)-16)) == ((NI)0))) goto LA8_;
			result = NIM_TRUE;
		}
		goto LA6_;
LA8_: ;
		{
			(*cell_1).rc = minuspercent___system_u805((*cell_1).rc, ((NI)16));
		}
LA6_: ;
		rememberCycle__system_u3500(result, cell_1, (*((TNimTypeV2**) (p_p0))));
	}
LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___jsgen_u506)(tyObject_PGlobalscolonObjectType___5ylNBaUZgofS9cIrLp09cbRA* dest_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastCyclicDyn(dest_p0);
		if (!T3_) goto LA4_;
		nimDestroyAndDispose(dest_p0);
	}
LA4_: ;
}
static N_INLINE(NIM_BOOL, nimDecRefIsLastCyclicStatic)(void* p_p0, TNimTypeV2* desc_p1) {
	NIM_BOOL result;
	result = NIM_FALSE;
	{
		tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* cell_1;
		NI T5_;
		if (!!((p_p0 == NIM_NIL))) goto LA3_;
		T5_ = (NI)0;
		T5_ = minuspercent___system_u805(((NI) (ptrdiff_t) (p_p0)), ((NI)16));
		cell_1 = ((tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A*) (T5_));
		{
			if (!((NI)((*cell_1).rc & ((NI)-16)) == ((NI)0))) goto LA8_;
			result = NIM_TRUE;
		}
		goto LA6_;
LA8_: ;
		{
			(*cell_1).rc = minuspercent___system_u805((*cell_1).rc, ((NI)16));
		}
LA6_: ;
		rememberCycle__system_u3500(result, cell_1, desc_p1);
	}
LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___jsgen_u319)(tySequence__P9aymq2R2Xa8At0XKJ6Bh1A dest_p0) {
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyObject_TBlock__e4aohBvIZbqlrYGhrE9cgpw));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___jsgen_u159)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* dest_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastCyclicStatic((*dest_p0).up, ((TNimTypeV2*) ((&NTIv2__k9cVsoDH6xQeAkEiVEPoauw_))));
		if (!T3_) goto LA4_;
		eqdestroy___jsgen_u159((&(*(*dest_p0).up)));
		nimRawDispose((*dest_p0).up, ((NI)8));
	}
LA4_: ;
	eqdestroy___pureZcollectionsZintsets_u100((*dest_p0).generatedParamCopies.data);
	{
		NIM_BOOL T8_;
		T8_ = (NIM_BOOL)0;
		T8_ = nimDecRefIsLastDyn((*dest_p0).generatedParamCopies.head);
		if (!T8_) goto LA9_;
		eqdestroy___pureZcollectionsZintsets_u66((&(*(*dest_p0).generatedParamCopies.head)));
		nimRawDispose((*dest_p0).generatedParamCopies.head, ((NI)8));
	}
LA9_: ;
	eqdestroy___system_u2691((*dest_p0).previousFileName);
	eqdestroy___jsgen_u319((*dest_p0).blocks);
	{
		NIM_BOOL T13_;
		T13_ = (NIM_BOOL)0;
		T13_ = nimDecRefIsLastCyclicDyn((*dest_p0).g);
		if (!T13_) goto LA14_;
		nimDestroyAndDispose((*dest_p0).g);
	}
LA14_: ;
	{
		NIM_BOOL T18_;
		T18_ = (NIM_BOOL)0;
		T18_ = nimDecRefIsLastCyclicDyn((*dest_p0).module);
		if (!T18_) goto LA19_;
		nimDestroyAndDispose((*dest_p0).module);
	}
LA19_: ;
	eqdestroy___cgendata_u1265((*dest_p0).optionsStack);
	eqdestroy___system_u2691((*dest_p0).body);
	eqdestroy___system_u2691((*dest_p0).locals);
	eqdestroy___system_u2691((*dest_p0).globals);
	{
		NIM_BOOL T23_;
		T23_ = (NIM_BOOL)0;
		T23_ = nimDecRefIsLastDyn((*dest_p0).prc);
		if (!T23_) goto LA24_;
		eqdestroy___ast_u3469((&(*(*dest_p0).prc)));
		nimRawDispose((*dest_p0).prc, ((NI)8));
	}
LA24_: ;
	{
		NIM_BOOL T28_;
		T28_ = (NIM_BOOL)0;
		T28_ = nimDecRefIsLastDyn((*dest_p0).procDef);
		if (!T28_) goto LA29_;
		eqdestroy___ast_u3270((&(*(*dest_p0).procDef)));
		nimRawDispose((*dest_p0).procDef, ((NI)8));
	}
LA29_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, rttiDestroy__jsgen_u8424)(void* dest_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqdestroy___jsgen_u159((&(*((tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw*) (dest_p0)))));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(NI, pluspercent___system_u785)(NI x_p0, NI y_p1) {
	NI result;
	result = ((NI) ((NU)((NU64)(((NU) (x_p0))) + (NU64)(((NU) (y_p1))))));
	return result;
}
static N_INLINE(void, add__system_u3021)(tyObject_CellSeq__gW9aeWLFbrNaeUKXqxYBXhg* s_p0, void** c_p1, TNimTypeV2* t_p2) {
	void** colontmp_;
	TNimTypeV2* colontmp__2;
	{
		if (!((*s_p0).cap <= (*s_p0).len)) goto LA3_;
		resize__system_u3029(s_p0);
	}
LA3_: ;
	colontmp_ = c_p1;
	colontmp__2 = t_p2;
	(*s_p0).d[(*s_p0).len].Field0 = colontmp_;
	(*s_p0).d[(*s_p0).len].Field1 = colontmp__2;
	(*s_p0).len = pluspercent___system_u785((*s_p0).len, ((NI)1));
}
static N_INLINE(void, nimTraceRefDyn)(void* q_p0, void* env_p1) {
	void** p_1;
	p_1 = ((void**) (q_p0));
	{
		tyObject_GcEnv__HccVszwojlCZRN46BE9cG8w* j_1;
		if (!!(((*p_1) == NIM_NIL))) goto LA3_;
		j_1 = ((tyObject_GcEnv__HccVszwojlCZRN46BE9cG8w*) (env_p1));
		add__system_u3021((&(*j_1).traceStack), p_1, (*((TNimTypeV2**) ((*p_1)))));
	}
LA3_: ;
}
static N_INLINE(void, nimTraceRef)(void* q_p0, TNimTypeV2* desc_p1, void* env_p2) {
	void** p_1;
	p_1 = ((void**) (q_p0));
	{
		tyObject_GcEnv__HccVszwojlCZRN46BE9cG8w* j_1;
		if (!!(((*p_1) == NIM_NIL))) goto LA3_;
		j_1 = ((tyObject_GcEnv__HccVszwojlCZRN46BE9cG8w*) (env_p2));
		add__system_u3021((&(*j_1).traceStack), p_1, desc_p1);
	}
LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqtrace___jsgen_u171)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* dest_p0, void* env_p1) {
	nimTraceRefDyn(&(*dest_p0).module, env_p1);
	nimTraceRefDyn(&(*dest_p0).g, env_p1);
	nimTraceRef(&(*dest_p0).up, ((TNimTypeV2*) ((&NTIv2__k9cVsoDH6xQeAkEiVEPoauw_))), env_p1);
}
static N_INLINE(NIM_BOOL, nimDecRefIsLast)(void* p_p0) {
	NIM_BOOL result;
	result = NIM_FALSE;
	{
		tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* cell_1;
		NI T5_;
		if (!!((p_p0 == NIM_NIL))) goto LA3_;
		T5_ = (NI)0;
		T5_ = minuspercent___system_u805(((NI) (ptrdiff_t) (p_p0)), ((NI)16));
		cell_1 = ((tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A*) (T5_));
		{
			if (!((NI)((NI64)((*cell_1).rc) >> (NU64)(((NI)4) & (64 - 1))) == ((NI)0))) goto LA8_;
			result = NIM_TRUE;
		}
		goto LA6_;
LA8_: ;
		{
			(*cell_1).rc = minuspercent___system_u805((*cell_1).rc, ((NI)16));
		}
LA6_: ;
	}
LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___jsgen_u186)(tyObject_TJSGen__eMRdF9b1ev54YKlmk5BuCUA* dest_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastCyclicStatic((*dest_p0).initProc, ((TNimTypeV2*) ((&NTIv2__k9cVsoDH6xQeAkEiVEPoauw_))));
		if (!T3_) goto LA4_;
		eqdestroy___jsgen_u159((&(*(*dest_p0).initProc)));
		nimRawDispose((*dest_p0).initProc, ((NI)8));
	}
LA4_: ;
	eqdestroy___cgendata_u1411((*dest_p0).sigConflicts.data);
	{
		NIM_BOOL T8_;
		T8_ = (NIM_BOOL)0;
		T8_ = nimDecRefIsLastDyn((*dest_p0).config);
		if (!T8_) goto LA9_;
		eqdestroy___options_u1751((&(*(*dest_p0).config)));
		nimRawDispose((*dest_p0).config, ((NI)8));
	}
LA9_: ;
	{
		NIM_BOOL T13_;
		T13_ = (NIM_BOOL)0;
		T13_ = nimDecRefIsLastDyn((*dest_p0).graph);
		if (!T13_) goto LA14_;
		eqdestroy___modulegraphs_u13532((&(*(*dest_p0).graph)));
		nimRawDispose((*dest_p0).graph, ((NI)8));
	}
LA14_: ;
	{
		NIM_BOOL T18_;
		T18_ = (NIM_BOOL)0;
		T18_ = nimDecRefIsLastDyn((*dest_p0).module);
		if (!T18_) goto LA19_;
		eqdestroy___ast_u3469((&(*(*dest_p0).module)));
		nimRawDispose((*dest_p0).module, ((NI)8));
	}
LA19_: ;
	{
		NIM_BOOL T23_;
		T23_ = (NIM_BOOL)0;
		T23_ = nimDecRefIsLast((*dest_p0).Sup.idgen);
		if (!T23_) goto LA24_;
		eqdestroy___ast_u3074((&(*(*dest_p0).Sup.idgen)));
		nimRawDispose((*dest_p0).Sup.idgen, ((NI)8));
	}
LA24_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, rttiDestroy__jsgen_u8422)(void* dest_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqdestroy___jsgen_u186((&(*((tyObject_TJSGen__eMRdF9b1ev54YKlmk5BuCUA*) (dest_p0)))));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqtrace___jsgen_u198)(tyObject_TJSGen__eMRdF9b1ev54YKlmk5BuCUA* dest_p0, void* env_p1) {
	nimTraceRef(&(*dest_p0).initProc, ((TNimTypeV2*) ((&NTIv2__k9cVsoDH6xQeAkEiVEPoauw_))), env_p1);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TJSGen__eMRdF9b1ev54YKlmk5BuCUA*, newModule__jsgen_u8125)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module_p1) {
	tyObject_TJSGen__eMRdF9b1ev54YKlmk5BuCUA* result;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD_;
	tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* colontmpD__2;
	tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* colontmpD__3;
	tyObject_TJSGen__eMRdF9b1ev54YKlmk5BuCUA* T6_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	{
		tyObject_PGlobalscolonObjectType___5ylNBaUZgofS9cIrLp09cbRA* T5_;
		if (!((*g_p0).backend == ((RootObj*) NIM_NIL))) goto LA3_;
		T5_ = NIM_NIL;
		T5_ = newGlobals__jsgen_u497();
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___jsgen_u506(T5_); goto BeforeRet_;}
		eqsink___ast_u4955(&(*g_p0).backend, &T5_->Sup);
	}
LA3_: ;
	T6_ = NIM_NIL;
	T6_ = (tyObject_TJSGen__eMRdF9b1ev54YKlmk5BuCUA*) nimNewObj(sizeof(tyObject_TJSGen__eMRdF9b1ev54YKlmk5BuCUA), NIM_ALIGNOF(tyObject_TJSGen__eMRdF9b1ev54YKlmk5BuCUA));
	(*T6_).Sup.Sup.m_type = (&NTIv2__eMRdF9b1ev54YKlmk5BuCUA_);
	colontmpD_ = eqdup___ast_u4580(module_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*T6_).module = colontmpD_;
	initCountTable__cgen_u30860(((NI)32), (&(*T6_).sigConflicts));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	colontmpD__2 = eqdup___modulegraphs_u14759(g_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*T6_).graph = colontmpD__2;
	colontmpD__3 = eqdup___options_u2141((*g_p0).config);
	(*T6_).config = colontmpD__3;
	result = T6_;
	{
		if (!(((*module_p1).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)15)))&63U)))!=0)) goto LA9_;
		(*(*((tyObject_PGlobalscolonObjectType___5ylNBaUZgofS9cIrLp09cbRA**) (&((*g_p0).backend))))).inSystem = NIM_TRUE;
	}
LA9_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___jsgen_u653)(tyObject_TJSGen__eMRdF9b1ev54YKlmk5BuCUA* dest_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastCyclicDyn(dest_p0);
		if (!T3_) goto LA4_;
		nimDestroyAndDispose(dest_p0);
	}
LA4_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ*, setupJSgen__jsgen_u8358)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p2) {
	tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ* result;
	tyObject_TJSGen__eMRdF9b1ev54YKlmk5BuCUA* T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	T1_ = NIM_NIL;
	T1_ = newModule__jsgen_u8125(graph_p0, s_p1);
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___jsgen_u653(T1_); goto BeforeRet_;}
	result = &T1_->Sup;
	eqcopy___ast_u3103(&(*result).idgen, idgen_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, skipCodegen__pipelineutils_u8)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* config_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
	NIM_BOOL result;
	result = (((NI)0) < (*config_p0).errorCounter);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___jsgen_u139)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* dest_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastCyclicStatic(dest_p0, ((TNimTypeV2*) ((&NTIv2__k9cVsoDH6xQeAkEiVEPoauw_))));
		if (!T3_) goto LA4_;
		eqdestroy___jsgen_u159((&(*dest_p0)));
		nimRawDispose(dest_p0, ((NI)8));
	}
LA4_: ;
}
static N_INLINE(void, nimIncRefCyclic)(void* p_p0, NIM_BOOL cyclic_p1) {
	tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* h_1;
	NI T1_;
	T1_ = (NI)0;
	T1_ = minuspercent___system_u805(((NI) (ptrdiff_t) (p_p0)), ((NI)16));
	h_1 = ((tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A*) (T1_));
	(*h_1).rc = pluspercent___system_u785((*h_1).rc, ((NI)16));
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TJSGen__eMRdF9b1ev54YKlmk5BuCUA*, eqdup___jsgen_u660)(tyObject_TJSGen__eMRdF9b1ev54YKlmk5BuCUA* src_p0, NIM_BOOL cyclic_p1) {
	tyObject_TJSGen__eMRdF9b1ev54YKlmk5BuCUA* result;
	tyObject_TJSGen__eMRdF9b1ev54YKlmk5BuCUA* colontmp_;
	result = NIM_NIL;
	colontmp_ = result;
	result = src_p0;
	{
		if (!src_p0) goto LA3_;
		nimIncRefCyclic(src_p0, cyclic_p1);
	}
LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_PGlobalscolonObjectType___5ylNBaUZgofS9cIrLp09cbRA*, eqdup___jsgen_u513)(tyObject_PGlobalscolonObjectType___5ylNBaUZgofS9cIrLp09cbRA* src_p0, NIM_BOOL cyclic_p1) {
	tyObject_PGlobalscolonObjectType___5ylNBaUZgofS9cIrLp09cbRA* result;
	tyObject_PGlobalscolonObjectType___5ylNBaUZgofS9cIrLp09cbRA* colontmp_;
	result = NIM_NIL;
	colontmp_ = result;
	result = src_p0;
	{
		if (!src_p0) goto LA3_;
		nimIncRefCyclic(src_p0, cyclic_p1);
	}
LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw*, newProc__jsgen_u605)(tyObject_PGlobalscolonObjectType___5ylNBaUZgofS9cIrLp09cbRA* globals_p0, tyObject_TJSGen__eMRdF9b1ev54YKlmk5BuCUA* module_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* procDef_p2, tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ options_p3) {
	tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* result;
	tySequence__bdNIx7Bah2llfuqeoTJEWQ colontmpD_;
	tySequence__bdNIx7Bah2llfuqeoTJEWQ colontmpD__2;
	tyObject_TJSGen__eMRdF9b1ev54YKlmk5BuCUA* colontmpD__3;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__4;
	tyObject_PGlobalscolonObjectType___5ylNBaUZgofS9cIrLp09cbRA* colontmpD__5;
	tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	T1_ = NIM_NIL;
	T1_ = (tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw*) nimNewObj(sizeof(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw), NIM_ALIGNOF(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw));
	(*T1_).blocks.len = 0; (*T1_).blocks.p = (tySequence__P9aymq2R2Xa8At0XKJ6Bh1A_Content*) newSeqPayload(0, sizeof(tyObject_TBlock__e4aohBvIZbqlrYGhrE9cgpw), NIM_ALIGNOF(tyObject_TBlock__e4aohBvIZbqlrYGhrE9cgpw));
	{
		tySequence__bdNIx7Bah2llfuqeoTJEWQ blitTmp_1;
		if (!!(((*module_p1).initProc == ((tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw*) NIM_NIL)))) goto LA4_;
		eqcopy___cgendata_u1268((&colontmpD_), (*(*module_p1).initProc).optionsStack);
		blitTmp_1 = colontmpD_;
		eqwasMoved___cgendata_u1262((&colontmpD_));
		(*T1_).optionsStack = blitTmp_1;
	}
	goto LA2_;
LA4_: ;
	{
		tySequence__bdNIx7Bah2llfuqeoTJEWQ blitTmp_2;
		colontmpD__2.len = 0; colontmpD__2.p = (tySequence__bdNIx7Bah2llfuqeoTJEWQ_Content*) newSeqPayload(0, sizeof(tyTuple__kIcKc1aSJCixG4QCidyBAg), NIM_ALIGNOF(tyTuple__kIcKc1aSJCixG4QCidyBAg));
		blitTmp_2 = colontmpD__2;
		eqwasMoved___cgendata_u1262((&colontmpD__2));
		(*T1_).optionsStack = blitTmp_2;
	}
LA2_: ;
	(*T1_).options = options_p3;
	colontmpD__3 = eqdup___jsgen_u660(module_p1, NIM_TRUE);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*T1_).module = colontmpD__3;
	colontmpD__4 = eqdup___ast_u3258(procDef_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*T1_).procDef = colontmpD__4;
	colontmpD__5 = eqdup___jsgen_u513(globals_p0, NIM_TRUE);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*T1_).g = colontmpD__5;
	(*T1_).extraIndent = ((NI) (!((procDef_p2 == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL)))));
	result = T1_;
	{
		if (!!((procDef_p2 == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL)))) goto LA9_;
		eqcopy___ast_u4577(&(*result).prc, (*(*procDef_p2)._kind_6.sons.p->data[((NI)0)])._kind_4.sym);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA9_: ;
	eqdestroy___cgendata_u1265(colontmpD__2);
	eqdestroy___cgendata_u1265(colontmpD_);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ, initProcOptions__jsgen_u674)(tyObject_TJSGen__eMRdF9b1ev54YKlmk5BuCUA* module_p0) {
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ result;
	result = (*(*module_p0).config).options;
	{
		if (!(*(*((tyObject_PGlobalscolonObjectType___5ylNBaUZgofS9cIrLp09cbRA**) (&((*(*module_p0).graph).backend))))).inSystem) goto LA3_;
		result &= ~(((NU32)1) << (((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)17))) & 31));
	}
LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw*, newInitProc__jsgen_u681)(tyObject_PGlobalscolonObjectType___5ylNBaUZgofS9cIrLp09cbRA* globals_p0, tyObject_TJSGen__eMRdF9b1ev54YKlmk5BuCUA* module_p1) {
	tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* result;
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	T1_ = initProcOptions__jsgen_u674(module_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	result = newProc__jsgen_u605(globals_p0, module_p1, ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL), T1_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___jsgen_u142)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw** dest_p0, tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* src_p1, NIM_BOOL cyclic_p2) {
	tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* colontmp_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmp_ = (*dest_p0);
	{
		if (!src_p1) goto LA3_;
		nimIncRefCyclic(src_p1, cyclic_p2);
	}
LA3_: ;
	(*dest_p0) = src_p1;
	{
		NIM_BOOL T7_;
		T7_ = (NIM_BOOL)0;
		T7_ = nimDecRefIsLastCyclicStatic(colontmp_, ((TNimTypeV2*) ((&NTIv2__k9cVsoDH6xQeAkEiVEPoauw_))));
		if (!T7_) goto LA8_;
		eqdestroy___jsgen_u159((&(*colontmp_)));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		nimRawDispose(colontmp_, ((NI)8));
	}
LA8_: ;
	}BeforeRet_: ;
}
static N_INLINE(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, owner__ast_u6254)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p0) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	eqcopy___ast_u4577(&result, (*s_p0).ownerField);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(void, nimCopyMem)(void* dest_p0, void* source_p1, NI size_p2) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest_p0, source_p1, ((size_t) (size_p2)));
}
static N_INLINE(void, copyMem__system_u1742)(void* dest_p0, void* source_p1, NI size_p2) {
	nimCopyMem(dest_p0, source_p1, size_p2);
}
static N_INLINE(void, appendString)(NimStringV2* dest_p0, NimStringV2 src_p1) {
	{
		if (!(((NI)0) < src_p1.len)) goto LA3_;
		copyMem__system_u1742(((void*) ((&(*(*dest_p0).p).data[(*dest_p0).len]))), ((void*) ((&(*src_p1.p).data[((NI)0)]))), (src_p1.len));
		(*dest_p0).len += src_p1.len;
		(*(*dest_p0).p).data[(*dest_p0).len] = 0;
	}
LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, indentLine__jsgen_u102)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, NimStringV2 r_p1) {
	NimStringV2 result;
	tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_2;
NIM_BOOL oldNimErrFin9_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	p_2 = NIM_NIL;
	eqcopy___jsgen_u142(&p_2, p_p0, NIM_FALSE);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NimStringV2 colontmpD_;
		NI ind_1;
		NimStringV2 T19_;
		if (!(((*(*(*p_2).module).config).legacyFeatures &((NU8)1<<((NU)((((tyEnum_LegacyFeature__yvNVqOQTgcxHpvo1MvfBfA)5)))&7U)))!=0)) goto LA4_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		ind_1 = ((NI)0);
		{
			while (1) {
				tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD__2;
				NI T10_;
				colontmpD__2 = NIM_NIL;
				T10_ = (*p_2).blocks.len;
				ind_1 += (NI)(T10_ + (*p_2).extraIndent);
				{
					NIM_BOOL T13_;
					T13_ = (NIM_BOOL)0;
					T13_ = ((*p_2).up == ((tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw*) NIM_NIL));
					if (T13_) goto LA14_;
					colontmpD__2 = owner__ast_u6254((*p_2).prc);
					if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
					T13_ = !(((*(*p_2).up).prc == colontmpD__2));
LA14_: ;
					if (!T13_) goto LA15_;
					eqdestroy___ast_u4574(colontmpD__2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
					goto LA7;
				}
LA15_: ;
				eqcopy___jsgen_u142(&p_2, (*p_2).up, NIM_FALSE);
				if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
				{
					LA9_:;
				}
				{
					oldNimErrFin9_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u4574(colontmpD__2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
					*nimErr_ = oldNimErrFin9_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
			}
		} LA7: ;
		T19_.len = 0; T19_.p = NIM_NIL;
		colontmpD_ = nsuRepeatChar(32, ((NI)(ind_1 * ((NI)2))));
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		T19_ = rawNewString(colontmpD_.len + r_p1.len + 0);
appendString((&T19_), colontmpD_);
appendString((&T19_), r_p1);
		result = T19_;
		{
			LA6_:;
		}
		{
			eqdestroy___system_u2691(colontmpD_);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA2_;
LA4_: ;
	{
		NimStringV2 colontmpD__3;
		NI ind_2;
		NI T23_;
		NimStringV2 T24_;
		colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
		T23_ = (*p_2).blocks.len;
		ind_2 = (NI)(T23_ + (*p_2).extraIndent);
		T24_.len = 0; T24_.p = NIM_NIL;
		colontmpD__3 = nsuRepeatChar(32, ((NI)(ind_2 * ((NI)2))));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T24_ = rawNewString(colontmpD__3.len + r_p1.len + 0);
appendString((&T24_), colontmpD__3);
appendString((&T24_), r_p1);
		result = T24_;
		eqdestroy___system_u2691(colontmpD__3);
	}
LA2_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___jsgen_u139(p_2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, frameCreate__jsgen_u7273)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, NimStringV2 procname_p1, NimStringV2 filename_p2) {
	NimStringV2 result;
	NimStringV2 colontmpD_;
	NimStringV2 colontmpD__2;
	NimStringV2 colontmpD__3;
	tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T1_;
	tyArray__TonP9cxJgj8gXu71dWIyNlA T2_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
	T1_[0] = procname_p1;
	T1_[1] = filename_p2;
	colontmpD_ = percent___jsgen_u7279(T1_, 2);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	result = indentLine__jsgen_u102(p_p0, colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	colontmpD__2 = percent___jsgen_u7284(T2_, 0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	colontmpD__3 = indentLine__jsgen_u102(p_p0, colontmpD__2);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	prepareAdd((&result), colontmpD__3.len + 0);
appendString((&result), colontmpD__3);
	eqdestroy___system_u2691(colontmpD__3);
	eqdestroy___system_u2691(colontmpD__2);
	eqdestroy___system_u2691(colontmpD_);
	}BeforeRet_: ;
	return result;
}
static N_INLINE(void, nimAddCharV1)(NimStringV2* s_p0, NIM_CHAR c_p1) {
	prepareAdd(s_p0, ((NI)1));
	(*(*s_p0).p).data[(*s_p0).len] = c_p1;
	(*s_p0).len += ((NI)1);
	(*(*s_p0).p).data[(*s_p0).len] = 0;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, escapeJSString__jsgen_u798)(NimStringV2 s_p0) {
	NimStringV2 result;
	result.len = 0; result.p = NIM_NIL;
	result = rawNewString(((NI)(s_p0.len + (NI)((NI64)(s_p0.len) >> (NU64)(((NI)2) & (64 - 1))))));
	prepareAdd((&result), 1);
appendString((&result), TM__BxLwT0mhrtgTPodf1v3xjg_12);
	{
		NIM_CHAR c_1;
		NI i_1;
		NI L_1;
		c_1 = (NIM_CHAR)0;
		i_1 = ((NI)0);
		L_1 = s_p0.len;
		{
			while (1) {
				if (!(i_1 < L_1)) goto LA3;
				c_1 = s_p0.p->data[i_1];
				switch (((NU8)(c_1))) {
				case 10:
				{
					prepareAdd((&result), 2);
appendString((&result), TM__BxLwT0mhrtgTPodf1v3xjg_14);
				}
				break;
				case 13:
				{
					prepareAdd((&result), 2);
appendString((&result), TM__BxLwT0mhrtgTPodf1v3xjg_16);
				}
				break;
				case 9:
				{
					prepareAdd((&result), 2);
appendString((&result), TM__BxLwT0mhrtgTPodf1v3xjg_18);
				}
				break;
				case 8:
				{
					prepareAdd((&result), 2);
appendString((&result), TM__BxLwT0mhrtgTPodf1v3xjg_20);
				}
				break;
				case 7:
				{
					prepareAdd((&result), 2);
appendString((&result), TM__BxLwT0mhrtgTPodf1v3xjg_22);
				}
				break;
				case 27:
				{
					prepareAdd((&result), 2);
appendString((&result), TM__BxLwT0mhrtgTPodf1v3xjg_24);
				}
				break;
				case 11:
				{
					prepareAdd((&result), 2);
appendString((&result), TM__BxLwT0mhrtgTPodf1v3xjg_26);
				}
				break;
				case 92:
				{
					prepareAdd((&result), 2);
appendString((&result), TM__BxLwT0mhrtgTPodf1v3xjg_28);
				}
				break;
				case 34:
				{
					prepareAdd((&result), 2);
appendString((&result), TM__BxLwT0mhrtgTPodf1v3xjg_30);
				}
				break;
				default:
				{
					nimAddCharV1((&result), c_1);
				}
				break;
				}
				i_1 += ((NI)1);
			} LA3: ;
		}
	}
	prepareAdd((&result), 1);
appendString((&result), TM__BxLwT0mhrtgTPodf1v3xjg_31);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, makeJSString__jsgen_u806)(NimStringV2 s_p0, NIM_BOOL escapeNonAscii_p1) {
	NimStringV2 result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	{
		if (!escapeNonAscii_p1) goto LA3_;
		result = nsuEscape(s_p0, TM__BxLwT0mhrtgTPodf1v3xjg_10, TM__BxLwT0mhrtgTPodf1v3xjg_11);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA3_: ;
	{
		result = escapeJSString__jsgen_u798(s_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI, len__ast_u3190)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0) {
	NI result;
	NI T1_;
	T1_ = (*n_p0)._kind_6.sons.len;
	result = T1_;
	return result;
}
static N_INLINE(NI, safeLen__ast_u3197)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0) {
	NI result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	{
		if (!((*n_p0).kind >= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)0) && (*n_p0).kind <= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)23))) goto LA3_;
		result = ((NI)0);
	}
	goto LA1_;
LA3_: ;
	{
		result = len__ast_u3190(n_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(int, nimCmpMem)(void* a_p0, void* b_p1, NI size_p2) {
	int result;
	result = memcmp(a_p0, b_p1, ((size_t) (size_p2)));
	return result;
}
static N_INLINE(NIM_BOOL, equalMem__system_u1750)(void* a_p0, void* b_p1, NI size_p2) {
	NIM_BOOL result;
	int T1_;
	T1_ = (int)0;
	T1_ = nimCmpMem(a_p0, b_p1, size_p2);
	result = (T1_ == ((NI32)0));
	return result;
}
static N_INLINE(NIM_BOOL, eqStrings)(NimStringV2 a_p0, NimStringV2 b_p1) {
	NIM_BOOL result;
	NI alen_1;
	NI blen_1;
{	result = NIM_FALSE;
	alen_1 = a_p0.len;
	blen_1 = b_p1.len;
	{
		if (!(alen_1 == blen_1)) goto LA3_;
		{
			if (!(alen_1 == ((NI)0))) goto LA7_;
			result = NIM_TRUE;
			goto BeforeRet_;
		}
LA7_: ;
		result = equalMem__system_u1750(((void*) ((&a_p0.p->data[((NI)0)]))), ((void*) ((&b_p1.p->data[((NI)0)]))), (alen_1));
		goto BeforeRet_;
	}
LA3_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, validJsName__jsgen_u706)(NimStringV2 name_p0) {
	NIM_BOOL result;
{	result = NIM_TRUE;
	switch (hashString(name_p0) & 63) {
	case 0: 
if (eqStrings(name_p0, TM__BxLwT0mhrtgTPodf1v3xjg_106)) goto LA1_;
break;
	case 1: 
if (eqStrings(name_p0, TM__BxLwT0mhrtgTPodf1v3xjg_122)) goto LA1_;
if (eqStrings(name_p0, TM__BxLwT0mhrtgTPodf1v3xjg_162)) goto LA1_;
break;
	case 3: 
if (eqStrings(name_p0, TM__BxLwT0mhrtgTPodf1v3xjg_146)) goto LA1_;
if (eqStrings(name_p0, TM__BxLwT0mhrtgTPodf1v3xjg_154)) goto LA1_;
break;
	case 4: 
if (eqStrings(name_p0, TM__BxLwT0mhrtgTPodf1v3xjg_100)) goto LA1_;
if (eqStrings(name_p0, TM__BxLwT0mhrtgTPodf1v3xjg_126)) goto LA1_;
break;
	case 7: 
if (eqStrings(name_p0, TM__BxLwT0mhrtgTPodf1v3xjg_48)) goto LA1_;
if (eqStrings(name_p0, TM__BxLwT0mhrtgTPodf1v3xjg_98)) goto LA1_;
break;
	case 8: 
if (eqStrings(name_p0, TM__BxLwT0mhrtgTPodf1v3xjg_132)) goto LA1_;
break;
	case 10: 
if (eqStrings(name_p0, TM__BxLwT0mhrtgTPodf1v3xjg_112)) goto LA1_;
break;
	case 11: 
if (eqStrings(name_p0, TM__BxLwT0mhrtgTPodf1v3xjg_104)) goto LA1_;
break;
	case 13: 
if (eqStrings(name_p0, TM__BxLwT0mhrtgTPodf1v3xjg_118)) goto LA1_;
break;
	case 15: 
if (eqStrings(name_p0, TM__BxLwT0mhrtgTPodf1v3xjg_50)) goto LA1_;
if (eqStrings(name_p0, TM__BxLwT0mhrtgTPodf1v3xjg_142)) goto LA1_;
break;
	case 17: 
if (eqStrings(name_p0, TM__BxLwT0mhrtgTPodf1v3xjg_140)) goto LA1_;
break;
	case 19: 
if (eqStrings(name_p0, TM__BxLwT0mhrtgTPodf1v3xjg_92)) goto LA1_;
break;
	case 20: 
if (eqStrings(name_p0, TM__BxLwT0mhrtgTPodf1v3xjg_68)) goto LA1_;
if (eqStrings(name_p0, TM__BxLwT0mhrtgTPodf1v3xjg_116)) goto LA1_;
if (eqStrings(name_p0, TM__BxLwT0mhrtgTPodf1v3xjg_136)) goto LA1_;
break;
	case 21: 
if (eqStrings(name_p0, TM__BxLwT0mhrtgTPodf1v3xjg_64)) goto LA1_;
if (eqStrings(name_p0, TM__BxLwT0mhrtgTPodf1v3xjg_76)) goto LA1_;
break;
	case 22: 
if (eqStrings(name_p0, TM__BxLwT0mhrtgTPodf1v3xjg_166)) goto LA1_;
break;
	case 23: 
if (eqStrings(name_p0, TM__BxLwT0mhrtgTPodf1v3xjg_70)) goto LA1_;
if (eqStrings(name_p0, TM__BxLwT0mhrtgTPodf1v3xjg_120)) goto LA1_;
break;
	case 24: 
if (eqStrings(name_p0, TM__BxLwT0mhrtgTPodf1v3xjg_138)) goto LA1_;
break;
	case 25: 
if (eqStrings(name_p0, TM__BxLwT0mhrtgTPodf1v3xjg_52)) goto LA1_;
break;
	case 26: 
if (eqStrings(name_p0, TM__BxLwT0mhrtgTPodf1v3xjg_62)) goto LA1_;
if (eqStrings(name_p0, TM__BxLwT0mhrtgTPodf1v3xjg_134)) goto LA1_;
break;
	case 29: 
if (eqStrings(name_p0, TM__BxLwT0mhrtgTPodf1v3xjg_60)) goto LA1_;
break;
	case 30: 
if (eqStrings(name_p0, TM__BxLwT0mhrtgTPodf1v3xjg_164)) goto LA1_;
break;
	case 34: 
if (eqStrings(name_p0, TM__BxLwT0mhrtgTPodf1v3xjg_108)) goto LA1_;
if (eqStrings(name_p0, TM__BxLwT0mhrtgTPodf1v3xjg_124)) goto LA1_;
break;
	case 36: 
if (eqStrings(name_p0, TM__BxLwT0mhrtgTPodf1v3xjg_72)) goto LA1_;
break;
	case 37: 
if (eqStrings(name_p0, TM__BxLwT0mhrtgTPodf1v3xjg_128)) goto LA1_;
if (eqStrings(name_p0, TM__BxLwT0mhrtgTPodf1v3xjg_150)) goto LA1_;
if (eqStrings(name_p0, TM__BxLwT0mhrtgTPodf1v3xjg_158)) goto LA1_;
break;
	case 38: 
if (eqStrings(name_p0, TM__BxLwT0mhrtgTPodf1v3xjg_54)) goto LA1_;
break;
	case 40: 
if (eqStrings(name_p0, TM__BxLwT0mhrtgTPodf1v3xjg_148)) goto LA1_;
break;
	case 42: 
if (eqStrings(name_p0, TM__BxLwT0mhrtgTPodf1v3xjg_84)) goto LA1_;
break;
	case 44: 
if (eqStrings(name_p0, TM__BxLwT0mhrtgTPodf1v3xjg_78)) goto LA1_;
if (eqStrings(name_p0, TM__BxLwT0mhrtgTPodf1v3xjg_102)) goto LA1_;
if (eqStrings(name_p0, TM__BxLwT0mhrtgTPodf1v3xjg_114)) goto LA1_;
if (eqStrings(name_p0, TM__BxLwT0mhrtgTPodf1v3xjg_130)) goto LA1_;
if (eqStrings(name_p0, TM__BxLwT0mhrtgTPodf1v3xjg_156)) goto LA1_;
break;
	case 45: 
if (eqStrings(name_p0, TM__BxLwT0mhrtgTPodf1v3xjg_96)) goto LA1_;
break;
	case 47: 
if (eqStrings(name_p0, TM__BxLwT0mhrtgTPodf1v3xjg_66)) goto LA1_;
break;
	case 48: 
if (eqStrings(name_p0, TM__BxLwT0mhrtgTPodf1v3xjg_94)) goto LA1_;
if (eqStrings(name_p0, TM__BxLwT0mhrtgTPodf1v3xjg_160)) goto LA1_;
break;
	case 49: 
if (eqStrings(name_p0, TM__BxLwT0mhrtgTPodf1v3xjg_82)) goto LA1_;
if (eqStrings(name_p0, TM__BxLwT0mhrtgTPodf1v3xjg_90)) goto LA1_;
break;
	case 50: 
if (eqStrings(name_p0, TM__BxLwT0mhrtgTPodf1v3xjg_86)) goto LA1_;
break;
	case 54: 
if (eqStrings(name_p0, TM__BxLwT0mhrtgTPodf1v3xjg_110)) goto LA1_;
break;
	case 55: 
if (eqStrings(name_p0, TM__BxLwT0mhrtgTPodf1v3xjg_44)) goto LA1_;
break;
	case 56: 
if (eqStrings(name_p0, TM__BxLwT0mhrtgTPodf1v3xjg_88)) goto LA1_;
break;
	case 57: 
if (eqStrings(name_p0, TM__BxLwT0mhrtgTPodf1v3xjg_144)) goto LA1_;
break;
	case 59: 
if (eqStrings(name_p0, TM__BxLwT0mhrtgTPodf1v3xjg_58)) goto LA1_;
if (eqStrings(name_p0, TM__BxLwT0mhrtgTPodf1v3xjg_152)) goto LA1_;
break;
	case 61: 
if (eqStrings(name_p0, TM__BxLwT0mhrtgTPodf1v3xjg_46)) goto LA1_;
if (eqStrings(name_p0, TM__BxLwT0mhrtgTPodf1v3xjg_74)) goto LA1_;
if (eqStrings(name_p0, TM__BxLwT0mhrtgTPodf1v3xjg_80)) goto LA1_;
break;
	case 62: 
if (eqStrings(name_p0, TM__BxLwT0mhrtgTPodf1v3xjg_56)) goto LA1_;
break;
	}
	goto LA2_;
	LA1_: ;
	{
		result = NIM_FALSE;
		goto BeforeRet_;
	}
	goto LA3_;
	LA2_: ;
	{
	}
LA3_: ;
	{
		if (!(((NU8)(name_p0.p->data[((NI)0)])) >= ((NU8)(48)) && ((NU8)(name_p0.p->data[((NI)0)])) <= ((NU8)(57)))) goto LA8_;
		result = NIM_FALSE;
		goto BeforeRet_;
	}
LA8_: ;
	{
		NIM_CHAR chr_1;
		NI i_1;
		NI L_1;
		chr_1 = (NIM_CHAR)0;
		i_1 = ((NI)0);
		L_1 = name_p0.len;
		{
			while (1) {
				if (!(i_1 < L_1)) goto LA12;
				chr_1 = name_p0.p->data[i_1];
				{
					if (!!((((NU8)(chr_1)) >= ((NU8)(65)) && ((NU8)(chr_1)) <= ((NU8)(90)) || ((NU8)(chr_1)) >= ((NU8)(97)) && ((NU8)(chr_1)) <= ((NU8)(122)) || ((NU8)(chr_1)) == ((NU8)(95)) || ((NU8)(chr_1)) == ((NU8)(36)) || ((NU8)(chr_1)) >= ((NU8)(48)) && ((NU8)(chr_1)) <= ((NU8)(57))))) goto LA15_;
					result = NIM_FALSE;
					goto BeforeRet_;
				}
LA15_: ;
				i_1 += ((NI)1);
			} LA12: ;
		}
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, mangleName__jsgen_u702)(tyObject_TJSGen__eMRdF9b1ev54YKlmk5BuCUA* m_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1) {
	NimStringV2 result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	eqcopy___system_u2694((&result), (*s_p1).loc.snippet);
	{
		if (!(result.len == 0)) goto LA3_;
		{
			NIM_BOOL T7_;
			T7_ = (NIM_BOOL)0;
			T7_ = ((*s_p1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)19));
			if (!(T7_)) goto LA8_;
			T7_ = validJsName__jsgen_u706((*(*s_p1).name).s);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
LA8_: ;
			if (!T7_) goto LA9_;
			eqcopy___system_u2694((&result), (*(*s_p1).name).s);
		}
		goto LA5_;
LA9_: ;
		{
			NimStringV2 T14_;
			if (!((*s_p1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)5))) goto LA12_;
			T14_.len = 0; T14_.p = NIM_NIL;
			T14_ = mangle__mangleutils_u4((*(*s_p1).name).s);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T14_); goto BeforeRet_;}
			eqsink___system_u2700((&result), T14_);
		}
		goto LA5_;
LA12_: ;
		{
			NimStringV2 x_1;
			NI i_1;
			x_1.len = 0; x_1.p = NIM_NIL;
			x_1 = rawNewString(((*(*s_p1).name).s.len));
			i_1 = ((NI)0);
			{
				while (1) {
					NIM_CHAR c_1;
					if (!(i_1 < (*(*s_p1).name).s.len)) goto LA17;
					c_1 = (*(*s_p1).name).s.p->data[i_1];
					switch (((NU8)(c_1))) {
					case 65 ... 90:
					case 97 ... 122:
					case 95:
					case 48 ... 57:
					{
						nimAddCharV1((&x_1), c_1);
					}
					break;
					default:
					{
						NimStringV2 colontmpD_;
						NimStringV2 colontmpD__2;
						NimStringV2 T20_;
						colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
						colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
						T20_.len = 0; T20_.p = NIM_NIL;
						colontmpD_ = toHex__pureZstrutils_u2114(((NU8)(c_1)), ((NI)2));
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						T20_ = rawNewString(colontmpD_.len + 3);
appendString((&T20_), TM__BxLwT0mhrtgTPodf1v3xjg_168);
appendString((&T20_), colontmpD_);
						colontmpD__2 = T20_;
						prepareAdd((&x_1), colontmpD__2.len + 0);
appendString((&x_1), colontmpD__2);
						eqdestroy___system_u2691(colontmpD__2);
						eqdestroy___system_u2691(colontmpD_);
					}
					break;
					}
					i_1 += ((NI)1);
				} LA17: ;
			}
			eqsink___system_u2700((&result), x_1);
		}
LA5_: ;
		{
			if (!!(((*s_p1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)19)))) goto LA23_;
			{
				NIM_BOOL T27_;
				NimStringV2 colontmpD__3;
				NimStringV2 T31_;
				T27_ = (NIM_BOOL)0;
				T27_ = hcrOn__options_u629((*m_p0).config);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				if (!T27_) goto LA28_;
				colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
				T31_.len = 0; T31_.p = NIM_NIL;
				T31_ = (*(*(*m_p0).module).name).s;
				colontmpD__3 = idOrSig__sighashes_u2002(s_p1, T31_, (&(*m_p0).sigConflicts), (*m_p0).config);
				if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
				prepareAdd((&result), colontmpD__3.len + 0);
appendString((&result), colontmpD__3);
				{
					LA30_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__3);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			}
			goto LA25_;
LA28_: ;
			{
				NimStringV2 colontmpD__4;
				if (!((*s_p1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)3))) goto LA35_;
				colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
				colontmpD__4 = mangleParamExt__mangleutils_u32(s_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				prepareAdd((&result), colontmpD__4.len + 0);
appendString((&result), colontmpD__4);
				eqdestroy___system_u2691(colontmpD__4);
			}
			goto LA25_;
LA35_: ;
			{
				NimStringV2 colontmpD__5;
				if (!((*s_p1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)12) || (*s_p1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)13) || (*s_p1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)14) || (*s_p1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)15) || (*s_p1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)16) || (*s_p1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)17) || (*s_p1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)18))) goto LA38_;
				colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
				colontmpD__5 = mangleProcNameExt__mangleutils_u35((*m_p0).graph, s_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				prepareAdd((&result), colontmpD__5.len + 0);
appendString((&result), colontmpD__5);
				eqdestroy___system_u2691(colontmpD__5);
			}
			goto LA25_;
LA38_: ;
			{
				NimStringV2 colontmpD__6;
				tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA xX60gensym18__1;
				colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
				prepareAdd((&result), 1);
appendString((&result), TM__BxLwT0mhrtgTPodf1v3xjg_170);
				xX60gensym18__1 = (*s_p1).itemId;
				colontmpD__6 = rope__ropes_u15(((NI64) ((NI)((NI)((NU64)(((NI) (xX60gensym18__1.module))) << (NU64)(((NI)24) & (64 - 1))) + ((NI) (xX60gensym18__1.item))))));
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				prepareAdd((&result), colontmpD__6.len + 0);
appendString((&result), colontmpD__6);
				eqdestroy___system_u2691(colontmpD__6);
			}
LA25_: ;
		}
LA23_: ;
		eqcopy___system_u2694((&(*s_p1).loc.snippet), result);
	}
LA3_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg**, X5BX5D___ast_u5281)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg** s_p0, NI s_p0Len_0, NI i_p1) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg** result;
	result = &s_p0[(NI)(s_p0Len_0 - i_p1)];
	return result;
}
static N_INLINE(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, elementType__ast_u5331)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* n_p0) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* result;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg** T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	T1_ = (tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg**)0;
	T1_ = X5BX5D___ast_u5281((((*n_p0).sons).p) ? ((*n_p0).sons.p->data) : NIM_NIL, (*n_p0).sons.len, ((NI)1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqcopy___ast_u3381(&result, (*T1_));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, skipModifier__ast_u5338)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* n_p0) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* result;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg** T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	T1_ = (tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg**)0;
	T1_ = X5BX5D___ast_u5281((((*n_p0).sons).p) ? ((*n_p0).sons.p->data) : NIM_NIL, (*n_p0).sons.len, ((NI)1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqcopy___ast_u3381(&result, (*T1_));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg, mapType__jsgen_u686)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p0) {
	tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg result;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)0;
	t_1 = NIM_NIL;
	t_1 = skipTypes__ast_u5379(typ_p0, TM__BxLwT0mhrtgTPodf1v3xjg_175);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	switch ((*t_1).kind) {
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)23):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)22):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)21):
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__2;
		colontmpD_ = NIM_NIL;
		colontmpD__2 = NIM_NIL;
		{
			colontmpD_ = elementType__ast_u5331(t_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			colontmpD__2 = skipTypes__ast_u5379(colontmpD_, TM__BxLwT0mhrtgTPodf1v3xjg_175);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!((*colontmpD__2).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)17) || (*colontmpD__2).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)16) || (*colontmpD__2).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)18) || (*colontmpD__2).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)27) || (*colontmpD__2).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)19) || (*colontmpD__2).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)48))) goto LA4_;
			result = ((tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)8);
		}
		goto LA2_;
LA4_: ;
		{
			result = ((tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)9);
		}
LA2_: ;
		eqdestroy___ast_u3378(colontmpD__2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)26):
	{
		result = ((tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)9);
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)20):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)13):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)15):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)50):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)47):
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__3;
		colontmpD__3 = NIM_NIL;
		colontmpD__3 = skipModifier__ast_u5338(t_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		result = mapType__jsgen_u686(colontmpD__3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(colontmpD__3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)31) ... ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)35):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)40) ... ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)44):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)14):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)2):
	{
		result = ((tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)5);
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)1):
	{
		result = ((tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)3);
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)36) ... ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)39):
	{
		result = ((tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)6);
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)19):
	{
		result = ((tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)8);
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)28):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)24):
	{
		result = ((tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)4);
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)17):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)16):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)18):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)27):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)48):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)49):
	{
		result = ((tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)8);
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)5):
	{
		result = ((tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)1);
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)12):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)10):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)9):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)0):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)61):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)30):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)3):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)6):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)7):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)8):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)51):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)54):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)56):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)57):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)58):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)59):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)63):
	{
		result = ((tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)0);
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)11):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)55):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)4):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)52):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)53):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)46):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)45):
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__4;
		colontmpD__4 = NIM_NIL;
		colontmpD__4 = skipModifier__ast_u5338(typ_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		result = mapType__jsgen_u686(colontmpD__4);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(colontmpD__4);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)60):
	{
		{
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__5;
			if (!!(((*t_1).n == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL)))) goto LA21_;
			colontmpD__5 = NIM_NIL;
			colontmpD__5 = skipModifier__ast_u5338(t_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			result = mapType__jsgen_u686(colontmpD__5);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			eqdestroy___ast_u3378(colontmpD__5);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		goto LA19_;
LA21_: ;
		{
			result = ((tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)0);
		}
LA19_: ;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)25):
	{
		result = ((tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)2);
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)29):
	{
		result = ((tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)7);
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)62):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)64):
	{
		raiseAssert__stdZassertions_u15(TM__BxLwT0mhrtgTPodf1v3xjg_177);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	default: __builtin_unreachable();
	}
	eqdestroy___ast_u3378(t_1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg, mapType__jsgen_u698)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p1) {
	tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)0;
	result = mapType__jsgen_u686(typ_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, putToSeq__jsgen_u4639)(NimStringV2 s_p0, NIM_BOOL indirect_p1) {
	NimStringV2 result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	eqcopy___system_u2694((&result), s_p0);
	{
		tyArray__YgExxhfgKcesA5EOUj1MOA T5_;
		NimStringV2 T6_;
		if (!indirect_p1) goto LA3_;
		T5_[0] = result;
		T6_.len = 0; T6_.p = NIM_NIL;
		T6_ = percent___jsgen_u4643(T5_, 1);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T6_); goto BeforeRet_;}
		eqsink___system_u2700((&result), T6_);
	}
LA3_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, arrayTypeForElemType__jsgen_u4808)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p1) {
	NimStringV2 result;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_2;
	NimStringV2 T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	typ_2 = NIM_NIL;
	typ_2 = skipTypes__ast_u5379(typ_p1, TM__BxLwT0mhrtgTPodf1v3xjg_196);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_.len = 0; T1_.p = NIM_NIL;
	switch ((*typ_2).kind) {
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)31):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)34):
	{
		result = TM__BxLwT0mhrtgTPodf1v3xjg_198;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)33):
	{
		result = TM__BxLwT0mhrtgTPodf1v3xjg_200;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)32):
	{
		result = TM__BxLwT0mhrtgTPodf1v3xjg_202;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)35):
	{
		NimStringV2 T6_;
		T6_.len = 0; T6_.p = NIM_NIL;
		{
			if (!(((*conf_p0).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)56)))&63U)))!=0)) goto LA9_;
			result = TM__BxLwT0mhrtgTPodf1v3xjg_204;
		}
		goto LA7_;
LA9_: ;
		{
			result = TM__BxLwT0mhrtgTPodf1v3xjg_205;
		}
LA7_: ;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)40):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)43):
	{
		result = TM__BxLwT0mhrtgTPodf1v3xjg_207;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)42):
	{
		result = TM__BxLwT0mhrtgTPodf1v3xjg_209;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)41):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)2):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)1):
	{
		result = TM__BxLwT0mhrtgTPodf1v3xjg_211;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)44):
	{
		NimStringV2 T16_;
		T16_.len = 0; T16_.p = NIM_NIL;
		{
			if (!(((*conf_p0).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)56)))&63U)))!=0)) goto LA19_;
			result = TM__BxLwT0mhrtgTPodf1v3xjg_213;
		}
		goto LA17_;
LA19_: ;
		{
			result = TM__BxLwT0mhrtgTPodf1v3xjg_214;
		}
LA17_: ;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)37):
	{
		result = TM__BxLwT0mhrtgTPodf1v3xjg_216;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)38):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)36):
	{
		result = TM__BxLwT0mhrtgTPodf1v3xjg_218;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)14):
	{
		NimStringV2 T25_;
		T25_.len = 0; T25_.p = NIM_NIL;
		switch ((*typ_2).size) {
		case IL64(1):
		{
			result = TM__BxLwT0mhrtgTPodf1v3xjg_219;
		}
		break;
		case IL64(2):
		{
			result = TM__BxLwT0mhrtgTPodf1v3xjg_220;
		}
		break;
		case IL64(4):
		{
			result = TM__BxLwT0mhrtgTPodf1v3xjg_221;
		}
		break;
		default:
		{
			result = TM__BxLwT0mhrtgTPodf1v3xjg_222;
		}
		break;
		}
	}
	break;
	default:
	{
		result = TM__BxLwT0mhrtgTPodf1v3xjg_223;
	}
	break;
	}
	eqdestroy___ast_u3378(typ_2);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(void, addInt__stdZprivateZdigitsutils_u204)(NimStringV2* result_p0, NI x_p1) {
	addInt__stdZprivateZdigitsutils_u187(result_p0, ((NI64) (x_p1)));
}
static N_INLINE(NimStringV2, toFileLineCol__msgs_u701)(tyTuple__kN8up2W6YKc5YA9avn5mV5w* info_p0) {
	NimStringV2 result;
	result = TM__BxLwT0mhrtgTPodf1v3xjg_224;
	prepareAdd((&result), (*info_p0).Field0.len + 0);
appendString((&result), (*info_p0).Field0);
	{
		if (!(((NI)0) < (*info_p0).Field1)) goto LA3_;
		prepareAdd((&result), 1);
appendString((&result), TM__BxLwT0mhrtgTPodf1v3xjg_226);
		addInt__stdZprivateZdigitsutils_u204((&result), (*info_p0).Field1);
		{
			if (!(((NI)0) < (NI)((*info_p0).Field2 + ((NI)1)))) goto LA7_;
			prepareAdd((&result), 2);
appendString((&result), TM__BxLwT0mhrtgTPodf1v3xjg_228);
			addInt__stdZprivateZdigitsutils_u204((&result), (NI)((*info_p0).Field2 + ((NI)1)));
		}
LA7_: ;
		prepareAdd((&result), 1);
appendString((&result), TM__BxLwT0mhrtgTPodf1v3xjg_230);
	}
LA3_: ;
	return result;
}
static N_INLINE(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ**, X5BX5D___ast_u5211)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** s_p0, NI s_p0Len_0, NI i_p1) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** result;
	result = &s_p0[(NI)(s_p0Len_0 - i_p1)];
	return result;
}
static N_INLINE(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, lastSon__ast_u5208)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	T1_ = (tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ**)0;
	T1_ = X5BX5D___ast_u5211((((*n_p0)._kind_6.sons).p) ? ((*n_p0)._kind_6.sons.p->data) : NIM_NIL, (*n_p0)._kind_6.sons.len, ((NI)1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqcopy___ast_u3255(&result, (*T1_));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, isCompileTimeOnly__types_u3655)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p0) {
	NIM_BOOL result;
	result = ((*t_p0).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)8) || (*t_p0).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)60) || (*t_p0).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)12));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, generateHeader__jsgen_u3304)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* prc_p1) {
	NimStringV2 result;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_1;
NIM_BOOL oldNimErrFin14_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	typ_1 = NIM_NIL;
	result = TM__BxLwT0mhrtgTPodf1v3xjg_235;
	eqcopy___ast_u3381(&typ_1, (*prc_p1).typ);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		if (!!((((*(*(*p_p0).module).config).legacyFeatures &((NU8)1<<((NU)((((tyEnum_LegacyFeature__yvNVqOQTgcxHpvo1MvfBfA)5)))&7U)))!=0))) goto LA4_;
		{
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* env_1;
			if (!((*typ_1).callConv == ((tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ)9))) goto LA8_;
			env_1 = NIM_NIL;
			env_1 = lastSon__ast_u5208((*(*prc_p1).ast)._kind_6.sons.p->data[((NI)3)]);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqsink___system_u2700((&(*(*env_1)._kind_4.sym).loc.snippet), TM__BxLwT0mhrtgTPodf1v3xjg_236);
			eqdestroy___ast_u3252(env_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA8_: ;
	}
LA4_: ;
	{
		NI i_1;
		NI colontmp_;
		NI i_2;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_u3190((*typ_1).n);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		i_2 = ((NI)1);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA12;
				i_1 = i_2;
				{
					tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* param_1;
					NimStringV2 name_1;
					param_1 = NIM_NIL;
					name_1.len = 0; name_1.p = NIM_NIL;
					eqcopy___ast_u4577(&param_1, (*(*(*typ_1).n)._kind_6.sons.p->data[i_1])._kind_4.sym);
					if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
					{
						NIM_BOOL T17_;
						T17_ = (NIM_BOOL)0;
						T17_ = isCompileTimeOnly__types_u3655((*param_1).typ);
						if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
						if (!T17_) goto LA18_;
						eqdestroy___system_u2691(name_1);
						eqdestroy___ast_u4574(param_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						goto LA13;
					}
LA18_: ;
					{
						if (!!((result.len == 0))) goto LA22_;
						prepareAdd((&result), 2);
appendString((&result), TM__BxLwT0mhrtgTPodf1v3xjg_237);
					}
LA22_: ;
					name_1 = mangleName__jsgen_u702((*p_p0).module, param_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
					prepareAdd((&result), name_1.len + 0);
appendString((&result), name_1);
					{
						tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg T26_;
						T26_ = (tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)0;
						T26_ = mapType__jsgen_u686((*param_1).typ);
						if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
						if (!(T26_ == ((tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)9))) goto LA27_;
						prepareAdd((&result), 2);
appendString((&result), TM__BxLwT0mhrtgTPodf1v3xjg_238);
						prepareAdd((&result), name_1.len + 0);
appendString((&result), name_1);
						prepareAdd((&result), 4);
appendString((&result), TM__BxLwT0mhrtgTPodf1v3xjg_240);
					}
LA27_: ;
					{
						LA14_:;
					}
					{
						oldNimErrFin14_ = *nimErr_; *nimErr_ = NIM_FALSE;
						eqdestroy___system_u2691(name_1);
						eqdestroy___ast_u4574(param_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						*nimErr_ = oldNimErrFin14_;
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				} LA13: ;
				i_2 += ((NI)1);
			} LA12: ;
		}
	}
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(typ_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, returnType__ast_u5354)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* n_p0) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	eqcopy___ast_u3381(&result, (*n_p0).sons.p->data[((NI)0)]);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI, toColumn__msgs_u698)(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p0) {
	NI result;
	result = ((NI) (info_p0.col));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, lineDir__jsgen_u2636)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* config_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, NI line_p2) {
	NimStringV2 result;
	NimStringV2 colontmpD_;
	NimStringV2 colontmpD__2;
	NimStringV2 colontmpD__3;
	tyArray__dyW7vpmfeTYw8kX3EXuaJA T1_;
	NI T2_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
	colontmpD_ = toFullPath__msgs_u624(config_p0, info_p1.fileIndex);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_[0] = colontmpD_;
	colontmpD__2 = rope__ropes_u15(((NI64) (line_p2)));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_[1] = colontmpD__2;
	T2_ = (NI)0;
	T2_ = toColumn__msgs_u698(info_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	colontmpD__3 = rope__ropes_u15(((NI64) (T2_)));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_[2] = colontmpD__3;
	result = percent___jsgen_u2641(T1_, 3);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqdestroy___system_u2691(colontmpD__3);
	eqdestroy___system_u2691(colontmpD__2);
	eqdestroy___system_u2691(colontmpD_);
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI, toLinenumber__msgs_u695)(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p0) {
	NI result;
	result = ((NI) (info_p0.line));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, optionalLine__jsgen_u7308)(NimStringV2 p_p0) {
	NimStringV2 result;
{	{
		if (!(p_p0.len == 0)) goto LA3_;
		result = TM__BxLwT0mhrtgTPodf1v3xjg_244;
		goto BeforeRet_;
	}
	goto LA1_;
LA3_: ;
	{
		NimStringV2 T6_;
		T6_.len = 0; T6_.p = NIM_NIL;
		T6_ = rawNewString(p_p0.len + 1);
appendString((&T6_), p_p0);
appendString((&T6_), TM__BxLwT0mhrtgTPodf1v3xjg_246);
		result = T6_;
		goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasFrameInfo__jsgen_u2617)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NIM_BOOL T3_;
	T1_ = (NIM_BOOL)0;
	T1_ = ((655360 & (*p_p0).options) == 655360);
	if (!(T1_)) goto LA2_;
	T3_ = (NIM_BOOL)0;
	T3_ = ((*p_p0).prc == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL));
	if (T3_) goto LA4_;
	T3_ = !((((*(*p_p0).prc).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)11)))&63U)))!=0));
LA4_: ;
	T1_ = T3_;
LA2_: ;
	result = T1_;
	return result;
}
static N_INLINE(void, appendChar)(NimStringV2* dest_p0, NIM_CHAR c_p1) {
	(*(*dest_p0).p).data[(*dest_p0).len] = c_p1;
	(*dest_p0).len += ((NI)1);
	(*(*dest_p0).p).data[(*dest_p0).len] = 0;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, frameDestroy__jsgen_u7289)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0) {
	NimStringV2 result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	result = indentLine__jsgen_u102(p_p0, TM__BxLwT0mhrtgTPodf1v3xjg_253);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, genProcBody__jsgen_u7292)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* prc_p1) {
	NimStringV2 result;
NIM_BOOL oldNimErrFin6_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	{
		NIM_BOOL T3_;
		tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD_;
		NimStringV2 colontmpD__2;
		NimStringV2 colontmpD__3;
		NimStringV2 colontmpD__4;
		NimStringV2 colontmpD__5;
		NimStringV2 T7_;
		T3_ = (NIM_BOOL)0;
		T3_ = hasFrameInfo__jsgen_u2617(p_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!T3_) goto LA4_;
		colontmpD_ = NIM_NIL;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
		colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
		colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
		T7_.len = 0; T7_.p = NIM_NIL;
		colontmpD_ = owner__ast_u6254(prc_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		T7_ = rawNewString((*(*colontmpD_).name).s.len + (*(*prc_p1).name).s.len + 1);
appendString((&T7_), (*(*colontmpD_).name).s);
appendChar((&T7_), 46);
appendString((&T7_), (*(*prc_p1).name).s);
		colontmpD__2 = T7_;
		colontmpD__3 = makeJSString__jsgen_u806(colontmpD__2, NIM_TRUE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		colontmpD__4 = toFilenameOption__msgs_u676((*(*p_p0).module).config, (*prc_p1).info.fileIndex, ((tyEnum_FilenameOption__o3jmnnVs6HdBg5KcNAzYiQ)5));
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		colontmpD__5 = makeJSString__jsgen_u806(colontmpD__4, NIM_TRUE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		result = frameCreate__jsgen_u7273(p_p0, colontmpD__3, colontmpD__5);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		{
			LA6_:;
		}
		{
			oldNimErrFin6_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___system_u2691(colontmpD__5);
			eqdestroy___system_u2691(colontmpD__4);
			eqdestroy___system_u2691(colontmpD__3);
			eqdestroy___system_u2691(colontmpD__2);
			eqdestroy___ast_u4574(colontmpD_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin6_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA4_: ;
	{
		result = TM__BxLwT0mhrtgTPodf1v3xjg_247;
	}
LA1_: ;
	{
		NimStringV2 colontmpD__6;
		NimStringV2 colontmpD__7;
		if (!(*p_p0).beforeRetNeeded) goto LA13_;
		colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
		colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
		colontmpD__6 = indentLine__jsgen_u102(p_p0, TM__BxLwT0mhrtgTPodf1v3xjg_249);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		prepareAdd((&result), colontmpD__6.len + 0);
appendString((&result), colontmpD__6);
		prepareAdd((&result), (*p_p0).body.len + 0);
appendString((&result), (*p_p0).body);
		colontmpD__7 = indentLine__jsgen_u102(p_p0, TM__BxLwT0mhrtgTPodf1v3xjg_251);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		prepareAdd((&result), colontmpD__7.len + 0);
appendString((&result), colontmpD__7);
		eqdestroy___system_u2691(colontmpD__7);
		eqdestroy___system_u2691(colontmpD__6);
	}
	goto LA11_;
LA13_: ;
	{
		prepareAdd((&result), (*p_p0).body.len + 0);
appendString((&result), (*p_p0).body);
	}
LA11_: ;
	{
		tyArray__YgExxhfgKcesA5EOUj1MOA T20_;
		NimStringV2 T21_;
		if (!((*(*prc_p1).typ).callConv == ((tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ)4))) goto LA18_;
		T20_[0] = result;
		T21_.len = 0; T21_.p = NIM_NIL;
		T21_ = percent___jsgen_u7303(T20_, 1);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T21_); goto BeforeRet_;}
		eqsink___system_u2700((&result), T21_);
	}
LA18_: ;
	{
		NIM_BOOL T24_;
		NimStringV2 colontmpD__8;
		T24_ = (NIM_BOOL)0;
		T24_ = hasFrameInfo__jsgen_u2617(p_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!T24_) goto LA25_;
		colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
		colontmpD__8 = frameDestroy__jsgen_u7289(p_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		prepareAdd((&result), colontmpD__8.len + 0);
appendString((&result), colontmpD__8);
		eqdestroy___system_u2691(colontmpD__8);
	}
LA25_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___jsgen_u570)(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* dest_p0) {
	eqdestroy___system_u2691((*dest_p0).tmpLoc);
	eqdestroy___system_u2691((*dest_p0).address);
	eqdestroy___system_u2691((*dest_p0).res);
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, genProc__jsgen_u1166)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* oldProc_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* prc_p1) {
	NimStringV2 result;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* resultSym_1;
	tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ a_1;
	tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_1;
	NimStringV2 returnStmt_1;
	NimStringV2 resultAsgn_1;
	NimStringV2 name_1;
	NimStringV2 header_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* transformedBody_1;
	NimStringV2 def_1;
	NimStringV2 colontmpD__2;
	NimStringV2 colontmpD__3;
NIM_BOOL oldNimErrFin28_;
NIM_BOOL oldNimErrFin8_;
	tySet_tyEnum_TransformFlag__CzUOfRCXpoYcP43GAlt9cnA T51_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	resultSym_1 = NIM_NIL;
	nimZeroMem((void*)(&a_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
	p_1 = NIM_NIL;
	returnStmt_1.len = 0; returnStmt_1.p = NIM_NIL;
	resultAsgn_1.len = 0; resultAsgn_1.p = NIM_NIL;
	name_1.len = 0; name_1.p = NIM_NIL;
	header_1.len = 0; header_1.p = NIM_NIL;
	colontmpD_ = NIM_NIL;
	transformedBody_1 = NIM_NIL;
	def_1.len = 0; def_1.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
	result = TM__BxLwT0mhrtgTPodf1v3xjg_232;
	nimZeroMem((void*)(&a_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
	p_1 = newProc__jsgen_u605((*oldProc_p0).g, (*oldProc_p0).module, (*prc_p1).ast, (*prc_p1).options);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	eqcopy___jsgen_u142(&(*p_1).up, oldProc_p0, NIM_TRUE);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	returnStmt_1 = TM__BxLwT0mhrtgTPodf1v3xjg_233;
	resultAsgn_1 = TM__BxLwT0mhrtgTPodf1v3xjg_234;
	name_1 = mangleName__jsgen_u702((*p_1).module, prc_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	header_1 = generateHeader__jsgen_u3304(p_1, prc_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NIM_BOOL T4_;
		NimStringV2 mname_1;
		tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* vX60gensym1488__1;
		NIM_BOOL useRawPointer_1;
		NIM_BOOL T9_;
		NIM_BOOL T10_;
		NIM_BOOL T11_;
		NIM_BOOL T12_;
		tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg T13_;
		tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg T15_;
		tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg T19_;
		T4_ = (NIM_BOOL)0;
		colontmpD_ = returnType__ast_u5354((*prc_p1).typ);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T4_ = !((colontmpD_ == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL)));
		if (!(T4_)) goto LA5_;
		T4_ = !((((*prc_p1).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)11)))&63U)))!=0));
LA5_: ;
		if (!T4_) goto LA6_;
		mname_1.len = 0; mname_1.p = NIM_NIL;
		vX60gensym1488__1 = NIM_NIL;
		eqcopy___ast_u4577(&resultSym_1, (*(*(*prc_p1).ast)._kind_6.sons.p->data[((NI)7)])._kind_4.sym);
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		mname_1 = mangleName__jsgen_u702((*p_1).module, resultSym_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		T9_ = (NIM_BOOL)0;
		T10_ = (NIM_BOOL)0;
		eqcopy___ast_u4577(&vX60gensym1488__1, resultSym_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		T11_ = (NIM_BOOL)0;
		T12_ = (NIM_BOOL)0;
		T13_ = 0;
		T12_ = !(((131080 & (*vX60gensym1488__1).flags) == T13_));
		if (!(T12_)) goto LA14_;
		T15_ = 0;
		T12_ = ((192 & (*vX60gensym1488__1).flags) == T15_);
LA14_: ;
		T11_ = T12_;
		if (!(T11_)) goto LA16_;
		T11_ = !(((*vX60gensym1488__1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)12) || (*vX60gensym1488__1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)13) || (*vX60gensym1488__1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)16) || (*vX60gensym1488__1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)14) || (*vX60gensym1488__1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)15) || (*vX60gensym1488__1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)10) || (*vX60gensym1488__1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)5) || (*vX60gensym1488__1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)9)));
LA16_: ;
		T10_ = !(T11_);
		if (!(T10_)) goto LA17_;
		T10_ = ((*(*resultSym_1).typ).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)23) || (*(*resultSym_1).typ).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)21) || (*(*resultSym_1).typ).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)47) || (*(*resultSym_1).typ).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)22) || (*(*resultSym_1).typ).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)45));
LA17_: ;
		T9_ = T10_;
		if (!(T9_)) goto LA18_;
		T19_ = (tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)0;
		T19_ = mapType__jsgen_u698(p_1, (*resultSym_1).typ);
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		T9_ = (T19_ == ((tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)9));
LA18_: ;
		useRawPointer_1 = T9_;
		{
			NimStringV2 colontmpD__4;
			NimStringV2 colontmpD__5;
			NimStringV2 colontmpD__6;
			tyArray__YgExxhfgKcesA5EOUj1MOA T24_;
			NimStringV2 T25_;
			tyArray__YgExxhfgKcesA5EOUj1MOA T26_;
			if (!useRawPointer_1) goto LA22_;
			colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
			colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
			colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
			T24_[0] = mname_1;
			colontmpD__4 = percent___jsgen_u7366(T24_, 1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
			T25_.len = 0; T25_.p = NIM_NIL;
			T25_ = indentLine__jsgen_u102(p_1, colontmpD__4);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T25_); goto LA8_;}
			eqsink___system_u2700((&resultAsgn_1), T25_);
			T26_[0] = mname_1;
			colontmpD__5 = percent___jsgen_u7371(T26_, 1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
			colontmpD__6 = indentLine__jsgen_u102(p_1, colontmpD__5);
			if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
			prepareAdd((&resultAsgn_1), colontmpD__6.len + 0);
appendString((&resultAsgn_1), colontmpD__6);
			eqdestroy___system_u2691(colontmpD__6);
			eqdestroy___system_u2691(colontmpD__5);
			eqdestroy___system_u2691(colontmpD__4);
		}
		goto LA20_;
LA22_: ;
		{
			NimStringV2 resVar_1;
			tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* vX60gensym1492__1;
			NimStringV2 colontmpD__7;
			NIM_BOOL T29_;
			NIM_BOOL T30_;
			tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg T31_;
			tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg T33_;
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T35_;
			NimStringV2 T36_;
			resVar_1.len = 0; resVar_1.p = NIM_NIL;
			vX60gensym1492__1 = NIM_NIL;
			colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
			eqcopy___ast_u4577(&vX60gensym1492__1, resultSym_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA28_;
			T29_ = (NIM_BOOL)0;
			T30_ = (NIM_BOOL)0;
			T31_ = 0;
			T30_ = !(((131080 & (*vX60gensym1492__1).flags) == T31_));
			if (!(T30_)) goto LA32_;
			T33_ = 0;
			T30_ = ((192 & (*vX60gensym1492__1).flags) == T33_);
LA32_: ;
			T29_ = T30_;
			if (!(T29_)) goto LA34_;
			T29_ = !(((*vX60gensym1492__1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)12) || (*vX60gensym1492__1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)13) || (*vX60gensym1492__1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)16) || (*vX60gensym1492__1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)14) || (*vX60gensym1492__1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)15) || (*vX60gensym1492__1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)10) || (*vX60gensym1492__1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)5) || (*vX60gensym1492__1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)9)));
LA34_: ;
			resVar_1 = createVar__jsgen_u4648(p_1, (*resultSym_1).typ, T29_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA28_;
			T35_[0] = mname_1;
			T35_[1] = resVar_1;
			colontmpD__7 = percent___jsgen_u7399(T35_, 2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA28_;
			T36_.len = 0; T36_.p = NIM_NIL;
			T36_ = indentLine__jsgen_u102(p_1, colontmpD__7);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T36_); goto LA28_;}
			eqsink___system_u2700((&resultAsgn_1), T36_);
			{
				LA28_:;
			}
			{
				oldNimErrFin28_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___system_u2691(colontmpD__7);
				eqdestroy___ast_u4574(vX60gensym1492__1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
				eqdestroy___system_u2691(resVar_1);
				*nimErr_ = oldNimErrFin28_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		}
LA20_: ;
		gen__jsgen_u1159(p_1, (*(*prc_p1).ast)._kind_6.sons.p->data[((NI)7)], (&a_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		{
			tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg T41_;
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T44_;
			NimStringV2 T45_;
			T41_ = (tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)0;
			T41_ = mapType__jsgen_u698(p_1, (*resultSym_1).typ);
			if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
			if (!(T41_ == ((tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)9))) goto LA42_;
			T44_[0] = a_1.address;
			T44_[1] = a_1.res;
			T45_.len = 0; T45_.p = NIM_NIL;
			T45_ = percent___jsgen_u7408(T44_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T45_); goto LA8_;}
			eqsink___system_u2700((&returnStmt_1), T45_);
		}
		goto LA39_;
LA42_: ;
		{
			tyArray__YgExxhfgKcesA5EOUj1MOA T47_;
			NimStringV2 T48_;
			T47_[0] = a_1.res;
			T48_.len = 0; T48_.p = NIM_NIL;
			T48_ = percent___jsgen_u7413(T47_, 1);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T48_); goto LA8_;}
			eqsink___system_u2700((&returnStmt_1), T48_);
		}
LA39_: ;
		{
			LA8_:;
		}
		{
			oldNimErrFin8_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u4574(vX60gensym1488__1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___system_u2691(mname_1);
			*nimErr_ = oldNimErrFin8_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA6_: ;
	T51_ = 0;
	transformedBody_1 = transformBody__transf_u26((*(*p_1).module).graph, (*(*p_1).module).Sup.idgen, prc_p1, T51_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T56_;
		if (!(((*prc_p1).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)42)))&63U)))!=0)) goto LA54_;
		T56_ = NIM_NIL;
		T56_ = injectDestructorCalls__injectdestructors_u3431((*(*p_1).module).graph, (*(*p_1).module).Sup.idgen, prc_p1, transformedBody_1);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T56_); goto LA1_;}
		eqsink___ast_u3261(&transformedBody_1, T56_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA54_: ;
	(*p_1).extraIndent += ((NI)1);
	genStmt__jsgen_u1163(p_1, transformedBody_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	(*p_1).extraIndent -= ((NI)1);
	{
		NI T61_;
		NimStringV2 T62_;
		if (!(((*(*(*p_1).module).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0)) goto LA59_;
		T61_ = (NI)0;
		T61_ = toLinenumber__msgs_u695((*prc_p1).info);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T62_.len = 0; T62_.p = NIM_NIL;
		T62_ = lineDir__jsgen_u2636((*(*p_1).module).config, (*prc_p1).info, T61_);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T62_); goto LA1_;}
		eqsink___system_u2700((&result), T62_);
	}
LA59_: ;
	{
		NimStringV2 colontmpD__8;
		NimStringV2 colontmpD__9;
		NimStringV2 colontmpD__10;
		NimStringV2 colontmpD__11;
		NimStringV2 colontmpD__12;
		NimStringV2 colontmpD__13;
		NimStringV2 colontmpD__14;
		NimStringV2 colontmpD__15;
		NimStringV2 T68_;
		tyArray__hSrJSIaqyFxuH67Wd7apZQ T69_;
		if (!!(((*prc_p1).constraint == 0))) goto LA65_;
		colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
		colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
		colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
		colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
		colontmpD__12.len = 0; colontmpD__12.p = NIM_NIL;
		colontmpD__13.len = 0; colontmpD__13.p = NIM_NIL;
		colontmpD__14.len = 0; colontmpD__14.p = NIM_NIL;
		colontmpD__15.len = 0; colontmpD__15.p = NIM_NIL;
		T68_.len = 0; T68_.p = NIM_NIL;
		T68_ = rawNewString((*(*prc_p1).constraint)._kind_3.strVal.len + 14);
appendString((&T68_), (*(*prc_p1).constraint)._kind_3.strVal);
appendString((&T68_), TM__BxLwT0mhrtgTPodf1v3xjg_242);
		colontmpD__8 = T68_;
		T69_[0] = TM__BxLwT0mhrtgTPodf1v3xjg_243;
		T69_[1] = name_1;
		T69_[2] = header_1;
		colontmpD__9 = optionalLine__jsgen_u7308((*p_1).globals);
		if (NIM_UNLIKELY(*nimErr_)) goto LA67_;
		T69_[3] = colontmpD__9;
		colontmpD__10 = optionalLine__jsgen_u7308((*p_1).locals);
		if (NIM_UNLIKELY(*nimErr_)) goto LA67_;
		T69_[4] = colontmpD__10;
		colontmpD__11 = optionalLine__jsgen_u7308(resultAsgn_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA67_;
		T69_[5] = colontmpD__11;
		colontmpD__12 = genProcBody__jsgen_u7292(p_1, prc_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA67_;
		colontmpD__13 = optionalLine__jsgen_u7308(colontmpD__12);
		if (NIM_UNLIKELY(*nimErr_)) goto LA67_;
		T69_[6] = colontmpD__13;
		colontmpD__14 = indentLine__jsgen_u102(p_1, returnStmt_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA67_;
		colontmpD__15 = optionalLine__jsgen_u7308(colontmpD__14);
		if (NIM_UNLIKELY(*nimErr_)) goto LA67_;
		T69_[7] = colontmpD__15;
		def_1 = runtimeFormat__ropes_u39(colontmpD__8, T69_, 8);
		if (NIM_UNLIKELY(*nimErr_)) goto LA67_;
		{
			LA67_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__15);
			eqdestroy___system_u2691(colontmpD__14);
			eqdestroy___system_u2691(colontmpD__13);
			eqdestroy___system_u2691(colontmpD__12);
			eqdestroy___system_u2691(colontmpD__11);
			eqdestroy___system_u2691(colontmpD__10);
			eqdestroy___system_u2691(colontmpD__9);
			eqdestroy___system_u2691(colontmpD__8);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA63_;
LA65_: ;
	{
		NimStringV2 colontmpD__16;
		NimStringV2 colontmpD__17;
		NimStringV2 colontmpD__18;
		NimStringV2 colontmpD__19;
		NimStringV2 colontmpD__20;
		NimStringV2 colontmpD__21;
		NimStringV2 colontmpD__22;
		tyArray__hFPV9bffMpPjoz9bsO9crekNg T81_;
		colontmpD__16.len = 0; colontmpD__16.p = NIM_NIL;
		colontmpD__17.len = 0; colontmpD__17.p = NIM_NIL;
		colontmpD__18.len = 0; colontmpD__18.p = NIM_NIL;
		colontmpD__19.len = 0; colontmpD__19.p = NIM_NIL;
		colontmpD__20.len = 0; colontmpD__20.p = NIM_NIL;
		colontmpD__21.len = 0; colontmpD__21.p = NIM_NIL;
		colontmpD__22.len = 0; colontmpD__22.p = NIM_NIL;
		{
			NIM_BOOL T76_;
			NimStringV2 thunkName_1;
			NimStringV2 colontmpD__23;
			NimStringV2 T79_;
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T80_;
			T76_ = (NIM_BOOL)0;
			T76_ = hcrOn__options_u629((*(*p_1).module).config);
			if (NIM_UNLIKELY(*nimErr_)) goto LA73_;
			if (!T76_) goto LA77_;
			thunkName_1.len = 0; thunkName_1.p = NIM_NIL;
			colontmpD__23.len = 0; colontmpD__23.p = NIM_NIL;
			eqcopy___system_u2694((&thunkName_1), name_1);
			T79_.len = 0; T79_.p = NIM_NIL;
			T79_ = rawNewString(name_1.len + 4);
appendString((&T79_), name_1);
appendString((&T79_), TM__BxLwT0mhrtgTPodf1v3xjg_255);
			eqsink___system_u2700((&name_1), T79_);
			T80_[0] = thunkName_1;
			T80_[1] = name_1;
			colontmpD__23 = percent___jsgen_u7442(T80_, 2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA73_;
			prepareAdd((&result), colontmpD__23.len + 0);
appendString((&result), colontmpD__23);
			eqdestroy___system_u2691(colontmpD__23);
			eqdestroy___system_u2691(thunkName_1);
		}
LA77_: ;
		T81_[0] = name_1;
		T81_[1] = header_1;
		colontmpD__16 = optionalLine__jsgen_u7308((*p_1).globals);
		if (NIM_UNLIKELY(*nimErr_)) goto LA73_;
		T81_[2] = colontmpD__16;
		colontmpD__17 = optionalLine__jsgen_u7308((*p_1).locals);
		if (NIM_UNLIKELY(*nimErr_)) goto LA73_;
		T81_[3] = colontmpD__17;
		colontmpD__18 = optionalLine__jsgen_u7308(resultAsgn_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA73_;
		T81_[4] = colontmpD__18;
		colontmpD__19 = genProcBody__jsgen_u7292(p_1, prc_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA73_;
		colontmpD__20 = optionalLine__jsgen_u7308(colontmpD__19);
		if (NIM_UNLIKELY(*nimErr_)) goto LA73_;
		T81_[5] = colontmpD__20;
		colontmpD__21 = indentLine__jsgen_u102(p_1, returnStmt_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA73_;
		colontmpD__22 = optionalLine__jsgen_u7308(colontmpD__21);
		if (NIM_UNLIKELY(*nimErr_)) goto LA73_;
		T81_[6] = colontmpD__22;
		def_1 = percent___jsgen_u7447(T81_, 7);
		if (NIM_UNLIKELY(*nimErr_)) goto LA73_;
		{
			LA73_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__22);
			eqdestroy___system_u2691(colontmpD__21);
			eqdestroy___system_u2691(colontmpD__20);
			eqdestroy___system_u2691(colontmpD__19);
			eqdestroy___system_u2691(colontmpD__18);
			eqdestroy___system_u2691(colontmpD__17);
			eqdestroy___system_u2691(colontmpD__16);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA63_: ;
	(*p_1).extraIndent -= ((NI)1);
	colontmpD__2 = indentLine__jsgen_u102(p_1, def_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&result), colontmpD__2.len + 0);
appendString((&result), colontmpD__2);
	colontmpD__3 = indentLine__jsgen_u102(p_1, TM__BxLwT0mhrtgTPodf1v3xjg_256);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&result), colontmpD__3.len + 0);
appendString((&result), colontmpD__3);
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___system_u2691(colontmpD__3);
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(def_1);
		eqdestroy___ast_u3252(transformedBody_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___system_u2691(header_1);
		eqdestroy___system_u2691(name_1);
		eqdestroy___system_u2691(resultAsgn_1);
		eqdestroy___system_u2691(returnStmt_1);
		eqdestroy___jsgen_u139(p_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___jsgen_u570((&a_1));
		eqdestroy___ast_u4574(resultSym_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, useMagic__jsgen_u1172)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, NimStringV2 name_p1) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_1;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	s_1 = NIM_NIL;
	{
		if (!(name_p1.len == ((NI)0))) goto LA4_;
		eqdestroy___ast_u4574(s_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		goto BeforeRet_;
	}
LA4_: ;
	s_1 = getCompilerProc__magicsys_u150((*(*p_p0).module).graph, name_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		if (!!((s_1 == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)))) goto LA8_;
		{
			NimStringV2 argX60gensym104__1;
			if (!!(((*s_1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)12) || (*s_1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)13) || (*s_1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)14) || (*s_1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)16)))) goto LA12_;
			argX60gensym104__1.len = 0; argX60gensym104__1.p = NIM_NIL;
			argX60gensym104__1 = toFileLineCol__msgs_u701((&TM__BxLwT0mhrtgTPodf1v3xjg_231));
			if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
			internalErrorImpl__msgs_u1598((*(*p_p0).module).config, unknownLineInfo__lineinfos_u364, argX60gensym104__1, (&TM__BxLwT0mhrtgTPodf1v3xjg_231));
			if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
			{
				LA14_:;
			}
			{
				eqdestroy___system_u2691(argX60gensym104__1);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA12_: ;
		{
			tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA xX60gensym107__1;
			NIM_BOOL T19_;
			NimStringV2 code_1;
			xX60gensym107__1 = (*s_1).itemId;
			T19_ = (NIM_BOOL)0;
			T19_ = containsOrIncl__astyaml_u223((&(*(*p_p0).g).generatedSyms), (NI)((NI)((NU64)(((NI) (xX60gensym107__1.module))) << (NU64)(((NI)24) & (64 - 1))) + ((NI) (xX60gensym107__1.item))));
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			if (!!(T19_)) goto LA20_;
			code_1.len = 0; code_1.p = NIM_NIL;
			code_1 = genProc__jsgen_u1166(p_p0, s_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA22_;
			prepareAdd((&(*(*p_p0).g).constants), code_1.len + 0);
appendString((&(*(*p_p0).g).constants), code_1);
			{
				LA22_:;
			}
			{
				eqdestroy___system_u2691(code_1);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA20_: ;
	}
	goto LA6_;
LA8_: ;
	{
		{
			NimStringV2 colontmpD_;
			NimStringV2 T31_;
			if (!!(((*p_p0).prc == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)))) goto LA28_;
			colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
			T31_.len = 0; T31_.p = NIM_NIL;
			T31_ = rawNewString(name_p1.len + 21);
appendString((&T31_), TM__BxLwT0mhrtgTPodf1v3xjg_258);
appendString((&T31_), name_p1);
			colontmpD_ = T31_;
			liMessage__msgs_u1227((*(*p_p0).module).config, (*(*p_p0).prc).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), colontmpD_, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)2), (&TM__BxLwT0mhrtgTPodf1v3xjg_259), NIM_FALSE, NIM_FALSE);
			if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
			{
				LA30_:;
			}
			{
				eqdestroy___system_u2691(colontmpD_);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		goto LA26_;
LA28_: ;
		{
			NimStringV2 colontmpD__2;
			NimStringV2 T36_;
			colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
			T36_.len = 0; T36_.p = NIM_NIL;
			T36_ = rawNewString(name_p1.len + 21);
appendString((&T36_), TM__BxLwT0mhrtgTPodf1v3xjg_260);
appendString((&T36_), name_p1);
			colontmpD__2 = T36_;
			liMessage__msgs_u1227((*(*p_p0).module).config, unknownLineInfo__lineinfos_u364, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), colontmpD__2, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)1), (&TM__BxLwT0mhrtgTPodf1v3xjg_261), NIM_FALSE, NIM_FALSE);
			if (NIM_UNLIKELY(*nimErr_)) goto LA35_;
			{
				LA35_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__2);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA26_: ;
	}
LA6_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u4574(s_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, baseClass__ast_u5348)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* n_p0) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	eqcopy___ast_u3381(&result, (*n_p0).sons.p->data[((NI)0)]);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genEnumInfo__jsgen_u1003)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p1, NimStringV2 name_p2) {
	NimStringV2 s_1;
	NimStringV2 n_1;
	NimStringV2 colontmpD_;
	NimStringV2 colontmpD__2;
	NimStringV2 colontmpD__3;
	NimStringV2 colontmpD__4;
	NimStringV2 colontmpD__5;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__6;
	tyArray__dyW7vpmfeTYw8kX3EXuaJA T23_;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA xX60gensym82__1;
	NI T24_;
	tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T25_;
	NimStringV2 T26_;
	tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T27_;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA xX60gensym84__1;
NIM_BOOL oldNimErrFin32_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	s_1.len = 0; s_1.p = NIM_NIL;
	n_1.len = 0; n_1.p = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
	colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
	colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
	colontmpD__6 = NIM_NIL;
	s_1 = TM__BxLwT0mhrtgTPodf1v3xjg_267;
	{
		NI i_1;
		NI colontmp_;
		NI i_2;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_u3190((*typ_p1).n);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		i_2 = ((NI)0);
		{
			while (1) {
				tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* field_1;
				NimStringV2 extName_1;
				NimStringV2 colontmpD__7;
				NimStringV2 colontmpD__8;
				NimStringV2 colontmpD__9;
				NimStringV2 T14_;
				tyArray__dyW7vpmfeTYw8kX3EXuaJA T20_;
				if (!(i_2 < colontmp_)) goto LA4;
				field_1 = NIM_NIL;
				extName_1.len = 0; extName_1.p = NIM_NIL;
				colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
				colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
				colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
				i_1 = i_2;
				{
					if (!!(((*(*(*typ_p1).n)._kind_6.sons.p->data[i_1]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3)))) goto LA8_;
					internalErrorImpl__msgs_u1598((*(*p_p0).module).config, (*(*typ_p1).n).info, TM__BxLwT0mhrtgTPodf1v3xjg_269, (&TM__BxLwT0mhrtgTPodf1v3xjg_270));
					if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
				}
LA8_: ;
				field_1 = (*(*(*typ_p1).n)._kind_6.sons.p->data[i_1])._kind_4.sym;
				{
					if (!(((NI)0) < i_1)) goto LA12_;
					prepareAdd((&s_1), 3);
appendString((&s_1), TM__BxLwT0mhrtgTPodf1v3xjg_273);
				}
LA12_: ;
				T14_.len = 0; T14_.p = NIM_NIL;
				{
					if (!((*field_1).ast == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL))) goto LA17_;
					eqcopy___system_u2694((&extName_1), (*(*field_1).name).s);
				}
				goto LA15_;
LA17_: ;
				{
					eqcopy___system_u2694((&extName_1), (*(*field_1).ast)._kind_3.strVal);
				}
LA15_: ;
				colontmpD__7 = rope__ropes_u15(((NI64) ((*field_1).position)));
				if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
				T20_[0] = colontmpD__7;
				T20_[1] = name_p2;
				colontmpD__8 = makeJSString__jsgen_u806(extName_1, NIM_TRUE);
				if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
				T20_[2] = colontmpD__8;
				colontmpD__9 = percent___jsgen_u1023(T20_, 3);
				if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
				prepareAdd((&s_1), colontmpD__9.len + 0);
appendString((&s_1), colontmpD__9);
				i_2 += ((NI)1);
				{
					LA5_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__9);
					eqdestroy___system_u2691(colontmpD__8);
					eqdestroy___system_u2691(colontmpD__7);
					eqdestroy___system_u2691(extName_1);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			} LA4: ;
		}
	}
	xX60gensym82__1 = (*typ_p1).itemId;
	colontmpD_ = rope__ropes_u15(((NI64) ((NI)((NI)((NU64)(((NI) (xX60gensym82__1.module))) << (NU64)(((NI)24) & (64 - 1))) + ((NI) (xX60gensym82__1.item))))));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T23_[0] = colontmpD_;
	T24_ = (NI)0;
	T24_ = len__ast_u3190((*typ_p1).n);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__2 = rope__ropes_u15(((NI64) (T24_)));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T23_[1] = colontmpD__2;
	T23_[2] = s_1;
	n_1 = percent___jsgen_u1035(T23_, 3);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T25_[0] = name_p2;
	colontmpD__3 = rope__ropes_u15(((NI64) ((*typ_p1).kind)));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T25_[1] = colontmpD__3;
	T26_.len = 0; T26_.p = NIM_NIL;
	T26_ = percent___jsgen_u907(T25_, 2);
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T26_); goto LA1_;}
	eqsink___system_u2700((&s_1), T26_);
	prepend__ropes_u36((&(*(*p_p0).g).typeInfo), s_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&(*(*p_p0).g).typeInfo), n_1.len + 0);
appendString((&(*(*p_p0).g).typeInfo), n_1);
	T27_[0] = name_p2;
	xX60gensym84__1 = (*typ_p1).itemId;
	colontmpD__4 = rope__ropes_u15(((NI64) ((NI)((NI)((NU64)(((NI) (xX60gensym84__1.module))) << (NU64)(((NI)24) & (64 - 1))) + ((NI) (xX60gensym84__1.item))))));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T27_[1] = colontmpD__4;
	colontmpD__5 = percent___jsgen_u932(T27_, 2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&(*(*p_p0).g).typeInfo), colontmpD__5.len + 0);
appendString((&(*(*p_p0).g).typeInfo), colontmpD__5);
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__10;
		NimStringV2 colontmpD__11;
		NimStringV2 colontmpD__12;
		tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T33_;
		colontmpD__6 = baseClass__ast_u5348(typ_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!!((colontmpD__6 == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL)))) goto LA30_;
		colontmpD__10 = NIM_NIL;
		colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
		colontmpD__12.len = 0; colontmpD__12.p = NIM_NIL;
		T33_[0] = name_p2;
		colontmpD__10 = baseClass__ast_u5348(typ_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA32_;
		colontmpD__11 = genTypeInfo__jsgen_u828(p_p0, colontmpD__10);
		if (NIM_UNLIKELY(*nimErr_)) goto LA32_;
		T33_[1] = colontmpD__11;
		colontmpD__12 = percent___jsgen_u945(T33_, 2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA32_;
		prepareAdd((&(*(*p_p0).g).typeInfo), colontmpD__12.len + 0);
appendString((&(*(*p_p0).g).typeInfo), colontmpD__12);
		{
			LA32_:;
		}
		{
			oldNimErrFin32_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___system_u2691(colontmpD__12);
			eqdestroy___system_u2691(colontmpD__11);
			eqdestroy___ast_u3378(colontmpD__10);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin32_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA30_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(colontmpD__6);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___system_u2691(colontmpD__5);
		eqdestroy___system_u2691(colontmpD__4);
		eqdestroy___system_u2691(colontmpD__3);
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___system_u2691(n_1);
		eqdestroy___system_u2691(s_1);
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(NIM_BOOL, objHasTypeField__jsgen_u888)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p0) {
	NIM_BOOL result;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
	NIM_BOOL T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	colontmpD_ = NIM_NIL;
	T1_ = (NIM_BOOL)0;
	T1_ = (((*t_p0).flags &((NU64)1<<((NU)((((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)3)))&63U)))!=0);
	if (T1_) goto LA2_;
	colontmpD_ = baseClass__ast_u5348(t_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_ = !((colontmpD_ == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL)));
LA2_: ;
	result = T1_;
	eqdestroy___ast_u3378(colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, rope__jsgen_u825)(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg arg_p0) {
	NimStringV2 result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	result = dollar___int128_u36(arg_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, genObjectFields__jsgen_u831)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p2) {
	NimStringV2 result;
	NimStringV2 s_1;
	NimStringV2 u_1;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* field_1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* b_1;
NIM_BOOL oldNimErrFin41_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	s_1.len = 0; s_1.p = NIM_NIL;
	u_1.len = 0; u_1.p = NIM_NIL;
	field_1 = NIM_NIL;
	b_1 = NIM_NIL;
	result = TM__BxLwT0mhrtgTPodf1v3xjg_274;
	switch ((*n_p2).kind) {
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)138):
	{
		{
			NI T5_;
			NimStringV2 T8_;
			T5_ = (NI)0;
			T5_ = len__ast_u3190(n_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			if (!(T5_ == ((NI)1))) goto LA6_;
			T8_.len = 0; T8_.p = NIM_NIL;
			T8_ = genObjectFields__jsgen_u831(p_p0, typ_p1, (*n_p2)._kind_6.sons.p->data[((NI)0)]);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T8_); goto LA1_;}
			eqsink___system_u2700((&result), T8_);
		}
		goto LA3_;
LA6_: ;
		{
			NimStringV2 colontmpD_;
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T21_;
			NI T22_;
			NimStringV2 T23_;
			colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
			s_1 = TM__BxLwT0mhrtgTPodf1v3xjg_275;
			{
				NI i_1;
				NI colontmp_;
				NI i_2;
				i_1 = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = len__ast_u3190(n_p2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
				i_2 = ((NI)0);
				{
					while (1) {
						NimStringV2 colontmpD__2;
						if (!(i_2 < colontmp_)) goto LA13;
						colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
						i_1 = i_2;
						{
							if (!(((NI)0) < i_1)) goto LA17_;
							prepareAdd((&s_1), 3);
appendString((&s_1), TM__BxLwT0mhrtgTPodf1v3xjg_276);
						}
LA17_: ;
						colontmpD__2 = genObjectFields__jsgen_u831(p_p0, typ_p1, (*n_p2)._kind_6.sons.p->data[i_1]);
						if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
						prepareAdd((&s_1), colontmpD__2.len + 0);
appendString((&s_1), colontmpD__2);
						i_2 += ((NI)1);
						{
							LA14_:;
						}
						{
							eqdestroy___system_u2691(colontmpD__2);
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
					} LA13: ;
				}
			}
			T22_ = (NI)0;
			T22_ = len__ast_u3190(n_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
			colontmpD_ = rope__ropes_u15(((NI64) (T22_)));
			if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
			T21_[0] = colontmpD_;
			T21_[1] = s_1;
			T23_.len = 0; T23_.p = NIM_NIL;
			T23_ = percent___jsgen_u845(T21_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T23_); goto LA10_;}
			eqsink___system_u2700((&result), T23_);
			{
				LA10_:;
			}
			{
				eqdestroy___system_u2691(colontmpD_);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA3_: ;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3):
	{
		NimStringV2 colontmpD__3;
		NimStringV2 colontmpD__4;
		tyArray__dyW7vpmfeTYw8kX3EXuaJA T28_;
		NimStringV2 T29_;
		colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
		colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
		eqcopy___ast_u4577(&field_1, (*n_p2)._kind_4.sym);
		if (NIM_UNLIKELY(*nimErr_)) goto LA27_;
		s_1 = genTypeInfo__jsgen_u828(p_p0, (*field_1).typ);
		if (NIM_UNLIKELY(*nimErr_)) goto LA27_;
		colontmpD__3 = mangleName__jsgen_u702((*p_p0).module, field_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA27_;
		T28_[0] = colontmpD__3;
		T28_[1] = s_1;
		colontmpD__4 = makeJSString__jsgen_u806((*(*field_1).name).s, NIM_TRUE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA27_;
		T28_[2] = colontmpD__4;
		T29_.len = 0; T29_.p = NIM_NIL;
		T29_ = percent___jsgen_u850(T28_, 3);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T29_); goto LA27_;}
		eqsink___system_u2700((&result), T29_);
		{
			LA27_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__4);
			eqdestroy___system_u2691(colontmpD__3);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)139):
	{
		NimStringV2 colontmpD__5;
		NimStringV2 colontmpD__6;
		NimStringV2 colontmpD__7;
		tyArray__awn6UrBeChh9cVy9ccoluuYg T76_;
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T77_;
		NimStringV2 T78_;
		colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
		colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
		colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
		{
			if (!!(((*(*n_p2)._kind_6.sons.p->data[((NI)0)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3)))) goto LA36_;
			internalErrorImpl__msgs_u1598((*(*p_p0).module).config, (*n_p2).info, TM__BxLwT0mhrtgTPodf1v3xjg_278, (&TM__BxLwT0mhrtgTPodf1v3xjg_279));
			if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
		}
LA36_: ;
		eqcopy___ast_u4577(&field_1, (*(*n_p2)._kind_6.sons.p->data[((NI)0)])._kind_4.sym);
		if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
		s_1 = genTypeInfo__jsgen_u828(p_p0, (*field_1).typ);
		if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
		{
			NI i_3;
			NI colontmp__2;
			NI i_4;
			i_3 = (NI)0;
			colontmp__2 = (NI)0;
			colontmp__2 = len__ast_u3190(n_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
			i_4 = ((NI)1);
			{
				while (1) {
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__8;
					NimStringV2 colontmpD__9;
					NimStringV2 colontmpD__10;
					tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T73_;
					if (!(i_4 < colontmp__2)) goto LA40;
					colontmpD__8 = NIM_NIL;
					colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
					colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
					i_3 = i_4;
					eqcopy___ast_u3255(&b_1, (*n_p2)._kind_6.sons.p->data[i_3]);
					if (NIM_UNLIKELY(*nimErr_)) goto LA41_;
					eqsink___system_u2700((&u_1), TM__BxLwT0mhrtgTPodf1v3xjg_280);
					switch ((*b_1).kind) {
					case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)85):
					{
						{
							NI T45_;
							T45_ = (NI)0;
							T45_ = len__ast_u3190(b_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA41_;
							if (!(T45_ < ((NI)2))) goto LA46_;
							internalErrorImpl__msgs_u1598((*(*p_p0).module).config, (*b_1).info, TM__BxLwT0mhrtgTPodf1v3xjg_282, (&TM__BxLwT0mhrtgTPodf1v3xjg_283));
							if (NIM_UNLIKELY(*nimErr_)) goto LA41_;
						}
LA46_: ;
						{
							NI j_1;
							NI colontmp__3;
							NI T49_;
							NI i_5;
							j_1 = (NI)0;
							colontmp__3 = (NI)0;
							T49_ = (NI)0;
							T49_ = len__ast_u3190(b_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA41_;
							colontmp__3 = (NI)(T49_ - ((NI)1));
							i_5 = ((NI)0);
							{
								while (1) {
									if (!(i_5 < colontmp__3)) goto LA51;
									j_1 = i_5;
									{
										if (!!((u_1.len == 0))) goto LA54_;
										prepareAdd((&u_1), 2);
appendString((&u_1), TM__BxLwT0mhrtgTPodf1v3xjg_284);
									}
LA54_: ;
									{
										NimStringV2 colontmpD__11;
										NimStringV2 colontmpD__12;
										NimStringV2 colontmpD__13;
										tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T60_;
										tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T61_;
										tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T62_;
										if (!((*(*b_1)._kind_6.sons.p->data[j_1]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)44))) goto LA58_;
										colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
										colontmpD__12.len = 0; colontmpD__12.p = NIM_NIL;
										colontmpD__13.len = 0; colontmpD__13.p = NIM_NIL;
										T61_ = getOrdValue__types_u167((*(*b_1)._kind_6.sons.p->data[j_1])._kind_6.sons.p->data[((NI)0)]);
										if (NIM_UNLIKELY(*nimErr_)) goto LA41_;
										colontmpD__11 = rope__jsgen_u825(T61_);
										if (NIM_UNLIKELY(*nimErr_)) goto LA41_;
										T60_[0] = colontmpD__11;
										T62_ = getOrdValue__types_u167((*(*b_1)._kind_6.sons.p->data[j_1])._kind_6.sons.p->data[((NI)1)]);
										if (NIM_UNLIKELY(*nimErr_)) goto LA41_;
										colontmpD__12 = rope__jsgen_u825(T62_);
										if (NIM_UNLIKELY(*nimErr_)) goto LA41_;
										T60_[1] = colontmpD__12;
										colontmpD__13 = percent___jsgen_u873(T60_, 2);
										if (NIM_UNLIKELY(*nimErr_)) goto LA41_;
										prepareAdd((&u_1), colontmpD__13.len + 0);
appendString((&u_1), colontmpD__13);
										eqdestroy___system_u2691(colontmpD__13);
										eqdestroy___system_u2691(colontmpD__12);
										eqdestroy___system_u2691(colontmpD__11);
									}
									goto LA56_;
LA58_: ;
									{
										NimStringV2 colontmpD__14;
										tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T64_;
										colontmpD__14.len = 0; colontmpD__14.p = NIM_NIL;
										T64_ = getOrdValue__types_u167((*b_1)._kind_6.sons.p->data[j_1]);
										if (NIM_UNLIKELY(*nimErr_)) goto LA41_;
										colontmpD__14 = rope__jsgen_u825(T64_);
										if (NIM_UNLIKELY(*nimErr_)) goto LA41_;
										prepareAdd((&u_1), colontmpD__14.len + 0);
appendString((&u_1), colontmpD__14);
										eqdestroy___system_u2691(colontmpD__14);
									}
LA56_: ;
									i_5 += ((NI)1);
								} LA51: ;
							}
						}
					}
					break;
					case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)88):
					{
						tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T66_;
						NimStringV2 T67_;
						T66_ = lengthOrd__types_u1505((*(*p_p0).module).config, (*field_1).typ);
						if (NIM_UNLIKELY(*nimErr_)) goto LA41_;
						T67_.len = 0; T67_.p = NIM_NIL;
						T67_ = rope__jsgen_u825(T66_);
						if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T67_); goto LA41_;}
						eqsink___system_u2700((&u_1), T67_);
					}
					break;
					default:
					{
						internalErrorImpl__msgs_u1598((*(*p_p0).module).config, (*n_p2).info, TM__BxLwT0mhrtgTPodf1v3xjg_286, (&TM__BxLwT0mhrtgTPodf1v3xjg_287));
						if (NIM_UNLIKELY(*nimErr_)) goto LA41_;
					}
					break;
					}
					{
						if (!!((result.len == 0))) goto LA71_;
						prepareAdd((&result), 3);
appendString((&result), TM__BxLwT0mhrtgTPodf1v3xjg_288);
					}
LA71_: ;
					T73_[0] = u_1;
					colontmpD__8 = lastSon__ast_u5208(b_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA41_;
					colontmpD__9 = genObjectFields__jsgen_u831(p_p0, typ_p1, colontmpD__8);
					if (NIM_UNLIKELY(*nimErr_)) goto LA41_;
					T73_[1] = colontmpD__9;
					colontmpD__10 = percent___jsgen_u878(T73_, 2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA41_;
					prepareAdd((&result), colontmpD__10.len + 0);
appendString((&result), colontmpD__10);
					i_4 += ((NI)1);
					{
						LA41_:;
					}
					{
						oldNimErrFin41_ = *nimErr_; *nimErr_ = NIM_FALSE;
						eqdestroy___system_u2691(colontmpD__10);
						eqdestroy___system_u2691(colontmpD__9);
						eqdestroy___ast_u3252(colontmpD__8);
						if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
						*nimErr_ = oldNimErrFin41_;
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
				} LA40: ;
			}
		}
		colontmpD__5 = mangleName__jsgen_u702((*p_p0).module, field_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
		T76_[0] = colontmpD__5;
		T76_[1] = s_1;
		T77_ = lengthOrd__types_u1505((*(*p_p0).module).config, (*field_1).typ);
		if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
		colontmpD__6 = rope__jsgen_u825(T77_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
		T76_[2] = colontmpD__6;
		colontmpD__7 = makeJSString__jsgen_u806((*(*field_1).name).s, NIM_TRUE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
		T76_[3] = colontmpD__7;
		T76_[4] = result;
		T78_.len = 0; T78_.p = NIM_NIL;
		T78_ = percent___jsgen_u883(T76_, 5);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T78_); goto LA33_;}
		eqsink___system_u2700((&result), T78_);
		{
			LA33_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__7);
			eqdestroy___system_u2691(colontmpD__6);
			eqdestroy___system_u2691(colontmpD__5);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	default:
	{
		internalErrorImpl__msgs_u1598((*(*p_p0).module).config, (*n_p2).info, TM__BxLwT0mhrtgTPodf1v3xjg_289, (&TM__BxLwT0mhrtgTPodf1v3xjg_290));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	}
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3252(b_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u4574(field_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___system_u2691(u_1);
		eqdestroy___system_u2691(s_1);
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genObjectInfo__jsgen_u899)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p1, NimStringV2 name_p2) {
	tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg colontmpD_;
	tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg colontmpD__2;
	NimStringV2 s_1;
	NimStringV2 colontmpD__3;
	NimStringV2 colontmpD__4;
	NimStringV2 colontmpD__5;
	NimStringV2 colontmpD__6;
	NimStringV2 colontmpD__7;
	NimStringV2 colontmpD__8;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__9;
	tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg kind_1;
	tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T8_;
	tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T9_;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA xX60gensym57__1;
	tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T10_;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA xX60gensym60__1;
NIM_BOOL oldNimErrFin17_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_ = (tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)0;
	colontmpD__2 = (tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)0;
	s_1.len = 0; s_1.p = NIM_NIL;
	colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
	colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
	colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
	colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
	colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
	colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
	colontmpD__9 = NIM_NIL;
	{
		NIM_BOOL T4_;
		T4_ = (NIM_BOOL)0;
		T4_ = objHasTypeField__jsgen_u888(typ_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!T4_) goto LA5_;
		colontmpD_ = ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)17);
		kind_1 = colontmpD_;
	}
	goto LA2_;
LA5_: ;
	{
		colontmpD__2 = ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)18);
		kind_1 = colontmpD__2;
	}
LA2_: ;
	T8_[0] = name_p2;
	colontmpD__3 = rope__ropes_u15(((NI64) (kind_1)));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T8_[1] = colontmpD__3;
	s_1 = percent___jsgen_u907(T8_, 2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepend__ropes_u36((&(*(*p_p0).g).typeInfo), s_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	xX60gensym57__1 = (*typ_p1).itemId;
	colontmpD__4 = rope__ropes_u15(((NI64) ((NI)((NI)((NU64)(((NI) (xX60gensym57__1.module))) << (NU64)(((NI)24) & (64 - 1))) + ((NI) (xX60gensym57__1.item))))));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T9_[0] = colontmpD__4;
	colontmpD__5 = genObjectFields__jsgen_u831(p_p0, typ_p1, (*typ_p1).n);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T9_[1] = colontmpD__5;
	colontmpD__6 = percent___jsgen_u920(T9_, 2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&(*(*p_p0).g).typeInfo), colontmpD__6.len + 0);
appendString((&(*(*p_p0).g).typeInfo), colontmpD__6);
	T10_[0] = name_p2;
	xX60gensym60__1 = (*typ_p1).itemId;
	colontmpD__7 = rope__ropes_u15(((NI64) ((NI)((NI)((NU64)(((NI) (xX60gensym60__1.module))) << (NU64)(((NI)24) & (64 - 1))) + ((NI) (xX60gensym60__1.item))))));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T10_[1] = colontmpD__7;
	colontmpD__8 = percent___jsgen_u932(T10_, 2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&(*(*p_p0).g).typeInfo), colontmpD__8.len + 0);
appendString((&(*(*p_p0).g).typeInfo), colontmpD__8);
	{
		NIM_BOOL T13_;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__10;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__11;
		NimStringV2 colontmpD__12;
		NimStringV2 colontmpD__13;
		tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T18_;
		T13_ = (NIM_BOOL)0;
		T13_ = ((*typ_p1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)17));
		if (!(T13_)) goto LA14_;
		colontmpD__9 = baseClass__ast_u5348(typ_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T13_ = !((colontmpD__9 == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL)));
LA14_: ;
		if (!T13_) goto LA15_;
		colontmpD__10 = NIM_NIL;
		colontmpD__11 = NIM_NIL;
		colontmpD__12.len = 0; colontmpD__12.p = NIM_NIL;
		colontmpD__13.len = 0; colontmpD__13.p = NIM_NIL;
		T18_[0] = name_p2;
		colontmpD__10 = baseClass__ast_u5348(typ_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
		colontmpD__11 = skipTypes__ast_u5379(colontmpD__10, TM__BxLwT0mhrtgTPodf1v3xjg_291);
		if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
		colontmpD__12 = genTypeInfo__jsgen_u828(p_p0, colontmpD__11);
		if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
		T18_[1] = colontmpD__12;
		colontmpD__13 = percent___jsgen_u945(T18_, 2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
		prepareAdd((&(*(*p_p0).g).typeInfo), colontmpD__13.len + 0);
appendString((&(*(*p_p0).g).typeInfo), colontmpD__13);
		{
			LA17_:;
		}
		{
			oldNimErrFin17_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___system_u2691(colontmpD__13);
			eqdestroy___system_u2691(colontmpD__12);
			eqdestroy___ast_u3378(colontmpD__11);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___ast_u3378(colontmpD__10);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin17_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA15_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(colontmpD__9);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___system_u2691(colontmpD__8);
		eqdestroy___system_u2691(colontmpD__7);
		eqdestroy___system_u2691(colontmpD__6);
		eqdestroy___system_u2691(colontmpD__5);
		eqdestroy___system_u2691(colontmpD__4);
		eqdestroy___system_u2691(colontmpD__3);
		eqdestroy___system_u2691(s_1);
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(NI, len__ast_u5502)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* n_p0) {
	NI result;
	NI T1_;
	T1_ = (*n_p0).sons.len;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, genTupleFields__jsgen_u950)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p1) {
	NimStringV2 result;
	NimStringV2 s_1;
	NimStringV2 colontmpD_;
	tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T13_;
	NI T14_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	s_1.len = 0; s_1.p = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	s_1 = TM__BxLwT0mhrtgTPodf1v3xjg_292;
	{
		NI i_1;
		NI colontmp_;
		NI i_2;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_u5502(typ_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		i_2 = ((NI)0);
		{
			while (1) {
				NimStringV2 colontmpD__2;
				NimStringV2 colontmpD__3;
				NimStringV2 colontmpD__4;
				tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T10_;
				if (!(i_2 < colontmp_)) goto LA4;
				colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
				colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
				colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
				i_1 = i_2;
				{
					if (!(((NI)0) < i_1)) goto LA8_;
					prepareAdd((&s_1), 3);
appendString((&s_1), TM__BxLwT0mhrtgTPodf1v3xjg_293);
				}
LA8_: ;
				colontmpD__2 = rope__ropes_u15(((NI64) (i_1)));
				if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
				T10_[0] = colontmpD__2;
				colontmpD__3 = genTypeInfo__jsgen_u828(p_p0, (*typ_p1).sons.p->data[i_1]);
				if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
				T10_[1] = colontmpD__3;
				colontmpD__4 = percent___jsgen_u960(T10_, 2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
				prepareAdd((&s_1), colontmpD__4.len + 0);
appendString((&s_1), colontmpD__4);
				i_2 += ((NI)1);
				{
					LA5_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__4);
					eqdestroy___system_u2691(colontmpD__3);
					eqdestroy___system_u2691(colontmpD__2);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			} LA4: ;
		}
	}
	T14_ = (NI)0;
	T14_ = len__ast_u5502(typ_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD_ = rope__ropes_u15(((NI64) (T14_)));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T13_[0] = colontmpD_;
	T13_[1] = s_1;
	result = percent___jsgen_u845(T13_, 2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___system_u2691(s_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genTupleInfo__jsgen_u969)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p1, NimStringV2 name_p2) {
	NimStringV2 s_1;
	NimStringV2 colontmpD_;
	NimStringV2 colontmpD__2;
	NimStringV2 colontmpD__3;
	NimStringV2 colontmpD__4;
	NimStringV2 colontmpD__5;
	NimStringV2 colontmpD__6;
	tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T2_;
	tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T3_;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA xX60gensym68__1;
	tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T4_;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA xX60gensym71__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	s_1.len = 0; s_1.p = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
	colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
	colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
	colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
	T2_[0] = name_p2;
	colontmpD_ = rope__ropes_u15(((NI64) ((*typ_p1).kind)));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T2_[1] = colontmpD_;
	s_1 = percent___jsgen_u907(T2_, 2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepend__ropes_u36((&(*(*p_p0).g).typeInfo), s_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	xX60gensym68__1 = (*typ_p1).itemId;
	colontmpD__2 = rope__ropes_u15(((NI64) ((NI)((NI)((NU64)(((NI) (xX60gensym68__1.module))) << (NU64)(((NI)24) & (64 - 1))) + ((NI) (xX60gensym68__1.item))))));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T3_[0] = colontmpD__2;
	colontmpD__3 = genTupleFields__jsgen_u950(p_p0, typ_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T3_[1] = colontmpD__3;
	colontmpD__4 = percent___jsgen_u920(T3_, 2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&(*(*p_p0).g).typeInfo), colontmpD__4.len + 0);
appendString((&(*(*p_p0).g).typeInfo), colontmpD__4);
	T4_[0] = name_p2;
	xX60gensym71__1 = (*typ_p1).itemId;
	colontmpD__5 = rope__ropes_u15(((NI64) ((NI)((NI)((NU64)(((NI) (xX60gensym71__1.module))) << (NU64)(((NI)24) & (64 - 1))) + ((NI) (xX60gensym71__1.item))))));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T4_[1] = colontmpD__5;
	colontmpD__6 = percent___jsgen_u932(T4_, 2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&(*(*p_p0).g).typeInfo), colontmpD__6.len + 0);
appendString((&(*(*p_p0).g).typeInfo), colontmpD__6);
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD__6);
		eqdestroy___system_u2691(colontmpD__5);
		eqdestroy___system_u2691(colontmpD__4);
		eqdestroy___system_u2691(colontmpD__3);
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___system_u2691(s_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, genTypeInfo__jsgen_u828)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p1) {
	NimStringV2 result;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_1;
	NimStringV2 colontmpD_;
	tyArray__YgExxhfgKcesA5EOUj1MOA T2_;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA xX60gensym89__1;
NIM_BOOL oldNimErrFin9_;
NIM_BOOL oldNimErrFin16_;
NIM_BOOL oldNimErrFin22_;
NIM_BOOL oldNimErrFin35_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	t_1 = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	t_1 = skipTypes__ast_u5379(typ_p1, TM__BxLwT0mhrtgTPodf1v3xjg_266);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	xX60gensym89__1 = (*t_1).itemId;
	colontmpD_ = rope__ropes_u15(((NI64) ((NI)((NI)((NU64)(((NI) (xX60gensym89__1.module))) << (NU64)(((NI)24) & (64 - 1))) + ((NI) (xX60gensym89__1.item))))));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T2_[0] = colontmpD_;
	result = percent___jsgen_u1083(T2_, 1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA xX60gensym91__1;
		NIM_BOOL T5_;
		xX60gensym91__1 = (*t_1).itemId;
		T5_ = (NIM_BOOL)0;
		T5_ = containsOrIncl__astyaml_u223((&(*(*p_p0).g).typeInfoGenerated), (NI)((NI)((NU64)(((NI) (xX60gensym91__1.module))) << (NU64)(((NI)24) & (64 - 1))) + ((NI) (xX60gensym91__1.item))));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!T5_) goto LA6_;
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___ast_u3378(t_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		goto BeforeRet_;
	}
LA6_: ;
	switch ((*t_1).kind) {
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)13):
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__2;
		NimStringV2 T10_;
		colontmpD__2 = NIM_NIL;
		colontmpD__2 = skipModifier__ast_u5338(t_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
		T10_.len = 0; T10_.p = NIM_NIL;
		T10_ = genTypeInfo__jsgen_u828(p_p0, colontmpD__2);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T10_); goto LA9_;}
		eqsink___system_u2700((&result), T10_);
		{
			LA9_:;
		}
		{
			oldNimErrFin9_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3378(colontmpD__2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin9_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)26):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)25):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)1):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)2):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)29):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)28):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)31) ... ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)44):
	{
		NimStringV2 s_1;
		NimStringV2 colontmpD__3;
		tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T14_;
		s_1.len = 0; s_1.p = NIM_NIL;
		colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
		T14_[0] = result;
		colontmpD__3 = rope__ropes_u15(((NI64) ((*t_1).kind)));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T14_[1] = colontmpD__3;
		s_1 = percent___jsgen_u1119(T14_, 2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		prepend__ropes_u36((&(*(*p_p0).g).typeInfo), s_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		eqdestroy___system_u2691(colontmpD__3);
		eqdestroy___system_u2691(s_1);
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)23):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)47):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)22):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)21):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)24):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)20):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)19):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)27):
	{
		NimStringV2 s_2;
		NimStringV2 colontmpD__4;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__5;
		NimStringV2 colontmpD__6;
		NimStringV2 colontmpD__7;
		tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T17_;
		tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T18_;
		s_2.len = 0; s_2.p = NIM_NIL;
		colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
		colontmpD__5 = NIM_NIL;
		colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
		colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
		T17_[0] = result;
		colontmpD__4 = rope__ropes_u15(((NI64) ((*t_1).kind)));
		if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
		T17_[1] = colontmpD__4;
		s_2 = percent___jsgen_u907(T17_, 2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
		prepend__ropes_u36((&(*(*p_p0).g).typeInfo), s_2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
		T18_[0] = result;
		colontmpD__5 = elementType__ast_u5331(t_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
		colontmpD__6 = genTypeInfo__jsgen_u828(p_p0, colontmpD__5);
		if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
		T18_[1] = colontmpD__6;
		colontmpD__7 = percent___jsgen_u945(T18_, 2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
		prepareAdd((&(*(*p_p0).g).typeInfo), colontmpD__7.len + 0);
appendString((&(*(*p_p0).g).typeInfo), colontmpD__7);
		{
			LA16_:;
		}
		{
			oldNimErrFin16_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___system_u2691(colontmpD__7);
			eqdestroy___system_u2691(colontmpD__6);
			eqdestroy___ast_u3378(colontmpD__5);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___system_u2691(colontmpD__4);
			eqdestroy___system_u2691(s_2);
			*nimErr_ = oldNimErrFin16_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)16):
	{
		NimStringV2 s_3;
		NimStringV2 colontmpD__8;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__9;
		NimStringV2 colontmpD__10;
		NimStringV2 colontmpD__11;
		tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T23_;
		tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T24_;
		s_3.len = 0; s_3.p = NIM_NIL;
		colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
		colontmpD__9 = NIM_NIL;
		colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
		colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
		T23_[0] = result;
		colontmpD__8 = rope__ropes_u15(((NI64) ((*t_1).kind)));
		if (NIM_UNLIKELY(*nimErr_)) goto LA22_;
		T23_[1] = colontmpD__8;
		s_3 = percent___jsgen_u907(T23_, 2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA22_;
		prepend__ropes_u36((&(*(*p_p0).g).typeInfo), s_3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA22_;
		T24_[0] = result;
		colontmpD__9 = elementType__ast_u5331(t_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA22_;
		colontmpD__10 = genTypeInfo__jsgen_u828(p_p0, colontmpD__9);
		if (NIM_UNLIKELY(*nimErr_)) goto LA22_;
		T24_[1] = colontmpD__10;
		colontmpD__11 = percent___jsgen_u945(T24_, 2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA22_;
		prepareAdd((&(*(*p_p0).g).typeInfo), colontmpD__11.len + 0);
appendString((&(*(*p_p0).g).typeInfo), colontmpD__11);
		{
			LA22_:;
		}
		{
			oldNimErrFin22_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___system_u2691(colontmpD__11);
			eqdestroy___system_u2691(colontmpD__10);
			eqdestroy___ast_u3378(colontmpD__9);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___system_u2691(colontmpD__8);
			eqdestroy___system_u2691(s_3);
			*nimErr_ = oldNimErrFin22_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)14):
	{
		genEnumInfo__jsgen_u1003(p_p0, t_1, result);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)17):
	{
		genObjectInfo__jsgen_u899(p_p0, t_1, result);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)18):
	{
		genTupleInfo__jsgen_u969(p_p0, t_1, result);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)60):
	{
		{
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__12;
			NimStringV2 T36_;
			if (!!(((*t_1).n == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL)))) goto LA33_;
			colontmpD__12 = NIM_NIL;
			colontmpD__12 = skipModifier__ast_u5338(t_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA35_;
			T36_.len = 0; T36_.p = NIM_NIL;
			T36_ = genTypeInfo__jsgen_u828(p_p0, colontmpD__12);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T36_); goto LA35_;}
			eqsink___system_u2700((&result), T36_);
			{
				LA35_:;
			}
			{
				oldNimErrFin35_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u3378(colontmpD__12);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				*nimErr_ = oldNimErrFin35_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		goto LA31_;
LA33_: ;
		{
			NimStringV2 colontmpD__13;
			NimStringV2 colontmpD__14;
			NimStringV2 T41_;
			colontmpD__13.len = 0; colontmpD__13.p = NIM_NIL;
			colontmpD__14.len = 0; colontmpD__14.p = NIM_NIL;
			T41_.len = 0; T41_.p = NIM_NIL;
			colontmpD__13 = dollar___ast_u182((*t_1).kind);
			T41_ = rawNewString(colontmpD__13.len + 13);
appendString((&T41_), TM__BxLwT0mhrtgTPodf1v3xjg_295);
appendString((&T41_), colontmpD__13);
appendChar((&T41_), 41);
			colontmpD__14 = T41_;
			internalErrorImpl__msgs_u1598((*(*p_p0).module).config, unknownLineInfo__lineinfos_u364, colontmpD__14, (&TM__BxLwT0mhrtgTPodf1v3xjg_296));
			if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
			{
				LA40_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__14);
				eqdestroy___system_u2691(colontmpD__13);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA31_: ;
	}
	break;
	default:
	{
		NimStringV2 colontmpD__15;
		NimStringV2 colontmpD__16;
		NimStringV2 T46_;
		colontmpD__15.len = 0; colontmpD__15.p = NIM_NIL;
		colontmpD__16.len = 0; colontmpD__16.p = NIM_NIL;
		T46_.len = 0; T46_.p = NIM_NIL;
		colontmpD__15 = dollar___ast_u182((*t_1).kind);
		T46_ = rawNewString(colontmpD__15.len + 13);
appendString((&T46_), TM__BxLwT0mhrtgTPodf1v3xjg_297);
appendString((&T46_), colontmpD__15);
appendChar((&T46_), 41);
		colontmpD__16 = T46_;
		internalErrorImpl__msgs_u1598((*(*p_p0).module).config, unknownLineInfo__lineinfos_u364, colontmpD__16, (&TM__BxLwT0mhrtgTPodf1v3xjg_298));
		if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
		{
			LA45_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__16);
			eqdestroy___system_u2691(colontmpD__15);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	}
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___ast_u3378(t_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, isEmptyType__ast_u7234)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p0) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	T1_ = (NIM_BOOL)0;
	T1_ = (t_p0 == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL));
	if (T1_) goto LA2_;
	T1_ = ((*t_p0).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)63) || (*t_p0).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)7));
LA2_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, createRecordVarAux__jsgen_u4652)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* rec_p1, tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* excludedFieldIDs_p2, NimStringV2* output_p3) {
NIM_BOOL oldNimErrFin9_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	switch ((*rec_p1).kind) {
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)138):
	{
		{
			NI i_1;
			NI colontmp_;
			NI i_2;
			i_1 = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__ast_u3190(rec_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			i_2 = ((NI)0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA4;
					i_1 = i_2;
					createRecordVarAux__jsgen_u4652(p_p0, (*rec_p1)._kind_6.sons.p->data[i_1], excludedFieldIDs_p2, output_p3);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					i_2 += ((NI)1);
				} LA4: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)139):
	{
		createRecordVarAux__jsgen_u4652(p_p0, (*rec_p1)._kind_6.sons.p->data[((NI)0)], excludedFieldIDs_p2, output_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		{
			NI i_3;
			NI colontmp__2;
			NI i_4;
			i_3 = (NI)0;
			colontmp__2 = (NI)0;
			colontmp__2 = len__ast_u3190(rec_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			i_4 = ((NI)1);
			{
				while (1) {
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD_;
					if (!(i_4 < colontmp__2)) goto LA8;
					colontmpD_ = NIM_NIL;
					i_3 = i_4;
					colontmpD_ = lastSon__ast_u5208((*rec_p1)._kind_6.sons.p->data[i_3]);
					if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
					createRecordVarAux__jsgen_u4652(p_p0, colontmpD_, excludedFieldIDs_p2, output_p3);
					if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
					i_4 += ((NI)1);
					{
						LA9_:;
					}
					{
						oldNimErrFin9_ = *nimErr_; *nimErr_ = NIM_FALSE;
						eqdestroy___ast_u3252(colontmpD_);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						*nimErr_ = oldNimErrFin9_;
					}
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				} LA8: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3):
	{
		{
			NIM_BOOL T15_;
			T15_ = (NIM_BOOL)0;
			T15_ = isEmptyType__ast_u7234((*(*rec_p1)._kind_4.sym).typ);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T15_) goto LA16_;
			goto BeforeRet_;
		}
LA16_: ;
		{
			tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA xX60gensym988__1;
			NIM_BOOL T20_;
			NimStringV2 colontmpD__2;
			NimStringV2 colontmpD__3;
			NimStringV2 colontmpD__4;
			tyArray__YgExxhfgKcesA5EOUj1MOA T28_;
			xX60gensym988__1 = (*(*rec_p1)._kind_4.sym).itemId;
			T20_ = (NIM_BOOL)0;
			T20_ = contains__astalgo_u2846(excludedFieldIDs_p2, (NI)((NI)((NU64)(((NI) (xX60gensym988__1.module))) << (NU64)(((NI)24) & (64 - 1))) + ((NI) (xX60gensym988__1.item))));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!!(T20_)) goto LA21_;
			colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
			colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
			colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
			{
				if (!(((NI)0) < (*output_p3).len)) goto LA26_;
				prepareAdd((&(*output_p3)), 2);
appendString((&(*output_p3)), TM__BxLwT0mhrtgTPodf1v3xjg_311);
			}
LA26_: ;
			colontmpD__2 = mangleName__jsgen_u702((*p_p0).module, (*rec_p1)._kind_4.sym);
			if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
			T28_[0] = colontmpD__2;
			colontmpD__3 = percent___jsgen_u4788(T28_, 1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
			prepareAdd((&(*output_p3)), colontmpD__3.len + 0);
appendString((&(*output_p3)), colontmpD__3);
			colontmpD__4 = createVar__jsgen_u4648(p_p0, (*(*rec_p1)._kind_4.sym).typ, NIM_FALSE);
			if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
			prepareAdd((&(*output_p3)), colontmpD__4.len + 0);
appendString((&(*output_p3)), colontmpD__4);
			{
				LA23_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__4);
				eqdestroy___system_u2691(colontmpD__3);
				eqdestroy___system_u2691(colontmpD__2);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA21_: ;
	}
	break;
	default:
	{
		internalErrorImpl__msgs_u1598((*(*p_p0).module).config, (*rec_p1).info, TM__BxLwT0mhrtgTPodf1v3xjg_313, (&TM__BxLwT0mhrtgTPodf1v3xjg_314));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, createObjInitList__jsgen_u4793)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p1, tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* excludedFieldIDs_p2, NimStringV2* output_p3) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_1;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	t_1 = NIM_NIL;
	eqcopy___ast_u3381(&t_1, typ_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NIM_BOOL T4_;
		NimStringV2 colontmpD_;
		NimStringV2 colontmpD__2;
		tyArray__YgExxhfgKcesA5EOUj1MOA T12_;
		T4_ = (NIM_BOOL)0;
		T4_ = objHasTypeField__jsgen_u888(t_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!T4_) goto LA5_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		{
			if (!(((NI)0) < (*output_p3).len)) goto LA10_;
			prepareAdd((&(*output_p3)), 2);
appendString((&(*output_p3)), TM__BxLwT0mhrtgTPodf1v3xjg_310);
		}
LA10_: ;
		colontmpD_ = genTypeInfo__jsgen_u828(p_p0, t_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		T12_[0] = colontmpD_;
		colontmpD__2 = percent___jsgen_u4799(T12_, 1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		prepareAdd((&(*output_p3)), colontmpD__2.len + 0);
appendString((&(*output_p3)), colontmpD__2);
		{
			LA7_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__2);
			eqdestroy___system_u2691(colontmpD_);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA5_: ;
	{
		while (1) {
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* T17_;
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* T18_;
			if (!!((t_1 == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL)))) goto LA16;
			T17_ = NIM_NIL;
			T17_ = skipTypes__ast_u5379(t_1, TM__BxLwT0mhrtgTPodf1v3xjg_291);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3378(T17_); goto LA1_;}
			eqsink___ast_u3387(&t_1, T17_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			createRecordVarAux__jsgen_u4652(p_p0, (*t_1).n, excludedFieldIDs_p2, output_p3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			T18_ = NIM_NIL;
			T18_ = baseClass__ast_u5348(t_1);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3378(T18_); goto LA1_;}
			eqsink___ast_u3387(&t_1, T18_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		} LA16: ;
	}
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(t_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, createVar__jsgen_u4648)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p1, NIM_BOOL indirect_p2) {
	NimStringV2 result;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_1;
NIM_BOOL oldNimErrFin17_;
NIM_BOOL oldNimErrFin24_;
NIM_BOOL oldNimErrFin81_;
NIM_BOOL oldNimErrFin105_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	t_1 = NIM_NIL;
	t_1 = skipTypes__ast_u5379(typ_p1, TM__BxLwT0mhrtgTPodf1v3xjg_175);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	switch ((*t_1).kind) {
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)32) ... ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)34):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)41) ... ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)43):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)14):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)2):
	{
		result = putToSeq__jsgen_u4639(TM__BxLwT0mhrtgTPodf1v3xjg_182, indirect_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)31):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)40):
	{
		{
			if (!eqStrings((*(*t_1).sym).loc.snippet, TM__BxLwT0mhrtgTPodf1v3xjg_184)) goto LA6_;
			result = putToSeq__jsgen_u4639(TM__BxLwT0mhrtgTPodf1v3xjg_186, indirect_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		goto LA4_;
LA6_: ;
		{
			result = putToSeq__jsgen_u4639(TM__BxLwT0mhrtgTPodf1v3xjg_187, indirect_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA4_: ;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)35):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)44):
	{
		{
			if (!(((*(*(*p_p0).module).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)56)))&63U)))!=0)) goto LA12_;
			result = putToSeq__jsgen_u4639(TM__BxLwT0mhrtgTPodf1v3xjg_188, indirect_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		goto LA10_;
LA12_: ;
		{
			result = putToSeq__jsgen_u4639(TM__BxLwT0mhrtgTPodf1v3xjg_189, indirect_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA10_: ;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)36) ... ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)39):
	{
		result = putToSeq__jsgen_u4639(TM__BxLwT0mhrtgTPodf1v3xjg_191, indirect_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)20):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)11):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)4):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)46):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)45):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)47):
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
		colontmpD_ = NIM_NIL;
		colontmpD_ = skipModifier__ast_u5338(typ_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
		result = createVar__jsgen_u4648(p_p0, colontmpD_, indirect_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
		{
			LA17_:;
		}
		{
			oldNimErrFin17_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3378(colontmpD_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin17_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)19):
	{
		result = putToSeq__jsgen_u4639(TM__BxLwT0mhrtgTPodf1v3xjg_193, indirect_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)1):
	{
		result = putToSeq__jsgen_u4639(TM__BxLwT0mhrtgTPodf1v3xjg_194, indirect_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)5):
	{
		result = putToSeq__jsgen_u4639(TM__BxLwT0mhrtgTPodf1v3xjg_195, indirect_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)16):
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* e_1;
		NimStringV2 jsTyp_1;
		NI length_1;
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T25_;
		e_1 = NIM_NIL;
		jsTyp_1.len = 0; jsTyp_1.p = NIM_NIL;
		T25_ = lengthOrd__types_u1505((*(*p_p0).module).config, t_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA24_;
		length_1 = toInt__int128_u257(T25_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA24_;
		e_1 = elemType__types_u254(t_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA24_;
		jsTyp_1 = arrayTypeForElemType__jsgen_u4808((*(*p_p0).module).config, e_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA24_;
		{
			NimStringV2 colontmpD__2;
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T30_;
			if (!(((NI)0) < jsTyp_1.len)) goto LA28_;
			colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
			T30_[0] = jsTyp_1;
			colontmpD__2 = rope__ropes_u15(((NI64) (length_1)));
			if (NIM_UNLIKELY(*nimErr_)) goto LA24_;
			T30_[1] = colontmpD__2;
			result = percent___jsgen_u4834(T30_, 2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA24_;
			eqdestroy___system_u2691(colontmpD__2);
		}
		goto LA26_;
LA28_: ;
		{
			NimStringV2 colontmpD__3;
			NimStringV2 colontmpD__4;
			NimStringV2 colontmpD__5;
			tyArray__dyW7vpmfeTYw8kX3EXuaJA T35_;
			if (!(((NI)32) < length_1)) goto LA32_;
			colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
			colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
			colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
			useMagic__jsgen_u1172(p_p0, TM__BxLwT0mhrtgTPodf1v3xjg_263);
			if (NIM_UNLIKELY(*nimErr_)) goto LA34_;
			useMagic__jsgen_u1172(p_p0, TM__BxLwT0mhrtgTPodf1v3xjg_265);
			if (NIM_UNLIKELY(*nimErr_)) goto LA34_;
			colontmpD__3 = rope__ropes_u15(((NI64) (length_1)));
			if (NIM_UNLIKELY(*nimErr_)) goto LA34_;
			T35_[0] = colontmpD__3;
			colontmpD__4 = createVar__jsgen_u4648(p_p0, e_1, NIM_FALSE);
			if (NIM_UNLIKELY(*nimErr_)) goto LA34_;
			T35_[1] = colontmpD__4;
			colontmpD__5 = genTypeInfo__jsgen_u828(p_p0, e_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA34_;
			T35_[2] = colontmpD__5;
			result = percent___jsgen_u4839(T35_, 3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA34_;
			{
				LA34_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__5);
				eqdestroy___system_u2691(colontmpD__4);
				eqdestroy___system_u2691(colontmpD__3);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA24_;
		}
		goto LA26_;
LA32_: ;
		{
			NI i_1;
			result = TM__BxLwT0mhrtgTPodf1v3xjg_300;
			i_1 = ((NI)0);
			{
				while (1) {
					NimStringV2 colontmpD__6;
					if (!(i_1 < length_1)) goto LA40;
					colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
					{
						if (!(((NI)0) < i_1)) goto LA44_;
						prepareAdd((&result), 2);
appendString((&result), TM__BxLwT0mhrtgTPodf1v3xjg_301);
					}
LA44_: ;
					colontmpD__6 = createVar__jsgen_u4648(p_p0, e_1, NIM_FALSE);
					if (NIM_UNLIKELY(*nimErr_)) goto LA41_;
					prepareAdd((&result), colontmpD__6.len + 0);
appendString((&result), colontmpD__6);
					i_1 += ((NI)1);
					{
						LA41_:;
					}
					{
						eqdestroy___system_u2691(colontmpD__6);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA24_;
				} LA40: ;
			}
			prepareAdd((&result), 1);
appendString((&result), TM__BxLwT0mhrtgTPodf1v3xjg_303);
		}
LA26_: ;
		{
			tyArray__YgExxhfgKcesA5EOUj1MOA T52_;
			NimStringV2 T53_;
			if (!indirect_p2) goto LA50_;
			T52_[0] = result;
			T53_.len = 0; T53_.p = NIM_NIL;
			T53_ = percent___jsgen_u4643(T52_, 1);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T53_); goto LA24_;}
			eqsink___system_u2700((&result), T53_);
		}
LA50_: ;
		{
			LA24_:;
		}
		{
			oldNimErrFin24_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___system_u2691(jsTyp_1);
			eqdestroy___ast_u3378(e_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin24_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)18):
	{
		NIM_BOOL first_1;
		result = TM__BxLwT0mhrtgTPodf1v3xjg_305;
		first_1 = NIM_TRUE;
		{
			NI i_2;
			NI colontmp_;
			NI i_3;
			i_2 = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__ast_u5502(t_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			i_3 = ((NI)0);
			{
				while (1) {
					if (!(i_3 < colontmp_)) goto LA59;
					i_2 = i_3;
					{
						NimStringV2 colontmpD__7;
						NimStringV2 colontmpD__8;
						NimStringV2 colontmpD__9;
						tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T71_;
						colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
						colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
						colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
						{
							NIM_BOOL T64_;
							T64_ = (NIM_BOOL)0;
							T64_ = isEmptyType__ast_u7234((*t_1).sons.p->data[i_2]);
							if (NIM_UNLIKELY(*nimErr_)) goto LA61_;
							if (!T64_) goto LA65_;
							eqdestroy___system_u2691(colontmpD__9);
							eqdestroy___system_u2691(colontmpD__8);
							eqdestroy___system_u2691(colontmpD__7);
							goto LA60;
						}
LA65_: ;
						{
							if (!!(first_1)) goto LA69_;
							prepareAdd((&result), 2);
appendString((&result), TM__BxLwT0mhrtgTPodf1v3xjg_306);
						}
LA69_: ;
						first_1 = NIM_FALSE;
						colontmpD__7 = rope__ropes_u15(((NI64) (i_2)));
						if (NIM_UNLIKELY(*nimErr_)) goto LA61_;
						T71_[0] = colontmpD__7;
						colontmpD__8 = createVar__jsgen_u4648(p_p0, (*t_1).sons.p->data[i_2], NIM_FALSE);
						if (NIM_UNLIKELY(*nimErr_)) goto LA61_;
						T71_[1] = colontmpD__8;
						colontmpD__9 = percent___jsgen_u4860(T71_, 2);
						if (NIM_UNLIKELY(*nimErr_)) goto LA61_;
						prepareAdd((&result), colontmpD__9.len + 0);
appendString((&result), colontmpD__9);
						{
							LA61_:;
						}
						{
							eqdestroy___system_u2691(colontmpD__9);
							eqdestroy___system_u2691(colontmpD__8);
							eqdestroy___system_u2691(colontmpD__7);
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					} LA60: ;
					i_3 += ((NI)1);
				} LA59: ;
			}
		}
		prepareAdd((&result), 1);
appendString((&result), TM__BxLwT0mhrtgTPodf1v3xjg_308);
		{
			tyArray__YgExxhfgKcesA5EOUj1MOA T78_;
			NimStringV2 T79_;
			if (!indirect_p2) goto LA76_;
			T78_[0] = result;
			T79_.len = 0; T79_.p = NIM_NIL;
			T79_ = percent___jsgen_u4643(T78_, 1);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T79_); goto LA1_;}
			eqsink___system_u2700((&result), T79_);
		}
LA76_: ;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)17):
	{
		NimStringV2 initList_1;
		tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA colontmpD__10;
		tyArray__YgExxhfgKcesA5EOUj1MOA T82_;
		initList_1.len = 0; initList_1.p = NIM_NIL;
		nimZeroMem((void*)(&colontmpD__10), sizeof(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA));
		initList_1 = TM__BxLwT0mhrtgTPodf1v3xjg_309;
		initIntSet__pureZcollectionsZintsets_u598((&colontmpD__10));
		if (NIM_UNLIKELY(*nimErr_)) goto LA81_;
		createObjInitList__jsgen_u4793(p_p0, t_1, (&colontmpD__10), (&initList_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA81_;
		T82_[0] = initList_1;
		result = percent___jsgen_u4870(T82_, 1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA81_;
		{
			tyArray__YgExxhfgKcesA5EOUj1MOA T87_;
			NimStringV2 T88_;
			if (!indirect_p2) goto LA85_;
			T87_[0] = result;
			T88_.len = 0; T88_.p = NIM_NIL;
			T88_ = percent___jsgen_u4643(T87_, 1);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T88_); goto LA81_;}
			eqsink___system_u2700((&result), T88_);
		}
LA85_: ;
		{
			LA81_:;
		}
		{
			oldNimErrFin81_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___pureZcollectionsZintsets_u230((&colontmpD__10));
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___system_u2691(initList_1);
			*nimErr_ = oldNimErrFin81_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)23):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)21):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)22):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)26):
	{
		{
			tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg T94_;
			T94_ = (tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)0;
			T94_ = mapType__jsgen_u698(p_p0, t_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			if (!(T94_ == ((tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)9))) goto LA95_;
			result = putToSeq__jsgen_u4639(TM__BxLwT0mhrtgTPodf1v3xjg_316, indirect_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		goto LA92_;
LA95_: ;
		{
			result = putToSeq__jsgen_u4639(TM__BxLwT0mhrtgTPodf1v3xjg_317, indirect_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA92_: ;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)24):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)28):
	{
		result = putToSeq__jsgen_u4639(TM__BxLwT0mhrtgTPodf1v3xjg_319, indirect_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)29):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)25):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)27):
	{
		result = putToSeq__jsgen_u4639(TM__BxLwT0mhrtgTPodf1v3xjg_320, indirect_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)60):
	{
		{
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__11;
			if (!!(((*t_1).n == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL)))) goto LA103_;
			colontmpD__11 = NIM_NIL;
			colontmpD__11 = skipModifier__ast_u5338(t_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA105_;
			result = createVar__jsgen_u4648(p_p0, colontmpD__11, indirect_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA105_;
			{
				LA105_:;
			}
			{
				oldNimErrFin105_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u3378(colontmpD__11);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				*nimErr_ = oldNimErrFin105_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		goto LA101_;
LA103_: ;
		{
			NimStringV2 colontmpD__12;
			NimStringV2 colontmpD__13;
			NimStringV2 T110_;
			colontmpD__12.len = 0; colontmpD__12.p = NIM_NIL;
			colontmpD__13.len = 0; colontmpD__13.p = NIM_NIL;
			T110_.len = 0; T110_.p = NIM_NIL;
			colontmpD__12 = dollar___ast_u182((*t_1).kind);
			T110_ = rawNewString(colontmpD__12.len + 11);
appendString((&T110_), TM__BxLwT0mhrtgTPodf1v3xjg_322);
appendString((&T110_), colontmpD__12);
			colontmpD__13 = T110_;
			internalErrorImpl__msgs_u1598((*(*p_p0).module).config, unknownLineInfo__lineinfos_u364, colontmpD__13, (&TM__BxLwT0mhrtgTPodf1v3xjg_323));
			if (NIM_UNLIKELY(*nimErr_)) goto LA109_;
			result = TM__BxLwT0mhrtgTPodf1v3xjg_324;
			{
				LA109_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__13);
				eqdestroy___system_u2691(colontmpD__12);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA101_: ;
	}
	break;
	default:
	{
		NimStringV2 colontmpD__14;
		NimStringV2 colontmpD__15;
		NimStringV2 T115_;
		colontmpD__14.len = 0; colontmpD__14.p = NIM_NIL;
		colontmpD__15.len = 0; colontmpD__15.p = NIM_NIL;
		T115_.len = 0; T115_.p = NIM_NIL;
		colontmpD__14 = dollar___ast_u182((*t_1).kind);
		T115_ = rawNewString(colontmpD__14.len + 11);
appendString((&T115_), TM__BxLwT0mhrtgTPodf1v3xjg_325);
appendString((&T115_), colontmpD__14);
		colontmpD__15 = T115_;
		internalErrorImpl__msgs_u1598((*(*p_p0).module).config, unknownLineInfo__lineinfos_u364, colontmpD__15, (&TM__BxLwT0mhrtgTPodf1v3xjg_326));
		if (NIM_UNLIKELY(*nimErr_)) goto LA114_;
		result = TM__BxLwT0mhrtgTPodf1v3xjg_327;
		{
			LA114_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__15);
			eqdestroy___system_u2691(colontmpD__14);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	}
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(t_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, needsNoCopy__jsgen_u3374)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* y_p1) {
	NIM_BOOL result;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
	NIM_BOOL T2_;
	NIM_BOOL T4_;
	NIM_BOOL T5_;
	tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg T6_;
	NIM_BOOL T8_;
	NIM_BOOL T9_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	colontmpD_ = NIM_NIL;
	T2_ = (NIM_BOOL)0;
	T2_ = ((TM__BxLwT0mhrtgTPodf1v3xjg_328[(NU)(((*y_p1).kind))>>3] &(1U<<((NU)(((*y_p1).kind))&7U)))!=0);
	if (T2_) goto LA3_;
	T4_ = (NIM_BOOL)0;
	T5_ = (NIM_BOOL)0;
	T6_ = (tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)0;
	T6_ = mapType__jsgen_u686((*y_p1).typField);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T5_ = !((T6_ == ((tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)9)));
	if (T5_) goto LA7_;
	T8_ = (NIM_BOOL)0;
	T9_ = (NIM_BOOL)0;
	T9_ = (((*(*(*p_p0).module).config).legacyFeatures &((NU8)1<<((NU)((((tyEnum_LegacyFeature__yvNVqOQTgcxHpvo1MvfBfA)5)))&7U)))!=0);
	if (!(T9_)) goto LA10_;
	T9_ = ((*y_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3));
LA10_: ;
	T8_ = T9_;
	if (!(T8_)) goto LA11_;
	T8_ = ((*(*y_p1)._kind_4.sym).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)3));
LA11_: ;
	T5_ = T8_;
LA7_: ;
	T4_ = T5_;
	if (!(T4_)) goto LA12_;
	colontmpD_ = skipTypes__ast_u5379((*y_p1).typField, TM__BxLwT0mhrtgTPodf1v3xjg_175);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T4_ = ((*colontmpD_).kind >= ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)1) && (*colontmpD_).kind <= ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)2) || (*colontmpD_).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)14) || (*colontmpD_).kind >= ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)21) && (*colontmpD_).kind <= ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)23) || (*colontmpD_).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)25) || (*colontmpD_).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)27) || (*colontmpD_).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)29) || (*colontmpD_).kind >= ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)31) && (*colontmpD_).kind <= ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)45) || (*colontmpD_).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)47));
LA12_: ;
	T2_ = T4_;
LA3_: ;
	result = T2_;
	eqdestroy___ast_u3378(colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	goto BeforeRet_;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getTemp__jsgen_u1235)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, NIM_BOOL defineInLocals_p1) {
	NimStringV2 result;
	NimStringV2 colontmpD_;
	tyArray__YgExxhfgKcesA5EOUj1MOA T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	(*p_p0).unique += ((NI)1);
	colontmpD_ = rope__ropes_u15(((NI64) ((*p_p0).unique)));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_[0] = colontmpD_;
	result = percent___jsgen_u1244(T1_, 1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		NimStringV2 colontmpD__2;
		NimStringV2 colontmpD__3;
		tyArray__YgExxhfgKcesA5EOUj1MOA T6_;
		if (!defineInLocals_p1) goto LA4_;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
		T6_[0] = result;
		colontmpD__2 = percent___jsgen_u1249(T6_, 1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		colontmpD__3 = indentLine__jsgen_u102(p_p0, colontmpD__2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		prepareAdd((&(*p_p0).locals), colontmpD__3.len + 0);
appendString((&(*p_p0).locals), colontmpD__3);
		eqdestroy___system_u2691(colontmpD__3);
		eqdestroy___system_u2691(colontmpD__2);
	}
LA4_: ;
	eqdestroy___system_u2691(colontmpD_);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genVarInit__jsgen_u4193)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* v_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p2) {
	tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ a_1;
	NimStringV2 s_1;
	NimStringV2 varCode_1;
	NimStringV2 varName_1;
	NIM_BOOL useReloadingGuard_1;
	NIM_BOOL T2_;
	NIM_BOOL useGlobalPragmas_1;
	NIM_BOOL T4_;
	tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg T6_;
NIM_BOOL oldNimErrFin46_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&a_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
	s_1.len = 0; s_1.p = NIM_NIL;
	varCode_1.len = 0; varCode_1.p = NIM_NIL;
	varName_1.len = 0; varName_1.p = NIM_NIL;
	nimZeroMem((void*)(&a_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
	varName_1 = mangleName__jsgen_u702((*p_p0).module, v_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T2_ = (NIM_BOOL)0;
	T2_ = (((*v_p1).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)3)))&63U)))!=0);
	if (!(T2_)) goto LA3_;
	T2_ = hcrOn__options_u629((*(*p_p0).module).config);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
LA3_: ;
	useReloadingGuard_1 = T2_;
	T4_ = (NIM_BOOL)0;
	T4_ = (((*v_p1).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)3)))&63U)))!=0);
	if (!(T4_)) goto LA5_;
	T6_ = 0;
	T4_ = !(((67110912 & (*v_p1).flags) == T6_));
LA5_: ;
	useGlobalPragmas_1 = T4_;
	{
		if (!((*v_p1).constraint == 0)) goto LA9_;
		{
			NimStringV2 colontmpD_;
			NimStringV2 colontmpD__2;
			NimStringV2 colontmpD__3;
			NimStringV2 colontmpD__4;
			tyArray__YgExxhfgKcesA5EOUj1MOA T15_;
			tyArray__YgExxhfgKcesA5EOUj1MOA T16_;
			if (!useReloadingGuard_1) goto LA13_;
			colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
			colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
			colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
			colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
			T15_[0] = varName_1;
			colontmpD_ = percent___jsgen_u1249(T15_, 1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			colontmpD__2 = indentLine__jsgen_u102(p_p0, colontmpD_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			prepareAdd((&(*p_p0).body), colontmpD__2.len + 0);
appendString((&(*p_p0).body), colontmpD__2);
			T16_[0] = varName_1;
			colontmpD__3 = percent___jsgen_u4931(T16_, 1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			colontmpD__4 = indentLine__jsgen_u102(p_p0, colontmpD__3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			prepareAdd((&(*p_p0).body), colontmpD__4.len + 0);
appendString((&(*p_p0).body), colontmpD__4);
			eqcopy___system_u2694((&varCode_1), varName_1);
			(*p_p0).extraIndent += ((NI)1);
			eqdestroy___system_u2691(colontmpD__4);
			eqdestroy___system_u2691(colontmpD__3);
			eqdestroy___system_u2691(colontmpD__2);
			eqdestroy___system_u2691(colontmpD_);
		}
		goto LA11_;
LA13_: ;
		{
			NimStringV2 colontmpD__5;
			NimStringV2 colontmpD__6;
			tyArray__YgExxhfgKcesA5EOUj1MOA T20_;
			NimStringV2 T21_;
			if (!useGlobalPragmas_1) goto LA18_;
			colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
			colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
			T20_[0] = varName_1;
			colontmpD__5 = percent___jsgen_u4941(T20_, 1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			colontmpD__6 = indentLine__jsgen_u102(p_p0, colontmpD__5);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			prepareAdd((&(*p_p0).body), colontmpD__6.len + 0);
appendString((&(*p_p0).body), colontmpD__6);
			T21_.len = 0; T21_.p = NIM_NIL;
			T21_ = rawNewString(varName_1.len + 11);
appendString((&T21_), TM__BxLwT0mhrtgTPodf1v3xjg_172);
appendString((&T21_), varName_1);
			varCode_1 = T21_;
			(*p_p0).extraIndent += ((NI)1);
			eqdestroy___system_u2691(colontmpD__6);
			eqdestroy___system_u2691(colontmpD__5);
		}
		goto LA11_;
LA18_: ;
		{
			varCode_1 = TM__BxLwT0mhrtgTPodf1v3xjg_174;
		}
LA11_: ;
	}
	goto LA7_;
LA9_: ;
	{
		eqcopy___system_u2694((&varCode_1), (*(*v_p1).constraint)._kind_3.strVal);
	}
LA7_: ;
	{
		tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* vX60gensym1026__1;
		if (!((*n_p2).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)1))) goto LA26_;
		vX60gensym1026__1 = NIM_NIL;
		{
			NIM_BOOL T30_;
			NIM_BOOL T31_;
			NIM_BOOL T32_;
			NIM_BOOL T33_;
			tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg T34_;
			tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg T36_;
			tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg T40_;
			NimStringV2 colontmpD__7;
			NimStringV2 colontmpD__8;
			NimStringV2 colontmpD__9;
			NimStringV2 colontmpD__10;
			tyArray__YgExxhfgKcesA5EOUj1MOA T43_;
			tyArray__YgExxhfgKcesA5EOUj1MOA T44_;
			T30_ = (NIM_BOOL)0;
			T31_ = (NIM_BOOL)0;
			vX60gensym1026__1 = v_p1;
			T32_ = (NIM_BOOL)0;
			T33_ = (NIM_BOOL)0;
			T34_ = 0;
			T33_ = !(((131080 & (*vX60gensym1026__1).flags) == T34_));
			if (!(T33_)) goto LA35_;
			T36_ = 0;
			T33_ = ((192 & (*vX60gensym1026__1).flags) == T36_);
LA35_: ;
			T32_ = T33_;
			if (!(T32_)) goto LA37_;
			T32_ = !(((*vX60gensym1026__1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)12) || (*vX60gensym1026__1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)13) || (*vX60gensym1026__1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)16) || (*vX60gensym1026__1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)14) || (*vX60gensym1026__1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)15) || (*vX60gensym1026__1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)10) || (*vX60gensym1026__1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)5) || (*vX60gensym1026__1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)9)));
LA37_: ;
			T31_ = !(T32_);
			if (!(T31_)) goto LA38_;
			T31_ = ((*(*v_p1).typ).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)23) || (*(*v_p1).typ).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)21) || (*(*v_p1).typ).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)47) || (*(*v_p1).typ).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)22) || (*(*v_p1).typ).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)45));
LA38_: ;
			T30_ = T31_;
			if (!(T30_)) goto LA39_;
			T40_ = (tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)0;
			T40_ = mapType__jsgen_u698(p_p0, (*v_p1).typ);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			T30_ = (T40_ == ((tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)9));
LA39_: ;
			if (!T30_) goto LA41_;
			colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
			colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
			colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
			colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
			T43_[0] = varName_1;
			colontmpD__7 = percent___jsgen_u4985(T43_, 1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			colontmpD__8 = indentLine__jsgen_u102(p_p0, colontmpD__7);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			prepareAdd((&(*p_p0).body), colontmpD__8.len + 0);
appendString((&(*p_p0).body), colontmpD__8);
			T44_[0] = varName_1;
			colontmpD__9 = percent___jsgen_u4990(T44_, 1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			colontmpD__10 = indentLine__jsgen_u102(p_p0, colontmpD__9);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			prepareAdd((&(*p_p0).body), colontmpD__10.len + 0);
appendString((&(*p_p0).body), colontmpD__10);
			eqdestroy___system_u2691(colontmpD__10);
			eqdestroy___system_u2691(colontmpD__9);
			eqdestroy___system_u2691(colontmpD__8);
			eqdestroy___system_u2691(colontmpD__7);
		}
		goto LA28_;
LA41_: ;
		{
			NimStringV2 colontmpD__11;
			tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* vX60gensym1033__1;
			NimStringV2 colontmpD__12;
			NimStringV2 colontmpD__13;
			NimStringV2 colontmpD__14;
			NimStringV2 T47_;
			tyArray__dyW7vpmfeTYw8kX3EXuaJA T48_;
			NIM_BOOL T49_;
			NIM_BOOL T50_;
			tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg T51_;
			tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg T53_;
			colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
			vX60gensym1033__1 = NIM_NIL;
			colontmpD__12.len = 0; colontmpD__12.p = NIM_NIL;
			colontmpD__13.len = 0; colontmpD__13.p = NIM_NIL;
			colontmpD__14.len = 0; colontmpD__14.p = NIM_NIL;
			T47_.len = 0; T47_.p = NIM_NIL;
			T47_ = rawNewString(varCode_1.len + 8);
appendString((&T47_), varCode_1);
appendString((&T47_), TM__BxLwT0mhrtgTPodf1v3xjg_179);
			colontmpD__11 = T47_;
			T48_[0] = TM__BxLwT0mhrtgTPodf1v3xjg_180;
			T48_[1] = varName_1;
			eqcopy___ast_u4577(&vX60gensym1033__1, v_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA46_;
			T49_ = (NIM_BOOL)0;
			T50_ = (NIM_BOOL)0;
			T51_ = 0;
			T50_ = !(((131080 & (*vX60gensym1033__1).flags) == T51_));
			if (!(T50_)) goto LA52_;
			T53_ = 0;
			T50_ = ((192 & (*vX60gensym1033__1).flags) == T53_);
LA52_: ;
			T49_ = T50_;
			if (!(T49_)) goto LA54_;
			T49_ = !(((*vX60gensym1033__1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)12) || (*vX60gensym1033__1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)13) || (*vX60gensym1033__1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)16) || (*vX60gensym1033__1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)14) || (*vX60gensym1033__1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)15) || (*vX60gensym1033__1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)10) || (*vX60gensym1033__1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)5) || (*vX60gensym1033__1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)9)));
LA54_: ;
			colontmpD__12 = createVar__jsgen_u4648(p_p0, (*v_p1).typ, T49_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA46_;
			T48_[2] = colontmpD__12;
			colontmpD__13 = runtimeFormat__ropes_u39(colontmpD__11, T48_, 3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA46_;
			colontmpD__14 = indentLine__jsgen_u102(p_p0, colontmpD__13);
			if (NIM_UNLIKELY(*nimErr_)) goto LA46_;
			prepareAdd((&(*p_p0).body), colontmpD__14.len + 0);
appendString((&(*p_p0).body), colontmpD__14);
			{
				LA46_:;
			}
			{
				oldNimErrFin46_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___system_u2691(colontmpD__14);
				eqdestroy___system_u2691(colontmpD__13);
				eqdestroy___system_u2691(colontmpD__12);
				eqdestroy___ast_u4574(vX60gensym1033__1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				eqdestroy___system_u2691(colontmpD__11);
				*nimErr_ = oldNimErrFin46_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA28_: ;
	}
	goto LA24_;
LA26_: ;
	{
		tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* vX60gensym1056__1;
		tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg T58_;
		vX60gensym1056__1 = NIM_NIL;
		gen__jsgen_u1159(p_p0, n_p2, (&a_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T58_ = (tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)0;
		T58_ = mapType__jsgen_u698(p_p0, (*v_p1).typ);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		switch (T58_) {
		case ((tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)8):
		case ((tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)4):
		{
			{
				NIM_BOOL T62_;
				T62_ = (NIM_BOOL)0;
				T62_ = ((*(*v_p1).typ).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)27) || (*(*v_p1).typ).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)48));
				if (T62_) goto LA63_;
				T62_ = needsNoCopy__jsgen_u3374(p_p0, n_p2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
LA63_: ;
				if (!T62_) goto LA64_;
				s_1 = a_1.res;
				eqwasMoved___system_u2688((&a_1.res));
			}
			goto LA60_;
LA64_: ;
			{
				NimStringV2 colontmpD__15;
				tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T68_;
				colontmpD__15.len = 0; colontmpD__15.p = NIM_NIL;
				useMagic__jsgen_u1172(p_p0, TM__BxLwT0mhrtgTPodf1v3xjg_329);
				if (NIM_UNLIKELY(*nimErr_)) goto LA67_;
				T68_[0] = a_1.res;
				colontmpD__15 = genTypeInfo__jsgen_u828(p_p0, (*n_p2).typField);
				if (NIM_UNLIKELY(*nimErr_)) goto LA67_;
				T68_[1] = colontmpD__15;
				s_1 = percent___jsgen_u5021(T68_, 2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA67_;
				{
					LA67_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__15);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
LA60_: ;
		}
		break;
		case ((tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)9):
		{
			NIM_BOOL targetBaseIndex_1;
			tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg T72_;
			T72_ = 0;
			targetBaseIndex_1 = ((131080 & (*v_p1).flags) == T72_);
			{
				if (!(a_1.typ == ((tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)9))) goto LA75_;
				{
					NimStringV2 colontmpD__16;
					NimStringV2 colontmpD__17;
					NimStringV2 colontmpD__18;
					NimStringV2 T81_;
					tyArray__Seu7uK9aaOSN0BK3EAjjSHw T82_;
					if (!targetBaseIndex_1) goto LA79_;
					colontmpD__16.len = 0; colontmpD__16.p = NIM_NIL;
					colontmpD__17.len = 0; colontmpD__17.p = NIM_NIL;
					colontmpD__18.len = 0; colontmpD__18.p = NIM_NIL;
					T81_.len = 0; T81_.p = NIM_NIL;
					T81_ = rawNewString(varCode_1.len + 21);
appendString((&T81_), varCode_1);
appendString((&T81_), TM__BxLwT0mhrtgTPodf1v3xjg_331);
					colontmpD__16 = T81_;
					T82_[0] = TM__BxLwT0mhrtgTPodf1v3xjg_332;
					T82_[1] = (*v_p1).loc.snippet;
					T82_[2] = a_1.address;
					T82_[3] = a_1.res;
					colontmpD__17 = runtimeFormat__ropes_u39(colontmpD__16, T82_, 4);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					colontmpD__18 = indentLine__jsgen_u102(p_p0, colontmpD__17);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					prepareAdd((&(*p_p0).body), colontmpD__18.len + 0);
appendString((&(*p_p0).body), colontmpD__18);
					eqdestroy___system_u2691(colontmpD__18);
					eqdestroy___system_u2691(colontmpD__17);
					eqdestroy___system_u2691(colontmpD__16);
				}
				goto LA77_;
LA79_: ;
				{
					tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* vX60gensym1043__1;
					vX60gensym1043__1 = NIM_NIL;
					{
						NIM_BOOL T86_;
						NIM_BOOL T87_;
						tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg T88_;
						tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg T90_;
						NimStringV2 colontmpD__19;
						NimStringV2 colontmpD__20;
						NimStringV2 colontmpD__21;
						NimStringV2 T94_;
						tyArray__Seu7uK9aaOSN0BK3EAjjSHw T95_;
						vX60gensym1043__1 = v_p1;
						T86_ = (NIM_BOOL)0;
						T87_ = (NIM_BOOL)0;
						T88_ = 0;
						T87_ = !(((131080 & (*vX60gensym1043__1).flags) == T88_));
						if (!(T87_)) goto LA89_;
						T90_ = 0;
						T87_ = ((192 & (*vX60gensym1043__1).flags) == T90_);
LA89_: ;
						T86_ = T87_;
						if (!(T86_)) goto LA91_;
						T86_ = !(((*vX60gensym1043__1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)12) || (*vX60gensym1043__1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)13) || (*vX60gensym1043__1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)16) || (*vX60gensym1043__1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)14) || (*vX60gensym1043__1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)15) || (*vX60gensym1043__1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)10) || (*vX60gensym1043__1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)5) || (*vX60gensym1043__1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)9)));
LA91_: ;
						if (!T86_) goto LA92_;
						colontmpD__19.len = 0; colontmpD__19.p = NIM_NIL;
						colontmpD__20.len = 0; colontmpD__20.p = NIM_NIL;
						colontmpD__21.len = 0; colontmpD__21.p = NIM_NIL;
						T94_.len = 0; T94_.p = NIM_NIL;
						T94_ = rawNewString(varCode_1.len + 16);
appendString((&T94_), varCode_1);
appendString((&T94_), TM__BxLwT0mhrtgTPodf1v3xjg_334);
						colontmpD__19 = T94_;
						T95_[0] = TM__BxLwT0mhrtgTPodf1v3xjg_335;
						T95_[1] = (*v_p1).loc.snippet;
						T95_[2] = a_1.address;
						T95_[3] = a_1.res;
						colontmpD__20 = runtimeFormat__ropes_u39(colontmpD__19, T95_, 4);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						colontmpD__21 = indentLine__jsgen_u102(p_p0, colontmpD__20);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						prepareAdd((&(*p_p0).body), colontmpD__21.len + 0);
appendString((&(*p_p0).body), colontmpD__21);
						eqdestroy___system_u2691(colontmpD__21);
						eqdestroy___system_u2691(colontmpD__20);
						eqdestroy___system_u2691(colontmpD__19);
					}
					goto LA84_;
LA92_: ;
					{
						NimStringV2 colontmpD__22;
						NimStringV2 colontmpD__23;
						NimStringV2 colontmpD__24;
						NimStringV2 T97_;
						tyArray__Seu7uK9aaOSN0BK3EAjjSHw T98_;
						colontmpD__22.len = 0; colontmpD__22.p = NIM_NIL;
						colontmpD__23.len = 0; colontmpD__23.p = NIM_NIL;
						colontmpD__24.len = 0; colontmpD__24.p = NIM_NIL;
						T97_.len = 0; T97_.p = NIM_NIL;
						T97_ = rawNewString(varCode_1.len + 14);
appendString((&T97_), varCode_1);
appendString((&T97_), TM__BxLwT0mhrtgTPodf1v3xjg_337);
						colontmpD__22 = T97_;
						T98_[0] = TM__BxLwT0mhrtgTPodf1v3xjg_338;
						T98_[1] = (*v_p1).loc.snippet;
						T98_[2] = a_1.address;
						T98_[3] = a_1.res;
						colontmpD__23 = runtimeFormat__ropes_u39(colontmpD__22, T98_, 4);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						colontmpD__24 = indentLine__jsgen_u102(p_p0, colontmpD__23);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						prepareAdd((&(*p_p0).body), colontmpD__24.len + 0);
appendString((&(*p_p0).body), colontmpD__24);
						eqdestroy___system_u2691(colontmpD__24);
						eqdestroy___system_u2691(colontmpD__23);
						eqdestroy___system_u2691(colontmpD__22);
					}
LA84_: ;
				}
LA77_: ;
			}
			goto LA73_;
LA75_: ;
			{
				{
					NimStringV2 tmp_1;
					NimStringV2 colontmpD__25;
					NimStringV2 colontmpD__26;
					tyArray__dyW7vpmfeTYw8kX3EXuaJA T104_;
					if (!targetBaseIndex_1) goto LA102_;
					tmp_1.len = 0; tmp_1.p = NIM_NIL;
					colontmpD__25.len = 0; colontmpD__25.p = NIM_NIL;
					colontmpD__26.len = 0; colontmpD__26.p = NIM_NIL;
					tmp_1 = getTemp__jsgen_u1235(p_p0, NIM_TRUE);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					T104_[0] = tmp_1;
					T104_[1] = a_1.res;
					T104_[2] = (*v_p1).loc.snippet;
					colontmpD__25 = percent___jsgen_u5062(T104_, 3);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					colontmpD__26 = indentLine__jsgen_u102(p_p0, colontmpD__25);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					prepareAdd((&(*p_p0).body), colontmpD__26.len + 0);
appendString((&(*p_p0).body), colontmpD__26);
					eqdestroy___system_u2691(colontmpD__26);
					eqdestroy___system_u2691(colontmpD__25);
					eqdestroy___system_u2691(tmp_1);
				}
				goto LA100_;
LA102_: ;
				{
					NimStringV2 colontmpD__27;
					NimStringV2 colontmpD__28;
					NimStringV2 colontmpD__29;
					NimStringV2 T106_;
					tyArray__dyW7vpmfeTYw8kX3EXuaJA T107_;
					colontmpD__27.len = 0; colontmpD__27.p = NIM_NIL;
					colontmpD__28.len = 0; colontmpD__28.p = NIM_NIL;
					colontmpD__29.len = 0; colontmpD__29.p = NIM_NIL;
					T106_.len = 0; T106_.p = NIM_NIL;
					T106_ = rawNewString(varCode_1.len + 8);
appendString((&T106_), varCode_1);
appendString((&T106_), TM__BxLwT0mhrtgTPodf1v3xjg_339);
					colontmpD__27 = T106_;
					T107_[0] = TM__BxLwT0mhrtgTPodf1v3xjg_340;
					T107_[1] = (*v_p1).loc.snippet;
					T107_[2] = a_1.res;
					colontmpD__28 = runtimeFormat__ropes_u39(colontmpD__27, T107_, 3);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					colontmpD__29 = indentLine__jsgen_u102(p_p0, colontmpD__28);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					prepareAdd((&(*p_p0).body), colontmpD__29.len + 0);
appendString((&(*p_p0).body), colontmpD__29);
					eqdestroy___system_u2691(colontmpD__29);
					eqdestroy___system_u2691(colontmpD__28);
					eqdestroy___system_u2691(colontmpD__27);
				}
LA100_: ;
			}
LA73_: ;
			eqdestroy___system_u2691(varName_1);
			eqdestroy___system_u2691(varCode_1);
			eqdestroy___system_u2691(s_1);
			eqdestroy___jsgen_u570((&a_1));
			goto BeforeRet_;
		}
		break;
		default:
		{
			s_1 = a_1.res;
			eqwasMoved___system_u2688((&a_1.res));
		}
		break;
		}
		{
			NIM_BOOL T111_;
			NIM_BOOL T112_;
			tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg T113_;
			tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg T115_;
			NimStringV2 colontmpD__30;
			NimStringV2 colontmpD__31;
			NimStringV2 colontmpD__32;
			NimStringV2 T119_;
			tyArray__dyW7vpmfeTYw8kX3EXuaJA T120_;
			vX60gensym1056__1 = v_p1;
			T111_ = (NIM_BOOL)0;
			T112_ = (NIM_BOOL)0;
			T113_ = 0;
			T112_ = !(((131080 & (*vX60gensym1056__1).flags) == T113_));
			if (!(T112_)) goto LA114_;
			T115_ = 0;
			T112_ = ((192 & (*vX60gensym1056__1).flags) == T115_);
LA114_: ;
			T111_ = T112_;
			if (!(T111_)) goto LA116_;
			T111_ = !(((*vX60gensym1056__1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)12) || (*vX60gensym1056__1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)13) || (*vX60gensym1056__1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)16) || (*vX60gensym1056__1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)14) || (*vX60gensym1056__1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)15) || (*vX60gensym1056__1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)10) || (*vX60gensym1056__1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)5) || (*vX60gensym1056__1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)9)));
LA116_: ;
			if (!T111_) goto LA117_;
			colontmpD__30.len = 0; colontmpD__30.p = NIM_NIL;
			colontmpD__31.len = 0; colontmpD__31.p = NIM_NIL;
			colontmpD__32.len = 0; colontmpD__32.p = NIM_NIL;
			T119_.len = 0; T119_.p = NIM_NIL;
			T119_ = rawNewString(varCode_1.len + 10);
appendString((&T119_), varCode_1);
appendString((&T119_), TM__BxLwT0mhrtgTPodf1v3xjg_342);
			colontmpD__30 = T119_;
			T120_[0] = TM__BxLwT0mhrtgTPodf1v3xjg_343;
			T120_[1] = (*v_p1).loc.snippet;
			T120_[2] = s_1;
			colontmpD__31 = runtimeFormat__ropes_u39(colontmpD__30, T120_, 3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			colontmpD__32 = indentLine__jsgen_u102(p_p0, colontmpD__31);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			prepareAdd((&(*p_p0).body), colontmpD__32.len + 0);
appendString((&(*p_p0).body), colontmpD__32);
			eqdestroy___system_u2691(colontmpD__32);
			eqdestroy___system_u2691(colontmpD__31);
			eqdestroy___system_u2691(colontmpD__30);
		}
		goto LA109_;
LA117_: ;
		{
			NimStringV2 colontmpD__33;
			NimStringV2 colontmpD__34;
			NimStringV2 colontmpD__35;
			NimStringV2 T122_;
			tyArray__dyW7vpmfeTYw8kX3EXuaJA T123_;
			colontmpD__33.len = 0; colontmpD__33.p = NIM_NIL;
			colontmpD__34.len = 0; colontmpD__34.p = NIM_NIL;
			colontmpD__35.len = 0; colontmpD__35.p = NIM_NIL;
			T122_.len = 0; T122_.p = NIM_NIL;
			T122_ = rawNewString(varCode_1.len + 8);
appendString((&T122_), varCode_1);
appendString((&T122_), TM__BxLwT0mhrtgTPodf1v3xjg_344);
			colontmpD__33 = T122_;
			T123_[0] = TM__BxLwT0mhrtgTPodf1v3xjg_345;
			T123_[1] = (*v_p1).loc.snippet;
			T123_[2] = s_1;
			colontmpD__34 = runtimeFormat__ropes_u39(colontmpD__33, T123_, 3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			colontmpD__35 = indentLine__jsgen_u102(p_p0, colontmpD__34);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			prepareAdd((&(*p_p0).body), colontmpD__35.len + 0);
appendString((&(*p_p0).body), colontmpD__35);
			eqdestroy___system_u2691(colontmpD__35);
			eqdestroy___system_u2691(colontmpD__34);
			eqdestroy___system_u2691(colontmpD__33);
		}
LA109_: ;
	}
LA24_: ;
	{
		NIM_BOOL T126_;
		NimStringV2 colontmpD__36;
		NimStringV2 colontmpD__37;
		tyArray__TonP9cxJgj8gXu71dWIyNlA T130_;
		T126_ = (NIM_BOOL)0;
		T126_ = useReloadingGuard_1;
		if (T126_) goto LA127_;
		T126_ = useGlobalPragmas_1;
LA127_: ;
		if (!T126_) goto LA128_;
		colontmpD__36.len = 0; colontmpD__36.p = NIM_NIL;
		colontmpD__37.len = 0; colontmpD__37.p = NIM_NIL;
		(*p_p0).extraIndent -= ((NI)1);
		colontmpD__36 = percent___cgen_u9681(T130_, 0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		colontmpD__37 = indentLine__jsgen_u102(p_p0, colontmpD__36);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		prepareAdd((&(*p_p0).body), colontmpD__37.len + 0);
appendString((&(*p_p0).body), colontmpD__37);
		eqdestroy___system_u2691(colontmpD__37);
		eqdestroy___system_u2691(colontmpD__36);
	}
LA128_: ;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(varName_1);
		eqdestroy___system_u2691(varCode_1);
		eqdestroy___system_u2691(s_1);
		eqdestroy___jsgen_u570((&a_1));
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genCopyForParamIfNeeded__jsgen_u4136)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_1;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD_;
	tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* owner_1;
NIM_BOOL oldNimErrFin10_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	s_1 = NIM_NIL;
	colontmpD_ = NIM_NIL;
	owner_1 = NIM_NIL;
	eqcopy___ast_u4577(&s_1, (*n_p1)._kind_4.sym);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NIM_BOOL T4_;
		T4_ = (NIM_BOOL)0;
		colontmpD_ = owner__ast_u6254(s_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T4_ = ((*p_p0).prc == colontmpD_);
		if (T4_) goto LA5_;
		T4_ = needsNoCopy__jsgen_u3374(p_p0, n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
LA5_: ;
		if (!T4_) goto LA6_;
		eqdestroy___jsgen_u139(owner_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u4574(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u4574(s_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		goto BeforeRet_;
	}
LA6_: ;
	eqcopy___jsgen_u142(&owner_1, (*p_p0).up, NIM_FALSE);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		while (1) {
			tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD__2;
			colontmpD__2 = NIM_NIL;
			{
				NimStringV2 colontmpD__3;
				NimStringV2 T16_;
				if (!(owner_1 == ((tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw*) NIM_NIL))) goto LA13_;
				colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
				T16_.len = 0; T16_.p = NIM_NIL;
				T16_ = rawNewString((*(*s_1).name).s.len + 55);
appendString((&T16_), TM__BxLwT0mhrtgTPodf1v3xjg_347);
appendString((&T16_), (*(*s_1).name).s);
				colontmpD__3 = T16_;
				internalErrorImpl__msgs_u1598((*(*p_p0).module).config, (*n_p1).info, colontmpD__3, (&TM__BxLwT0mhrtgTPodf1v3xjg_348));
				if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
				{
					LA15_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__3);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
			}
LA13_: ;
			{
				colontmpD__2 = owner__ast_u6254(s_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
				if (!((*owner_1).prc == colontmpD__2)) goto LA21_;
				{
					tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA xX60gensym886__1;
					NIM_BOOL T25_;
					NimStringV2 copy_1;
					NimStringV2 colontmpD__4;
					NimStringV2 colontmpD__5;
					tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T29_;
					xX60gensym886__1 = (*s_1).itemId;
					T25_ = (NIM_BOOL)0;
					T25_ = containsOrIncl__astyaml_u223((&(*owner_1).generatedParamCopies), (NI)((NI)((NU64)(((NI) (xX60gensym886__1.module))) << (NU64)(((NI)24) & (64 - 1))) + ((NI) (xX60gensym886__1.item))));
					if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
					if (!!(T25_)) goto LA26_;
					copy_1.len = 0; copy_1.p = NIM_NIL;
					colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
					colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
					T29_[0] = (*s_1).loc.snippet;
					colontmpD__4 = genTypeInfo__jsgen_u828(p_p0, (*s_1).typ);
					if (NIM_UNLIKELY(*nimErr_)) goto LA28_;
					T29_[1] = colontmpD__4;
					copy_1 = percent___jsgen_u4187(T29_, 2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA28_;
					colontmpD__5 = indentLine__jsgen_u102(owner_1, copy_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA28_;
					prepareAdd((&(*owner_1).locals), colontmpD__5.len + 0);
appendString((&(*owner_1).locals), colontmpD__5);
					{
						LA28_:;
					}
					{
						eqdestroy___system_u2691(colontmpD__5);
						eqdestroy___system_u2691(colontmpD__4);
						eqdestroy___system_u2691(copy_1);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
				}
LA26_: ;
				eqdestroy___ast_u4574(colontmpD__2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				eqdestroy___jsgen_u139(owner_1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				eqdestroy___ast_u4574(colontmpD_);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				eqdestroy___ast_u4574(s_1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				goto BeforeRet_;
			}
LA21_: ;
			eqcopy___jsgen_u142(&owner_1, (*owner_1).up, NIM_FALSE);
			if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
			{
				LA10_:;
			}
			{
				oldNimErrFin10_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u4574(colontmpD__2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				*nimErr_ = oldNimErrFin10_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
	}
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___jsgen_u139(owner_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u4574(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u4574(s_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genConstant__jsgen_u1169)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* c_p1) {
NIM_BOOL oldNimErrFin8_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NIM_BOOL T3_;
		tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA xX60gensym1088__1;
		NIM_BOOL T5_;
		NimStringV2 oldBody_1;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD_;
		T3_ = (NIM_BOOL)0;
		T3_ = !((((*c_p1).loc.flags &((NU16)1<<((NU)((((tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg)2)))&15U)))!=0));
		if (!(T3_)) goto LA4_;
		xX60gensym1088__1 = (*c_p1).itemId;
		T5_ = (NIM_BOOL)0;
		T5_ = containsOrIncl__astyaml_u223((&(*(*p_p0).g).generatedSyms), (NI)((NI)((NU64)(((NI) (xX60gensym1088__1.module))) << (NU64)(((NI)24) & (64 - 1))) + ((NI) (xX60gensym1088__1.item))));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T3_ = !(T5_);
LA4_: ;
		if (!T3_) goto LA6_;
		oldBody_1.len = 0; oldBody_1.p = NIM_NIL;
		colontmpD_ = NIM_NIL;
		oldBody_1 = (*p_p0).body;
		eqwasMoved___system_u2688((&(*p_p0).body));
		colontmpD_ = astdef__ast_u4596(c_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		genVarInit__jsgen_u4193(p_p0, c_p1, colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		prepareAdd((&(*(*p_p0).g).constants), (*p_p0).body.len + 0);
appendString((&(*(*p_p0).g).constants), (*p_p0).body);
		eqsink___system_u2700((&(*p_p0).body), oldBody_1);
		eqwasMoved___system_u2688((&oldBody_1));
		{
			LA8_:;
		}
		{
			oldNimErrFin8_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3252(colontmpD_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			eqdestroy___system_u2691(oldBody_1);
			*nimErr_ = oldNimErrFin8_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA6_: ;
	}BeforeRet_: ;
}
static N_INLINE(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, getBody__modulegraphs_u17880)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	eqcopy___ast_u3255(&result, (*(*s_p1).ast)._kind_6.sons.p->data[((NI)6)]);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		NIM_BOOL T3_;
		tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* T7_;
		tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* T8_;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T9_;
		T3_ = (NIM_BOOL)0;
		T3_ = (result == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL));
		if (!(T3_)) goto LA4_;
		T3_ = ((*(*g_p0).config).symbolFiles == ((tyEnum_SymbolFilesOption__2eyIIreuRXhYT9buPPZbBYA)2) || (*(*g_p0).config).symbolFiles == ((tyEnum_SymbolFilesOption__2eyIIreuRXhYT9buPPZbBYA)3) || (*(*g_p0).config).symbolFiles == ((tyEnum_SymbolFilesOption__2eyIIreuRXhYT9buPPZbBYA)4));
LA4_: ;
		if (!T3_) goto LA5_;
		T7_ = NIM_NIL;
		T7_ = (*g_p0).config;
		T8_ = NIM_NIL;
		T8_ = (*g_p0).cache;
		T9_ = NIM_NIL;
		T9_ = loadProcBody__icZic_u21187(T7_, T8_, (&(*g_p0).packed_0), s_p1);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T9_); goto BeforeRet_;}
		eqsink___ast_u3261(&result, T9_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqcopy___ast_u3255(&(*(*s_p1).ast)._kind_6.sons.p->data[((NI)6)], result);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA5_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, attachProc__jsgen_u4076)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, NimStringV2 content_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p2) {
	prepareAdd((&(*(*p_p0).g).code), content_p1.len + 0);
appendString((&(*(*p_p0).g).code), content_p1);
}
N_LIB_PRIVATE N_NIMCALL(void, attachProc__jsgen_u4080)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1) {
	NimStringV2 newp_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	newp_1.len = 0; newp_1.p = NIM_NIL;
	newp_1 = genProc__jsgen_u1166(p_p0, s_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	attachProc__jsgen_u4076(p_p0, newp_1, s_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(newp_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genProcForSymIfNeeded__jsgen_u4084)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1) {
NIM_BOOL oldNimErrFin10_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA xX60gensym876__1;
		NIM_BOOL T3_;
		xX60gensym876__1 = (*s_p1).itemId;
		T3_ = (NIM_BOOL)0;
		T3_ = containsOrIncl__astyaml_u223((&(*(*p_p0).g).generatedSyms), (NI)((NI)((NU64)(((NI) (xX60gensym876__1.module))) << (NU64)(((NI)24) & (64 - 1))) + ((NI) (xX60gensym876__1.item))));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!(T3_)) goto LA4_;
		{
			NimStringV2 newp_1;
			tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* owner_1;
			if (!(((*(*(*p_p0).module).config).legacyFeatures &((NU8)1<<((NU)((((tyEnum_LegacyFeature__yvNVqOQTgcxHpvo1MvfBfA)5)))&7U)))!=0)) goto LA8_;
			newp_1.len = 0; newp_1.p = NIM_NIL;
			owner_1 = NIM_NIL;
			newp_1 = genProc__jsgen_u1166(p_p0, s_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
			eqcopy___jsgen_u142(&owner_1, p_p0, NIM_FALSE);
			if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
			{
				tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD_;
				colontmpD_ = NIM_NIL;
				while (1) {
					NIM_BOOL T13_;
					tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* T15_;
					T13_ = (NIM_BOOL)0;
					T13_ = !((owner_1 == ((tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw*) NIM_NIL)));
					if (!(T13_)) goto LA14_;
					T15_ = NIM_NIL;
					T15_ = owner__ast_u6254(s_p1);
					if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u4574(T15_); goto LA10_;}
					eqsink___ast_u4583(&colontmpD_, T15_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
					T13_ = !(((*owner_1).prc == colontmpD_));
LA14_: ;
					if (!T13_) goto LA12;
					eqcopy___jsgen_u142(&owner_1, (*owner_1).up, NIM_FALSE);
					if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
				} LA12: ;
				eqdestroy___ast_u4574(colontmpD_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
			}
			{
				if (!!((owner_1 == ((tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw*) NIM_NIL)))) goto LA18_;
				prepareAdd((&(*owner_1).locals), newp_1.len + 0);
appendString((&(*owner_1).locals), newp_1);
			}
			goto LA16_;
LA18_: ;
			{
				attachProc__jsgen_u4076(p_p0, newp_1, s_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
			}
LA16_: ;
			{
				LA10_:;
			}
			{
				oldNimErrFin10_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___jsgen_u139(owner_1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				eqdestroy___system_u2691(newp_1);
				*nimErr_ = oldNimErrFin10_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		goto LA6_;
LA8_: ;
		{
			attachProc__jsgen_u4080(p_p0, s_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA6_: ;
	}
LA4_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genSym__jsgen_u4197)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* r_p2) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_1;
NIM_BOOL oldNimErrFin15_;
NIM_BOOL oldNimErrFin82_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	s_1 = NIM_NIL;
	eqcopy___ast_u4577(&s_1, (*n_p1)._kind_4.sym);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	switch ((*s_1).kind) {
	case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)8):
	case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)9):
	case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)3):
	case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)5):
	case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)11):
	case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)21):
	{
		tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* vX60gensym898__1;
		tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg k_1;
		vX60gensym898__1 = NIM_NIL;
		{
			NimStringV2 colontmpD_;
			NimStringV2 T8_;
			if (!((*s_1).loc.snippet.len == 0)) goto LA5_;
			colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
			T8_.len = 0; T8_.p = NIM_NIL;
			T8_ = rawNewString((*(*s_1).name).s.len + 30);
appendString((&T8_), TM__BxLwT0mhrtgTPodf1v3xjg_41);
appendString((&T8_), (*(*s_1).name).s);
			colontmpD_ = T8_;
			internalErrorImpl__msgs_u1598((*(*p_p0).module).config, (*n_p1).info, colontmpD_, (&TM__BxLwT0mhrtgTPodf1v3xjg_42));
			if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
			{
				LA7_:;
			}
			{
				eqdestroy___system_u2691(colontmpD_);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA5_: ;
		{
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__2;
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__3;
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__4;
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T16_;
			if (!(((*s_1).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)28)))&63U)))!=0)) goto LA13_;
			colontmpD__2 = NIM_NIL;
			colontmpD__3 = NIM_NIL;
			colontmpD__4 = NIM_NIL;
			T16_ = NIM_NIL;
			{
				colontmpD__2 = astdef__ast_u4596(s_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
				if (!!((colontmpD__2 == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL)))) goto LA19_;
				colontmpD__3 = astdef__ast_u4596(s_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
				T16_ = colontmpD__3;
			}
			goto LA17_;
LA19_: ;
			{
				colontmpD__4 = newNodeI__ast_u4091(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)1), (*s_1).info);
				if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
				T16_ = colontmpD__4;
			}
LA17_: ;
			genVarInit__jsgen_u4193(p_p0, s_1, T16_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
			{
				LA15_:;
			}
			{
				oldNimErrFin15_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u3252(colontmpD__4);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				eqdestroy___ast_u3252(colontmpD__3);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				eqdestroy___ast_u3252(colontmpD__2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				*nimErr_ = oldNimErrFin15_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA13_: ;
		{
			NIM_BOOL T26_;
			T26_ = (NIM_BOOL)0;
			T26_ = (((*(*(*p_p0).module).config).legacyFeatures &((NU8)1<<((NU)((((tyEnum_LegacyFeature__yvNVqOQTgcxHpvo1MvfBfA)5)))&7U)))!=0);
			if (!(T26_)) goto LA27_;
			T26_ = ((*s_1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)3));
LA27_: ;
			if (!T26_) goto LA28_;
			genCopyForParamIfNeeded__jsgen_u4136(p_p0, n_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA28_: ;
		k_1 = mapType__jsgen_u698(p_p0, (*s_1).typ);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		{
			if (!(k_1 == ((tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)9))) goto LA32_;
			(*r_p2).typ = ((tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)9);
			{
				tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg T36_;
				tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* vX60gensym895__1;
				T36_ = 0;
				if (!!(((131080 & (*s_1).flags) == T36_))) goto LA37_;
				vX60gensym895__1 = NIM_NIL;
				{
					NIM_BOOL T41_;
					NIM_BOOL T42_;
					tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg T43_;
					tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg T45_;
					tyArray__YgExxhfgKcesA5EOUj1MOA T49_;
					NimStringV2 T50_;
					tyArray__YgExxhfgKcesA5EOUj1MOA T51_;
					NimStringV2 T52_;
					vX60gensym895__1 = s_1;
					T41_ = (NIM_BOOL)0;
					T42_ = (NIM_BOOL)0;
					T43_ = 0;
					T42_ = !(((131080 & (*vX60gensym895__1).flags) == T43_));
					if (!(T42_)) goto LA44_;
					T45_ = 0;
					T42_ = ((192 & (*vX60gensym895__1).flags) == T45_);
LA44_: ;
					T41_ = T42_;
					if (!(T41_)) goto LA46_;
					T41_ = !(((*vX60gensym895__1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)12) || (*vX60gensym895__1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)13) || (*vX60gensym895__1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)16) || (*vX60gensym895__1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)14) || (*vX60gensym895__1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)15) || (*vX60gensym895__1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)10) || (*vX60gensym895__1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)5) || (*vX60gensym895__1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)9)));
LA46_: ;
					if (!T41_) goto LA47_;
					T49_[0] = (*s_1).loc.snippet;
					T50_.len = 0; T50_.p = NIM_NIL;
					T50_ = percent___jsgen_u4253(T49_, 1);
					if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T50_); goto LA1_;}
					eqsink___system_u2700((&(*r_p2).address), T50_);
					T51_[0] = (*s_1).loc.snippet;
					T52_.len = 0; T52_.p = NIM_NIL;
					T52_ = percent___jsgen_u4258(T51_, 1);
					if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T52_); goto LA1_;}
					eqsink___system_u2700((&(*r_p2).res), T52_);
				}
				goto LA39_;
LA47_: ;
				{
					tyArray__YgExxhfgKcesA5EOUj1MOA T54_;
					NimStringV2 T55_;
					tyArray__YgExxhfgKcesA5EOUj1MOA T56_;
					NimStringV2 T57_;
					T54_[0] = (*s_1).loc.snippet;
					T55_.len = 0; T55_.p = NIM_NIL;
					T55_ = percent___jsgen_u3725(T54_, 1);
					if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T55_); goto LA1_;}
					eqsink___system_u2700((&(*r_p2).address), T55_);
					T56_[0] = (*s_1).loc.snippet;
					T57_.len = 0; T57_.p = NIM_NIL;
					T57_ = percent___jsgen_u3720(T56_, 1);
					if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T57_); goto LA1_;}
					eqsink___system_u2700((&(*r_p2).res), T57_);
				}
LA39_: ;
			}
			goto LA34_;
LA37_: ;
			{
				NimStringV2 T59_;
				eqcopy___system_u2694((&(*r_p2).address), (*s_1).loc.snippet);
				T59_.len = 0; T59_.p = NIM_NIL;
				T59_ = rawNewString((*s_1).loc.snippet.len + 4);
appendString((&T59_), (*s_1).loc.snippet);
appendString((&T59_), TM__BxLwT0mhrtgTPodf1v3xjg_349);
				eqsink___system_u2700((&(*r_p2).res), T59_);
			}
LA34_: ;
		}
		goto LA30_;
LA32_: ;
		{
			NIM_BOOL T61_;
			NIM_BOOL T62_;
			tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg T63_;
			tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg T65_;
			tyArray__YgExxhfgKcesA5EOUj1MOA T69_;
			NimStringV2 T70_;
			vX60gensym898__1 = s_1;
			T61_ = (NIM_BOOL)0;
			T62_ = (NIM_BOOL)0;
			T63_ = 0;
			T62_ = !(((131080 & (*vX60gensym898__1).flags) == T63_));
			if (!(T62_)) goto LA64_;
			T65_ = 0;
			T62_ = ((192 & (*vX60gensym898__1).flags) == T65_);
LA64_: ;
			T61_ = T62_;
			if (!(T61_)) goto LA66_;
			T61_ = !(((*vX60gensym898__1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)12) || (*vX60gensym898__1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)13) || (*vX60gensym898__1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)16) || (*vX60gensym898__1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)14) || (*vX60gensym898__1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)15) || (*vX60gensym898__1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)10) || (*vX60gensym898__1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)5) || (*vX60gensym898__1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)9)));
LA66_: ;
			if (!T61_) goto LA67_;
			T69_[0] = (*s_1).loc.snippet;
			T70_.len = 0; T70_.p = NIM_NIL;
			T70_ = percent___jsgen_u3725(T69_, 1);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T70_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T70_);
		}
		goto LA30_;
LA67_: ;
		{
			eqcopy___system_u2694((&(*r_p2).res), (*s_1).loc.snippet);
		}
LA30_: ;
	}
	break;
	case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)10):
	{
		genConstant__jsgen_u1169(p_p0, s_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		{
			NimStringV2 colontmpD__5;
			NimStringV2 T78_;
			if (!((*s_1).loc.snippet.len == 0)) goto LA75_;
			colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
			T78_.len = 0; T78_.p = NIM_NIL;
			T78_ = rawNewString((*(*s_1).name).s.len + 30);
appendString((&T78_), TM__BxLwT0mhrtgTPodf1v3xjg_350);
appendString((&T78_), (*(*s_1).name).s);
			colontmpD__5 = T78_;
			internalErrorImpl__msgs_u1598((*(*p_p0).module).config, (*n_p1).info, colontmpD__5, (&TM__BxLwT0mhrtgTPodf1v3xjg_351));
			if (NIM_UNLIKELY(*nimErr_)) goto LA77_;
			{
				LA77_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__5);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA75_: ;
		eqcopy___system_u2694((&(*r_p2).res), (*s_1).loc.snippet);
	}
	break;
	case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)12):
	case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)13):
	case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)16):
	case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)14):
	case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)15):
	{
		NimStringV2 colontmpD__6;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__7;
		colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
		colontmpD__7 = NIM_NIL;
		{
			NimStringV2 colontmpD__8;
			NimStringV2 T88_;
			if (!(((*s_1).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)28)))&63U)))!=0)) goto LA85_;
			colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
			T88_.len = 0; T88_.p = NIM_NIL;
			T88_ = rawNewString((*(*s_1).name).s.len + 48);
appendString((&T88_), TM__BxLwT0mhrtgTPodf1v3xjg_353);
appendString((&T88_), (*(*s_1).name).s);
			colontmpD__8 = T88_;
			liMessage__msgs_u1227((*(*p_p0).module).config, (*n_p1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), colontmpD__8, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__BxLwT0mhrtgTPodf1v3xjg_354), NIM_FALSE, NIM_FALSE);
			if (NIM_UNLIKELY(*nimErr_)) goto LA87_;
			{
				LA87_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__8);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA82_;
		}
LA85_: ;
		colontmpD__6 = mangleName__jsgen_u702((*p_p0).module, s_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA82_;
		(void)(colontmpD__6);
		eqcopy___system_u2694((&(*r_p2).res), (*s_1).loc.snippet);
		{
			NIM_BOOL T93_;
			NIM_BOOL T94_;
			tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg T97_;
			T93_ = (NIM_BOOL)0;
			T94_ = (NIM_BOOL)0;
			T94_ = (((*s_1).loc.flags &((NU16)1<<((NU)((((tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg)2)))&15U)))!=0);
			if (T94_) goto LA95_;
			T94_ = !(((*s_1).magic == ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)0) || (*s_1).magic == ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)157) || (*s_1).magic == ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)156) || (*s_1).magic == ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)144)));
LA95_: ;
			T93_ = T94_;
			if (T93_) goto LA96_;
			T97_ = 0;
			T93_ = !(((IL64(4294967360) & (*s_1).flags) == T97_));
LA96_: ;
			if (!T93_) goto LA98_;
		}
		goto LA91_;
LA98_: ;
		{
			NIM_BOOL T101_;
			T101_ = (NIM_BOOL)0;
			T101_ = ((*s_1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)14));
			if (!(T101_)) goto LA102_;
			colontmpD__7 = getBody__modulegraphs_u17880((*(*p_p0).module).graph, s_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA82_;
			T101_ = ((*colontmpD__7).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)1));
LA102_: ;
			if (!T101_) goto LA103_;
		}
		goto LA91_;
LA103_: ;
		{
			tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* blitTmp_1;
			if (!(((*s_1).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)4)))&63U)))!=0)) goto LA106_;
			blitTmp_1 = s_1;
			eqwasMoved___ast_u4571(&s_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA82_;
			add__renderer_u83((&(*(*p_p0).g).forwarded), blitTmp_1);
		}
		goto LA91_;
LA106_: ;
		{
			genProcForSymIfNeeded__jsgen_u4084(p_p0, s_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA82_;
		}
LA91_: ;
		{
			LA82_:;
		}
		{
			oldNimErrFin82_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3252(colontmpD__7);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___system_u2691(colontmpD__6);
			*nimErr_ = oldNimErrFin82_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	default:
	{
		{
			NimStringV2 colontmpD__9;
			NimStringV2 T117_;
			if (!((*s_1).loc.snippet.len == 0)) goto LA114_;
			colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
			T117_.len = 0; T117_.p = NIM_NIL;
			T117_ = rawNewString((*(*s_1).name).s.len + 30);
appendString((&T117_), TM__BxLwT0mhrtgTPodf1v3xjg_355);
appendString((&T117_), (*(*s_1).name).s);
			colontmpD__9 = T117_;
			internalErrorImpl__msgs_u1598((*(*p_p0).module).config, (*n_p1).info, colontmpD__9, (&TM__BxLwT0mhrtgTPodf1v3xjg_356));
			if (NIM_UNLIKELY(*nimErr_)) goto LA116_;
			{
				LA116_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__9);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA114_: ;
		{
			tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg T122_;
			NimStringV2 T125_;
			T122_ = (tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)0;
			T122_ = mapType__jsgen_u698(p_p0, (*s_1).typ);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			if (!(T122_ == ((tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)9))) goto LA123_;
			eqcopy___system_u2694((&(*r_p2).address), (*s_1).loc.snippet);
			T125_.len = 0; T125_.p = NIM_NIL;
			T125_ = rawNewString((*s_1).loc.snippet.len + 4);
appendString((&T125_), (*s_1).loc.snippet);
appendString((&T125_), TM__BxLwT0mhrtgTPodf1v3xjg_357);
			eqsink___system_u2700((&(*r_p2).res), T125_);
		}
		goto LA120_;
LA123_: ;
		{
			eqcopy___system_u2694((&(*r_p2).res), (*s_1).loc.snippet);
		}
LA120_: ;
	}
	break;
	}
	(*r_p2).kind = ((tyEnum_TResKind__UiCSai1lX4RMkJ9bHo9aP2HA)2);
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u4574(s_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, makeJsNimStrLit__jsgen_u810)(NimStringV2 s_p0) {
	NimStringV2 result;
	NimStringV2 x_1;
	NI i_1;
	result.len = 0; result.p = NIM_NIL;
	x_1.len = 0; x_1.p = NIM_NIL;
	x_1 = rawNewString(((NI)((NI)(((NI)4) * s_p0.len) + ((NI)1))));
	prepareAdd((&x_1), 1);
appendString((&x_1), TM__BxLwT0mhrtgTPodf1v3xjg_368);
	i_1 = ((NI)0);
	{
		if (!(i_1 < s_p0.len)) goto LA3_;
		addInt__stdZprivateZdigitsutils_u187((&x_1), ((NI64) (((NU8)(s_p0.p->data[i_1])))));
		i_1 += ((NI)1);
	}
LA3_: ;
	{
		while (1) {
			if (!(i_1 < s_p0.len)) goto LA6;
			prepareAdd((&x_1), 1);
appendString((&x_1), TM__BxLwT0mhrtgTPodf1v3xjg_370);
			addInt__stdZprivateZdigitsutils_u187((&x_1), ((NI64) (((NU8)(s_p0.p->data[i_1])))));
			i_1 += ((NI)1);
		} LA6: ;
	}
	prepareAdd((&x_1), 1);
appendString((&x_1), TM__BxLwT0mhrtgTPodf1v3xjg_371);
	result = x_1;
	return result;
}
static N_INLINE(NIM_BOOL, signbit__astyaml_u680)(NF x_p0) {
	NIM_BOOL result;
	int T1_;
	T1_ = (int)0;
	T1_ = signbit(x_p0);
	result = !((T1_ == ((NI32)0)));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genLineDir__jsgen_u2646)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
	NI line_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	line_1 = toLinenumber__msgs_u695((*n_p1).info);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!(line_1 < ((NI)0))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	{
		NimStringV2 colontmpD_;
		NimStringV2 colontmpD__2;
		NimStringV2 colontmpD__3;
		tyArray__YgExxhfgKcesA5EOUj1MOA T9_;
		if (!(((*(*(*p_p0).module).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)32)))&63U)))!=0)) goto LA7_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
		colontmpD_ = sourceLine__msgs_u1210((*(*p_p0).module).config, (*n_p1).info);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T9_[0] = colontmpD_;
		colontmpD__2 = percent___jsgen_u2654(T9_, 1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		colontmpD__3 = indentLine__jsgen_u102(p_p0, colontmpD__2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		prepareAdd((&(*p_p0).body), colontmpD__3.len + 0);
appendString((&(*p_p0).body), colontmpD__3);
		eqdestroy___system_u2691(colontmpD__3);
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(colontmpD_);
	}
LA7_: ;
	{
		NIM_BOOL T12_;
		NimStringV2 colontmpD__4;
		NimStringV2 colontmpD__5;
		NimStringV2 colontmpD__6;
		tyArray__YgExxhfgKcesA5EOUj1MOA T16_;
		T12_ = (NIM_BOOL)0;
		T12_ = (((*p_p0).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0);
		if (T12_) goto LA13_;
		T12_ = (((*(*(*p_p0).module).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0);
LA13_: ;
		if (!T12_) goto LA14_;
		colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
		colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
		colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
		colontmpD__4 = lineDir__jsgen_u2636((*(*p_p0).module).config, (*n_p1).info, line_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T16_[0] = colontmpD__4;
		colontmpD__5 = percent___cgen_u21793(T16_, 1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		colontmpD__6 = indentLine__jsgen_u102(p_p0, colontmpD__5);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		prepareAdd((&(*p_p0).body), colontmpD__6.len + 0);
appendString((&(*p_p0).body), colontmpD__6);
		eqdestroy___system_u2691(colontmpD__6);
		eqdestroy___system_u2691(colontmpD__5);
		eqdestroy___system_u2691(colontmpD__4);
	}
LA14_: ;
	{
		NIM_BOOL T19_;
		NimStringV2 colontmpD__7;
		NimStringV2 colontmpD__8;
		NimStringV2 colontmpD__9;
		NimStringV2 currentFileName_1;
		tyArray__YgExxhfgKcesA5EOUj1MOA T22_;
		NimStringV2 T23_;
		T19_ = (NIM_BOOL)0;
		T19_ = hasFrameInfo__jsgen_u2617(p_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!T19_) goto LA20_;
		colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
		colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
		colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
		currentFileName_1.len = 0; currentFileName_1.p = NIM_NIL;
		colontmpD__7 = rope__ropes_u15(((NI64) (line_1)));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T22_[0] = colontmpD__7;
		colontmpD__8 = percent___jsgen_u2671(T22_, 1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		colontmpD__9 = indentLine__jsgen_u102(p_p0, colontmpD__8);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		prepareAdd((&(*p_p0).body), colontmpD__9.len + 0);
appendString((&(*p_p0).body), colontmpD__9);
		T23_.len = 0; T23_.p = NIM_NIL;
		{
			NIM_BOOL T26_;
			NimStringV2 T30_;
			T26_ = (NIM_BOOL)0;
			T26_ = ((*n_p1).info.fileIndex < ((NI32)0));
			if (T26_) goto LA27_;
			T26_ = ((*(*p_p0).module).config == ((tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg*) NIM_NIL));
LA27_: ;
			if (!T26_) goto LA28_;
			T30_.len = 0; T30_.p = NIM_NIL;
			{
				if (!((*n_p1).info.fileIndex == ((NI32)-3))) goto LA33_;
				currentFileName_1 = TM__BxLwT0mhrtgTPodf1v3xjg_387;
			}
			goto LA31_;
LA33_: ;
			{
				currentFileName_1 = TM__BxLwT0mhrtgTPodf1v3xjg_389;
			}
LA31_: ;
		}
		goto LA24_;
LA28_: ;
		{
			eqcopy___system_u2694((&currentFileName_1), (*(*(*p_p0).module).config).m.fileInfos.p->data[(*n_p1).info.fileIndex].shortName);
		}
LA24_: ;
		{
			NimStringV2 colontmpD__10;
			NimStringV2 colontmpD__11;
			NimStringV2 colontmpD__12;
			tyArray__YgExxhfgKcesA5EOUj1MOA T41_;
			if (!!(eqStrings((*p_p0).previousFileName, currentFileName_1))) goto LA39_;
			colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
			colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
			colontmpD__12.len = 0; colontmpD__12.p = NIM_NIL;
			colontmpD__10 = makeJSString__jsgen_u806(currentFileName_1, NIM_TRUE);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			T41_[0] = colontmpD__10;
			colontmpD__11 = percent___jsgen_u2681(T41_, 1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			colontmpD__12 = indentLine__jsgen_u102(p_p0, colontmpD__11);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			prepareAdd((&(*p_p0).body), colontmpD__12.len + 0);
appendString((&(*p_p0).body), colontmpD__12);
			eqsink___system_u2700((&(*p_p0).previousFileName), currentFileName_1);
			eqwasMoved___system_u2688((&currentFileName_1));
			eqdestroy___system_u2691(colontmpD__12);
			eqdestroy___system_u2691(colontmpD__11);
			eqdestroy___system_u2691(colontmpD__10);
		}
LA39_: ;
		eqdestroy___system_u2691(currentFileName_1);
		eqdestroy___system_u2691(colontmpD__9);
		eqdestroy___system_u2691(colontmpD__8);
		eqdestroy___system_u2691(colontmpD__7);
	}
LA20_: ;
	}BeforeRet_: ;
}
static N_INLINE(NIM_BOOL, isAtom__ast_u7223)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	T1_ = (NIM_BOOL)0;
	T1_ = (((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)0) <= (*n_p0).kind);
	if (!(T1_)) goto LA2_;
	T1_ = ((*n_p0).kind <= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)23));
LA2_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isSimpleExpr__jsgen_u1221)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
	NIM_BOOL result;
NIM_BOOL oldNimErrFin3_;
NIM_BOOL oldNimErrFin15_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	switch ((*n_p1).kind) {
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)26) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)32):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)42):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)45):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)37):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)160):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)38):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)41):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)39):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)47):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)65):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)63):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)64):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)60):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)58):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)59):
	{
		{
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* c_1;
			c_1 = NIM_NIL;
			{
				NI i_1;
				NI colontmp_;
				NI i_2;
				i_1 = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = safeLen__ast_u3197(n_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
				i_2 = ((NI)0);
				{
					while (1) {
						if (!(i_2 < colontmp_)) goto LA6;
						i_1 = i_2;
						eqcopy___ast_u3255(&c_1, (*n_p1)._kind_6.sons.p->data[i_1]);
						if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
						{
							NIM_BOOL T9_;
							T9_ = (NIM_BOOL)0;
							T9_ = isSimpleExpr__jsgen_u1221(p_p0, c_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
							if (!!(T9_)) goto LA10_;
							result = NIM_FALSE;
							eqdestroy___ast_u3252(c_1);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
							goto BeforeRet_;
						}
LA10_: ;
						i_2 += ((NI)1);
					} LA6: ;
				}
			}
			{
				LA3_:;
			}
			{
				oldNimErrFin3_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u3252(c_1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				*nimErr_ = oldNimErrFin3_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		result = NIM_TRUE;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)126):
	{
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD_;
		colontmpD_ = NIM_NIL;
		{
			NI i_3;
			NI colontmp__2;
			NI T17_;
			NI i_4;
			i_3 = (NI)0;
			colontmp__2 = (NI)0;
			T17_ = (NI)0;
			T17_ = len__ast_u3190(n_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
			colontmp__2 = (NI)(T17_ - ((NI)1));
			i_4 = ((NI)0);
			{
				while (1) {
					if (!(i_4 < colontmp__2)) goto LA19;
					i_3 = i_4;
					{
						if (!!(((*(*n_p1)._kind_6.sons.p->data[i_3]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)125) || (*(*n_p1)._kind_6.sons.p->data[i_3]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)1)))) goto LA22_;
						result = NIM_FALSE;
						eqdestroy___ast_u3252(colontmpD_);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						goto BeforeRet_;
					}
LA22_: ;
					i_4 += ((NI)1);
				} LA19: ;
			}
		}
		colontmpD_ = lastSon__ast_u5208(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
		result = isSimpleExpr__jsgen_u1221(p_p0, colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
		{
			LA15_:;
		}
		{
			oldNimErrFin15_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3252(colontmpD_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin15_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	default:
	{
		result = isAtom__ast_u7223(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NimStringV2, rdLoc__jsgen_u593)(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* a_p0) {
	NimStringV2 result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	{
		if (!!(((*a_p0).typ == ((tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)9)))) goto LA3_;
		eqcopy___system_u2694((&result), (*a_p0).res);
	}
	goto LA1_;
LA3_: ;
	{
		tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T6_;
		T6_[0] = (*a_p0).address;
		T6_[1] = (*a_p0).res;
		result = percent___cgen_u9083(T6_, 2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genOr__jsgen_u1303)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* b_p2, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* r_p3) {
	tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ x_1;
	tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ y_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&x_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
	nimZeroMem((void*)(&y_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
	nimZeroMem((void*)(&x_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
	nimZeroMem((void*)(&y_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
	{
		NIM_BOOL T4_;
		NimStringV2 colontmpD_;
		NimStringV2 colontmpD__2;
		tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T9_;
		NimStringV2 T10_;
		T4_ = (NIM_BOOL)0;
		T4_ = isSimpleExpr__jsgen_u1221(p_p0, a_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!(T4_)) goto LA5_;
		T4_ = isSimpleExpr__jsgen_u1221(p_p0, b_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
LA5_: ;
		if (!T4_) goto LA6_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		gen__jsgen_u1159(p_p0, a_p1, (&x_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		gen__jsgen_u1159(p_p0, b_p2, (&y_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		(*r_p3).kind = ((tyEnum_TResKind__UiCSai1lX4RMkJ9bHo9aP2HA)1);
		colontmpD_ = rdLoc__jsgen_u593((&x_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		T9_[0] = colontmpD_;
		colontmpD__2 = rdLoc__jsgen_u593((&y_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		T9_[1] = colontmpD__2;
		T10_.len = 0; T10_.p = NIM_NIL;
		T10_ = percent___jsgen_u1325(T9_, 2);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T10_); goto LA8_;}
		eqsink___system_u2700((&(*r_p3).res), T10_);
		{
			LA8_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__2);
			eqdestroy___system_u2691(colontmpD_);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA2_;
LA6_: ;
	{
		NimStringV2 colontmpD__3;
		NimStringV2 colontmpD__4;
		NimStringV2 colontmpD__5;
		NimStringV2 colontmpD__6;
		NimStringV2 colontmpD__7;
		NimStringV2 colontmpD__8;
		NimStringV2 colontmpD__9;
		NimStringV2 colontmpD__10;
		NimStringV2 colontmpD__11;
		NimStringV2 T15_;
		tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T16_;
		tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T17_;
		colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
		colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
		colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
		colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
		colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
		colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
		colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
		colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
		colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
		T15_.len = 0; T15_.p = NIM_NIL;
		T15_ = getTemp__jsgen_u1235(p_p0, NIM_TRUE);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T15_); goto LA14_;}
		eqsink___system_u2700((&(*r_p3).res), T15_);
		(*r_p3).kind = ((tyEnum_TResKind__UiCSai1lX4RMkJ9bHo9aP2HA)2);
		gen__jsgen_u1159(p_p0, a_p1, (&x_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
		colontmpD__3 = rdLoc__jsgen_u593((&x_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
		T16_[0] = colontmpD__3;
		colontmpD__4 = rdLoc__jsgen_u593((&(*r_p3)));
		if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
		T16_[1] = colontmpD__4;
		colontmpD__5 = percent___jsgen_u1330(T16_, 2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
		colontmpD__6 = indentLine__jsgen_u102(p_p0, colontmpD__5);
		if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
		prepareAdd((&(*p_p0).body), colontmpD__6.len + 0);
appendString((&(*p_p0).body), colontmpD__6);
		(*p_p0).extraIndent += ((NI)1);
		gen__jsgen_u1159(p_p0, b_p2, (&y_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
		colontmpD__7 = rdLoc__jsgen_u593((&y_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
		T17_[0] = colontmpD__7;
		colontmpD__8 = rdLoc__jsgen_u593((&(*r_p3)));
		if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
		T17_[1] = colontmpD__8;
		colontmpD__9 = percent___jsgen_u1293(T17_, 2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
		colontmpD__10 = indentLine__jsgen_u102(p_p0, colontmpD__9);
		if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
		prepareAdd((&(*p_p0).body), colontmpD__10.len + 0);
appendString((&(*p_p0).body), colontmpD__10);
		(*p_p0).extraIndent -= ((NI)1);
		colontmpD__11 = indentLine__jsgen_u102(p_p0, TM__BxLwT0mhrtgTPodf1v3xjg_390);
		if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
		prepareAdd((&(*p_p0).body), colontmpD__11.len + 0);
appendString((&(*p_p0).body), colontmpD__11);
		{
			LA14_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__11);
			eqdestroy___system_u2691(colontmpD__10);
			eqdestroy___system_u2691(colontmpD__9);
			eqdestroy___system_u2691(colontmpD__8);
			eqdestroy___system_u2691(colontmpD__7);
			eqdestroy___system_u2691(colontmpD__6);
			eqdestroy___system_u2691(colontmpD__5);
			eqdestroy___system_u2691(colontmpD__4);
			eqdestroy___system_u2691(colontmpD__3);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA2_: ;
	{
		LA1_:;
	}
	{
		eqdestroy___jsgen_u570((&y_1));
		eqdestroy___jsgen_u570((&x_1));
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genAnd__jsgen_u1254)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* b_p2, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* r_p3) {
	tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ x_1;
	tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ y_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&x_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
	nimZeroMem((void*)(&y_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
	nimZeroMem((void*)(&x_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
	nimZeroMem((void*)(&y_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
	{
		NIM_BOOL T4_;
		NimStringV2 colontmpD_;
		NimStringV2 colontmpD__2;
		tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T9_;
		NimStringV2 T10_;
		T4_ = (NIM_BOOL)0;
		T4_ = isSimpleExpr__jsgen_u1221(p_p0, a_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!(T4_)) goto LA5_;
		T4_ = isSimpleExpr__jsgen_u1221(p_p0, b_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
LA5_: ;
		if (!T4_) goto LA6_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		gen__jsgen_u1159(p_p0, a_p1, (&x_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		gen__jsgen_u1159(p_p0, b_p2, (&y_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		(*r_p3).kind = ((tyEnum_TResKind__UiCSai1lX4RMkJ9bHo9aP2HA)1);
		colontmpD_ = rdLoc__jsgen_u593((&x_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		T9_[0] = colontmpD_;
		colontmpD__2 = rdLoc__jsgen_u593((&y_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		T9_[1] = colontmpD__2;
		T10_.len = 0; T10_.p = NIM_NIL;
		T10_ = percent___jsgen_u1278(T9_, 2);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T10_); goto LA8_;}
		eqsink___system_u2700((&(*r_p3).res), T10_);
		{
			LA8_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__2);
			eqdestroy___system_u2691(colontmpD_);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA2_;
LA6_: ;
	{
		NimStringV2 colontmpD__3;
		NimStringV2 colontmpD__4;
		NimStringV2 colontmpD__5;
		NimStringV2 colontmpD__6;
		NimStringV2 colontmpD__7;
		NimStringV2 colontmpD__8;
		NimStringV2 colontmpD__9;
		NimStringV2 colontmpD__10;
		NimStringV2 colontmpD__11;
		NimStringV2 T15_;
		tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T16_;
		tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T17_;
		colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
		colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
		colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
		colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
		colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
		colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
		colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
		colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
		colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
		T15_.len = 0; T15_.p = NIM_NIL;
		T15_ = getTemp__jsgen_u1235(p_p0, NIM_TRUE);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T15_); goto LA14_;}
		eqsink___system_u2700((&(*r_p3).res), T15_);
		(*r_p3).kind = ((tyEnum_TResKind__UiCSai1lX4RMkJ9bHo9aP2HA)2);
		gen__jsgen_u1159(p_p0, a_p1, (&x_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
		colontmpD__3 = rdLoc__jsgen_u593((&x_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
		T16_[0] = colontmpD__3;
		colontmpD__4 = rdLoc__jsgen_u593((&(*r_p3)));
		if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
		T16_[1] = colontmpD__4;
		colontmpD__5 = percent___jsgen_u1283(T16_, 2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
		colontmpD__6 = indentLine__jsgen_u102(p_p0, colontmpD__5);
		if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
		prepareAdd((&(*p_p0).body), colontmpD__6.len + 0);
appendString((&(*p_p0).body), colontmpD__6);
		(*p_p0).extraIndent += ((NI)1);
		gen__jsgen_u1159(p_p0, b_p2, (&y_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
		colontmpD__7 = rdLoc__jsgen_u593((&y_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
		T17_[0] = colontmpD__7;
		colontmpD__8 = rdLoc__jsgen_u593((&(*r_p3)));
		if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
		T17_[1] = colontmpD__8;
		colontmpD__9 = percent___jsgen_u1293(T17_, 2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
		colontmpD__10 = indentLine__jsgen_u102(p_p0, colontmpD__9);
		if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
		prepareAdd((&(*p_p0).body), colontmpD__10.len + 0);
appendString((&(*p_p0).body), colontmpD__10);
		(*p_p0).extraIndent -= ((NI)1);
		colontmpD__11 = indentLine__jsgen_u102(p_p0, TM__BxLwT0mhrtgTPodf1v3xjg_391);
		if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
		prepareAdd((&(*p_p0).body), colontmpD__11.len + 0);
appendString((&(*p_p0).body), colontmpD__11);
		{
			LA14_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__11);
			eqdestroy___system_u2691(colontmpD__10);
			eqdestroy___system_u2691(colontmpD__9);
			eqdestroy___system_u2691(colontmpD__8);
			eqdestroy___system_u2691(colontmpD__7);
			eqdestroy___system_u2691(colontmpD__6);
			eqdestroy___system_u2691(colontmpD__5);
			eqdestroy___system_u2691(colontmpD__4);
			eqdestroy___system_u2691(colontmpD__3);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA2_: ;
	{
		LA1_:;
	}
	{
		eqdestroy___jsgen_u570((&y_1));
		eqdestroy___jsgen_u570((&x_1));
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, unsignedTrimmer__jsgen_u1494)(NI64 size_p0) {
	NimStringV2 result;
	NimStringV2 T1_;
	T1_.len = 0; T1_.p = NIM_NIL;
	switch (size_p0) {
	case IL64(1):
	{
		result = TM__BxLwT0mhrtgTPodf1v3xjg_393;
	}
	break;
	case IL64(2):
	{
		result = TM__BxLwT0mhrtgTPodf1v3xjg_395;
	}
	break;
	case IL64(4):
	{
		result = TM__BxLwT0mhrtgTPodf1v3xjg_397;
	}
	break;
	default:
	{
		result = TM__BxLwT0mhrtgTPodf1v3xjg_398;
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, binaryUintExpr__jsgen_u1698)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* r_p2, NimStringV2 op_p3) {
	tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ x_1;
	tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ y_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
	NI64 size_1;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&x_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
	nimZeroMem((void*)(&y_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
	colontmpD_ = NIM_NIL;
	nimZeroMem((void*)(&x_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
	nimZeroMem((void*)(&y_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
	gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], (&x_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)2)], (&y_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD_ = skipTypes__ast_u5379((*(*n_p1)._kind_6.sons.p->data[((NI)1)]).typField, abstractRange__types_u92);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	size_1 = (*colontmpD_).size;
	{
		NIM_BOOL T4_;
		NimStringV2 colontmpD__2;
		NimStringV2 colontmpD__3;
		tyArray__dyW7vpmfeTYw8kX3EXuaJA T8_;
		NimStringV2 T9_;
		T4_ = (NIM_BOOL)0;
		T4_ = (size_1 == IL64(8));
		if (!(T4_)) goto LA5_;
		T4_ = (((*(*(*p_p0).module).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)56)))&63U)))!=0);
LA5_: ;
		if (!T4_) goto LA6_;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
		colontmpD__2 = rdLoc__jsgen_u593((&x_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T8_[0] = colontmpD__2;
		T8_[1] = op_p3;
		colontmpD__3 = rdLoc__jsgen_u593((&y_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T8_[2] = colontmpD__3;
		T9_.len = 0; T9_.p = NIM_NIL;
		T9_ = percent___jsgen_u1720(T8_, 3);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T9_); goto LA1_;}
		eqsink___system_u2700((&(*r_p2).res), T9_);
		eqdestroy___system_u2691(colontmpD__3);
		eqdestroy___system_u2691(colontmpD__2);
	}
	goto LA2_;
LA6_: ;
	{
		NimStringV2 trimmer_1;
		NimStringV2 colontmpD__4;
		NimStringV2 colontmpD__5;
		tyArray__Seu7uK9aaOSN0BK3EAjjSHw T11_;
		NimStringV2 T12_;
		trimmer_1.len = 0; trimmer_1.p = NIM_NIL;
		colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
		colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
		trimmer_1 = unsignedTrimmer__jsgen_u1494(size_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		colontmpD__4 = rdLoc__jsgen_u593((&x_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T11_[0] = colontmpD__4;
		T11_[1] = op_p3;
		colontmpD__5 = rdLoc__jsgen_u593((&y_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T11_[2] = colontmpD__5;
		T11_[3] = trimmer_1;
		T12_.len = 0; T12_.p = NIM_NIL;
		T12_ = percent___jsgen_u1726(T11_, 4);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T12_); goto LA1_;}
		eqsink___system_u2700((&(*r_p2).res), T12_);
		eqdestroy___system_u2691(colontmpD__5);
		eqdestroy___system_u2691(colontmpD__4);
		eqdestroy___system_u2691(trimmer_1);
	}
LA2_: ;
	(*r_p2).kind = ((tyEnum_TResKind__UiCSai1lX4RMkJ9bHo9aP2HA)1);
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___jsgen_u570((&y_1));
		eqdestroy___jsgen_u570((&x_1));
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, signedTrimmer__jsgen_u1497)(NI64 size_p0) {
	NimStringV2 result;
	NimStringV2 colontmpD_;
	tyArray__YgExxhfgKcesA5EOUj1MOA T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD_ = dollar___systemZdollars_u29((NI64)(IL64(32) - (NI64)(size_p0 * IL64(8))));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_[0] = colontmpD_;
	result = percent___jsgen_u1500(T1_, 1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqdestroy___system_u2691(colontmpD_);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, arithAux__jsgen_u1559)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* r_p2, tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg op_p3) {
	tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ x_1;
	tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ y_1;
	NimStringV2 xLoc_1;
	NimStringV2 yLoc_1;
	NI i_1;
NIM_BOOL oldNimErrFin121_;
NIM_BOOL oldNimErrFin166_;
NIM_BOOL oldNimErrFin684_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&x_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
	nimZeroMem((void*)(&y_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
	xLoc_1.len = 0; xLoc_1.p = NIM_NIL;
	yLoc_1.len = 0; yLoc_1.p = NIM_NIL;
	nimZeroMem((void*)(&x_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
	nimZeroMem((void*)(&y_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
	xLoc_1 = TM__BxLwT0mhrtgTPodf1v3xjg_407;
	yLoc_1 = TM__BxLwT0mhrtgTPodf1v3xjg_408;
	i_1 = !((((*p_p0).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)5)))&31U)))!=0));
	useMagic__jsgen_u1172(p_p0, jsMagics__jsgen_u1351[(op_p3)- 46][(i_1)- 0]);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NI T4_;
		NimStringV2 T7_;
		NimStringV2 T8_;
		T4_ = (NI)0;
		T4_ = len__ast_u3190(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!(((NI)2) < T4_)) goto LA5_;
		gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], (&x_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)2)], (&y_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T7_.len = 0; T7_.p = NIM_NIL;
		T7_ = rdLoc__jsgen_u593((&x_1));
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T7_); goto LA1_;}
		eqsink___system_u2700((&xLoc_1), T7_);
		T8_.len = 0; T8_.p = NIM_NIL;
		T8_ = rdLoc__jsgen_u593((&y_1));
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T8_); goto LA1_;}
		eqsink___system_u2700((&yLoc_1), T8_);
	}
	goto LA2_;
LA5_: ;
	{
		NimStringV2 T10_;
		gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], r_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T10_.len = 0; T10_.p = NIM_NIL;
		T10_ = rdLoc__jsgen_u593((&(*r_p2)));
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T10_); goto LA1_;}
		eqsink___system_u2700((&xLoc_1), T10_);
	}
LA2_: ;
	switch (op_p3) {
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)46):
	{
		{
			if (!(i_1 == ((NI)0))) goto LA14_;
			{
				NIM_BOOL T18_;
				tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T22_;
				NimStringV2 T23_;
				T18_ = (NIM_BOOL)0;
				T18_ = ((*(*(*n_p1)._kind_6.sons.p->data[((NI)1)]).typField).size == IL64(8));
				if (!(T18_)) goto LA19_;
				T18_ = (((*(*(*p_p0).module).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)56)))&63U)))!=0);
LA19_: ;
				if (!T18_) goto LA20_;
				useMagic__jsgen_u1172(p_p0, TM__BxLwT0mhrtgTPodf1v3xjg_423);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				T22_[0] = xLoc_1;
				T22_[1] = yLoc_1;
				T23_.len = 0; T23_.p = NIM_NIL;
				T23_ = percent___jsgen_u1596(T22_, 2);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T23_); goto LA1_;}
				eqsink___system_u2700((&(*r_p2).res), T23_);
			}
			goto LA16_;
LA20_: ;
			{
				tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T25_;
				NimStringV2 T26_;
				T25_[0] = xLoc_1;
				T25_[1] = yLoc_1;
				T26_.len = 0; T26_.p = NIM_NIL;
				T26_ = percent___jsgen_u1601(T25_, 2);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T26_); goto LA1_;}
				eqsink___system_u2700((&(*r_p2).res), T26_);
			}
LA16_: ;
		}
		goto LA12_;
LA14_: ;
		{
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T28_;
			NimStringV2 T29_;
			T28_[0] = xLoc_1;
			T28_[1] = yLoc_1;
			T29_.len = 0; T29_.p = NIM_NIL;
			T29_ = percent___jsgen_u1606(T28_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T29_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T29_);
		}
LA12_: ;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)47):
	{
		{
			if (!(i_1 == ((NI)0))) goto LA33_;
			{
				NIM_BOOL T37_;
				tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T41_;
				NimStringV2 T42_;
				T37_ = (NIM_BOOL)0;
				T37_ = ((*(*(*n_p1)._kind_6.sons.p->data[((NI)1)]).typField).size == IL64(8));
				if (!(T37_)) goto LA38_;
				T37_ = (((*(*(*p_p0).module).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)56)))&63U)))!=0);
LA38_: ;
				if (!T37_) goto LA39_;
				useMagic__jsgen_u1172(p_p0, TM__BxLwT0mhrtgTPodf1v3xjg_425);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				T41_[0] = xLoc_1;
				T41_[1] = yLoc_1;
				T42_.len = 0; T42_.p = NIM_NIL;
				T42_ = percent___jsgen_u1615(T41_, 2);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T42_); goto LA1_;}
				eqsink___system_u2700((&(*r_p2).res), T42_);
			}
			goto LA35_;
LA39_: ;
			{
				tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T44_;
				NimStringV2 T45_;
				T44_[0] = xLoc_1;
				T44_[1] = yLoc_1;
				T45_.len = 0; T45_.p = NIM_NIL;
				T45_ = percent___jsgen_u1620(T44_, 2);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T45_); goto LA1_;}
				eqsink___system_u2700((&(*r_p2).res), T45_);
			}
LA35_: ;
		}
		goto LA31_;
LA33_: ;
		{
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T47_;
			NimStringV2 T48_;
			T47_[0] = xLoc_1;
			T47_[1] = yLoc_1;
			T48_.len = 0; T48_.p = NIM_NIL;
			T48_ = percent___jsgen_u1625(T47_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T48_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T48_);
		}
LA31_: ;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)48):
	{
		{
			if (!(i_1 == ((NI)0))) goto LA52_;
			{
				NIM_BOOL T56_;
				tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T60_;
				NimStringV2 T61_;
				T56_ = (NIM_BOOL)0;
				T56_ = ((*(*(*n_p1)._kind_6.sons.p->data[((NI)1)]).typField).size == IL64(8));
				if (!(T56_)) goto LA57_;
				T56_ = (((*(*(*p_p0).module).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)56)))&63U)))!=0);
LA57_: ;
				if (!T56_) goto LA58_;
				useMagic__jsgen_u1172(p_p0, TM__BxLwT0mhrtgTPodf1v3xjg_427);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				T60_[0] = xLoc_1;
				T60_[1] = yLoc_1;
				T61_.len = 0; T61_.p = NIM_NIL;
				T61_ = percent___jsgen_u1634(T60_, 2);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T61_); goto LA1_;}
				eqsink___system_u2700((&(*r_p2).res), T61_);
			}
			goto LA54_;
LA58_: ;
			{
				tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T63_;
				NimStringV2 T64_;
				T63_[0] = xLoc_1;
				T63_[1] = yLoc_1;
				T64_.len = 0; T64_.p = NIM_NIL;
				T64_ = percent___jsgen_u1639(T63_, 2);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T64_); goto LA1_;}
				eqsink___system_u2700((&(*r_p2).res), T64_);
			}
LA54_: ;
		}
		goto LA50_;
LA52_: ;
		{
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T66_;
			NimStringV2 T67_;
			T66_[0] = xLoc_1;
			T66_[1] = yLoc_1;
			T67_.len = 0; T67_.p = NIM_NIL;
			T67_ = percent___jsgen_u1644(T66_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T67_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T67_);
		}
LA50_: ;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)49):
	{
		{
			NIM_BOOL T71_;
			T71_ = (NIM_BOOL)0;
			T71_ = ((*(*(*n_p1)._kind_6.sons.p->data[((NI)1)]).typField).size == IL64(8));
			if (!(T71_)) goto LA72_;
			T71_ = (((*(*(*p_p0).module).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)56)))&63U)))!=0);
LA72_: ;
			if (!T71_) goto LA73_;
			useMagic__jsgen_u1172(p_p0, TM__BxLwT0mhrtgTPodf1v3xjg_429);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			{
				tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T79_;
				NimStringV2 T80_;
				if (!(i_1 == ((NI)0))) goto LA77_;
				T79_[0] = xLoc_1;
				T79_[1] = yLoc_1;
				T80_.len = 0; T80_.p = NIM_NIL;
				T80_ = percent___jsgen_u1653(T79_, 2);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T80_); goto LA1_;}
				eqsink___system_u2700((&(*r_p2).res), T80_);
			}
			goto LA75_;
LA77_: ;
			{
				tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T82_;
				NimStringV2 T83_;
				T82_[0] = xLoc_1;
				T82_[1] = yLoc_1;
				T83_.len = 0; T83_.p = NIM_NIL;
				T83_ = percent___jsgen_u1658(T82_, 2);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T83_); goto LA1_;}
				eqsink___system_u2700((&(*r_p2).res), T83_);
			}
LA75_: ;
		}
		goto LA69_;
LA73_: ;
		{
			{
				tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T89_;
				NimStringV2 T90_;
				if (!(i_1 == ((NI)0))) goto LA87_;
				T89_[0] = xLoc_1;
				T89_[1] = yLoc_1;
				T90_.len = 0; T90_.p = NIM_NIL;
				T90_ = percent___jsgen_u1663(T89_, 2);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T90_); goto LA1_;}
				eqsink___system_u2700((&(*r_p2).res), T90_);
			}
			goto LA85_;
LA87_: ;
			{
				tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T92_;
				NimStringV2 T93_;
				T92_[0] = xLoc_1;
				T92_[1] = yLoc_1;
				T93_.len = 0; T93_.p = NIM_NIL;
				T93_ = percent___jsgen_u1668(T92_, 2);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T93_); goto LA1_;}
				eqsink___system_u2700((&(*r_p2).res), T93_);
			}
LA85_: ;
		}
LA69_: ;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)50):
	{
		{
			NIM_BOOL T97_;
			T97_ = (NIM_BOOL)0;
			T97_ = ((*(*(*n_p1)._kind_6.sons.p->data[((NI)1)]).typField).size == IL64(8));
			if (!(T97_)) goto LA98_;
			T97_ = (((*(*(*p_p0).module).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)56)))&63U)))!=0);
LA98_: ;
			if (!T97_) goto LA99_;
			useMagic__jsgen_u1172(p_p0, TM__BxLwT0mhrtgTPodf1v3xjg_431);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			{
				tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T105_;
				NimStringV2 T106_;
				if (!(i_1 == ((NI)0))) goto LA103_;
				T105_[0] = xLoc_1;
				T105_[1] = yLoc_1;
				T106_.len = 0; T106_.p = NIM_NIL;
				T106_ = percent___jsgen_u1677(T105_, 2);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T106_); goto LA1_;}
				eqsink___system_u2700((&(*r_p2).res), T106_);
			}
			goto LA101_;
LA103_: ;
			{
				tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T108_;
				NimStringV2 T109_;
				T108_[0] = xLoc_1;
				T108_[1] = yLoc_1;
				T109_.len = 0; T109_.p = NIM_NIL;
				T109_ = percent___jsgen_u1682(T108_, 2);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T109_); goto LA1_;}
				eqsink___system_u2700((&(*r_p2).res), T109_);
			}
LA101_: ;
		}
		goto LA95_;
LA99_: ;
		{
			{
				tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T115_;
				NimStringV2 T116_;
				if (!(i_1 == ((NI)0))) goto LA113_;
				T115_[0] = xLoc_1;
				T115_[1] = yLoc_1;
				T116_.len = 0; T116_.p = NIM_NIL;
				T116_ = percent___jsgen_u1687(T115_, 2);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T116_); goto LA1_;}
				eqsink___system_u2700((&(*r_p2).res), T116_);
			}
			goto LA111_;
LA113_: ;
			{
				tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T118_;
				NimStringV2 T119_;
				T118_[0] = xLoc_1;
				T118_[1] = yLoc_1;
				T119_.len = 0; T119_.p = NIM_NIL;
				T119_ = percent___jsgen_u1692(T118_, 2);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T119_); goto LA1_;}
				eqsink___system_u2700((&(*r_p2).res), T119_);
			}
LA111_: ;
		}
LA95_: ;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)51):
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_1;
		typ_1 = NIM_NIL;
		typ_1 = skipTypes__ast_u5379((*(*n_p1)._kind_6.sons.p->data[((NI)1)]).typField, TM__BxLwT0mhrtgTPodf1v3xjg_358);
		if (NIM_UNLIKELY(*nimErr_)) goto LA121_;
		switch ((*typ_1).kind) {
		case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)40) ... ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)43):
		{
			binaryUintExpr__jsgen_u1698(p_p0, n_p1, r_p2, TM__BxLwT0mhrtgTPodf1v3xjg_432);
			if (NIM_UNLIKELY(*nimErr_)) goto LA121_;
		}
		break;
		case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)44):
		{
			{
				tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T128_;
				NimStringV2 T129_;
				if (!(((*(*(*p_p0).module).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)56)))&63U)))!=0)) goto LA126_;
				T128_[0] = xLoc_1;
				T128_[1] = yLoc_1;
				T129_.len = 0; T129_.p = NIM_NIL;
				T129_ = percent___jsgen_u1735(T128_, 2);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T129_); goto LA121_;}
				eqsink___system_u2700((&(*r_p2).res), T129_);
			}
			goto LA124_;
LA126_: ;
			{
				binaryUintExpr__jsgen_u1698(p_p0, n_p1, r_p2, TM__BxLwT0mhrtgTPodf1v3xjg_433);
				if (NIM_UNLIKELY(*nimErr_)) goto LA121_;
			}
LA124_: ;
		}
		break;
		default:
		{
			{
				NIM_BOOL T134_;
				T134_ = (NIM_BOOL)0;
				T134_ = ((*typ_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)35));
				if (!(T134_)) goto LA135_;
				T134_ = (((*(*(*p_p0).module).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)56)))&63U)))!=0);
LA135_: ;
				if (!T134_) goto LA136_;
				{
					tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T142_;
					NimStringV2 T143_;
					if (!!((((*p_p0).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)5)))&31U)))!=0))) goto LA140_;
					T142_[0] = xLoc_1;
					T142_[1] = yLoc_1;
					T143_.len = 0; T143_.p = NIM_NIL;
					T143_ = percent___jsgen_u1759(T142_, 2);
					if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T143_); goto LA121_;}
					eqsink___system_u2700((&(*r_p2).res), T143_);
				}
				goto LA138_;
LA140_: ;
				{
					tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ xX60gensym213__1;
					tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ yX60gensym213__1;
					NimStringV2 aX60gensym213__1;
					NimStringV2 tmpX60gensym213__1;
					NimStringV2 bX60gensym213__1;
					NimStringV2 tmp2X60gensym213__1;
					tyArray__Seu7uK9aaOSN0BK3EAjjSHw T146_;
					NimStringV2 T147_;
					nimZeroMem((void*)(&xX60gensym213__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
					nimZeroMem((void*)(&yX60gensym213__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
					aX60gensym213__1.len = 0; aX60gensym213__1.p = NIM_NIL;
					tmpX60gensym213__1.len = 0; tmpX60gensym213__1.p = NIM_NIL;
					bX60gensym213__1.len = 0; bX60gensym213__1.p = NIM_NIL;
					tmp2X60gensym213__1.len = 0; tmp2X60gensym213__1.p = NIM_NIL;
					nimZeroMem((void*)(&xX60gensym213__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
					nimZeroMem((void*)(&yX60gensym213__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
					useMagic__jsgen_u1172(p_p0, TM__BxLwT0mhrtgTPodf1v3xjg_434);
					if (NIM_UNLIKELY(*nimErr_)) goto LA145_;
					gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], (&xX60gensym213__1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA145_;
					gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)2)], (&yX60gensym213__1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA145_;
					aX60gensym213__1 = rdLoc__jsgen_u593((&xX60gensym213__1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA145_;
					tmpX60gensym213__1 = rdLoc__jsgen_u593((&xX60gensym213__1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA145_;
					bX60gensym213__1 = rdLoc__jsgen_u593((&yX60gensym213__1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA145_;
					tmp2X60gensym213__1 = rdLoc__jsgen_u593((&yX60gensym213__1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA145_;
					T146_[0] = aX60gensym213__1;
					T146_[1] = bX60gensym213__1;
					T146_[2] = tmpX60gensym213__1;
					T146_[3] = tmp2X60gensym213__1;
					T147_.len = 0; T147_.p = NIM_NIL;
					T147_ = percent___jsgen_u1784(T146_, 4);
					if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T147_); goto LA145_;}
					eqsink___system_u2700((&(*r_p2).res), T147_);
					(*r_p2).kind = ((tyEnum_TResKind__UiCSai1lX4RMkJ9bHo9aP2HA)1);
					{
						LA145_:;
					}
					{
						eqdestroy___system_u2691(tmp2X60gensym213__1);
						eqdestroy___system_u2691(bX60gensym213__1);
						eqdestroy___system_u2691(tmpX60gensym213__1);
						eqdestroy___system_u2691(aX60gensym213__1);
						eqdestroy___jsgen_u570((&yX60gensym213__1));
						eqdestroy___jsgen_u570((&xX60gensym213__1));
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA121_;
				}
LA138_: ;
			}
			goto LA132_;
LA136_: ;
			{
				{
					tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T155_;
					NimStringV2 T156_;
					if (!!((((*p_p0).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)5)))&31U)))!=0))) goto LA153_;
					T155_[0] = xLoc_1;
					T155_[1] = yLoc_1;
					T156_.len = 0; T156_.p = NIM_NIL;
					T156_ = percent___jsgen_u1793(T155_, 2);
					if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T156_); goto LA121_;}
					eqsink___system_u2700((&(*r_p2).res), T156_);
				}
				goto LA151_;
LA153_: ;
				{
					tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ xX60gensym220__1;
					tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ yX60gensym220__1;
					NimStringV2 aX60gensym220__1;
					NimStringV2 tmpX60gensym220__1;
					NimStringV2 bX60gensym220__1;
					NimStringV2 tmp2X60gensym220__1;
					tyArray__Seu7uK9aaOSN0BK3EAjjSHw T159_;
					NimStringV2 T160_;
					nimZeroMem((void*)(&xX60gensym220__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
					nimZeroMem((void*)(&yX60gensym220__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
					aX60gensym220__1.len = 0; aX60gensym220__1.p = NIM_NIL;
					tmpX60gensym220__1.len = 0; tmpX60gensym220__1.p = NIM_NIL;
					bX60gensym220__1.len = 0; bX60gensym220__1.p = NIM_NIL;
					tmp2X60gensym220__1.len = 0; tmp2X60gensym220__1.p = NIM_NIL;
					nimZeroMem((void*)(&xX60gensym220__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
					nimZeroMem((void*)(&yX60gensym220__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
					useMagic__jsgen_u1172(p_p0, TM__BxLwT0mhrtgTPodf1v3xjg_435);
					if (NIM_UNLIKELY(*nimErr_)) goto LA158_;
					gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], (&xX60gensym220__1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA158_;
					gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)2)], (&yX60gensym220__1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA158_;
					aX60gensym220__1 = rdLoc__jsgen_u593((&xX60gensym220__1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA158_;
					tmpX60gensym220__1 = rdLoc__jsgen_u593((&xX60gensym220__1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA158_;
					bX60gensym220__1 = rdLoc__jsgen_u593((&yX60gensym220__1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA158_;
					tmp2X60gensym220__1 = rdLoc__jsgen_u593((&yX60gensym220__1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA158_;
					T159_[0] = aX60gensym220__1;
					T159_[1] = bX60gensym220__1;
					T159_[2] = tmpX60gensym220__1;
					T159_[3] = tmp2X60gensym220__1;
					T160_.len = 0; T160_.p = NIM_NIL;
					T160_ = percent___jsgen_u1601(T159_, 4);
					if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T160_); goto LA158_;}
					eqsink___system_u2700((&(*r_p2).res), T160_);
					(*r_p2).kind = ((tyEnum_TResKind__UiCSai1lX4RMkJ9bHo9aP2HA)1);
					{
						LA158_:;
					}
					{
						eqdestroy___system_u2691(tmp2X60gensym220__1);
						eqdestroy___system_u2691(bX60gensym220__1);
						eqdestroy___system_u2691(tmpX60gensym220__1);
						eqdestroy___system_u2691(aX60gensym220__1);
						eqdestroy___jsgen_u570((&yX60gensym220__1));
						eqdestroy___jsgen_u570((&xX60gensym220__1));
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA121_;
				}
LA151_: ;
			}
LA132_: ;
		}
		break;
		}
		{
			LA121_:;
		}
		{
			oldNimErrFin121_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3378(typ_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin121_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)52):
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_2;
		typ_2 = NIM_NIL;
		typ_2 = skipTypes__ast_u5379((*(*n_p1)._kind_6.sons.p->data[((NI)1)]).typField, TM__BxLwT0mhrtgTPodf1v3xjg_358);
		if (NIM_UNLIKELY(*nimErr_)) goto LA166_;
		switch ((*typ_2).kind) {
		case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)40) ... ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)43):
		{
			binaryUintExpr__jsgen_u1698(p_p0, n_p1, r_p2, TM__BxLwT0mhrtgTPodf1v3xjg_436);
			if (NIM_UNLIKELY(*nimErr_)) goto LA166_;
		}
		break;
		case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)44):
		{
			{
				tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T173_;
				NimStringV2 T174_;
				if (!(((*(*(*p_p0).module).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)56)))&63U)))!=0)) goto LA171_;
				T173_[0] = xLoc_1;
				T173_[1] = yLoc_1;
				T174_.len = 0; T174_.p = NIM_NIL;
				T174_ = percent___jsgen_u1834(T173_, 2);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T174_); goto LA166_;}
				eqsink___system_u2700((&(*r_p2).res), T174_);
			}
			goto LA169_;
LA171_: ;
			{
				binaryUintExpr__jsgen_u1698(p_p0, n_p1, r_p2, TM__BxLwT0mhrtgTPodf1v3xjg_437);
				if (NIM_UNLIKELY(*nimErr_)) goto LA166_;
			}
LA169_: ;
		}
		break;
		default:
		{
			{
				NIM_BOOL T179_;
				T179_ = (NIM_BOOL)0;
				T179_ = ((*typ_2).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)35));
				if (!(T179_)) goto LA180_;
				T179_ = (((*(*(*p_p0).module).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)56)))&63U)))!=0);
LA180_: ;
				if (!T179_) goto LA181_;
				{
					tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T187_;
					NimStringV2 T188_;
					if (!!((((*p_p0).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)5)))&31U)))!=0))) goto LA185_;
					T187_[0] = xLoc_1;
					T187_[1] = yLoc_1;
					T188_.len = 0; T188_.p = NIM_NIL;
					T188_ = percent___jsgen_u1858(T187_, 2);
					if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T188_); goto LA166_;}
					eqsink___system_u2700((&(*r_p2).res), T188_);
				}
				goto LA183_;
LA185_: ;
				{
					tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ xX60gensym234__1;
					tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ yX60gensym234__1;
					NimStringV2 aX60gensym234__1;
					NimStringV2 tmpX60gensym234__1;
					NimStringV2 bX60gensym234__1;
					NimStringV2 tmp2X60gensym234__1;
					tyArray__Seu7uK9aaOSN0BK3EAjjSHw T191_;
					NimStringV2 T192_;
					nimZeroMem((void*)(&xX60gensym234__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
					nimZeroMem((void*)(&yX60gensym234__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
					aX60gensym234__1.len = 0; aX60gensym234__1.p = NIM_NIL;
					tmpX60gensym234__1.len = 0; tmpX60gensym234__1.p = NIM_NIL;
					bX60gensym234__1.len = 0; bX60gensym234__1.p = NIM_NIL;
					tmp2X60gensym234__1.len = 0; tmp2X60gensym234__1.p = NIM_NIL;
					nimZeroMem((void*)(&xX60gensym234__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
					nimZeroMem((void*)(&yX60gensym234__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
					useMagic__jsgen_u1172(p_p0, TM__BxLwT0mhrtgTPodf1v3xjg_438);
					if (NIM_UNLIKELY(*nimErr_)) goto LA190_;
					gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], (&xX60gensym234__1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA190_;
					gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)2)], (&yX60gensym234__1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA190_;
					aX60gensym234__1 = rdLoc__jsgen_u593((&xX60gensym234__1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA190_;
					tmpX60gensym234__1 = rdLoc__jsgen_u593((&xX60gensym234__1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA190_;
					bX60gensym234__1 = rdLoc__jsgen_u593((&yX60gensym234__1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA190_;
					tmp2X60gensym234__1 = rdLoc__jsgen_u593((&yX60gensym234__1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA190_;
					T191_[0] = aX60gensym234__1;
					T191_[1] = bX60gensym234__1;
					T191_[2] = tmpX60gensym234__1;
					T191_[3] = tmp2X60gensym234__1;
					T192_.len = 0; T192_.p = NIM_NIL;
					T192_ = percent___jsgen_u1883(T191_, 4);
					if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T192_); goto LA190_;}
					eqsink___system_u2700((&(*r_p2).res), T192_);
					(*r_p2).kind = ((tyEnum_TResKind__UiCSai1lX4RMkJ9bHo9aP2HA)1);
					{
						LA190_:;
					}
					{
						eqdestroy___system_u2691(tmp2X60gensym234__1);
						eqdestroy___system_u2691(bX60gensym234__1);
						eqdestroy___system_u2691(tmpX60gensym234__1);
						eqdestroy___system_u2691(aX60gensym234__1);
						eqdestroy___jsgen_u570((&yX60gensym234__1));
						eqdestroy___jsgen_u570((&xX60gensym234__1));
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA166_;
				}
LA183_: ;
			}
			goto LA177_;
LA181_: ;
			{
				{
					tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T200_;
					NimStringV2 T201_;
					if (!!((((*p_p0).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)5)))&31U)))!=0))) goto LA198_;
					T200_[0] = xLoc_1;
					T200_[1] = yLoc_1;
					T201_.len = 0; T201_.p = NIM_NIL;
					T201_ = percent___jsgen_u1892(T200_, 2);
					if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T201_); goto LA166_;}
					eqsink___system_u2700((&(*r_p2).res), T201_);
				}
				goto LA196_;
LA198_: ;
				{
					tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ xX60gensym241__1;
					tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ yX60gensym241__1;
					NimStringV2 aX60gensym241__1;
					NimStringV2 tmpX60gensym241__1;
					NimStringV2 bX60gensym241__1;
					NimStringV2 tmp2X60gensym241__1;
					tyArray__Seu7uK9aaOSN0BK3EAjjSHw T204_;
					NimStringV2 T205_;
					nimZeroMem((void*)(&xX60gensym241__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
					nimZeroMem((void*)(&yX60gensym241__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
					aX60gensym241__1.len = 0; aX60gensym241__1.p = NIM_NIL;
					tmpX60gensym241__1.len = 0; tmpX60gensym241__1.p = NIM_NIL;
					bX60gensym241__1.len = 0; bX60gensym241__1.p = NIM_NIL;
					tmp2X60gensym241__1.len = 0; tmp2X60gensym241__1.p = NIM_NIL;
					nimZeroMem((void*)(&xX60gensym241__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
					nimZeroMem((void*)(&yX60gensym241__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
					useMagic__jsgen_u1172(p_p0, TM__BxLwT0mhrtgTPodf1v3xjg_439);
					if (NIM_UNLIKELY(*nimErr_)) goto LA203_;
					gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], (&xX60gensym241__1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA203_;
					gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)2)], (&yX60gensym241__1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA203_;
					aX60gensym241__1 = rdLoc__jsgen_u593((&xX60gensym241__1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA203_;
					tmpX60gensym241__1 = rdLoc__jsgen_u593((&xX60gensym241__1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA203_;
					bX60gensym241__1 = rdLoc__jsgen_u593((&yX60gensym241__1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA203_;
					tmp2X60gensym241__1 = rdLoc__jsgen_u593((&yX60gensym241__1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA203_;
					T204_[0] = aX60gensym241__1;
					T204_[1] = bX60gensym241__1;
					T204_[2] = tmpX60gensym241__1;
					T204_[3] = tmp2X60gensym241__1;
					T205_.len = 0; T205_.p = NIM_NIL;
					T205_ = percent___jsgen_u1620(T204_, 4);
					if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T205_); goto LA203_;}
					eqsink___system_u2700((&(*r_p2).res), T205_);
					(*r_p2).kind = ((tyEnum_TResKind__UiCSai1lX4RMkJ9bHo9aP2HA)1);
					{
						LA203_:;
					}
					{
						eqdestroy___system_u2691(tmp2X60gensym241__1);
						eqdestroy___system_u2691(bX60gensym241__1);
						eqdestroy___system_u2691(tmpX60gensym241__1);
						eqdestroy___system_u2691(aX60gensym241__1);
						eqdestroy___jsgen_u570((&yX60gensym241__1));
						eqdestroy___jsgen_u570((&xX60gensym241__1));
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA166_;
				}
LA196_: ;
			}
LA177_: ;
		}
		break;
		}
		{
			LA166_:;
		}
		{
			oldNimErrFin166_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3378(typ_2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin166_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)53):
	{
		{
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T215_;
			NimStringV2 T216_;
			if (!(i_1 == ((NI)0))) goto LA213_;
			T215_[0] = xLoc_1;
			T215_[1] = yLoc_1;
			T216_.len = 0; T216_.p = NIM_NIL;
			T216_ = percent___jsgen_u1606(T215_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T216_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T216_);
		}
		goto LA211_;
LA213_: ;
		{
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T218_;
			NimStringV2 T219_;
			T218_[0] = xLoc_1;
			T218_[1] = yLoc_1;
			T219_.len = 0; T219_.p = NIM_NIL;
			T219_ = percent___jsgen_u1606(T218_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T219_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T219_);
		}
LA211_: ;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)54):
	{
		{
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T225_;
			NimStringV2 T226_;
			if (!(i_1 == ((NI)0))) goto LA223_;
			T225_[0] = xLoc_1;
			T225_[1] = yLoc_1;
			T226_.len = 0; T226_.p = NIM_NIL;
			T226_ = percent___jsgen_u1625(T225_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T226_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T226_);
		}
		goto LA221_;
LA223_: ;
		{
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T228_;
			NimStringV2 T229_;
			T228_[0] = xLoc_1;
			T228_[1] = yLoc_1;
			T229_.len = 0; T229_.p = NIM_NIL;
			T229_ = percent___jsgen_u1625(T228_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T229_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T229_);
		}
LA221_: ;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)55):
	{
		{
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T235_;
			NimStringV2 T236_;
			if (!(i_1 == ((NI)0))) goto LA233_;
			T235_[0] = xLoc_1;
			T235_[1] = yLoc_1;
			T236_.len = 0; T236_.p = NIM_NIL;
			T236_ = percent___jsgen_u1644(T235_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T236_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T236_);
		}
		goto LA231_;
LA233_: ;
		{
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T238_;
			NimStringV2 T239_;
			T238_[0] = xLoc_1;
			T238_[1] = yLoc_1;
			T239_.len = 0; T239_.p = NIM_NIL;
			T239_ = percent___jsgen_u1644(T238_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T239_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T239_);
		}
LA231_: ;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)56):
	{
		{
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T245_;
			NimStringV2 T246_;
			if (!(i_1 == ((NI)0))) goto LA243_;
			T245_[0] = xLoc_1;
			T245_[1] = yLoc_1;
			T246_.len = 0; T246_.p = NIM_NIL;
			T246_ = percent___jsgen_u1945(T245_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T246_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T246_);
		}
		goto LA241_;
LA243_: ;
		{
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T248_;
			NimStringV2 T249_;
			T248_[0] = xLoc_1;
			T248_[1] = yLoc_1;
			T249_.len = 0; T249_.p = NIM_NIL;
			T249_ = percent___jsgen_u1945(T248_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T249_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T249_);
		}
LA241_: ;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)57):
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_3;
		typ_3 = NIM_NIL;
		typ_3 = skipTypes__ast_u5379((*(*n_p1)._kind_6.sons.p->data[((NI)1)]).typField, TM__BxLwT0mhrtgTPodf1v3xjg_358);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		{
			NIM_BOOL T253_;
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T257_;
			NimStringV2 T258_;
			T253_ = (NIM_BOOL)0;
			T253_ = ((*typ_3).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)35));
			if (!(T253_)) goto LA254_;
			T253_ = (((*(*(*p_p0).module).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)56)))&63U)))!=0);
LA254_: ;
			if (!T253_) goto LA255_;
			T257_[0] = xLoc_1;
			T257_[1] = yLoc_1;
			T258_.len = 0; T258_.p = NIM_NIL;
			T258_ = percent___jsgen_u1963(T257_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T258_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T258_);
		}
		goto LA251_;
LA255_: ;
		{
			NIM_BOOL T260_;
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T264_;
			NimStringV2 T265_;
			T260_ = (NIM_BOOL)0;
			T260_ = ((*typ_3).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)44));
			if (!(T260_)) goto LA261_;
			T260_ = (((*(*(*p_p0).module).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)56)))&63U)))!=0);
LA261_: ;
			if (!T260_) goto LA262_;
			T264_[0] = xLoc_1;
			T264_[1] = yLoc_1;
			T265_.len = 0; T265_.p = NIM_NIL;
			T265_ = percent___jsgen_u1976(T264_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T265_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T265_);
		}
		goto LA251_;
LA262_: ;
		{
			NI64 bitmask_1;
			bitmask_1 = (NI64)((NI64)((*typ_3).size * IL64(8)) - IL64(1));
			{
				NimStringV2 trimmerU_1;
				NimStringV2 trimmerS_1;
				NimStringV2 colontmpD_;
				tyArray__awn6UrBeChh9cVy9ccoluuYg T271_;
				NimStringV2 T272_;
				if (!((*typ_3).kind >= ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)31) && (*typ_3).kind <= ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)34))) goto LA269_;
				trimmerU_1.len = 0; trimmerU_1.p = NIM_NIL;
				trimmerS_1.len = 0; trimmerS_1.p = NIM_NIL;
				colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
				trimmerU_1 = unsignedTrimmer__jsgen_u1494((*typ_3).size);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				trimmerS_1 = signedTrimmer__jsgen_u1497((*typ_3).size);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				T271_[0] = xLoc_1;
				T271_[1] = trimmerU_1;
				T271_[2] = yLoc_1;
				T271_[3] = trimmerS_1;
				colontmpD_ = dollar___systemZdollars_u29(bitmask_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				T271_[4] = colontmpD_;
				T272_.len = 0; T272_.p = NIM_NIL;
				T272_ = percent___jsgen_u1988(T271_, 5);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T272_); goto LA1_;}
				eqsink___system_u2700((&(*r_p2).res), T272_);
				eqdestroy___system_u2691(colontmpD_);
				eqdestroy___system_u2691(trimmerS_1);
				eqdestroy___system_u2691(trimmerU_1);
			}
			goto LA267_;
LA269_: ;
			{
				NimStringV2 colontmpD__2;
				tyArray__dyW7vpmfeTYw8kX3EXuaJA T274_;
				NimStringV2 T275_;
				colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
				T274_[0] = xLoc_1;
				T274_[1] = yLoc_1;
				colontmpD__2 = dollar___systemZdollars_u29(bitmask_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				T274_[2] = colontmpD__2;
				T275_.len = 0; T275_.p = NIM_NIL;
				T275_ = percent___jsgen_u1993(T274_, 3);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T275_); goto LA1_;}
				eqsink___system_u2700((&(*r_p2).res), T275_);
				eqdestroy___system_u2691(colontmpD__2);
			}
LA267_: ;
		}
LA251_: ;
		eqdestroy___ast_u3378(typ_3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)58):
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_4;
		typ_4 = NIM_NIL;
		typ_4 = skipTypes__ast_u5379((*(*n_p1)._kind_6.sons.p->data[((NI)1)]).typField, TM__BxLwT0mhrtgTPodf1v3xjg_358);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		{
			if (!((*typ_4).size == IL64(8))) goto LA279_;
			{
				NIM_BOOL T283_;
				tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T287_;
				NimStringV2 T288_;
				T283_ = (NIM_BOOL)0;
				T283_ = ((*typ_4).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)35));
				if (!(T283_)) goto LA284_;
				T283_ = (((*(*(*p_p0).module).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)56)))&63U)))!=0);
LA284_: ;
				if (!T283_) goto LA285_;
				T287_[0] = xLoc_1;
				T287_[1] = yLoc_1;
				T288_.len = 0; T288_.p = NIM_NIL;
				T288_ = percent___jsgen_u2007(T287_, 2);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T288_); goto LA1_;}
				eqsink___system_u2700((&(*r_p2).res), T288_);
			}
			goto LA281_;
LA285_: ;
			{
				NIM_BOOL T290_;
				tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T294_;
				NimStringV2 T295_;
				T290_ = (NIM_BOOL)0;
				T290_ = ((*typ_4).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)44));
				if (!(T290_)) goto LA291_;
				T290_ = (((*(*(*p_p0).module).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)56)))&63U)))!=0);
LA291_: ;
				if (!T290_) goto LA292_;
				T294_[0] = xLoc_1;
				T294_[1] = yLoc_1;
				T295_.len = 0; T295_.p = NIM_NIL;
				T295_ = percent___jsgen_u2020(T294_, 2);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T295_); goto LA1_;}
				eqsink___system_u2700((&(*r_p2).res), T295_);
			}
			goto LA281_;
LA292_: ;
			{
				tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T297_;
				NimStringV2 T298_;
				T297_[0] = xLoc_1;
				T297_[1] = yLoc_1;
				T298_.len = 0; T298_.p = NIM_NIL;
				T298_ = percent___jsgen_u2025(T297_, 2);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T298_); goto LA1_;}
				eqsink___system_u2700((&(*r_p2).res), T298_);
			}
LA281_: ;
		}
		goto LA277_;
LA279_: ;
		{
			NI64 bitmask_2;
			bitmask_2 = (NI64)((NI64)((*typ_4).size * IL64(8)) - IL64(1));
			{
				NimStringV2 trimmer_1;
				NimStringV2 colontmpD__3;
				tyArray__Seu7uK9aaOSN0BK3EAjjSHw T304_;
				NimStringV2 T305_;
				if (!((*typ_4).kind >= ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)40) && (*typ_4).kind <= ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)43))) goto LA302_;
				trimmer_1.len = 0; trimmer_1.p = NIM_NIL;
				colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
				trimmer_1 = unsignedTrimmer__jsgen_u1494((*typ_4).size);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				T304_[0] = xLoc_1;
				T304_[1] = yLoc_1;
				T304_[2] = trimmer_1;
				colontmpD__3 = dollar___systemZdollars_u29(bitmask_2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				T304_[3] = colontmpD__3;
				T305_.len = 0; T305_.p = NIM_NIL;
				T305_ = percent___jsgen_u2036(T304_, 4);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T305_); goto LA1_;}
				eqsink___system_u2700((&(*r_p2).res), T305_);
				eqdestroy___system_u2691(colontmpD__3);
				eqdestroy___system_u2691(trimmer_1);
			}
			goto LA300_;
LA302_: ;
			{
				NimStringV2 trimmer_2;
				NimStringV2 colontmpD__4;
				tyArray__Seu7uK9aaOSN0BK3EAjjSHw T307_;
				NimStringV2 T308_;
				trimmer_2.len = 0; trimmer_2.p = NIM_NIL;
				colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
				trimmer_2 = signedTrimmer__jsgen_u1497((*typ_4).size);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				T307_[0] = xLoc_1;
				T307_[1] = yLoc_1;
				T307_[2] = trimmer_2;
				colontmpD__4 = dollar___systemZdollars_u29(bitmask_2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				T307_[3] = colontmpD__4;
				T308_.len = 0; T308_.p = NIM_NIL;
				T308_ = percent___jsgen_u2036(T307_, 4);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T308_); goto LA1_;}
				eqsink___system_u2700((&(*r_p2).res), T308_);
				eqdestroy___system_u2691(colontmpD__4);
				eqdestroy___system_u2691(trimmer_2);
			}
LA300_: ;
		}
LA277_: ;
		eqdestroy___ast_u3378(typ_4);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)59):
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_5;
		typ_5 = NIM_NIL;
		typ_5 = skipTypes__ast_u5379((*(*n_p1)._kind_6.sons.p->data[((NI)1)]).typField, TM__BxLwT0mhrtgTPodf1v3xjg_358);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		{
			if (!((*typ_5).size == IL64(8))) goto LA312_;
			{
				tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T318_;
				NimStringV2 T319_;
				if (!(((*(*(*p_p0).module).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)56)))&63U)))!=0)) goto LA316_;
				T318_[0] = xLoc_1;
				T318_[1] = yLoc_1;
				T319_.len = 0; T319_.p = NIM_NIL;
				T319_ = percent___jsgen_u1976(T318_, 2);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T319_); goto LA1_;}
				eqsink___system_u2700((&(*r_p2).res), T319_);
			}
			goto LA314_;
LA316_: ;
			{
				tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T321_;
				NimStringV2 T322_;
				T321_[0] = xLoc_1;
				T321_[1] = yLoc_1;
				T322_.len = 0; T322_.p = NIM_NIL;
				T322_ = percent___jsgen_u2055(T321_, 2);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T322_); goto LA1_;}
				eqsink___system_u2700((&(*r_p2).res), T322_);
			}
LA314_: ;
		}
		goto LA310_;
LA312_: ;
		{
			NI64 bitmask_3;
			bitmask_3 = (NI64)((NI64)((*typ_5).size * IL64(8)) - IL64(1));
			{
				NimStringV2 colontmpD__5;
				tyArray__dyW7vpmfeTYw8kX3EXuaJA T328_;
				NimStringV2 T329_;
				if (!((*typ_5).kind >= ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)40) && (*typ_5).kind <= ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)43))) goto LA326_;
				colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
				T328_[0] = xLoc_1;
				T328_[1] = yLoc_1;
				colontmpD__5 = dollar___systemZdollars_u29(bitmask_3);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				T328_[2] = colontmpD__5;
				T329_.len = 0; T329_.p = NIM_NIL;
				T329_ = percent___jsgen_u2065(T328_, 3);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T329_); goto LA1_;}
				eqsink___system_u2700((&(*r_p2).res), T329_);
				eqdestroy___system_u2691(colontmpD__5);
			}
			goto LA324_;
LA326_: ;
			{
				NimStringV2 colontmpD__6;
				tyArray__dyW7vpmfeTYw8kX3EXuaJA T331_;
				NimStringV2 T332_;
				colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
				T331_[0] = xLoc_1;
				T331_[1] = yLoc_1;
				colontmpD__6 = dollar___systemZdollars_u29(bitmask_3);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				T331_[2] = colontmpD__6;
				T332_.len = 0; T332_.p = NIM_NIL;
				T332_ = percent___jsgen_u2070(T331_, 3);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T332_); goto LA1_;}
				eqsink___system_u2700((&(*r_p2).res), T332_);
				eqdestroy___system_u2691(colontmpD__6);
			}
LA324_: ;
		}
LA310_: ;
		eqdestroy___ast_u3378(typ_5);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)60):
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typX60gensym284__1;
		typX60gensym284__1 = NIM_NIL;
		typX60gensym284__1 = skipTypes__ast_u5379((*(*n_p1)._kind_6.sons.p->data[((NI)1)]).typField, TM__BxLwT0mhrtgTPodf1v3xjg_358);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		{
			tyArray__dyW7vpmfeTYw8kX3EXuaJA T338_;
			NimStringV2 T339_;
			if (!((*typX60gensym284__1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)40) || (*typX60gensym284__1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)43))) goto LA336_;
			T338_[0] = xLoc_1;
			T338_[1] = TM__BxLwT0mhrtgTPodf1v3xjg_441;
			T338_[2] = yLoc_1;
			T339_.len = 0; T339_.p = NIM_NIL;
			T339_ = percent___jsgen_u2081(T338_, 3);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T339_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T339_);
		}
		goto LA334_;
LA336_: ;
		{
			tyArray__dyW7vpmfeTYw8kX3EXuaJA T341_;
			NimStringV2 T342_;
			T341_[0] = xLoc_1;
			T341_[1] = TM__BxLwT0mhrtgTPodf1v3xjg_442;
			T341_[2] = yLoc_1;
			T342_.len = 0; T342_.p = NIM_NIL;
			T342_ = percent___jsgen_u2086(T341_, 3);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T342_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T342_);
		}
LA334_: ;
		eqdestroy___ast_u3378(typX60gensym284__1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)61):
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typX60gensym288__1;
		typX60gensym288__1 = NIM_NIL;
		typX60gensym288__1 = skipTypes__ast_u5379((*(*n_p1)._kind_6.sons.p->data[((NI)1)]).typField, TM__BxLwT0mhrtgTPodf1v3xjg_358);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		{
			tyArray__dyW7vpmfeTYw8kX3EXuaJA T348_;
			NimStringV2 T349_;
			if (!((*typX60gensym288__1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)40) || (*typX60gensym288__1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)43))) goto LA346_;
			T348_[0] = xLoc_1;
			T348_[1] = TM__BxLwT0mhrtgTPodf1v3xjg_444;
			T348_[2] = yLoc_1;
			T349_.len = 0; T349_.p = NIM_NIL;
			T349_ = percent___jsgen_u2081(T348_, 3);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T349_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T349_);
		}
		goto LA344_;
LA346_: ;
		{
			tyArray__dyW7vpmfeTYw8kX3EXuaJA T351_;
			NimStringV2 T352_;
			T351_[0] = xLoc_1;
			T351_[1] = TM__BxLwT0mhrtgTPodf1v3xjg_445;
			T351_[2] = yLoc_1;
			T352_.len = 0; T352_.p = NIM_NIL;
			T352_ = percent___jsgen_u2086(T351_, 3);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T352_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T352_);
		}
LA344_: ;
		eqdestroy___ast_u3378(typX60gensym288__1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)62):
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typX60gensym292__1;
		typX60gensym292__1 = NIM_NIL;
		typX60gensym292__1 = skipTypes__ast_u5379((*(*n_p1)._kind_6.sons.p->data[((NI)1)]).typField, TM__BxLwT0mhrtgTPodf1v3xjg_358);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		{
			tyArray__dyW7vpmfeTYw8kX3EXuaJA T358_;
			NimStringV2 T359_;
			if (!((*typX60gensym292__1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)40) || (*typX60gensym292__1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)43))) goto LA356_;
			T358_[0] = xLoc_1;
			T358_[1] = TM__BxLwT0mhrtgTPodf1v3xjg_447;
			T358_[2] = yLoc_1;
			T359_.len = 0; T359_.p = NIM_NIL;
			T359_ = percent___jsgen_u2081(T358_, 3);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T359_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T359_);
		}
		goto LA354_;
LA356_: ;
		{
			tyArray__dyW7vpmfeTYw8kX3EXuaJA T361_;
			NimStringV2 T362_;
			T361_[0] = xLoc_1;
			T361_[1] = TM__BxLwT0mhrtgTPodf1v3xjg_448;
			T361_[2] = yLoc_1;
			T362_.len = 0; T362_.p = NIM_NIL;
			T362_ = percent___jsgen_u2086(T361_, 3);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T362_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T362_);
		}
LA354_: ;
		eqdestroy___ast_u3378(typX60gensym292__1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)63):
	{
		{
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T368_;
			NimStringV2 T369_;
			if (!(i_1 == ((NI)0))) goto LA366_;
			T368_[0] = xLoc_1;
			T368_[1] = yLoc_1;
			T369_.len = 0; T369_.p = NIM_NIL;
			T369_ = percent___jsgen_u2119(T368_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T369_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T369_);
		}
		goto LA364_;
LA366_: ;
		{
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T371_;
			NimStringV2 T372_;
			T371_[0] = xLoc_1;
			T371_[1] = yLoc_1;
			T372_.len = 0; T372_.p = NIM_NIL;
			T372_ = percent___jsgen_u2119(T371_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T372_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T372_);
		}
LA364_: ;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)64):
	{
		{
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T378_;
			NimStringV2 T379_;
			if (!(i_1 == ((NI)0))) goto LA376_;
			T378_[0] = xLoc_1;
			T378_[1] = yLoc_1;
			T379_.len = 0; T379_.p = NIM_NIL;
			T379_ = percent___jsgen_u2128(T378_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T379_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T379_);
		}
		goto LA374_;
LA376_: ;
		{
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T381_;
			NimStringV2 T382_;
			T381_[0] = xLoc_1;
			T381_[1] = yLoc_1;
			T382_.len = 0; T382_.p = NIM_NIL;
			T382_ = percent___jsgen_u2128(T381_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T382_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T382_);
		}
LA374_: ;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)65):
	{
		{
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T388_;
			NimStringV2 T389_;
			if (!(i_1 == ((NI)0))) goto LA386_;
			T388_[0] = xLoc_1;
			T388_[1] = yLoc_1;
			T389_.len = 0; T389_.p = NIM_NIL;
			T389_ = percent___jsgen_u2137(T388_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T389_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T389_);
		}
		goto LA384_;
LA386_: ;
		{
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T391_;
			NimStringV2 T392_;
			T391_[0] = xLoc_1;
			T391_[1] = yLoc_1;
			T392_.len = 0; T392_.p = NIM_NIL;
			T392_ = percent___jsgen_u2137(T391_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T392_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T392_);
		}
LA384_: ;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)66):
	{
		{
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T398_;
			NimStringV2 T399_;
			if (!(i_1 == ((NI)0))) goto LA396_;
			T398_[0] = xLoc_1;
			T398_[1] = yLoc_1;
			T399_.len = 0; T399_.p = NIM_NIL;
			T399_ = percent___jsgen_u2137(T398_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T399_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T399_);
		}
		goto LA394_;
LA396_: ;
		{
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T401_;
			NimStringV2 T402_;
			T401_[0] = xLoc_1;
			T401_[1] = yLoc_1;
			T402_.len = 0; T402_.p = NIM_NIL;
			T402_ = percent___jsgen_u2137(T401_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T402_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T402_);
		}
LA394_: ;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)67):
	{
		{
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T408_;
			NimStringV2 T409_;
			if (!(i_1 == ((NI)0))) goto LA406_;
			T408_[0] = xLoc_1;
			T408_[1] = yLoc_1;
			T409_.len = 0; T409_.p = NIM_NIL;
			T409_ = percent___jsgen_u2137(T408_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T409_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T409_);
		}
		goto LA404_;
LA406_: ;
		{
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T411_;
			NimStringV2 T412_;
			T411_[0] = xLoc_1;
			T411_[1] = yLoc_1;
			T412_.len = 0; T412_.p = NIM_NIL;
			T412_ = percent___jsgen_u2137(T411_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T412_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T412_);
		}
LA404_: ;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)68):
	{
		{
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T418_;
			NimStringV2 T419_;
			if (!(i_1 == ((NI)0))) goto LA416_;
			T418_[0] = xLoc_1;
			T418_[1] = yLoc_1;
			T419_.len = 0; T419_.p = NIM_NIL;
			T419_ = percent___jsgen_u2137(T418_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T419_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T419_);
		}
		goto LA414_;
LA416_: ;
		{
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T421_;
			NimStringV2 T422_;
			T421_[0] = xLoc_1;
			T421_[1] = yLoc_1;
			T422_.len = 0; T422_.p = NIM_NIL;
			T422_ = percent___jsgen_u2137(T421_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T422_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T422_);
		}
LA414_: ;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)69):
	{
		{
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T428_;
			NimStringV2 T429_;
			if (!(i_1 == ((NI)0))) goto LA426_;
			T428_[0] = xLoc_1;
			T428_[1] = yLoc_1;
			T429_.len = 0; T429_.p = NIM_NIL;
			T429_ = percent___jsgen_u2170(T428_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T429_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T429_);
		}
		goto LA424_;
LA426_: ;
		{
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T431_;
			NimStringV2 T432_;
			T431_[0] = xLoc_1;
			T431_[1] = yLoc_1;
			T432_.len = 0; T432_.p = NIM_NIL;
			T432_ = percent___jsgen_u2170(T431_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T432_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T432_);
		}
LA424_: ;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)70):
	{
		{
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T438_;
			NimStringV2 T439_;
			if (!(i_1 == ((NI)0))) goto LA436_;
			T438_[0] = xLoc_1;
			T438_[1] = yLoc_1;
			T439_.len = 0; T439_.p = NIM_NIL;
			T439_ = percent___cgen_u21605(T438_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T439_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T439_);
		}
		goto LA434_;
LA436_: ;
		{
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T441_;
			NimStringV2 T442_;
			T441_[0] = xLoc_1;
			T441_[1] = yLoc_1;
			T442_.len = 0; T442_.p = NIM_NIL;
			T442_ = percent___cgen_u21605(T441_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T442_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T442_);
		}
LA434_: ;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)71):
	{
		{
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T448_;
			NimStringV2 T449_;
			if (!(i_1 == ((NI)0))) goto LA446_;
			T448_[0] = xLoc_1;
			T448_[1] = yLoc_1;
			T449_.len = 0; T449_.p = NIM_NIL;
			T449_ = percent___cgen_u21610(T448_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T449_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T449_);
		}
		goto LA444_;
LA446_: ;
		{
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T451_;
			NimStringV2 T452_;
			T451_[0] = xLoc_1;
			T451_[1] = yLoc_1;
			T452_.len = 0; T452_.p = NIM_NIL;
			T452_ = percent___cgen_u21610(T451_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T452_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T452_);
		}
LA444_: ;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)72):
	{
		{
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T458_;
			NimStringV2 T459_;
			if (!(i_1 == ((NI)0))) goto LA456_;
			T458_[0] = xLoc_1;
			T458_[1] = yLoc_1;
			T459_.len = 0; T459_.p = NIM_NIL;
			T459_ = percent___cgen_u21615(T458_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T459_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T459_);
		}
		goto LA454_;
LA456_: ;
		{
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T461_;
			NimStringV2 T462_;
			T461_[0] = xLoc_1;
			T461_[1] = yLoc_1;
			T462_.len = 0; T462_.p = NIM_NIL;
			T462_ = percent___cgen_u21615(T461_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T462_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T462_);
		}
LA454_: ;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)73):
	{
		{
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T468_;
			NimStringV2 T469_;
			if (!(i_1 == ((NI)0))) goto LA466_;
			T468_[0] = xLoc_1;
			T468_[1] = yLoc_1;
			T469_.len = 0; T469_.p = NIM_NIL;
			T469_ = percent___cgen_u21605(T468_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T469_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T469_);
		}
		goto LA464_;
LA466_: ;
		{
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T471_;
			NimStringV2 T472_;
			T471_[0] = xLoc_1;
			T471_[1] = yLoc_1;
			T472_.len = 0; T472_.p = NIM_NIL;
			T472_ = percent___cgen_u21605(T471_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T472_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T472_);
		}
LA464_: ;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)74):
	{
		{
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T478_;
			NimStringV2 T479_;
			if (!(i_1 == ((NI)0))) goto LA476_;
			T478_[0] = xLoc_1;
			T478_[1] = yLoc_1;
			T479_.len = 0; T479_.p = NIM_NIL;
			T479_ = percent___cgen_u21610(T478_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T479_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T479_);
		}
		goto LA474_;
LA476_: ;
		{
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T481_;
			NimStringV2 T482_;
			T481_[0] = xLoc_1;
			T481_[1] = yLoc_1;
			T482_.len = 0; T482_.p = NIM_NIL;
			T482_ = percent___cgen_u21610(T481_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T482_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T482_);
		}
LA474_: ;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)75):
	{
		{
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T488_;
			NimStringV2 T489_;
			if (!(i_1 == ((NI)0))) goto LA486_;
			T488_[0] = xLoc_1;
			T488_[1] = yLoc_1;
			T489_.len = 0; T489_.p = NIM_NIL;
			T489_ = percent___cgen_u21615(T488_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T489_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T489_);
		}
		goto LA484_;
LA486_: ;
		{
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T491_;
			NimStringV2 T492_;
			T491_[0] = xLoc_1;
			T491_[1] = yLoc_1;
			T492_.len = 0; T492_.p = NIM_NIL;
			T492_ = percent___cgen_u21615(T491_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T492_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T492_);
		}
LA484_: ;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)76):
	{
		{
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T498_;
			NimStringV2 T499_;
			if (!(i_1 == ((NI)0))) goto LA496_;
			T498_[0] = xLoc_1;
			T498_[1] = yLoc_1;
			T499_.len = 0; T499_.p = NIM_NIL;
			T499_ = percent___cgen_u21610(T498_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T499_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T499_);
		}
		goto LA494_;
LA496_: ;
		{
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T501_;
			NimStringV2 T502_;
			T501_[0] = xLoc_1;
			T501_[1] = yLoc_1;
			T502_.len = 0; T502_.p = NIM_NIL;
			T502_ = percent___cgen_u21610(T501_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T502_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T502_);
		}
LA494_: ;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)77):
	{
		{
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T508_;
			NimStringV2 T509_;
			if (!(i_1 == ((NI)0))) goto LA506_;
			T508_[0] = xLoc_1;
			T508_[1] = yLoc_1;
			T509_.len = 0; T509_.p = NIM_NIL;
			T509_ = percent___cgen_u21615(T508_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T509_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T509_);
		}
		goto LA504_;
LA506_: ;
		{
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T511_;
			NimStringV2 T512_;
			T511_[0] = xLoc_1;
			T511_[1] = yLoc_1;
			T512_.len = 0; T512_.p = NIM_NIL;
			T512_ = percent___cgen_u21615(T511_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T512_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T512_);
		}
LA504_: ;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)78):
	{
		{
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T518_;
			NimStringV2 T519_;
			if (!(i_1 == ((NI)0))) goto LA516_;
			T518_[0] = xLoc_1;
			T518_[1] = yLoc_1;
			T519_.len = 0; T519_.p = NIM_NIL;
			T519_ = percent___cgen_u21605(T518_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T519_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T519_);
		}
		goto LA514_;
LA516_: ;
		{
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T521_;
			NimStringV2 T522_;
			T521_[0] = xLoc_1;
			T521_[1] = yLoc_1;
			T522_.len = 0; T522_.p = NIM_NIL;
			T522_ = percent___cgen_u21605(T521_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T522_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T522_);
		}
LA514_: ;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)79):
	{
		{
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T528_;
			NimStringV2 T529_;
			if (!(i_1 == ((NI)0))) goto LA526_;
			T528_[0] = xLoc_1;
			T528_[1] = yLoc_1;
			T529_.len = 0; T529_.p = NIM_NIL;
			T529_ = percent___cgen_u21610(T528_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T529_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T529_);
		}
		goto LA524_;
LA526_: ;
		{
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T531_;
			NimStringV2 T532_;
			T531_[0] = xLoc_1;
			T531_[1] = yLoc_1;
			T532_.len = 0; T532_.p = NIM_NIL;
			T532_ = percent___cgen_u21610(T531_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T532_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T532_);
		}
LA524_: ;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)80):
	{
		{
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T538_;
			NimStringV2 T539_;
			if (!(i_1 == ((NI)0))) goto LA536_;
			T538_[0] = xLoc_1;
			T538_[1] = yLoc_1;
			T539_.len = 0; T539_.p = NIM_NIL;
			T539_ = percent___cgen_u21615(T538_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T539_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T539_);
		}
		goto LA534_;
LA536_: ;
		{
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T541_;
			NimStringV2 T542_;
			T541_[0] = xLoc_1;
			T541_[1] = yLoc_1;
			T542_.len = 0; T542_.p = NIM_NIL;
			T542_ = percent___cgen_u21615(T541_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T542_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T542_);
		}
LA534_: ;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)81):
	{
		{
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T548_;
			NimStringV2 T549_;
			if (!(i_1 == ((NI)0))) goto LA546_;
			T548_[0] = xLoc_1;
			T548_[1] = yLoc_1;
			T549_.len = 0; T549_.p = NIM_NIL;
			T549_ = percent___cgen_u21605(T548_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T549_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T549_);
		}
		goto LA544_;
LA546_: ;
		{
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T551_;
			NimStringV2 T552_;
			T551_[0] = xLoc_1;
			T551_[1] = yLoc_1;
			T552_.len = 0; T552_.p = NIM_NIL;
			T552_ = percent___cgen_u21605(T551_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T552_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T552_);
		}
LA544_: ;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)82):
	{
		{
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T558_;
			NimStringV2 T559_;
			if (!(i_1 == ((NI)0))) goto LA556_;
			T558_[0] = xLoc_1;
			T558_[1] = yLoc_1;
			T559_.len = 0; T559_.p = NIM_NIL;
			T559_ = percent___cgen_u21610(T558_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T559_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T559_);
		}
		goto LA554_;
LA556_: ;
		{
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T561_;
			NimStringV2 T562_;
			T561_[0] = xLoc_1;
			T561_[1] = yLoc_1;
			T562_.len = 0; T562_.p = NIM_NIL;
			T562_ = percent___cgen_u21610(T561_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T562_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T562_);
		}
LA554_: ;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)83):
	{
		{
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T568_;
			NimStringV2 T569_;
			if (!(i_1 == ((NI)0))) goto LA566_;
			T568_[0] = xLoc_1;
			T568_[1] = yLoc_1;
			T569_.len = 0; T569_.p = NIM_NIL;
			T569_ = percent___cgen_u21615(T568_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T569_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T569_);
		}
		goto LA564_;
LA566_: ;
		{
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T571_;
			NimStringV2 T572_;
			T571_[0] = xLoc_1;
			T571_[1] = yLoc_1;
			T572_.len = 0; T572_.p = NIM_NIL;
			T572_ = percent___cgen_u21615(T571_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T572_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T572_);
		}
LA564_: ;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)84):
	{
		{
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T578_;
			NimStringV2 T579_;
			if (!(i_1 == ((NI)0))) goto LA576_;
			T578_[0] = xLoc_1;
			T578_[1] = yLoc_1;
			T579_.len = 0; T579_.p = NIM_NIL;
			T579_ = percent___cgen_u21605(T578_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T579_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T579_);
		}
		goto LA574_;
LA576_: ;
		{
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T581_;
			NimStringV2 T582_;
			T581_[0] = xLoc_1;
			T581_[1] = yLoc_1;
			T582_.len = 0; T582_.p = NIM_NIL;
			T582_ = percent___cgen_u21605(T581_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T582_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T582_);
		}
LA574_: ;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)85):
	{
		{
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T588_;
			NimStringV2 T589_;
			if (!(i_1 == ((NI)0))) goto LA586_;
			T588_[0] = xLoc_1;
			T588_[1] = yLoc_1;
			T589_.len = 0; T589_.p = NIM_NIL;
			T589_ = percent___cgen_u21610(T588_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T589_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T589_);
		}
		goto LA584_;
LA586_: ;
		{
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T591_;
			NimStringV2 T592_;
			T591_[0] = xLoc_1;
			T591_[1] = yLoc_1;
			T592_.len = 0; T592_.p = NIM_NIL;
			T592_ = percent___cgen_u21610(T591_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T592_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T592_);
		}
LA584_: ;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)86):
	{
		{
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T598_;
			NimStringV2 T599_;
			if (!(i_1 == ((NI)0))) goto LA596_;
			T598_[0] = xLoc_1;
			T598_[1] = yLoc_1;
			T599_.len = 0; T599_.p = NIM_NIL;
			T599_ = percent___cgen_u21615(T598_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T599_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T599_);
		}
		goto LA594_;
LA596_: ;
		{
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T601_;
			NimStringV2 T602_;
			T601_[0] = xLoc_1;
			T601_[1] = yLoc_1;
			T602_.len = 0; T602_.p = NIM_NIL;
			T602_ = percent___cgen_u21615(T601_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T602_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T602_);
		}
LA594_: ;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)87):
	{
		{
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T608_;
			NimStringV2 T609_;
			if (!(i_1 == ((NI)0))) goto LA606_;
			T608_[0] = xLoc_1;
			T608_[1] = yLoc_1;
			T609_.len = 0; T609_.p = NIM_NIL;
			T609_ = percent___cgen_u21605(T608_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T609_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T609_);
		}
		goto LA604_;
LA606_: ;
		{
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T611_;
			NimStringV2 T612_;
			T611_[0] = xLoc_1;
			T611_[1] = yLoc_1;
			T612_.len = 0; T612_.p = NIM_NIL;
			T612_ = percent___cgen_u21605(T611_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T612_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T612_);
		}
LA604_: ;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)88):
	{
		{
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T618_;
			NimStringV2 T619_;
			if (!(i_1 == ((NI)0))) goto LA616_;
			T618_[0] = xLoc_1;
			T618_[1] = yLoc_1;
			T619_.len = 0; T619_.p = NIM_NIL;
			T619_ = percent___cgen_u21610(T618_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T619_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T619_);
		}
		goto LA614_;
LA616_: ;
		{
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T621_;
			NimStringV2 T622_;
			T621_[0] = xLoc_1;
			T621_[1] = yLoc_1;
			T622_.len = 0; T622_.p = NIM_NIL;
			T622_ = percent___cgen_u21610(T621_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T622_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T622_);
		}
LA614_: ;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)89):
	{
		{
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T628_;
			NimStringV2 T629_;
			if (!(i_1 == ((NI)0))) goto LA626_;
			T628_[0] = xLoc_1;
			T628_[1] = yLoc_1;
			T629_.len = 0; T629_.p = NIM_NIL;
			T629_ = percent___cgen_u21615(T628_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T629_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T629_);
		}
		goto LA624_;
LA626_: ;
		{
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T631_;
			NimStringV2 T632_;
			T631_[0] = xLoc_1;
			T631_[1] = yLoc_1;
			T632_.len = 0; T632_.p = NIM_NIL;
			T632_ = percent___cgen_u21615(T631_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T632_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T632_);
		}
LA624_: ;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)90):
	{
		{
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T638_;
			NimStringV2 T639_;
			if (!(i_1 == ((NI)0))) goto LA636_;
			T638_[0] = xLoc_1;
			T638_[1] = yLoc_1;
			T639_.len = 0; T639_.p = NIM_NIL;
			T639_ = percent___cgen_u21693(T638_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T639_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T639_);
		}
		goto LA634_;
LA636_: ;
		{
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T641_;
			NimStringV2 T642_;
			T641_[0] = xLoc_1;
			T641_[1] = yLoc_1;
			T642_.len = 0; T642_.p = NIM_NIL;
			T642_ = percent___cgen_u21693(T641_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T642_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T642_);
		}
LA634_: ;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)91):
	{
		{
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T648_;
			NimStringV2 T649_;
			if (!(i_1 == ((NI)0))) goto LA646_;
			T648_[0] = xLoc_1;
			T648_[1] = yLoc_1;
			T649_.len = 0; T649_.p = NIM_NIL;
			T649_ = percent___cgen_u21605(T648_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T649_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T649_);
		}
		goto LA644_;
LA646_: ;
		{
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T651_;
			NimStringV2 T652_;
			T651_[0] = xLoc_1;
			T651_[1] = yLoc_1;
			T652_.len = 0; T652_.p = NIM_NIL;
			T652_ = percent___cgen_u21605(T651_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T652_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T652_);
		}
LA644_: ;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)92):
	{
		{
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T658_;
			NimStringV2 T659_;
			if (!(i_1 == ((NI)0))) goto LA656_;
			T658_[0] = xLoc_1;
			T658_[1] = yLoc_1;
			T659_.len = 0; T659_.p = NIM_NIL;
			T659_ = percent___cgen_u21605(T658_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T659_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T659_);
		}
		goto LA654_;
LA656_: ;
		{
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T661_;
			NimStringV2 T662_;
			T661_[0] = xLoc_1;
			T661_[1] = yLoc_1;
			T662_.len = 0; T662_.p = NIM_NIL;
			T662_ = percent___cgen_u21605(T661_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T662_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T662_);
		}
LA654_: ;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)93):
	{
		{
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T668_;
			NimStringV2 T669_;
			if (!(i_1 == ((NI)0))) goto LA666_;
			T668_[0] = xLoc_1;
			T668_[1] = yLoc_1;
			T669_.len = 0; T669_.p = NIM_NIL;
			T669_ = percent___jsgen_u2363(T668_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T669_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T669_);
		}
		goto LA664_;
LA666_: ;
		{
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T671_;
			NimStringV2 T672_;
			T671_[0] = xLoc_1;
			T671_[1] = yLoc_1;
			T672_.len = 0; T672_.p = NIM_NIL;
			T672_ = percent___cgen_u21479(T671_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T672_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T672_);
		}
LA664_: ;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)94):
	{
		{
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T678_;
			NimStringV2 T679_;
			if (!(i_1 == ((NI)0))) goto LA676_;
			T678_[0] = xLoc_1;
			T678_[1] = yLoc_1;
			T679_.len = 0; T679_.p = NIM_NIL;
			T679_ = percent___jsgen_u2372(T678_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T679_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T679_);
		}
		goto LA674_;
LA676_: ;
		{
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T681_;
			NimStringV2 T682_;
			T681_[0] = xLoc_1;
			T681_[1] = yLoc_1;
			T682_.len = 0; T682_.p = NIM_NIL;
			T682_ = percent___cgen_u21479(T681_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T682_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T682_);
		}
LA674_: ;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)95):
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_6;
		typ_6 = NIM_NIL;
		typ_6 = skipTypes__ast_u5379((*(*n_p1)._kind_6.sons.p->data[((NI)1)]).typField, TM__BxLwT0mhrtgTPodf1v3xjg_358);
		if (NIM_UNLIKELY(*nimErr_)) goto LA684_;
		{
			NIM_BOOL T687_;
			T687_ = (NIM_BOOL)0;
			T687_ = ((*typ_6).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)35));
			if (!(T687_)) goto LA688_;
			T687_ = (((*(*(*p_p0).module).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)56)))&63U)))!=0);
LA688_: ;
			if (!T687_) goto LA689_;
			useMagic__jsgen_u1172(p_p0, TM__BxLwT0mhrtgTPodf1v3xjg_450);
			if (NIM_UNLIKELY(*nimErr_)) goto LA684_;
			{
				tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T695_;
				NimStringV2 T696_;
				if (!(i_1 == ((NI)0))) goto LA693_;
				T695_[0] = xLoc_1;
				T695_[1] = yLoc_1;
				T696_.len = 0; T696_.p = NIM_NIL;
				T696_ = percent___jsgen_u2390(T695_, 2);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T696_); goto LA684_;}
				eqsink___system_u2700((&(*r_p2).res), T696_);
			}
			goto LA691_;
LA693_: ;
			{
				tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T698_;
				NimStringV2 T699_;
				T698_[0] = xLoc_1;
				T698_[1] = yLoc_1;
				T699_.len = 0; T699_.p = NIM_NIL;
				T699_ = percent___jsgen_u2390(T698_, 2);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T699_); goto LA684_;}
				eqsink___system_u2700((&(*r_p2).res), T699_);
			}
LA691_: ;
		}
		goto LA685_;
LA689_: ;
		{
			{
				tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T705_;
				NimStringV2 T706_;
				if (!(i_1 == ((NI)0))) goto LA703_;
				T705_[0] = xLoc_1;
				T705_[1] = yLoc_1;
				T706_.len = 0; T706_.p = NIM_NIL;
				T706_ = percent___jsgen_u2399(T705_, 2);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T706_); goto LA684_;}
				eqsink___system_u2700((&(*r_p2).res), T706_);
			}
			goto LA701_;
LA703_: ;
			{
				tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T708_;
				NimStringV2 T709_;
				T708_[0] = xLoc_1;
				T708_[1] = yLoc_1;
				T709_.len = 0; T709_.p = NIM_NIL;
				T709_ = percent___jsgen_u2404(T708_, 2);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T709_); goto LA684_;}
				eqsink___system_u2700((&(*r_p2).res), T709_);
			}
LA701_: ;
		}
LA685_: ;
		{
			LA684_:;
		}
		{
			oldNimErrFin684_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3378(typ_6);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin684_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)96):
	{
		{
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T717_;
			NimStringV2 T718_;
			if (!(i_1 == ((NI)0))) goto LA715_;
			T717_[0] = xLoc_1;
			T717_[1] = yLoc_1;
			T718_.len = 0; T718_.p = NIM_NIL;
			T718_ = percent___cgen_u21788(T717_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T718_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T718_);
		}
		goto LA713_;
LA715_: ;
		{
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T720_;
			NimStringV2 T721_;
			T720_[0] = xLoc_1;
			T720_[1] = yLoc_1;
			T721_.len = 0; T721_.p = NIM_NIL;
			T721_ = percent___cgen_u21788(T720_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T721_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T721_);
		}
LA713_: ;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)97):
	{
		{
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T727_;
			NimStringV2 T728_;
			if (!(i_1 == ((NI)0))) goto LA725_;
			T727_[0] = xLoc_1;
			T727_[1] = yLoc_1;
			T728_.len = 0; T728_.p = NIM_NIL;
			T728_ = percent___jsgen_u2417(T727_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T728_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T728_);
		}
		goto LA723_;
LA725_: ;
		{
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T730_;
			NimStringV2 T731_;
			T730_[0] = xLoc_1;
			T730_[1] = yLoc_1;
			T731_.len = 0; T731_.p = NIM_NIL;
			T731_ = percent___jsgen_u2417(T730_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T731_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T731_);
		}
LA723_: ;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)98):
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_7;
		typ_7 = NIM_NIL;
		typ_7 = skipTypes__ast_u5379((*(*n_p1)._kind_6.sons.p->data[((NI)1)]).typField, TM__BxLwT0mhrtgTPodf1v3xjg_358);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		{
			if (!((*typ_7).kind >= ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)40) && (*typ_7).kind <= ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)44))) goto LA735_;
			{
				NIM_BOOL T739_;
				tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T743_;
				NimStringV2 T744_;
				T739_ = (NIM_BOOL)0;
				T739_ = ((*typ_7).size == IL64(8));
				if (!(T739_)) goto LA740_;
				T739_ = (((*(*(*p_p0).module).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)56)))&63U)))!=0);
LA740_: ;
				if (!T739_) goto LA741_;
				T743_[0] = xLoc_1;
				T743_[1] = yLoc_1;
				T744_.len = 0; T744_.p = NIM_NIL;
				T744_ = percent___jsgen_u2435(T743_, 2);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T744_); goto LA1_;}
				eqsink___system_u2700((&(*r_p2).res), T744_);
			}
			goto LA737_;
LA741_: ;
			{
				NimStringV2 trimmer_3;
				tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T746_;
				NimStringV2 T747_;
				trimmer_3.len = 0; trimmer_3.p = NIM_NIL;
				trimmer_3 = unsignedTrimmer__jsgen_u1494((*typ_7).size);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				T746_[0] = xLoc_1;
				T746_[1] = trimmer_3;
				T747_.len = 0; T747_.p = NIM_NIL;
				T747_ = percent___jsgen_u2441(T746_, 2);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T747_); goto LA1_;}
				eqsink___system_u2700((&(*r_p2).res), T747_);
				eqdestroy___system_u2691(trimmer_3);
			}
LA737_: ;
		}
		goto LA733_;
LA735_: ;
		{
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T749_;
			NimStringV2 T750_;
			T749_[0] = xLoc_1;
			T749_[1] = yLoc_1;
			T750_.len = 0; T750_.p = NIM_NIL;
			T750_ = percent___jsgen_u2446(T749_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T750_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T750_);
		}
LA733_: ;
		eqdestroy___ast_u3378(typ_7);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)99):
	{
		{
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T756_;
			NimStringV2 T757_;
			if (!(i_1 == ((NI)0))) goto LA754_;
			T756_[0] = xLoc_1;
			T756_[1] = yLoc_1;
			T757_.len = 0; T757_.p = NIM_NIL;
			T757_ = percent___jsgen_u2417(T756_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T757_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T757_);
		}
		goto LA752_;
LA754_: ;
		{
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T759_;
			NimStringV2 T760_;
			T759_[0] = xLoc_1;
			T759_[1] = yLoc_1;
			T760_.len = 0; T760_.p = NIM_NIL;
			T760_ = percent___jsgen_u2417(T759_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T760_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T760_);
		}
LA752_: ;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)100):
	{
		{
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T766_;
			NimStringV2 T767_;
			if (!(i_1 == ((NI)0))) goto LA764_;
			T766_[0] = xLoc_1;
			T766_[1] = yLoc_1;
			T767_.len = 0; T767_.p = NIM_NIL;
			T767_ = percent___cgen_u21479(T766_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T767_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T767_);
		}
		goto LA762_;
LA764_: ;
		{
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T769_;
			NimStringV2 T770_;
			T769_[0] = xLoc_1;
			T769_[1] = yLoc_1;
			T770_.len = 0; T770_.p = NIM_NIL;
			T770_ = percent___cgen_u21479(T769_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T770_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T770_);
		}
LA762_: ;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)101):
	{
		{
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T776_;
			NimStringV2 T777_;
			if (!(i_1 == ((NI)0))) goto LA774_;
			T776_[0] = xLoc_1;
			T776_[1] = yLoc_1;
			T777_.len = 0; T777_.p = NIM_NIL;
			T777_ = percent___jsgen_u2467(T776_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T777_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T777_);
		}
		goto LA772_;
LA774_: ;
		{
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T779_;
			NimStringV2 T780_;
			T779_[0] = xLoc_1;
			T779_[1] = yLoc_1;
			T780_.len = 0; T780_.p = NIM_NIL;
			T780_ = percent___jsgen_u2467(T779_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T780_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T780_);
		}
LA772_: ;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)102):
	{
		{
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T786_;
			NimStringV2 T787_;
			if (!(i_1 == ((NI)0))) goto LA784_;
			T786_[0] = xLoc_1;
			T786_[1] = yLoc_1;
			T787_.len = 0; T787_.p = NIM_NIL;
			T787_ = percent___jsgen_u2476(T786_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T787_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T787_);
		}
		goto LA782_;
LA784_: ;
		{
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T789_;
			NimStringV2 T790_;
			T789_[0] = xLoc_1;
			T789_[1] = yLoc_1;
			T790_.len = 0; T790_.p = NIM_NIL;
			T790_ = percent___jsgen_u2476(T789_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T790_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T790_);
		}
LA782_: ;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)103):
	{
		{
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T796_;
			NimStringV2 T797_;
			if (!(i_1 == ((NI)0))) goto LA794_;
			T796_[0] = xLoc_1;
			T796_[1] = yLoc_1;
			T797_.len = 0; T797_.p = NIM_NIL;
			T797_ = percent___jsgen_u2485(T796_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T797_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T797_);
		}
		goto LA792_;
LA794_: ;
		{
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T799_;
			NimStringV2 T800_;
			T799_[0] = xLoc_1;
			T799_[1] = yLoc_1;
			T800_.len = 0; T800_.p = NIM_NIL;
			T800_ = percent___jsgen_u2485(T799_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T800_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T800_);
		}
LA792_: ;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)104):
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)155):
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)157):
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)156):
	{
		{
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T806_;
			NimStringV2 T807_;
			if (!(i_1 == ((NI)0))) goto LA804_;
			T806_[0] = xLoc_1;
			T806_[1] = yLoc_1;
			T807_.len = 0; T807_.p = NIM_NIL;
			T807_ = percent___cgen_u21793(T806_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T807_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T807_);
		}
		goto LA802_;
LA804_: ;
		{
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T809_;
			NimStringV2 T810_;
			T809_[0] = xLoc_1;
			T809_[1] = yLoc_1;
			T810_.len = 0; T810_.p = NIM_NIL;
			T810_ = percent___cgen_u21793(T809_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T810_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T810_);
		}
LA802_: ;
	}
	break;
	default:
	{
	}
	break;
	}
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(yLoc_1);
		eqdestroy___system_u2691(xLoc_1);
		eqdestroy___jsgen_u570((&y_1));
		eqdestroy___jsgen_u570((&x_1));
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, arith__jsgen_u2527)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* r_p2, tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg op_p3) {
NIM_BOOL oldNimErrFin5_;
NIM_BOOL oldNimErrFin32_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	switch (op_p3) {
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)65):
	{
		binaryUintExpr__jsgen_u1698(p_p0, n_p1, r_p2, TM__BxLwT0mhrtgTPodf1v3xjg_400);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)66):
	{
		binaryUintExpr__jsgen_u1698(p_p0, n_p1, r_p2, TM__BxLwT0mhrtgTPodf1v3xjg_402);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)67):
	{
		binaryUintExpr__jsgen_u1698(p_p0, n_p1, r_p2, TM__BxLwT0mhrtgTPodf1v3xjg_404);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)68):
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
		colontmpD_ = NIM_NIL;
		binaryUintExpr__jsgen_u1698(p_p0, n_p1, r_p2, TM__BxLwT0mhrtgTPodf1v3xjg_406);
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		{
			NIM_BOOL T8_;
			tyArray__YgExxhfgKcesA5EOUj1MOA T12_;
			NimStringV2 T13_;
			T8_ = (NIM_BOOL)0;
			T8_ = !((((*(*(*p_p0).module).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)56)))&63U)))!=0));
			if (!(T8_)) goto LA9_;
			colontmpD_ = skipTypes__ast_u5379((*(*n_p1)._kind_6.sons.p->data[((NI)1)]).typField, TM__BxLwT0mhrtgTPodf1v3xjg_196);
			if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
			T8_ = ((*colontmpD_).size == IL64(8));
LA9_: ;
			if (!T8_) goto LA10_;
			T12_[0] = (*r_p2).res;
			T13_.len = 0; T13_.p = NIM_NIL;
			T13_ = percent___jsgen_u2564(T12_, 1);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T13_); goto LA5_;}
			eqsink___system_u2700((&(*r_p2).res), T13_);
		}
LA10_: ;
		{
			LA5_:;
		}
		{
			oldNimErrFin5_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3378(colontmpD_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin5_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)49):
	{
		arithAux__jsgen_u1559(p_p0, n_p1, r_p2, op_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)50):
	{
		arithAux__jsgen_u1559(p_p0, n_p1, r_p2, op_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)101):
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)102):
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)103):
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)104):
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)105):
	{
		arithAux__jsgen_u1559(p_p0, n_p1, r_p2, op_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)87):
	{
		{
			tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg T22_;
			T22_ = (tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)0;
			T22_ = mapType__jsgen_u686((*(*n_p1)._kind_6.sons.p->data[((NI)1)]).typField);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!!((T22_ == ((tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)9)))) goto LA23_;
			arithAux__jsgen_u1559(p_p0, n_p1, r_p2, op_p3);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		goto LA20_;
LA23_: ;
		{
			tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ x_1;
			tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ y_1;
			tyArray__Seu7uK9aaOSN0BK3EAjjSHw T27_;
			NimStringV2 T28_;
			nimZeroMem((void*)(&x_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
			nimZeroMem((void*)(&y_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
			nimZeroMem((void*)(&x_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
			nimZeroMem((void*)(&y_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
			gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], (&x_1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
			gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)2)], (&y_1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
			T27_[0] = x_1.address;
			T27_[1] = y_1.address;
			T27_[2] = x_1.res;
			T27_[3] = y_1.res;
			T28_.len = 0; T28_.p = NIM_NIL;
			T28_ = percent___jsgen_u2583(T27_, 4);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T28_); goto LA26_;}
			eqsink___system_u2700((&(*r_p2).res), T28_);
			{
				LA26_:;
			}
			{
				eqdestroy___jsgen_u570((&y_1));
				eqdestroy___jsgen_u570((&x_1));
			}
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA20_: ;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)92):
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__2;
		colontmpD__2 = NIM_NIL;
		{
			tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ xX60gensym446__1;
			tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ yX60gensym446__1;
			NimStringV2 aX60gensym446__1;
			NimStringV2 tmpX60gensym446__1;
			NimStringV2 bX60gensym446__1;
			NimStringV2 tmp2X60gensym446__1;
			tyArray__Seu7uK9aaOSN0BK3EAjjSHw T38_;
			NimStringV2 T39_;
			colontmpD__2 = skipTypes__ast_u5379((*(*n_p1)._kind_6.sons.p->data[((NI)1)]).typField, TM__BxLwT0mhrtgTPodf1v3xjg_175);
			if (NIM_UNLIKELY(*nimErr_)) goto LA32_;
			if (!((*colontmpD__2).callConv == ((tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ)9))) goto LA35_;
			nimZeroMem((void*)(&xX60gensym446__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
			nimZeroMem((void*)(&yX60gensym446__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
			aX60gensym446__1.len = 0; aX60gensym446__1.p = NIM_NIL;
			tmpX60gensym446__1.len = 0; tmpX60gensym446__1.p = NIM_NIL;
			bX60gensym446__1.len = 0; bX60gensym446__1.p = NIM_NIL;
			tmp2X60gensym446__1.len = 0; tmp2X60gensym446__1.p = NIM_NIL;
			nimZeroMem((void*)(&xX60gensym446__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
			nimZeroMem((void*)(&yX60gensym446__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
			useMagic__jsgen_u1172(p_p0, TM__BxLwT0mhrtgTPodf1v3xjg_452);
			if (NIM_UNLIKELY(*nimErr_)) goto LA37_;
			gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], (&xX60gensym446__1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA37_;
			gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)2)], (&yX60gensym446__1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA37_;
			aX60gensym446__1 = rdLoc__jsgen_u593((&xX60gensym446__1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA37_;
			tmpX60gensym446__1 = rdLoc__jsgen_u593((&xX60gensym446__1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA37_;
			bX60gensym446__1 = rdLoc__jsgen_u593((&yX60gensym446__1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA37_;
			tmp2X60gensym446__1 = rdLoc__jsgen_u593((&yX60gensym446__1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA37_;
			T38_[0] = aX60gensym446__1;
			T38_[1] = bX60gensym446__1;
			T38_[2] = tmpX60gensym446__1;
			T38_[3] = tmp2X60gensym446__1;
			T39_.len = 0; T39_.p = NIM_NIL;
			T39_ = percent___jsgen_u2612(T38_, 4);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T39_); goto LA37_;}
			eqsink___system_u2700((&(*r_p2).res), T39_);
			(*r_p2).kind = ((tyEnum_TResKind__UiCSai1lX4RMkJ9bHo9aP2HA)1);
			{
				LA37_:;
			}
			{
				eqdestroy___system_u2691(tmp2X60gensym446__1);
				eqdestroy___system_u2691(bX60gensym446__1);
				eqdestroy___system_u2691(tmpX60gensym446__1);
				eqdestroy___system_u2691(aX60gensym446__1);
				eqdestroy___jsgen_u570((&yX60gensym446__1));
				eqdestroy___jsgen_u570((&xX60gensym446__1));
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA32_;
		}
		goto LA33_;
LA35_: ;
		{
			arithAux__jsgen_u1559(p_p0, n_p1, r_p2, op_p3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA32_;
		}
LA33_: ;
		{
			LA32_:;
		}
		{
			oldNimErrFin32_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3378(colontmpD__2);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin32_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	default:
	{
		arithAux__jsgen_u1559(p_p0, n_p1, r_p2, op_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	}
	(*r_p2).kind = ((tyEnum_TResKind__UiCSai1lX4RMkJ9bHo9aP2HA)1);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genReprAux__jsgen_u5333)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* r_p2, NimStringV2 magic_p3, NimStringV2 typ_p4) {
	NimStringV2 colontmpD_;
	tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ a_1;
	NimStringV2 T2_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	nimZeroMem((void*)(&a_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
	useMagic__jsgen_u1172(p_p0, magic_p3);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T2_.len = 0; T2_.p = NIM_NIL;
	T2_ = rawNewString(magic_p3.len + 1);
appendString((&T2_), magic_p3);
appendString((&T2_), TM__BxLwT0mhrtgTPodf1v3xjg_453);
	colontmpD_ = T2_;
	prepareAdd((&(*r_p2).res), colontmpD_.len + 0);
appendString((&(*r_p2).res), colontmpD_);
	nimZeroMem((void*)(&a_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
	gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], (&a_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		if (!eqStrings(magic_p3, TM__BxLwT0mhrtgTPodf1v3xjg_455)) goto LA5_;
		{
			if (!(a_1.address.len == ((NI)0))) goto LA9_;
			prepareAdd((&(*r_p2).res), a_1.res.len + 0);
appendString((&(*r_p2).res), a_1.res);
			prepareAdd((&(*r_p2).res), 6);
appendString((&(*r_p2).res), TM__BxLwT0mhrtgTPodf1v3xjg_457);
		}
		goto LA7_;
LA9_: ;
		{
			NimStringV2 colontmpD__2;
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T12_;
			colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
			T12_[0] = a_1.address;
			T12_[1] = a_1.res;
			colontmpD__2 = percent___cgen_u14643(T12_, 2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			prepareAdd((&(*r_p2).res), colontmpD__2.len + 0);
appendString((&(*r_p2).res), colontmpD__2);
			eqdestroy___system_u2691(colontmpD__2);
		}
LA7_: ;
	}
	goto LA3_;
LA5_: ;
	{
		prepareAdd((&(*r_p2).res), a_1.res.len + 0);
appendString((&(*r_p2).res), a_1.res);
	}
LA3_: ;
	{
		if (!!((typ_p4.len == 0))) goto LA16_;
		prepareAdd((&(*r_p2).res), 2);
appendString((&(*r_p2).res), TM__BxLwT0mhrtgTPodf1v3xjg_458);
		prepareAdd((&(*r_p2).res), typ_p4.len + 0);
appendString((&(*r_p2).res), typ_p4);
	}
LA16_: ;
	prepareAdd((&(*r_p2).res), 1);
appendString((&(*r_p2).res), TM__BxLwT0mhrtgTPodf1v3xjg_459);
	{
		LA1_:;
	}
	{
		eqdestroy___jsgen_u570((&a_1));
		eqdestroy___system_u2691(colontmpD_);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genRepr__jsgen_u5348)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* r_p2) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_1;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	t_1 = NIM_NIL;
	t_1 = skipTypes__ast_u5379((*(*n_p1)._kind_6.sons.p->data[((NI)1)]).typField, TM__BxLwT0mhrtgTPodf1v3xjg_358);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	switch ((*t_1).kind) {
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)31) ... ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)35):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)40) ... ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)44):
	{
		genReprAux__jsgen_u5333(p_p0, n_p1, r_p2, TM__BxLwT0mhrtgTPodf1v3xjg_461, TM__BxLwT0mhrtgTPodf1v3xjg_462);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)2):
	{
		genReprAux__jsgen_u5333(p_p0, n_p1, r_p2, TM__BxLwT0mhrtgTPodf1v3xjg_464, TM__BxLwT0mhrtgTPodf1v3xjg_465);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)1):
	{
		genReprAux__jsgen_u5333(p_p0, n_p1, r_p2, TM__BxLwT0mhrtgTPodf1v3xjg_467, TM__BxLwT0mhrtgTPodf1v3xjg_468);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)36) ... ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)39):
	{
		genReprAux__jsgen_u5333(p_p0, n_p1, r_p2, TM__BxLwT0mhrtgTPodf1v3xjg_470, TM__BxLwT0mhrtgTPodf1v3xjg_471);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)28):
	{
		genReprAux__jsgen_u5333(p_p0, n_p1, r_p2, TM__BxLwT0mhrtgTPodf1v3xjg_473, TM__BxLwT0mhrtgTPodf1v3xjg_474);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)14):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)15):
	{
		NimStringV2 colontmpD_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		colontmpD_ = genTypeInfo__jsgen_u828(p_p0, t_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		genReprAux__jsgen_u5333(p_p0, n_p1, r_p2, TM__BxLwT0mhrtgTPodf1v3xjg_476, colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		{
			LA8_:;
		}
		{
			eqdestroy___system_u2691(colontmpD_);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)19):
	{
		NimStringV2 colontmpD__2;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		colontmpD__2 = genTypeInfo__jsgen_u828(p_p0, t_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
		genReprAux__jsgen_u5333(p_p0, n_p1, r_p2, TM__BxLwT0mhrtgTPodf1v3xjg_478, colontmpD__2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
		{
			LA12_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__2);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)3):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)63):
	{
		liMessage__msgs_u1227((*(*p_p0).module).config, (*n_p1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), TM__BxLwT0mhrtgTPodf1v3xjg_480, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__BxLwT0mhrtgTPodf1v3xjg_481), NIM_FALSE, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)26):
	{
		genReprAux__jsgen_u5333(p_p0, n_p1, r_p2, TM__BxLwT0mhrtgTPodf1v3xjg_483, TM__BxLwT0mhrtgTPodf1v3xjg_484);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)27):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)48):
	{
		genReprAux__jsgen_u5333(p_p0, n_p1, r_p2, TM__BxLwT0mhrtgTPodf1v3xjg_486, TM__BxLwT0mhrtgTPodf1v3xjg_487);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	default:
	{
		NimStringV2 colontmpD__3;
		colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
		colontmpD__3 = genTypeInfo__jsgen_u828(p_p0, t_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
		genReprAux__jsgen_u5333(p_p0, n_p1, r_p2, TM__BxLwT0mhrtgTPodf1v3xjg_488, colontmpD__3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
		{
			LA19_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__3);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	}
	(*r_p2).kind = ((tyEnum_TResKind__UiCSai1lX4RMkJ9bHo9aP2HA)1);
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(t_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genSwap__jsgen_u3634)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* stmtList_1;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD_;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD__2;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* T2_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	stmtList_1 = NIM_NIL;
	colontmpD_ = NIM_NIL;
	colontmpD__2 = NIM_NIL;
	T2_ = NIM_NIL;
	{
		if (!!(((*p_p0).prc == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)))) goto LA5_;
		eqcopy___ast_u4577(&colontmpD_, (*p_p0).prc);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T2_ = colontmpD_;
	}
	goto LA3_;
LA5_: ;
	{
		eqcopy___ast_u4577(&colontmpD__2, (*(*p_p0).module).module);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T2_ = colontmpD__2;
	}
LA3_: ;
	stmtList_1 = lowerSwap__lowerings_u156((*(*p_p0).module).graph, n_p1, (*(*p_p0).module).Sup.idgen, T2_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NI i_1;
		NI colontmp_;
		NI i_2;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_u3190(stmtList_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		i_2 = ((NI)0);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA10;
				i_1 = i_2;
				genStmt__jsgen_u1163(p_p0, (*stmtList_1)._kind_6.sons.p->data[i_1]);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				i_2 += ((NI)1);
			} LA10: ;
		}
	}
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u4574(colontmpD__2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u4574(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3252(stmtList_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, needsTemp__jsgen_u1352)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
	NIM_BOOL result;
NIM_BOOL oldNimErrFin6_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_FALSE;
	{
		if (!((*n_p1).kind >= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)26) && (*n_p1).kind <= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)32) || (*n_p1).kind >= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)38) && (*n_p1).kind <= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)39) || (*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)41) || (*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)160))) goto LA3_;
		result = NIM_TRUE;
		goto BeforeRet_;
	}
LA3_: ;
	{
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* c_1;
		c_1 = NIM_NIL;
		{
			NI i_1;
			NI colontmp_;
			NI i_2;
			i_1 = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = safeLen__ast_u3197(n_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
			i_2 = ((NI)0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA9;
					i_1 = i_2;
					eqcopy___ast_u3255(&c_1, (*n_p1)._kind_6.sons.p->data[i_1]);
					if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
					{
						NIM_BOOL T12_;
						T12_ = (NIM_BOOL)0;
						T12_ = needsTemp__jsgen_u1352(p_p0, c_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
						if (!T12_) goto LA13_;
						result = NIM_TRUE;
						eqdestroy___ast_u3252(c_1);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						goto BeforeRet_;
					}
LA13_: ;
					i_2 += ((NI)1);
				} LA9: ;
			}
		}
		{
			LA6_:;
		}
		{
			oldNimErrFin6_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3252(c_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin6_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, maybeMakeTemp__jsgen_u1365)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* x_p2, tyTuple__UV3llMMYFckfui8YMBuUZA* Result) {
	NimStringV2 a_1;
	NimStringV2 b_1;
	tyTuple__UV3llMMYFckfui8YMBuUZA T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)Result, sizeof(tyTuple__UV3llMMYFckfui8YMBuUZA));
	a_1.len = 0; a_1.p = NIM_NIL;
	b_1.len = 0; b_1.p = NIM_NIL;
	a_1 = rdLoc__jsgen_u593(x_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqcopy___system_u2694((&b_1), a_1);
	{
		NIM_BOOL T4_;
		tyTuple__UV3llMMYFckfui8YMBuUZA colontmpD_;
		tyTuple__UV3llMMYFckfui8YMBuUZA colontmpD__2;
		T4_ = (NIM_BOOL)0;
		T4_ = needsTemp__jsgen_u1352(p_p0, n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!T4_) goto LA5_;
		nimZeroMem((void*)(&colontmpD_), sizeof(tyTuple__UV3llMMYFckfui8YMBuUZA));
		nimZeroMem((void*)(&colontmpD__2), sizeof(tyTuple__UV3llMMYFckfui8YMBuUZA));
		{
			NIM_BOOL T9_;
			NIM_BOOL T11_;
			tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg T12_;
			tyArray__YgExxhfgKcesA5EOUj1MOA T16_;
			NimStringV2 T17_;
			NimStringV2 blitTmp_1;
			NimStringV2 blitTmp_2;
			tyTuple__UV3llMMYFckfui8YMBuUZA blitTmp_3;
			T9_ = (NIM_BOOL)0;
			T9_ = !(((*x_p2).tmpLoc.len == 0));
			if (!(T9_)) goto LA10_;
			T11_ = (NIM_BOOL)0;
			T12_ = (tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)0;
			T12_ = mapType__jsgen_u686((*n_p1).typField);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			T11_ = (T12_ == ((tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)9));
			if (T11_) goto LA13_;
			T11_ = ((*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)65) || (*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)47));
LA13_: ;
			T9_ = T11_;
LA10_: ;
			if (!T9_) goto LA14_;
			T16_[0] = (*x_p2).tmpLoc;
			T17_.len = 0; T17_.p = NIM_NIL;
			T17_ = percent___jsgen_u1382(T16_, 1);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T17_); goto BeforeRet_;}
			eqsink___system_u2700((&b_1), T17_);
			blitTmp_1 = a_1;
			colontmpD_.Field0 = blitTmp_1;
			blitTmp_2 = b_1;
			colontmpD_.Field1 = blitTmp_2;
			nimZeroMem((void*)(&blitTmp_3), sizeof(tyTuple__UV3llMMYFckfui8YMBuUZA));
			blitTmp_3 = colontmpD_;
			eqwasMoved___stdZprivateZospaths2_u303((&colontmpD_));
			(*Result) = blitTmp_3;
		}
		goto LA7_;
LA14_: ;
		{
			NimStringV2 tmp_1;
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T19_;
			NimStringV2 T20_;
			NimStringV2 blitTmp_4;
			NimStringV2 blitTmp_5;
			tyTuple__UV3llMMYFckfui8YMBuUZA blitTmp_6;
			tmp_1.len = 0; tmp_1.p = NIM_NIL;
			tmp_1 = getTemp__jsgen_u1235(p_p0, NIM_TRUE);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			eqcopy___system_u2694((&b_1), tmp_1);
			T19_[0] = tmp_1;
			T19_[1] = a_1;
			T20_.len = 0; T20_.p = NIM_NIL;
			T20_ = percent___jsgen_u1390(T19_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T20_); goto BeforeRet_;}
			eqsink___system_u2700((&a_1), T20_);
			blitTmp_4 = a_1;
			colontmpD__2.Field0 = blitTmp_4;
			blitTmp_5 = b_1;
			colontmpD__2.Field1 = blitTmp_5;
			eqdestroy___system_u2691(tmp_1);
			nimZeroMem((void*)(&blitTmp_6), sizeof(tyTuple__UV3llMMYFckfui8YMBuUZA));
			blitTmp_6 = colontmpD__2;
			eqwasMoved___stdZprivateZospaths2_u303((&colontmpD__2));
			(*Result) = blitTmp_6;
		}
LA7_: ;
		eqdestroy___stdZprivateZospaths2_u306((&colontmpD__2));
		eqdestroy___stdZprivateZospaths2_u306((&colontmpD_));
	}
	goto LA2_;
LA5_: ;
	{
		NimStringV2 blitTmp_7;
		NimStringV2 blitTmp_8;
		blitTmp_7 = a_1;
		(*Result).Field0 = blitTmp_7;
		blitTmp_8 = b_1;
		(*Result).Field1 = blitTmp_8;
	}
LA2_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genConStrStr__jsgen_u5277)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* r_p2) {
	tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ a_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__2;
NIM_BOOL oldNimErrFin13_;
	NI T23_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&a_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
	colontmpD_ = NIM_NIL;
	colontmpD__2 = NIM_NIL;
	nimZeroMem((void*)(&a_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
	gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], (&a_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	(*r_p2).kind = ((tyEnum_TResKind__UiCSai1lX4RMkJ9bHo9aP2HA)1);
	{
		NimStringV2 colontmpD__3;
		tyArray__YgExxhfgKcesA5EOUj1MOA T6_;
		colontmpD_ = skipTypes__ast_u5379((*(*n_p1)._kind_6.sons.p->data[((NI)1)]).typField, TM__BxLwT0mhrtgTPodf1v3xjg_358);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!((*colontmpD_).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)2))) goto LA4_;
		colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
		T6_[0] = a_1.res;
		colontmpD__3 = percent___jsgen_u5290(T6_, 1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		prepareAdd((&(*r_p2).res), colontmpD__3.len + 0);
appendString((&(*r_p2).res), colontmpD__3);
		eqdestroy___system_u2691(colontmpD__3);
	}
	goto LA2_;
LA4_: ;
	{
		NimStringV2 colontmpD__4;
		tyArray__YgExxhfgKcesA5EOUj1MOA T8_;
		colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
		T8_[0] = a_1.res;
		colontmpD__4 = percent___jsgen_u5295(T8_, 1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		prepareAdd((&(*r_p2).res), colontmpD__4.len + 0);
appendString((&(*r_p2).res), colontmpD__4);
		eqdestroy___system_u2691(colontmpD__4);
	}
LA2_: ;
	{
		NI i_1;
		NI colontmp_;
		NI T10_;
		NI i_2;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T10_ = (NI)0;
		T10_ = len__ast_u3190(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		colontmp_ = (NI)(T10_ - ((NI)1));
		i_2 = ((NI)2);
		{
			while (1) {
				tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__5;
				if (!(i_2 < colontmp_)) goto LA12;
				colontmpD__5 = NIM_NIL;
				i_1 = i_2;
				gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[i_1], (&a_1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
				{
					NimStringV2 colontmpD__6;
					tyArray__YgExxhfgKcesA5EOUj1MOA T18_;
					colontmpD__5 = skipTypes__ast_u5379((*(*n_p1)._kind_6.sons.p->data[i_1]).typField, TM__BxLwT0mhrtgTPodf1v3xjg_358);
					if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
					if (!((*colontmpD__5).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)2))) goto LA16_;
					colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
					T18_[0] = a_1.res;
					colontmpD__6 = percent___jsgen_u5309(T18_, 1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
					prepareAdd((&(*r_p2).res), colontmpD__6.len + 0);
appendString((&(*r_p2).res), colontmpD__6);
					eqdestroy___system_u2691(colontmpD__6);
				}
				goto LA14_;
LA16_: ;
				{
					NimStringV2 colontmpD__7;
					tyArray__YgExxhfgKcesA5EOUj1MOA T20_;
					colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
					T20_[0] = a_1.res;
					colontmpD__7 = percent___jsgen_u5314(T20_, 1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
					prepareAdd((&(*r_p2).res), colontmpD__7.len + 0);
appendString((&(*r_p2).res), colontmpD__7);
					eqdestroy___system_u2691(colontmpD__7);
				}
LA14_: ;
				i_2 += ((NI)1);
				{
					LA13_:;
				}
				{
					oldNimErrFin13_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3378(colontmpD__5);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin13_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			} LA12: ;
		}
	}
	T23_ = (NI)0;
	T23_ = len__ast_u3190(n_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[(NI)(T23_ - ((NI)1))], (&a_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NI T26_;
		NimStringV2 colontmpD__8;
		tyArray__YgExxhfgKcesA5EOUj1MOA T29_;
		T26_ = (NI)0;
		T26_ = len__ast_u3190(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		colontmpD__2 = skipTypes__ast_u5379((*(*n_p1)._kind_6.sons.p->data[(NI)(T26_ - ((NI)1))]).typField, TM__BxLwT0mhrtgTPodf1v3xjg_358);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!((*colontmpD__2).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)2))) goto LA27_;
		colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
		T29_[0] = a_1.res;
		colontmpD__8 = percent___jsgen_u5323(T29_, 1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		prepareAdd((&(*r_p2).res), colontmpD__8.len + 0);
appendString((&(*r_p2).res), colontmpD__8);
		eqdestroy___system_u2691(colontmpD__8);
	}
	goto LA24_;
LA27_: ;
	{
		NimStringV2 colontmpD__9;
		tyArray__YgExxhfgKcesA5EOUj1MOA T31_;
		colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
		T31_[0] = a_1.res;
		colontmpD__9 = percent___jsgen_u5328(T31_, 1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		prepareAdd((&(*r_p2).res), colontmpD__9.len + 0);
appendString((&(*r_p2).res), colontmpD__9);
		eqdestroy___system_u2691(colontmpD__9);
	}
LA24_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(colontmpD__2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___jsgen_u570((&a_1));
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genNew__jsgen_u5195)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
	tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ a_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&a_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
	t_1 = NIM_NIL;
	colontmpD_ = NIM_NIL;
	nimZeroMem((void*)(&a_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
	gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], (&a_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD_ = skipTypes__ast_u5379((*(*n_p1)._kind_6.sons.p->data[((NI)1)]).typField, TM__BxLwT0mhrtgTPodf1v3xjg_504);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	eqcopy___ast_u3381(&t_1, (*colontmpD_).sons.p->data[((NI)0)]);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg T4_;
		NimStringV2 colontmpD__2;
		NimStringV2 colontmpD__3;
		NimStringV2 colontmpD__4;
		NimStringV2 colontmpD__5;
		tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T8_;
		T4_ = (tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)0;
		T4_ = mapType__jsgen_u686(t_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!(T4_ == ((tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)8))) goto LA5_;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
		colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
		colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
		colontmpD__2 = rdLoc__jsgen_u593((&a_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		T8_[0] = colontmpD__2;
		colontmpD__3 = createVar__jsgen_u4648(p_p0, t_1, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		T8_[1] = colontmpD__3;
		colontmpD__4 = percent___jsgen_u2814(T8_, 2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		colontmpD__5 = indentLine__jsgen_u102(p_p0, colontmpD__4);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		prepareAdd((&(*p_p0).body), colontmpD__5.len + 0);
appendString((&(*p_p0).body), colontmpD__5);
		{
			LA7_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__5);
			eqdestroy___system_u2691(colontmpD__4);
			eqdestroy___system_u2691(colontmpD__3);
			eqdestroy___system_u2691(colontmpD__2);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA2_;
LA5_: ;
	{
		NimStringV2 colontmpD__6;
		NimStringV2 colontmpD__7;
		NimStringV2 colontmpD__8;
		tyArray__dyW7vpmfeTYw8kX3EXuaJA T15_;
		if (!(a_1.typ == ((tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)9))) goto LA12_;
		colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
		colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
		colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
		T15_[0] = a_1.address;
		T15_[1] = a_1.res;
		colontmpD__6 = createVar__jsgen_u4648(p_p0, t_1, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
		T15_[2] = colontmpD__6;
		colontmpD__7 = percent___jsgen_u5216(T15_, 3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
		colontmpD__8 = indentLine__jsgen_u102(p_p0, colontmpD__7);
		if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
		prepareAdd((&(*p_p0).body), colontmpD__8.len + 0);
appendString((&(*p_p0).body), colontmpD__8);
		{
			LA14_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__8);
			eqdestroy___system_u2691(colontmpD__7);
			eqdestroy___system_u2691(colontmpD__6);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA2_;
LA12_: ;
	{
		NimStringV2 colontmpD__9;
		NimStringV2 colontmpD__10;
		NimStringV2 colontmpD__11;
		NimStringV2 colontmpD__12;
		tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T20_;
		colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
		colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
		colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
		colontmpD__12.len = 0; colontmpD__12.p = NIM_NIL;
		colontmpD__9 = rdLoc__jsgen_u593((&a_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
		T20_[0] = colontmpD__9;
		colontmpD__10 = createVar__jsgen_u4648(p_p0, t_1, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
		T20_[1] = colontmpD__10;
		colontmpD__11 = percent___jsgen_u5221(T20_, 2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
		colontmpD__12 = indentLine__jsgen_u102(p_p0, colontmpD__11);
		if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
		prepareAdd((&(*p_p0).body), colontmpD__12.len + 0);
appendString((&(*p_p0).body), colontmpD__12);
		{
			LA19_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__12);
			eqdestroy___system_u2691(colontmpD__11);
			eqdestroy___system_u2691(colontmpD__10);
			eqdestroy___system_u2691(colontmpD__9);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA2_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(t_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___jsgen_u570((&a_1));
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genJSArrayConstr__jsgen_u5439)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* r_p2) {
	tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ a_1;
NIM_BOOL oldNimErrFin20_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&a_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
	nimZeroMem((void*)(&a_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
	eqsink___system_u2700((&(*r_p2).res), TM__BxLwT0mhrtgTPodf1v3xjg_505);
	(*r_p2).kind = ((tyEnum_TResKind__UiCSai1lX4RMkJ9bHo9aP2HA)1);
	{
		NI i_1;
		NI colontmp_;
		NI i_2;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_u3190(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		i_2 = ((NI)0);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA4;
				i_1 = i_2;
				{
					if (!(((NI)0) < i_1)) goto LA7_;
					prepareAdd((&(*r_p2).res), 2);
appendString((&(*r_p2).res), TM__BxLwT0mhrtgTPodf1v3xjg_506);
				}
LA7_: ;
				gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[i_1], (&a_1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				{
					NimStringV2 colontmpD_;
					tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T13_;
					if (!(a_1.typ == ((tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)9))) goto LA11_;
					colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
					T13_[0] = a_1.address;
					T13_[1] = a_1.res;
					colontmpD_ = percent___jsgen_u873(T13_, 2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					prepareAdd((&(*r_p2).res), colontmpD_.len + 0);
appendString((&(*r_p2).res), colontmpD_);
					eqdestroy___system_u2691(colontmpD_);
				}
				goto LA9_;
LA11_: ;
				{
					{
						NIM_BOOL T17_;
						tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_1;
						NimStringV2 colontmpD__2;
						NimStringV2 colontmpD__3;
						tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T21_;
						NimStringV2 T22_;
						T17_ = (NIM_BOOL)0;
						T17_ = needsNoCopy__jsgen_u3374(p_p0, (*n_p1)._kind_6.sons.p->data[i_1]);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						if (!!(T17_)) goto LA18_;
						typ_1 = NIM_NIL;
						colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
						colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
						typ_1 = skipTypes__ast_u5379((*(*n_p1)._kind_6.sons.p->data[i_1]).typField, TM__BxLwT0mhrtgTPodf1v3xjg_175);
						if (NIM_UNLIKELY(*nimErr_)) goto LA20_;
						useMagic__jsgen_u1172(p_p0, TM__BxLwT0mhrtgTPodf1v3xjg_507);
						if (NIM_UNLIKELY(*nimErr_)) goto LA20_;
						colontmpD__2 = rdLoc__jsgen_u593((&a_1));
						if (NIM_UNLIKELY(*nimErr_)) goto LA20_;
						T21_[0] = colontmpD__2;
						colontmpD__3 = genTypeInfo__jsgen_u828(p_p0, typ_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA20_;
						T21_[1] = colontmpD__3;
						T22_.len = 0; T22_.p = NIM_NIL;
						T22_ = percent___jsgen_u5021(T21_, 2);
						if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T22_); goto LA20_;}
						eqsink___system_u2700((&a_1.res), T22_);
						{
							LA20_:;
						}
						{
							oldNimErrFin20_ = *nimErr_; *nimErr_ = NIM_FALSE;
							eqdestroy___system_u2691(colontmpD__3);
							eqdestroy___system_u2691(colontmpD__2);
							eqdestroy___ast_u3378(typ_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
							*nimErr_ = oldNimErrFin20_;
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					}
LA18_: ;
					prepareAdd((&(*r_p2).res), a_1.res.len + 0);
appendString((&(*r_p2).res), a_1.res);
				}
LA9_: ;
				i_2 += ((NI)1);
			} LA4: ;
		}
	}
	prepareAdd((&(*r_p2).res), 1);
appendString((&(*r_p2).res), TM__BxLwT0mhrtgTPodf1v3xjg_508);
	{
		LA1_:;
	}
	{
		eqdestroy___jsgen_u570((&a_1));
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genArgNoParam__jsgen_u4373)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* r_p2) {
	tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ a_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&a_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
	nimZeroMem((void*)(&a_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
	gen__jsgen_u1159(p_p0, n_p1, (&a_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		if (!(a_1.typ == ((tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)9))) goto LA4_;
		prepareAdd((&(*r_p2).res), a_1.address.len + 0);
appendString((&(*r_p2).res), a_1.address);
		prepareAdd((&(*r_p2).res), 2);
appendString((&(*r_p2).res), TM__BxLwT0mhrtgTPodf1v3xjg_512);
		prepareAdd((&(*r_p2).res), a_1.res.len + 0);
appendString((&(*r_p2).res), a_1.res);
	}
	goto LA2_;
LA4_: ;
	{
		prepareAdd((&(*r_p2).res), a_1.res.len + 0);
appendString((&(*r_p2).res), a_1.res);
	}
LA2_: ;
	{
		LA1_:;
	}
	{
		eqdestroy___jsgen_u570((&a_1));
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genArg__jsgen_u4386)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* param_p2, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* r_p3, NI* emitted_p4) {
	tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ a_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&a_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
	colontmpD_ = NIM_NIL;
	nimZeroMem((void*)(&a_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
	gen__jsgen_u1159(p_p0, n_p1, (&a_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NIM_BOOL T4_;
		NimStringV2 colontmpD__2;
		tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T8_;
		T4_ = (NIM_BOOL)0;
		colontmpD_ = skipTypes__ast_u5379((*param_p2).typ, TM__BxLwT0mhrtgTPodf1v3xjg_504);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T4_ = ((*colontmpD_).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)27) || (*colontmpD_).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)48));
		if (!(T4_)) goto LA5_;
		T4_ = (a_1.typ == ((tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)9));
LA5_: ;
		if (!T4_) goto LA6_;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		T8_[0] = a_1.address;
		T8_[1] = a_1.res;
		colontmpD__2 = percent___cgen_u9083(T8_, 2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		prepareAdd((&(*r_p3).res), colontmpD__2.len + 0);
appendString((&(*r_p3).res), colontmpD__2);
		eqdestroy___system_u2691(colontmpD__2);
	}
	goto LA2_;
LA6_: ;
	{
		if (!(a_1.typ == ((tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)9))) goto LA10_;
		prepareAdd((&(*r_p3).res), a_1.address.len + 0);
appendString((&(*r_p3).res), a_1.address);
		prepareAdd((&(*r_p3).res), 2);
appendString((&(*r_p3).res), TM__BxLwT0mhrtgTPodf1v3xjg_513);
		prepareAdd((&(*r_p3).res), a_1.res.len + 0);
appendString((&(*r_p3).res), a_1.res);
		{
			if (!!((emitted_p4 == ((NI*) NIM_NIL)))) goto LA14_;
			(*emitted_p4) += ((NI)1);
		}
LA14_: ;
	}
	goto LA2_;
LA10_: ;
	{
		NIM_BOOL T17_;
		NIM_BOOL T18_;
		tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg T21_;
		NimStringV2 tmp_1;
		NimStringV2 colontmpD__3;
		NimStringV2 colontmpD__4;
		tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T24_;
		T17_ = (NIM_BOOL)0;
		T18_ = (NIM_BOOL)0;
		T18_ = ((*(*n_p1).typField).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)23) || (*(*n_p1).typField).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)21) || (*(*n_p1).typField).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)22) || (*(*n_p1).typField).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)47) || (*(*n_p1).typField).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)45));
		if (!(T18_)) goto LA19_;
		T18_ = ((*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)27) || (*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)29) || (*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)30) || (*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)31) || (*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)26) || (*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)28) || (*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)32));
LA19_: ;
		T17_ = T18_;
		if (!(T17_)) goto LA20_;
		T21_ = (tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)0;
		T21_ = mapType__jsgen_u686((*param_p2).typ);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T17_ = (T21_ == ((tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)9));
LA20_: ;
		if (!T17_) goto LA22_;
		tmp_1.len = 0; tmp_1.p = NIM_NIL;
		colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
		colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
		tmp_1 = getTemp__jsgen_u1235(p_p0, NIM_TRUE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T24_[0] = tmp_1;
		colontmpD__3 = rdLoc__jsgen_u593((&a_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T24_[1] = colontmpD__3;
		colontmpD__4 = percent___jsgen_u4435(T24_, 2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		prepareAdd((&(*r_p3).res), colontmpD__4.len + 0);
appendString((&(*r_p3).res), colontmpD__4);
		{
			if (!!((emitted_p4 == ((NI*) NIM_NIL)))) goto LA27_;
			(*emitted_p4) += ((NI)1);
		}
LA27_: ;
		eqdestroy___system_u2691(colontmpD__4);
		eqdestroy___system_u2691(colontmpD__3);
		eqdestroy___system_u2691(tmp_1);
	}
	goto LA2_;
LA22_: ;
	{
		prepareAdd((&(*r_p3).res), a_1.res.len + 0);
appendString((&(*r_p3).res), a_1.res);
	}
LA2_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___jsgen_u570((&a_1));
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genArgs__jsgen_u4449)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* r_p2, NI start_p3) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_1;
	NIM_BOOL hasArgs_1;
	NI emitted_1;
NIM_BOOL oldNimErrFin6_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	typ_1 = NIM_NIL;
	prepareAdd((&(*r_p2).res), 1);
appendString((&(*r_p2).res), TM__BxLwT0mhrtgTPodf1v3xjg_510);
	hasArgs_1 = NIM_FALSE;
	typ_1 = skipTypes__ast_u5379((*(*n_p1)._kind_6.sons.p->data[((NI)0)]).typField, TM__BxLwT0mhrtgTPodf1v3xjg_175);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	emitted_1 = (NI)(start_p3 - ((NI)1));
	{
		NI i_1;
		NI colontmp_;
		NI i_2;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_u3190(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		i_2 = start_p3;
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA4;
				i_1 = i_2;
				{
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* it_1;
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* paramType_1;
					it_1 = NIM_NIL;
					paramType_1 = NIM_NIL;
					eqcopy___ast_u3255(&it_1, (*n_p1)._kind_6.sons.p->data[i_1]);
					if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
					paramType_1 = ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL);
					{
						NI T9_;
						T9_ = (NI)0;
						T9_ = len__ast_u5502(typ_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
						if (!(i_1 < T9_)) goto LA10_;
						eqcopy___ast_u3255(&paramType_1, (*(*typ_1).n)._kind_6.sons.p->data[i_1]);
						if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
						{
							NIM_BOOL T14_;
							T14_ = (NIM_BOOL)0;
							T14_ = isCompileTimeOnly__types_u3655((*paramType_1).typField);
							if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
							if (!T14_) goto LA15_;
							eqdestroy___ast_u3252(paramType_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
							eqdestroy___ast_u3252(it_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
							goto LA5;
						}
LA15_: ;
					}
LA10_: ;
					{
						if (!hasArgs_1) goto LA19_;
						prepareAdd((&(*r_p2).res), 2);
appendString((&(*r_p2).res), TM__BxLwT0mhrtgTPodf1v3xjg_511);
					}
LA19_: ;
					{
						if (!(paramType_1 == 0)) goto LA23_;
						genArgNoParam__jsgen_u4373(p_p0, it_1, r_p2);
						if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
					}
					goto LA21_;
LA23_: ;
					{
						genArg__jsgen_u4386(p_p0, it_1, (*paramType_1)._kind_4.sym, r_p2, (&emitted_1));
						if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
					}
LA21_: ;
					emitted_1 += ((NI)1);
					hasArgs_1 = NIM_TRUE;
					{
						LA6_:;
					}
					{
						oldNimErrFin6_ = *nimErr_; *nimErr_ = NIM_FALSE;
						eqdestroy___ast_u3252(paramType_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						eqdestroy___ast_u3252(it_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						*nimErr_ = oldNimErrFin6_;
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				} LA5: ;
				i_2 += ((NI)1);
			} LA4: ;
		}
	}
	prepareAdd((&(*r_p2).res), 1);
appendString((&(*r_p2).res), TM__BxLwT0mhrtgTPodf1v3xjg_514);
	(*r_p2).kind = ((tyEnum_TResKind__UiCSai1lX4RMkJ9bHo9aP2HA)1);
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(typ_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genCall__jsgen_u4598)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* r_p2) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)0)], r_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	genArgs__jsgen_u4449(p_p0, n_p1, r_p2, ((NI)1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg t_1;
		if (!!(((*n_p1).typField == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL)))) goto LA3_;
		t_1 = mapType__jsgen_u686((*n_p1).typField);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		{
			NimStringV2 tmp_1;
			NimStringV2 colontmpD_;
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T9_;
			NimStringV2 T10_;
			tyArray__YgExxhfgKcesA5EOUj1MOA T11_;
			NimStringV2 T12_;
			if (!(t_1 == ((tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)9))) goto LA7_;
			tmp_1.len = 0; tmp_1.p = NIM_NIL;
			colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
			tmp_1 = getTemp__jsgen_u1235(p_p0, NIM_TRUE);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			T9_[0] = tmp_1;
			colontmpD_ = rdLoc__jsgen_u593((&(*r_p2)));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			T9_[1] = colontmpD_;
			T10_.len = 0; T10_.p = NIM_NIL;
			T10_ = percent___jsgen_u3715(T9_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T10_); goto BeforeRet_;}
			eqsink___system_u2700((&(*r_p2).address), T10_);
			T11_[0] = tmp_1;
			T12_.len = 0; T12_.p = NIM_NIL;
			T12_ = percent___jsgen_u3720(T11_, 1);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T12_); goto BeforeRet_;}
			eqsink___system_u2700((&(*r_p2).res), T12_);
			eqsink___system_u2700((&(*r_p2).tmpLoc), tmp_1);
			(*r_p2).typ = t_1;
			eqdestroy___system_u2691(colontmpD_);
		}
LA7_: ;
	}
LA3_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genOrd__jsgen_u5245)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* r_p2) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_ = NIM_NIL;
	colontmpD_ = skipTypes__ast_u5379((*(*n_p1)._kind_6.sons.p->data[((NI)1)]).typField, TM__BxLwT0mhrtgTPodf1v3xjg_515);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	switch ((*colontmpD_).kind) {
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)14):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)31) ... ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)34):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)40) ... ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)43):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)2):
	{
		gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], r_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)35):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)44):
	{
		{
			NimStringV2 aX60gensym1107__1;
			NimStringV2 tmpX60gensym1107__1;
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T14_;
			NimStringV2 T15_;
			if (!(((*(*(*p_p0).module).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)56)))&63U)))!=0)) goto LA6_;
			aX60gensym1107__1.len = 0; aX60gensym1107__1.p = NIM_NIL;
			tmpX60gensym1107__1.len = 0; tmpX60gensym1107__1.p = NIM_NIL;
			useMagic__jsgen_u1172(p_p0, TM__BxLwT0mhrtgTPodf1v3xjg_516);
			if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
			gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], r_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
			aX60gensym1107__1 = rdLoc__jsgen_u593((&(*r_p2)));
			if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
			tmpX60gensym1107__1 = rdLoc__jsgen_u593((&(*r_p2)));
			if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
			{
				NIM_BOOL T11_;
				tyTuple__UV3llMMYFckfui8YMBuUZA tmpTupleAsgn;
				T11_ = (NIM_BOOL)0;
				T11_ = contains__pureZstrutils_u1833(TM__BxLwT0mhrtgTPodf1v3xjg_518, TM__BxLwT0mhrtgTPodf1v3xjg_519);
				if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
				if (!T11_) goto LA12_;
				nimZeroMem((void*)(&tmpTupleAsgn), sizeof(tyTuple__UV3llMMYFckfui8YMBuUZA));
				maybeMakeTemp__jsgen_u1365(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], (&(*r_p2)), (&tmpTupleAsgn));
				if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
				eqsink___system_u2700((&aX60gensym1107__1), tmpTupleAsgn.Field0);
				eqsink___system_u2700((&tmpX60gensym1107__1), tmpTupleAsgn.Field1);
			}
LA12_: ;
			T14_[0] = aX60gensym1107__1;
			T14_[1] = tmpX60gensym1107__1;
			T15_.len = 0; T15_.p = NIM_NIL;
			T15_ = percent___jsgen_u5262(T14_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T15_); goto LA8_;}
			eqsink___system_u2700((&(*r_p2).res), T15_);
			(*r_p2).kind = ((tyEnum_TResKind__UiCSai1lX4RMkJ9bHo9aP2HA)1);
			{
				LA8_:;
			}
			{
				eqdestroy___system_u2691(tmpX60gensym1107__1);
				eqdestroy___system_u2691(aX60gensym1107__1);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		goto LA4_;
LA6_: ;
		{
			gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], r_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA4_: ;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)1):
	{
		NimStringV2 aX60gensym1112__1;
		NimStringV2 tmpX60gensym1112__1;
		tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T26_;
		NimStringV2 T27_;
		aX60gensym1112__1.len = 0; aX60gensym1112__1.p = NIM_NIL;
		tmpX60gensym1112__1.len = 0; tmpX60gensym1112__1.p = NIM_NIL;
		useMagic__jsgen_u1172(p_p0, TM__BxLwT0mhrtgTPodf1v3xjg_520);
		if (NIM_UNLIKELY(*nimErr_)) goto LA20_;
		gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], r_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA20_;
		aX60gensym1112__1 = rdLoc__jsgen_u593((&(*r_p2)));
		if (NIM_UNLIKELY(*nimErr_)) goto LA20_;
		tmpX60gensym1112__1 = rdLoc__jsgen_u593((&(*r_p2)));
		if (NIM_UNLIKELY(*nimErr_)) goto LA20_;
		{
			NIM_BOOL T23_;
			tyTuple__UV3llMMYFckfui8YMBuUZA tmpTupleAsgn_2;
			T23_ = (NIM_BOOL)0;
			T23_ = contains__pureZstrutils_u1833(TM__BxLwT0mhrtgTPodf1v3xjg_522, TM__BxLwT0mhrtgTPodf1v3xjg_523);
			if (NIM_UNLIKELY(*nimErr_)) goto LA20_;
			if (!T23_) goto LA24_;
			nimZeroMem((void*)(&tmpTupleAsgn_2), sizeof(tyTuple__UV3llMMYFckfui8YMBuUZA));
			maybeMakeTemp__jsgen_u1365(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], (&(*r_p2)), (&tmpTupleAsgn_2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA20_;
			eqsink___system_u2700((&aX60gensym1112__1), tmpTupleAsgn_2.Field0);
			eqsink___system_u2700((&tmpX60gensym1112__1), tmpTupleAsgn_2.Field1);
		}
LA24_: ;
		T26_[0] = aX60gensym1112__1;
		T26_[1] = tmpX60gensym1112__1;
		T27_.len = 0; T27_.p = NIM_NIL;
		T27_ = percent___jsgen_u5272(T26_, 2);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T27_); goto LA20_;}
		eqsink___system_u2700((&(*r_p2).res), T27_);
		(*r_p2).kind = ((tyEnum_TResKind__UiCSai1lX4RMkJ9bHo9aP2HA)1);
		{
			LA20_:;
		}
		{
			eqdestroy___system_u2691(tmpX60gensym1112__1);
			eqdestroy___system_u2691(aX60gensym1112__1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	default:
	{
		internalErrorImpl__msgs_u1598((*(*p_p0).module).config, (*n_p1).info, TM__BxLwT0mhrtgTPodf1v3xjg_525, (&TM__BxLwT0mhrtgTPodf1v3xjg_526));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	}
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, indexType__ast_u5345)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* n_p0) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	eqcopy___ast_u3381(&result, (*n_p0).sons.p->data[((NI)0)]);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, maybeMakeTempAssignable__jsgen_u1399)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* x_p2, tyTuple__UV3llMMYFckfui8YMBuUZA* Result) {
	NimStringV2 a_1;
	NimStringV2 b_1;
NIM_BOOL oldNimErrFin28_;
NIM_BOOL oldNimErrFin23_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)Result, sizeof(tyTuple__UV3llMMYFckfui8YMBuUZA));
	a_1.len = 0; a_1.p = NIM_NIL;
	b_1.len = 0; b_1.p = NIM_NIL;
	a_1 = rdLoc__jsgen_u593(x_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	eqcopy___system_u2694((&b_1), a_1);
	{
		NIM_BOOL T4_;
		T4_ = (NIM_BOOL)0;
		T4_ = needsTemp__jsgen_u1352(p_p0, n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!T4_) goto LA5_;
		{
			NIM_BOOL T9_;
			NIM_BOOL T11_;
			tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg T12_;
			NimStringV2 colontmp_;
			NimStringV2 colontmp__2;
			tyArray__YgExxhfgKcesA5EOUj1MOA T16_;
			NimStringV2 T17_;
			NimStringV2 blitTmp_1;
			NimStringV2 blitTmp_2;
			T9_ = (NIM_BOOL)0;
			T9_ = !(((*x_p2).tmpLoc.len == 0));
			if (!(T9_)) goto LA10_;
			T11_ = (NIM_BOOL)0;
			T12_ = (tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)0;
			T12_ = mapType__jsgen_u686((*n_p1).typField);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			T11_ = (T12_ == ((tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)9));
			if (T11_) goto LA13_;
			T11_ = ((*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)65) || (*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)47));
LA13_: ;
			T9_ = T11_;
LA10_: ;
			if (!T9_) goto LA14_;
			colontmp_.len = 0; colontmp_.p = NIM_NIL;
			colontmp__2.len = 0; colontmp__2.p = NIM_NIL;
			T16_[0] = (*x_p2).tmpLoc;
			T17_.len = 0; T17_.p = NIM_NIL;
			T17_ = percent___jsgen_u1382(T16_, 1);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T17_); goto LA1_;}
			eqsink___system_u2700((&b_1), T17_);
			colontmp_ = a_1;
			eqwasMoved___system_u2688((&a_1));
			colontmp__2 = b_1;
			eqwasMoved___system_u2688((&b_1));
			blitTmp_1 = colontmp_;
			(*Result).Field0 = blitTmp_1;
			blitTmp_2 = colontmp__2;
			(*Result).Field1 = blitTmp_2;
		}
		goto LA7_;
LA14_: ;
		{
			NIM_BOOL T19_;
			tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ address_1;
			tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ index_1;
			tyTuple__UV3llMMYFckfui8YMBuUZA tmpTuple_1;
			NimStringV2 m1_1;
			NimStringV2 tmp1_1;
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_1;
			tyTuple__UV3llMMYFckfui8YMBuUZA tmpTuple_2;
			NimStringV2 n1_1;
			NimStringV2 tmp2_1;
			NimStringV2 colontmp__3;
			NimStringV2 colontmp__4;
			tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg first_1;
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T52_;
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T53_;
			NimStringV2 blitTmp_3;
			NimStringV2 blitTmp_4;
			T19_ = (NIM_BOOL)0;
			T19_ = !(((*x_p2).tmpLoc.len == 0));
			if (!(T19_)) goto LA20_;
			T19_ = ((*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)42));
LA20_: ;
			if (!T19_) goto LA21_;
			nimZeroMem((void*)(&address_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
			nimZeroMem((void*)(&index_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
			nimZeroMem((void*)(&tmpTuple_1), sizeof(tyTuple__UV3llMMYFckfui8YMBuUZA));
			m1_1.len = 0; m1_1.p = NIM_NIL;
			tmp1_1.len = 0; tmp1_1.p = NIM_NIL;
			typ_1 = NIM_NIL;
			nimZeroMem((void*)(&tmpTuple_2), sizeof(tyTuple__UV3llMMYFckfui8YMBuUZA));
			n1_1.len = 0; n1_1.p = NIM_NIL;
			tmp2_1.len = 0; tmp2_1.p = NIM_NIL;
			colontmp__3.len = 0; colontmp__3.p = NIM_NIL;
			colontmp__4.len = 0; colontmp__4.p = NIM_NIL;
			nimZeroMem((void*)(&address_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
			nimZeroMem((void*)(&index_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
			first_1 = Zero__int128_u8;
			gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)0)], (&address_1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
			gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], (&index_1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
			maybeMakeTemp__jsgen_u1365(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)0)], (&address_1), (&tmpTuple_1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
			m1_1 = tmpTuple_1.Field0;
			eqwasMoved___system_u2688((&tmpTuple_1.Field0));
			tmp1_1 = tmpTuple_1.Field1;
			eqwasMoved___system_u2688((&tmpTuple_1.Field1));
			typ_1 = skipTypes__ast_u5379((*(*n_p1)._kind_6.sons.p->data[((NI)0)]).typField, TM__BxLwT0mhrtgTPodf1v3xjg_527);
			if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
			{
				tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
				if (!((*typ_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)16))) goto LA26_;
				colontmpD_ = NIM_NIL;
				colontmpD_ = indexType__ast_u5345(typ_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA28_;
				first_1 = firstOrd__types_u1182((*(*p_p0).module).config, colontmpD_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA28_;
				{
					LA28_:;
				}
				{
					oldNimErrFin28_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3378(colontmpD_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
					*nimErr_ = oldNimErrFin28_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
			}
LA26_: ;
			{
				if (!(((*p_p0).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)4)))&31U)))!=0)) goto LA33_;
				useMagic__jsgen_u1172(p_p0, TM__BxLwT0mhrtgTPodf1v3xjg_529);
				if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
				{
					NIM_BOOL T37_;
					tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T40_;
					NimStringV2 T41_;
					T37_ = (NIM_BOOL)0;
					T37_ = eqeq___int128_u980(first_1, IL64(0));
					if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
					if (!T37_) goto LA38_;
					T40_[0] = index_1.res;
					T40_[1] = tmp1_1;
					T41_.len = 0; T41_.p = NIM_NIL;
					T41_ = percent___jsgen_u1449(T40_, 2);
					if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T41_); goto LA23_;}
					eqsink___system_u2700((&index_1.res), T41_);
				}
				goto LA35_;
LA38_: ;
				{
					NimStringV2 colontmpD__2;
					tyArray__dyW7vpmfeTYw8kX3EXuaJA T43_;
					NimStringV2 T44_;
					colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
					T43_[0] = index_1.res;
					colontmpD__2 = rope__jsgen_u825(first_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
					T43_[1] = colontmpD__2;
					T43_[2] = tmp1_1;
					T44_.len = 0; T44_.p = NIM_NIL;
					T44_ = percent___jsgen_u1454(T43_, 3);
					if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T44_); goto LA23_;}
					eqsink___system_u2700((&index_1.res), T44_);
					eqdestroy___system_u2691(colontmpD__2);
				}
LA35_: ;
			}
			goto LA31_;
LA33_: ;
			{
				NIM_BOOL T46_;
				NimStringV2 colontmpD__3;
				tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T49_;
				NimStringV2 T50_;
				T46_ = (NIM_BOOL)0;
				T46_ = eqeq___int128_u980(first_1, IL64(0));
				if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
				if (!!(T46_)) goto LA47_;
				colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
				T49_[0] = index_1.res;
				colontmpD__3 = rope__jsgen_u825(first_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
				T49_[1] = colontmpD__3;
				T50_.len = 0; T50_.p = NIM_NIL;
				T50_ = percent___jsgen_u1459(T49_, 2);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T50_); goto LA23_;}
				eqsink___system_u2700((&index_1.res), T50_);
				eqdestroy___system_u2691(colontmpD__3);
			}
			goto LA31_;
LA47_: ;
			{
			}
LA31_: ;
			maybeMakeTemp__jsgen_u1365(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], (&index_1), (&tmpTuple_2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
			n1_1 = tmpTuple_2.Field0;
			eqwasMoved___system_u2688((&tmpTuple_2.Field0));
			tmp2_1 = tmpTuple_2.Field1;
			eqwasMoved___system_u2688((&tmpTuple_2.Field1));
			T52_[0] = m1_1;
			T52_[1] = n1_1;
			colontmp__3 = percent___cgen_u9083(T52_, 2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
			T53_[0] = tmp1_1;
			T53_[1] = tmp2_1;
			colontmp__4 = percent___cgen_u9083(T53_, 2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
			blitTmp_3 = colontmp__3;
			eqwasMoved___system_u2688((&colontmp__3));
			(*Result).Field0 = blitTmp_3;
			blitTmp_4 = colontmp__4;
			eqwasMoved___system_u2688((&colontmp__4));
			(*Result).Field1 = blitTmp_4;
			{
				LA23_:;
			}
			{
				oldNimErrFin23_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___system_u2691(colontmp__4);
				eqdestroy___system_u2691(colontmp__3);
				eqdestroy___system_u2691(tmp2_1);
				eqdestroy___system_u2691(n1_1);
				eqdestroy___stdZprivateZospaths2_u306((&tmpTuple_2));
				eqdestroy___ast_u3378(typ_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				eqdestroy___system_u2691(tmp1_1);
				eqdestroy___system_u2691(m1_1);
				eqdestroy___stdZprivateZospaths2_u306((&tmpTuple_1));
				eqdestroy___jsgen_u570((&index_1));
				eqdestroy___jsgen_u570((&address_1));
				*nimErr_ = oldNimErrFin23_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		goto LA7_;
LA21_: ;
		{
			NimStringV2 colontmp__5;
			NimStringV2 colontmp__6;
			NimStringV2 blitTmp_5;
			NimStringV2 blitTmp_6;
			colontmp__5.len = 0; colontmp__5.p = NIM_NIL;
			colontmp__6.len = 0; colontmp__6.p = NIM_NIL;
			colontmp__5 = a_1;
			eqwasMoved___system_u2688((&a_1));
			colontmp__6 = b_1;
			eqwasMoved___system_u2688((&b_1));
			blitTmp_5 = colontmp__5;
			(*Result).Field0 = blitTmp_5;
			blitTmp_6 = colontmp__6;
			(*Result).Field1 = blitTmp_6;
		}
LA7_: ;
	}
	goto LA2_;
LA5_: ;
	{
		NimStringV2 colontmp__7;
		NimStringV2 colontmp__8;
		NimStringV2 blitTmp_7;
		NimStringV2 blitTmp_8;
		colontmp__7.len = 0; colontmp__7.p = NIM_NIL;
		colontmp__8.len = 0; colontmp__8.p = NIM_NIL;
		colontmp__7 = a_1;
		eqwasMoved___system_u2688((&a_1));
		colontmp__8 = b_1;
		eqwasMoved___system_u2688((&b_1));
		blitTmp_7 = colontmp__7;
		(*Result).Field0 = blitTmp_7;
		blitTmp_8 = colontmp__8;
		(*Result).Field1 = blitTmp_8;
	}
LA2_: ;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(b_1);
		eqdestroy___system_u2691(a_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, binaryUintExpr__jsgen_u5721)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* r_p2, NimStringV2 op_p3) {
	tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ x_1;
	tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ y_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
	tyTuple__UV3llMMYFckfui8YMBuUZA tmpTuple_1;
	NimStringV2 a_1;
	NimStringV2 tmp_1;
	NI64 size_1;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&x_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
	nimZeroMem((void*)(&y_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
	colontmpD_ = NIM_NIL;
	nimZeroMem((void*)(&tmpTuple_1), sizeof(tyTuple__UV3llMMYFckfui8YMBuUZA));
	a_1.len = 0; a_1.p = NIM_NIL;
	tmp_1.len = 0; tmp_1.p = NIM_NIL;
	nimZeroMem((void*)(&x_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
	nimZeroMem((void*)(&y_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
	gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], (&x_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)2)], (&y_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD_ = skipTypes__ast_u5379((*(*n_p1)._kind_6.sons.p->data[((NI)1)]).typField, abstractRange__types_u92);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	size_1 = (*colontmpD_).size;
	maybeMakeTempAssignable__jsgen_u1399(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], (&x_1), (&tmpTuple_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	a_1 = tmpTuple_1.Field0;
	eqwasMoved___system_u2688((&tmpTuple_1.Field0));
	tmp_1 = tmpTuple_1.Field1;
	eqwasMoved___system_u2688((&tmpTuple_1.Field1));
	{
		NIM_BOOL T4_;
		NimStringV2 colontmpD__2;
		tyArray__Seu7uK9aaOSN0BK3EAjjSHw T8_;
		NimStringV2 T9_;
		T4_ = (NIM_BOOL)0;
		T4_ = (size_1 == IL64(8));
		if (!(T4_)) goto LA5_;
		T4_ = (((*(*(*p_p0).module).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)56)))&63U)))!=0);
LA5_: ;
		if (!T4_) goto LA6_;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		T8_[0] = a_1;
		T8_[1] = op_p3;
		colontmpD__2 = rdLoc__jsgen_u593((&y_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T8_[2] = colontmpD__2;
		T8_[3] = tmp_1;
		T9_.len = 0; T9_.p = NIM_NIL;
		T9_ = percent___jsgen_u5746(T8_, 4);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T9_); goto LA1_;}
		eqsink___system_u2700((&(*r_p2).res), T9_);
		eqdestroy___system_u2691(colontmpD__2);
	}
	goto LA2_;
LA6_: ;
	{
		NimStringV2 trimmer_1;
		NimStringV2 colontmpD__3;
		tyArray__awn6UrBeChh9cVy9ccoluuYg T11_;
		NimStringV2 T12_;
		trimmer_1.len = 0; trimmer_1.p = NIM_NIL;
		colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
		trimmer_1 = unsignedTrimmer__jsgen_u1494(size_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T11_[0] = a_1;
		T11_[1] = op_p3;
		colontmpD__3 = rdLoc__jsgen_u593((&y_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T11_[2] = colontmpD__3;
		T11_[3] = trimmer_1;
		T11_[4] = tmp_1;
		T12_.len = 0; T12_.p = NIM_NIL;
		T12_ = percent___jsgen_u5752(T11_, 5);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T12_); goto LA1_;}
		eqsink___system_u2700((&(*r_p2).res), T12_);
		eqdestroy___system_u2691(colontmpD__3);
		eqdestroy___system_u2691(trimmer_1);
	}
LA2_: ;
	(*r_p2).kind = ((tyEnum_TResKind__UiCSai1lX4RMkJ9bHo9aP2HA)1);
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___system_u2691(tmp_1);
		eqdestroy___system_u2691(a_1);
		eqdestroy___stdZprivateZospaths2_u306((&tmpTuple_1));
		eqdestroy___ast_u3378(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___jsgen_u570((&y_1));
		eqdestroy___jsgen_u570((&x_1));
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genNewSeq__jsgen_u5226)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
	tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ x_1;
	tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ y_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
	NimStringV2 colontmpD__2;
	NimStringV2 colontmpD__3;
	NimStringV2 colontmpD__4;
	NimStringV2 colontmpD__5;
	NimStringV2 colontmpD__6;
	tyArray__dyW7vpmfeTYw8kX3EXuaJA T2_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&x_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
	nimZeroMem((void*)(&y_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
	t_1 = NIM_NIL;
	colontmpD_ = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
	colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
	colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
	colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
	nimZeroMem((void*)(&x_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
	nimZeroMem((void*)(&y_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
	gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], (&x_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)2)], (&y_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD_ = skipTypes__ast_u5379((*(*n_p1)._kind_6.sons.p->data[((NI)1)]).typField, TM__BxLwT0mhrtgTPodf1v3xjg_504);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	eqcopy___ast_u3381(&t_1, (*colontmpD_).sons.p->data[((NI)0)]);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__2 = rdLoc__jsgen_u593((&x_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T2_[0] = colontmpD__2;
	colontmpD__3 = rdLoc__jsgen_u593((&y_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T2_[1] = colontmpD__3;
	colontmpD__4 = createVar__jsgen_u4648(p_p0, t_1, NIM_FALSE);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T2_[2] = colontmpD__4;
	colontmpD__5 = percent___jsgen_u5240(T2_, 3);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__6 = indentLine__jsgen_u102(p_p0, colontmpD__5);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&(*p_p0).body), colontmpD__6.len + 0);
appendString((&(*p_p0).body), colontmpD__6);
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___system_u2691(colontmpD__6);
		eqdestroy___system_u2691(colontmpD__5);
		eqdestroy___system_u2691(colontmpD__4);
		eqdestroy___system_u2691(colontmpD__3);
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___ast_u3378(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(t_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___jsgen_u570((&y_1));
		eqdestroy___jsgen_u570((&x_1));
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genOf__jsgen_u5353)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* r_p2) {
	tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ x_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_1;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&x_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
	t_1 = NIM_NIL;
	nimZeroMem((void*)(&x_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
	t_1 = skipTypes__ast_u5379((*(*n_p1)._kind_6.sons.p->data[((NI)2)]).typField, TM__BxLwT0mhrtgTPodf1v3xjg_571);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], (&x_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NimStringV2 colontmpD_;
		tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T7_;
		NimStringV2 T8_;
		if (!(((*t_1).flags &((NU64)1<<((NU)((((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)2)))&63U)))!=0)) goto LA4_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		T7_[0] = x_1.res;
		colontmpD_ = genTypeInfo__jsgen_u828(p_p0, t_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		T7_[1] = colontmpD_;
		T8_.len = 0; T8_.p = NIM_NIL;
		T8_ = percent___jsgen_u5371(T7_, 2);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T8_); goto LA6_;}
		eqsink___system_u2700((&(*r_p2).res), T8_);
		{
			LA6_:;
		}
		{
			eqdestroy___system_u2691(colontmpD_);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA2_;
LA4_: ;
	{
		NimStringV2 colontmpD__2;
		tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T13_;
		NimStringV2 T14_;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		useMagic__jsgen_u1172(p_p0, TM__BxLwT0mhrtgTPodf1v3xjg_573);
		if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
		T13_[0] = x_1.res;
		colontmpD__2 = genTypeInfo__jsgen_u828(p_p0, t_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
		T13_[1] = colontmpD__2;
		T14_.len = 0; T14_.p = NIM_NIL;
		T14_ = percent___jsgen_u5376(T13_, 2);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T14_); goto LA12_;}
		eqsink___system_u2700((&(*r_p2).res), T14_);
		{
			LA12_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__2);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA2_: ;
	(*r_p2).kind = ((tyEnum_TResKind__UiCSai1lX4RMkJ9bHo9aP2HA)1);
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(t_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___jsgen_u570((&x_1));
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genDefault__jsgen_u5381)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* r_p2) {
	NimStringV2 T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	T1_.len = 0; T1_.p = NIM_NIL;
	T1_ = createVar__jsgen_u4648(p_p0, (*n_p1).typField, NIM_FALSE);
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T1_); goto BeforeRet_;}
	eqsink___system_u2700((&(*r_p2).res), T1_);
	(*r_p2).kind = ((tyEnum_TResKind__UiCSai1lX4RMkJ9bHo9aP2HA)1);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genWasMoved__jsgen_u5385)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
	tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ x_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&x_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
	nimZeroMem((void*)(&x_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
	gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], (&x_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NimStringV2 colontmpD_;
		NimStringV2 colontmpD__2;
		tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T6_;
		if (!(x_1.typ == ((tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)9))) goto LA4_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		T6_[0] = x_1.address;
		T6_[1] = x_1.res;
		colontmpD_ = percent___jsgen_u5397(T6_, 2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		colontmpD__2 = indentLine__jsgen_u102(p_p0, colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		prepareAdd((&(*p_p0).body), colontmpD__2.len + 0);
appendString((&(*p_p0).body), colontmpD__2);
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(colontmpD_);
	}
	goto LA2_;
LA4_: ;
	{
		tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ y_1;
		tyTuple__UV3llMMYFckfui8YMBuUZA tmpTuple_1;
		NimStringV2 a_1;
		NimStringV2 colontmpD__3;
		NimStringV2 colontmpD__4;
		NimStringV2 colontmpD__5;
		tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T9_;
		nimZeroMem((void*)(&y_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
		nimZeroMem((void*)(&tmpTuple_1), sizeof(tyTuple__UV3llMMYFckfui8YMBuUZA));
		a_1.len = 0; a_1.p = NIM_NIL;
		colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
		colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
		colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
		nimZeroMem((void*)(&y_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
		genDefault__jsgen_u5381(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], (&y_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		maybeMakeTempAssignable__jsgen_u1399(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], (&x_1), (&tmpTuple_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		a_1 = tmpTuple_1.Field0;
		eqwasMoved___system_u2688((&tmpTuple_1.Field0));
		T9_[0] = a_1;
		colontmpD__3 = rdLoc__jsgen_u593((&y_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		T9_[1] = colontmpD__3;
		colontmpD__4 = percent___jsgen_u2814(T9_, 2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		colontmpD__5 = indentLine__jsgen_u102(p_p0, colontmpD__4);
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		prepareAdd((&(*p_p0).body), colontmpD__5.len + 0);
appendString((&(*p_p0).body), colontmpD__5);
		{
			LA8_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__5);
			eqdestroy___system_u2691(colontmpD__4);
			eqdestroy___system_u2691(colontmpD__3);
			eqdestroy___system_u2691(a_1);
			eqdestroy___stdZprivateZospaths2_u306((&tmpTuple_1));
			eqdestroy___jsgen_u570((&y_1));
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA2_: ;
	{
		LA1_:;
	}
	{
		eqdestroy___jsgen_u570((&x_1));
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genEcho__jsgen_u4620)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* r_p2) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_2;
NIM_BOOL oldNimErrFin13_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	n_2 = NIM_NIL;
	n_2 = skipConv__types_u3729((*n_p1)._kind_6.sons.p->data[((NI)1)]);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NimStringV2 argX60gensym977__1;
		if (!!(((*n_2).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)41)))) goto LA4_;
		argX60gensym977__1.len = 0; argX60gensym977__1.p = NIM_NIL;
		argX60gensym977__1 = toFileLineCol__msgs_u701((&TM__BxLwT0mhrtgTPodf1v3xjg_574));
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		internalErrorImpl__msgs_u1598((*(*p_p0).module).config, unknownLineInfo__lineinfos_u364, argX60gensym977__1, (&TM__BxLwT0mhrtgTPodf1v3xjg_574));
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		{
			LA6_:;
		}
		{
			eqdestroy___system_u2691(argX60gensym977__1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA4_: ;
	useMagic__jsgen_u1172(p_p0, TM__BxLwT0mhrtgTPodf1v3xjg_576);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	useMagic__jsgen_u1172(p_p0, TM__BxLwT0mhrtgTPodf1v3xjg_578);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&(*r_p2).res), 8);
appendString((&(*r_p2).res), TM__BxLwT0mhrtgTPodf1v3xjg_580);
	{
		NI i_1;
		NI colontmp_;
		NI i_2;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_u3190(n_2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		i_2 = ((NI)0);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA11;
				i_1 = i_2;
				{
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* it_1;
					it_1 = NIM_NIL;
					eqcopy___ast_u3255(&it_1, (*n_2)._kind_6.sons.p->data[i_1]);
					if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
					{
						NIM_BOOL T16_;
						T16_ = (NIM_BOOL)0;
						T16_ = isCompileTimeOnly__types_u3655((*it_1).typField);
						if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
						if (!T16_) goto LA17_;
						eqdestroy___ast_u3252(it_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						goto LA12;
					}
LA17_: ;
					{
						if (!(((NI)0) < i_1)) goto LA21_;
						prepareAdd((&(*r_p2).res), 2);
appendString((&(*r_p2).res), TM__BxLwT0mhrtgTPodf1v3xjg_581);
					}
LA21_: ;
					genArgNoParam__jsgen_u4373(p_p0, it_1, r_p2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
					{
						LA13_:;
					}
					{
						oldNimErrFin13_ = *nimErr_; *nimErr_ = NIM_FALSE;
						eqdestroy___ast_u3252(it_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						*nimErr_ = oldNimErrFin13_;
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				} LA12: ;
				i_2 += ((NI)1);
			} LA11: ;
		}
	}
	prepareAdd((&(*r_p2).res), 1);
appendString((&(*r_p2).res), TM__BxLwT0mhrtgTPodf1v3xjg_582);
	(*r_p2).kind = ((tyEnum_TResKind__UiCSai1lX4RMkJ9bHo9aP2HA)1);
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3252(n_2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genMove__jsgen_u5413)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* r_p2) {
	tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ a_1;
	NimStringV2 colontmpD_;
	NimStringV2 colontmpD__2;
	NimStringV2 colontmpD__3;
	NimStringV2 colontmpD__4;
	NimStringV2 T2_;
	tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T3_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&a_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
	colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
	nimZeroMem((void*)(&a_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
	(*r_p2).kind = ((tyEnum_TResKind__UiCSai1lX4RMkJ9bHo9aP2HA)2);
	T2_.len = 0; T2_.p = NIM_NIL;
	T2_ = getTemp__jsgen_u1235(p_p0, NIM_TRUE);
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T2_); goto LA1_;}
	eqsink___system_u2700((&(*r_p2).res), T2_);
	gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], (&a_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD_ = rdLoc__jsgen_u593((&(*r_p2)));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T3_[0] = colontmpD_;
	colontmpD__2 = rdLoc__jsgen_u593((&a_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T3_[1] = colontmpD__2;
	colontmpD__3 = percent___jsgen_u2814(T3_, 2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__4 = indentLine__jsgen_u102(p_p0, colontmpD__3);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&(*p_p0).body), colontmpD__4.len + 0);
appendString((&(*p_p0).body), colontmpD__4);
	genWasMoved__jsgen_u5385(p_p0, n_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD__4);
		eqdestroy___system_u2691(colontmpD__3);
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___jsgen_u570((&a_1));
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genDup__jsgen_u5426)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* r_p2) {
	tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ a_1;
	NimStringV2 colontmpD_;
	NimStringV2 colontmpD__2;
	NimStringV2 colontmpD__3;
	NimStringV2 colontmpD__4;
	NimStringV2 T2_;
	tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T3_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&a_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
	colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
	nimZeroMem((void*)(&a_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
	(*r_p2).kind = ((tyEnum_TResKind__UiCSai1lX4RMkJ9bHo9aP2HA)2);
	T2_.len = 0; T2_.p = NIM_NIL;
	T2_ = getTemp__jsgen_u1235(p_p0, NIM_TRUE);
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T2_); goto LA1_;}
	eqsink___system_u2700((&(*r_p2).res), T2_);
	gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], (&a_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD_ = rdLoc__jsgen_u593((&(*r_p2)));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T3_[0] = colontmpD_;
	colontmpD__2 = rdLoc__jsgen_u593((&a_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T3_[1] = colontmpD__2;
	colontmpD__3 = percent___jsgen_u2814(T3_, 2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__4 = indentLine__jsgen_u102(p_p0, colontmpD__3);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&(*p_p0).body), colontmpD__4.len + 0);
appendString((&(*p_p0).body), colontmpD__4);
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD__4);
		eqdestroy___system_u2691(colontmpD__3);
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___jsgen_u570((&a_1));
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genMagic__jsgen_u5466)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* r_p2) {
	tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ a_1;
	NimStringV2 line_1;
	NimStringV2 filen_1;
	tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg op_1;
NIM_BOOL oldNimErrFin13_;
NIM_BOOL oldNimErrFin112_;
NIM_BOOL oldNimErrFin125_;
NIM_BOOL oldNimErrFin138_;
NIM_BOOL oldNimErrFin192_;
NIM_BOOL oldNimErrFin252_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&a_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
	line_1.len = 0; line_1.p = NIM_NIL;
	filen_1.len = 0; filen_1.p = NIM_NIL;
	op_1 = (*(*(*n_p1)._kind_6.sons.p->data[((NI)0)])._kind_4.sym).magic;
	switch (op_1) {
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)107):
	{
		genOr__jsgen_u1303(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], (*n_p1)._kind_6.sons.p->data[((NI)2)], r_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)106):
	{
		genAnd__jsgen_u1254(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], (*n_p1)._kind_6.sons.p->data[((NI)2)], r_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)46) ... ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)104):
	{
		arith__jsgen_u2527(p_p0, n_p1, r_p2, op_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)133):
	{
		genRepr__jsgen_u5348(p_p0, n_p1, r_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)141):
	{
		genSwap__jsgen_u3634(p_p0, n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)129):
	{
		tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ xX60gensym1165__1;
		tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ yX60gensym1165__1;
		NimStringV2 aX60gensym1165__1;
		NimStringV2 tmpX60gensym1165__1;
		NimStringV2 bX60gensym1165__1;
		NimStringV2 tmp2X60gensym1165__1;
		tyArray__Seu7uK9aaOSN0BK3EAjjSHw T8_;
		NimStringV2 T9_;
		nimZeroMem((void*)(&xX60gensym1165__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
		nimZeroMem((void*)(&yX60gensym1165__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
		aX60gensym1165__1.len = 0; aX60gensym1165__1.p = NIM_NIL;
		tmpX60gensym1165__1.len = 0; tmpX60gensym1165__1.p = NIM_NIL;
		bX60gensym1165__1.len = 0; bX60gensym1165__1.p = NIM_NIL;
		tmp2X60gensym1165__1.len = 0; tmp2X60gensym1165__1.p = NIM_NIL;
		nimZeroMem((void*)(&xX60gensym1165__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
		nimZeroMem((void*)(&yX60gensym1165__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
		useMagic__jsgen_u1172(p_p0, TM__BxLwT0mhrtgTPodf1v3xjg_490);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], (&xX60gensym1165__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)2)], (&yX60gensym1165__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		aX60gensym1165__1 = rdLoc__jsgen_u593((&xX60gensym1165__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		tmpX60gensym1165__1 = rdLoc__jsgen_u593((&xX60gensym1165__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		bX60gensym1165__1 = rdLoc__jsgen_u593((&yX60gensym1165__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		tmp2X60gensym1165__1 = rdLoc__jsgen_u593((&yX60gensym1165__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		T8_[0] = aX60gensym1165__1;
		T8_[1] = bX60gensym1165__1;
		T8_[2] = tmpX60gensym1165__1;
		T8_[3] = tmp2X60gensym1165__1;
		T9_.len = 0; T9_.p = NIM_NIL;
		T9_ = percent___jsgen_u5494(T8_, 4);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T9_); goto LA7_;}
		eqsink___system_u2700((&(*r_p2).res), T9_);
		(*r_p2).kind = ((tyEnum_TResKind__UiCSai1lX4RMkJ9bHo9aP2HA)1);
		{
			LA7_:;
		}
		{
			eqdestroy___system_u2691(tmp2X60gensym1165__1);
			eqdestroy___system_u2691(bX60gensym1165__1);
			eqdestroy___system_u2691(tmpX60gensym1165__1);
			eqdestroy___system_u2691(aX60gensym1165__1);
			eqdestroy___jsgen_u570((&yX60gensym1165__1));
			eqdestroy___jsgen_u570((&xX60gensym1165__1));
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)130):
	{
		tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ lhs_1;
		tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ rhs_1;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
		nimZeroMem((void*)(&lhs_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
		nimZeroMem((void*)(&rhs_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
		colontmpD_ = NIM_NIL;
		nimZeroMem((void*)(&lhs_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
		nimZeroMem((void*)(&rhs_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
		gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], (&lhs_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)2)], (&rhs_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		{
			tyTuple__UV3llMMYFckfui8YMBuUZA tmpTuple_1;
			NimStringV2 b_1;
			NimStringV2 tmp_1;
			NimStringV2 colontmpD__2;
			tyArray__dyW7vpmfeTYw8kX3EXuaJA T18_;
			NimStringV2 T19_;
			colontmpD_ = skipTypes__ast_u5379((*(*n_p1)._kind_6.sons.p->data[((NI)1)]).typField, TM__BxLwT0mhrtgTPodf1v3xjg_358);
			if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
			if (!((*colontmpD_).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)29))) goto LA16_;
			nimZeroMem((void*)(&tmpTuple_1), sizeof(tyTuple__UV3llMMYFckfui8YMBuUZA));
			b_1.len = 0; b_1.p = NIM_NIL;
			tmp_1.len = 0; tmp_1.p = NIM_NIL;
			colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
			maybeMakeTemp__jsgen_u1365(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)2)], (&rhs_1), (&tmpTuple_1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
			b_1 = tmpTuple_1.Field0;
			eqwasMoved___system_u2688((&tmpTuple_1.Field0));
			tmp_1 = tmpTuple_1.Field1;
			eqwasMoved___system_u2688((&tmpTuple_1.Field1));
			T18_[0] = b_1;
			colontmpD__2 = rdLoc__jsgen_u593((&lhs_1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
			T18_[1] = colontmpD__2;
			T18_[2] = tmp_1;
			T19_.len = 0; T19_.p = NIM_NIL;
			T19_ = percent___jsgen_u5516(T18_, 3);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T19_); goto LA13_;}
			eqsink___system_u2700((&(*r_p2).res), T19_);
			eqdestroy___system_u2691(colontmpD__2);
			eqdestroy___system_u2691(tmp_1);
			eqdestroy___system_u2691(b_1);
			eqdestroy___stdZprivateZospaths2_u306((&tmpTuple_1));
		}
		goto LA14_;
LA16_: ;
		{
			NimStringV2 colontmpD__3;
			NimStringV2 colontmpD__4;
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T22_;
			NimStringV2 T23_;
			colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
			colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
			useMagic__jsgen_u1172(p_p0, TM__BxLwT0mhrtgTPodf1v3xjg_492);
			if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
			colontmpD__3 = rdLoc__jsgen_u593((&lhs_1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
			T22_[0] = colontmpD__3;
			colontmpD__4 = rdLoc__jsgen_u593((&rhs_1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
			T22_[1] = colontmpD__4;
			T23_.len = 0; T23_.p = NIM_NIL;
			T23_ = percent___jsgen_u5521(T22_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T23_); goto LA21_;}
			eqsink___system_u2700((&(*r_p2).res), T23_);
			{
				LA21_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__4);
				eqdestroy___system_u2691(colontmpD__3);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		}
LA14_: ;
		(*r_p2).kind = ((tyEnum_TResKind__UiCSai1lX4RMkJ9bHo9aP2HA)1);
		{
			LA13_:;
		}
		{
			oldNimErrFin13_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3378(colontmpD_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			eqdestroy___jsgen_u570((&rhs_1));
			eqdestroy___jsgen_u570((&lhs_1));
			*nimErr_ = oldNimErrFin13_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)131):
	{
		tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ x_1;
		tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ y_1;
		nimZeroMem((void*)(&x_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
		nimZeroMem((void*)(&y_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
		nimZeroMem((void*)(&x_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
		nimZeroMem((void*)(&y_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
		gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], (&x_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
		gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)2)], (&y_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
		{
			tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg T32_;
			NimStringV2 c_1;
			NimStringV2 colontmpD__5;
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T35_;
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T36_;
			NimStringV2 T37_;
			T32_ = (tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)0;
			T32_ = mapType__jsgen_u686((*(*n_p1)._kind_6.sons.p->data[((NI)2)]).typField);
			if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
			if (!(T32_ == ((tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)9))) goto LA33_;
			c_1.len = 0; c_1.p = NIM_NIL;
			colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
			T35_[0] = y_1.address;
			T35_[1] = y_1.res;
			c_1 = percent___jsgen_u873(T35_, 2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
			colontmpD__5 = rdLoc__jsgen_u593((&x_1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
			T36_[0] = colontmpD__5;
			T36_[1] = c_1;
			T37_.len = 0; T37_.p = NIM_NIL;
			T37_ = percent___jsgen_u5545(T36_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T37_); goto LA29_;}
			eqsink___system_u2700((&(*r_p2).res), T37_);
			eqdestroy___system_u2691(colontmpD__5);
			eqdestroy___system_u2691(c_1);
		}
		goto LA30_;
LA33_: ;
		{
			NIM_BOOL T39_;
			NimStringV2 colontmpD__6;
			NimStringV2 colontmpD__7;
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T42_;
			NimStringV2 T43_;
			T39_ = (NIM_BOOL)0;
			T39_ = needsNoCopy__jsgen_u3374(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)2)]);
			if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
			if (!T39_) goto LA40_;
			colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
			colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
			colontmpD__6 = rdLoc__jsgen_u593((&x_1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
			T42_[0] = colontmpD__6;
			colontmpD__7 = rdLoc__jsgen_u593((&y_1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
			T42_[1] = colontmpD__7;
			T43_.len = 0; T43_.p = NIM_NIL;
			T43_ = percent___jsgen_u5545(T42_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T43_); goto LA29_;}
			eqsink___system_u2700((&(*r_p2).res), T43_);
			eqdestroy___system_u2691(colontmpD__7);
			eqdestroy___system_u2691(colontmpD__6);
		}
		goto LA30_;
LA40_: ;
		{
			NimStringV2 c_2;
			NimStringV2 colontmpD__8;
			NimStringV2 colontmpD__9;
			NimStringV2 colontmpD__10;
			NimStringV2 colontmpD__11;
			NimStringV2 colontmpD__12;
			tyArray__dyW7vpmfeTYw8kX3EXuaJA T46_;
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T47_;
			NimStringV2 T48_;
			c_2.len = 0; c_2.p = NIM_NIL;
			colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
			colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
			colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
			colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
			colontmpD__12.len = 0; colontmpD__12.p = NIM_NIL;
			useMagic__jsgen_u1172(p_p0, TM__BxLwT0mhrtgTPodf1v3xjg_493);
			if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
			c_2 = getTemp__jsgen_u1235(p_p0, NIM_FALSE);
			if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
			T46_[0] = c_2;
			colontmpD__8 = rdLoc__jsgen_u593((&y_1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
			T46_[1] = colontmpD__8;
			colontmpD__9 = genTypeInfo__jsgen_u828(p_p0, (*(*n_p1)._kind_6.sons.p->data[((NI)2)]).typField);
			if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
			T46_[2] = colontmpD__9;
			colontmpD__10 = percent___jsgen_u5555(T46_, 3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
			colontmpD__11 = indentLine__jsgen_u102(p_p0, colontmpD__10);
			if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
			prepareAdd((&(*p_p0).body), colontmpD__11.len + 0);
appendString((&(*p_p0).body), colontmpD__11);
			colontmpD__12 = rdLoc__jsgen_u593((&x_1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
			T47_[0] = colontmpD__12;
			T47_[1] = c_2;
			T48_.len = 0; T48_.p = NIM_NIL;
			T48_ = percent___jsgen_u5545(T47_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T48_); goto LA45_;}
			eqsink___system_u2700((&(*r_p2).res), T48_);
			{
				LA45_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__12);
				eqdestroy___system_u2691(colontmpD__11);
				eqdestroy___system_u2691(colontmpD__10);
				eqdestroy___system_u2691(colontmpD__9);
				eqdestroy___system_u2691(colontmpD__8);
				eqdestroy___system_u2691(c_2);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
		}
LA30_: ;
		(*r_p2).kind = ((tyEnum_TResKind__UiCSai1lX4RMkJ9bHo9aP2HA)1);
		{
			LA29_:;
		}
		{
			eqdestroy___jsgen_u570((&y_1));
			eqdestroy___jsgen_u570((&x_1));
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)123):
	{
		genConStrStr__jsgen_u5277(p_p0, n_p1, r_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)113):
	{
		tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ xX60gensym1183__1;
		tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ yX60gensym1183__1;
		NimStringV2 aX60gensym1183__1;
		NimStringV2 tmpX60gensym1183__1;
		NimStringV2 bX60gensym1183__1;
		NimStringV2 tmp2X60gensym1183__1;
		tyArray__Seu7uK9aaOSN0BK3EAjjSHw T56_;
		NimStringV2 T57_;
		nimZeroMem((void*)(&xX60gensym1183__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
		nimZeroMem((void*)(&yX60gensym1183__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
		aX60gensym1183__1.len = 0; aX60gensym1183__1.p = NIM_NIL;
		tmpX60gensym1183__1.len = 0; tmpX60gensym1183__1.p = NIM_NIL;
		bX60gensym1183__1.len = 0; bX60gensym1183__1.p = NIM_NIL;
		tmp2X60gensym1183__1.len = 0; tmp2X60gensym1183__1.p = NIM_NIL;
		nimZeroMem((void*)(&xX60gensym1183__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
		nimZeroMem((void*)(&yX60gensym1183__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
		useMagic__jsgen_u1172(p_p0, TM__BxLwT0mhrtgTPodf1v3xjg_495);
		if (NIM_UNLIKELY(*nimErr_)) goto LA55_;
		gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], (&xX60gensym1183__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA55_;
		gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)2)], (&yX60gensym1183__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA55_;
		aX60gensym1183__1 = rdLoc__jsgen_u593((&xX60gensym1183__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA55_;
		tmpX60gensym1183__1 = rdLoc__jsgen_u593((&xX60gensym1183__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA55_;
		bX60gensym1183__1 = rdLoc__jsgen_u593((&yX60gensym1183__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA55_;
		tmp2X60gensym1183__1 = rdLoc__jsgen_u593((&yX60gensym1183__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA55_;
		T56_[0] = aX60gensym1183__1;
		T56_[1] = bX60gensym1183__1;
		T56_[2] = tmpX60gensym1183__1;
		T56_[3] = tmp2X60gensym1183__1;
		T57_.len = 0; T57_.p = NIM_NIL;
		T57_ = percent___jsgen_u5584(T56_, 4);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T57_); goto LA55_;}
		eqsink___system_u2700((&(*r_p2).res), T57_);
		(*r_p2).kind = ((tyEnum_TResKind__UiCSai1lX4RMkJ9bHo9aP2HA)1);
		{
			LA55_:;
		}
		{
			eqdestroy___system_u2691(tmp2X60gensym1183__1);
			eqdestroy___system_u2691(bX60gensym1183__1);
			eqdestroy___system_u2691(tmpX60gensym1183__1);
			eqdestroy___system_u2691(aX60gensym1183__1);
			eqdestroy___jsgen_u570((&yX60gensym1183__1));
			eqdestroy___jsgen_u570((&xX60gensym1183__1));
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)114):
	{
		tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ xX60gensym1188__1;
		tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ yX60gensym1188__1;
		NimStringV2 aX60gensym1188__1;
		NimStringV2 tmpX60gensym1188__1;
		NimStringV2 bX60gensym1188__1;
		NimStringV2 tmp2X60gensym1188__1;
		tyArray__Seu7uK9aaOSN0BK3EAjjSHw T62_;
		NimStringV2 T63_;
		nimZeroMem((void*)(&xX60gensym1188__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
		nimZeroMem((void*)(&yX60gensym1188__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
		aX60gensym1188__1.len = 0; aX60gensym1188__1.p = NIM_NIL;
		tmpX60gensym1188__1.len = 0; tmpX60gensym1188__1.p = NIM_NIL;
		bX60gensym1188__1.len = 0; bX60gensym1188__1.p = NIM_NIL;
		tmp2X60gensym1188__1.len = 0; tmp2X60gensym1188__1.p = NIM_NIL;
		nimZeroMem((void*)(&xX60gensym1188__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
		nimZeroMem((void*)(&yX60gensym1188__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
		useMagic__jsgen_u1172(p_p0, TM__BxLwT0mhrtgTPodf1v3xjg_497);
		if (NIM_UNLIKELY(*nimErr_)) goto LA61_;
		gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], (&xX60gensym1188__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA61_;
		gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)2)], (&yX60gensym1188__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA61_;
		aX60gensym1188__1 = rdLoc__jsgen_u593((&xX60gensym1188__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA61_;
		tmpX60gensym1188__1 = rdLoc__jsgen_u593((&xX60gensym1188__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA61_;
		bX60gensym1188__1 = rdLoc__jsgen_u593((&yX60gensym1188__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA61_;
		tmp2X60gensym1188__1 = rdLoc__jsgen_u593((&yX60gensym1188__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA61_;
		T62_[0] = aX60gensym1188__1;
		T62_[1] = bX60gensym1188__1;
		T62_[2] = tmpX60gensym1188__1;
		T62_[3] = tmp2X60gensym1188__1;
		T63_.len = 0; T63_.p = NIM_NIL;
		T63_ = percent___jsgen_u5609(T62_, 4);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T63_); goto LA61_;}
		eqsink___system_u2700((&(*r_p2).res), T63_);
		(*r_p2).kind = ((tyEnum_TResKind__UiCSai1lX4RMkJ9bHo9aP2HA)1);
		{
			LA61_:;
		}
		{
			eqdestroy___system_u2691(tmp2X60gensym1188__1);
			eqdestroy___system_u2691(bX60gensym1188__1);
			eqdestroy___system_u2691(tmpX60gensym1188__1);
			eqdestroy___system_u2691(aX60gensym1188__1);
			eqdestroy___jsgen_u570((&yX60gensym1188__1));
			eqdestroy___jsgen_u570((&xX60gensym1188__1));
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)115):
	{
		tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ xX60gensym1193__1;
		tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ yX60gensym1193__1;
		NimStringV2 aX60gensym1193__1;
		NimStringV2 tmpX60gensym1193__1;
		NimStringV2 bX60gensym1193__1;
		NimStringV2 tmp2X60gensym1193__1;
		tyArray__Seu7uK9aaOSN0BK3EAjjSHw T68_;
		NimStringV2 T69_;
		nimZeroMem((void*)(&xX60gensym1193__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
		nimZeroMem((void*)(&yX60gensym1193__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
		aX60gensym1193__1.len = 0; aX60gensym1193__1.p = NIM_NIL;
		tmpX60gensym1193__1.len = 0; tmpX60gensym1193__1.p = NIM_NIL;
		bX60gensym1193__1.len = 0; bX60gensym1193__1.p = NIM_NIL;
		tmp2X60gensym1193__1.len = 0; tmp2X60gensym1193__1.p = NIM_NIL;
		nimZeroMem((void*)(&xX60gensym1193__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
		nimZeroMem((void*)(&yX60gensym1193__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
		useMagic__jsgen_u1172(p_p0, TM__BxLwT0mhrtgTPodf1v3xjg_498);
		if (NIM_UNLIKELY(*nimErr_)) goto LA67_;
		gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], (&xX60gensym1193__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA67_;
		gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)2)], (&yX60gensym1193__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA67_;
		aX60gensym1193__1 = rdLoc__jsgen_u593((&xX60gensym1193__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA67_;
		tmpX60gensym1193__1 = rdLoc__jsgen_u593((&xX60gensym1193__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA67_;
		bX60gensym1193__1 = rdLoc__jsgen_u593((&yX60gensym1193__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA67_;
		tmp2X60gensym1193__1 = rdLoc__jsgen_u593((&yX60gensym1193__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA67_;
		T68_[0] = aX60gensym1193__1;
		T68_[1] = bX60gensym1193__1;
		T68_[2] = tmpX60gensym1193__1;
		T68_[3] = tmp2X60gensym1193__1;
		T69_.len = 0; T69_.p = NIM_NIL;
		T69_ = percent___jsgen_u5634(T68_, 4);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T69_); goto LA67_;}
		eqsink___system_u2700((&(*r_p2).res), T69_);
		(*r_p2).kind = ((tyEnum_TResKind__UiCSai1lX4RMkJ9bHo9aP2HA)1);
		{
			LA67_:;
		}
		{
			eqdestroy___system_u2691(tmp2X60gensym1193__1);
			eqdestroy___system_u2691(bX60gensym1193__1);
			eqdestroy___system_u2691(tmpX60gensym1193__1);
			eqdestroy___system_u2691(aX60gensym1193__1);
			eqdestroy___jsgen_u570((&yX60gensym1193__1));
			eqdestroy___jsgen_u570((&xX60gensym1193__1));
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)142):
	{
		{
			tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg T75_;
			NimStringV2 aX60gensym1201__1;
			NimStringV2 tmpX60gensym1201__1;
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T84_;
			NimStringV2 T85_;
			T75_ = (tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)0;
			T75_ = mapType__jsgen_u686((*(*n_p1)._kind_6.sons.p->data[((NI)1)]).typField);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!!((T75_ == ((tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)9)))) goto LA76_;
			aX60gensym1201__1.len = 0; aX60gensym1201__1.p = NIM_NIL;
			tmpX60gensym1201__1.len = 0; tmpX60gensym1201__1.p = NIM_NIL;
			useMagic__jsgen_u1172(p_p0, TM__BxLwT0mhrtgTPodf1v3xjg_499);
			if (NIM_UNLIKELY(*nimErr_)) goto LA78_;
			gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], r_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA78_;
			aX60gensym1201__1 = rdLoc__jsgen_u593((&(*r_p2)));
			if (NIM_UNLIKELY(*nimErr_)) goto LA78_;
			tmpX60gensym1201__1 = rdLoc__jsgen_u593((&(*r_p2)));
			if (NIM_UNLIKELY(*nimErr_)) goto LA78_;
			{
				NIM_BOOL T81_;
				tyTuple__UV3llMMYFckfui8YMBuUZA tmpTupleAsgn;
				T81_ = (NIM_BOOL)0;
				T81_ = contains__pureZstrutils_u1833(TM__BxLwT0mhrtgTPodf1v3xjg_501, TM__BxLwT0mhrtgTPodf1v3xjg_503);
				if (NIM_UNLIKELY(*nimErr_)) goto LA78_;
				if (!T81_) goto LA82_;
				nimZeroMem((void*)(&tmpTupleAsgn), sizeof(tyTuple__UV3llMMYFckfui8YMBuUZA));
				maybeMakeTemp__jsgen_u1365(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], (&(*r_p2)), (&tmpTupleAsgn));
				if (NIM_UNLIKELY(*nimErr_)) goto LA78_;
				eqsink___system_u2700((&aX60gensym1201__1), tmpTupleAsgn.Field0);
				eqsink___system_u2700((&tmpX60gensym1201__1), tmpTupleAsgn.Field1);
			}
LA82_: ;
			T84_[0] = aX60gensym1201__1;
			T84_[1] = tmpX60gensym1201__1;
			T85_.len = 0; T85_.p = NIM_NIL;
			T85_ = percent___jsgen_u5648(T84_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T85_); goto LA78_;}
			eqsink___system_u2700((&(*r_p2).res), T85_);
			(*r_p2).kind = ((tyEnum_TResKind__UiCSai1lX4RMkJ9bHo9aP2HA)1);
			{
				LA78_:;
			}
			{
				eqdestroy___system_u2691(tmpX60gensym1201__1);
				eqdestroy___system_u2691(aX60gensym1201__1);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		goto LA73_;
LA76_: ;
		{
			tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ x_2;
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T90_;
			NimStringV2 T91_;
			nimZeroMem((void*)(&x_2), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
			nimZeroMem((void*)(&x_2), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
			gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], (&x_2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA89_;
			T90_[0] = x_2.address;
			T90_[1] = x_2.res;
			T91_.len = 0; T91_.p = NIM_NIL;
			T91_ = percent___jsgen_u5658(T90_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T91_); goto LA89_;}
			eqsink___system_u2700((&(*r_p2).res), T91_);
			{
				LA89_:;
			}
			{
				eqdestroy___jsgen_u570((&x_2));
			}
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA73_: ;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)105):
	{
		genRepr__jsgen_u5348(p_p0, n_p1, r_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)32):
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)33):
	{
		genNew__jsgen_u5195(p_p0, n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)43):
	{
		gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], r_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)143):
	{
		{
			if (!((*(*n_p1)._kind_6.sons.p->data[((NI)1)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)41))) goto LA100_;
			genJSArrayConstr__jsgen_u5439(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], r_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		goto LA98_;
LA100_: ;
		{
			tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ x_3;
			NimStringV2 colontmpD__13;
			NimStringV2 colontmpD__14;
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T104_;
			NimStringV2 T105_;
			nimZeroMem((void*)(&x_3), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
			colontmpD__13.len = 0; colontmpD__13.p = NIM_NIL;
			colontmpD__14.len = 0; colontmpD__14.p = NIM_NIL;
			nimZeroMem((void*)(&x_3), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
			gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], (&x_3));
			if (NIM_UNLIKELY(*nimErr_)) goto LA103_;
			useMagic__jsgen_u1172(p_p0, TM__BxLwT0mhrtgTPodf1v3xjg_509);
			if (NIM_UNLIKELY(*nimErr_)) goto LA103_;
			colontmpD__13 = rdLoc__jsgen_u593((&x_3));
			if (NIM_UNLIKELY(*nimErr_)) goto LA103_;
			T104_[0] = colontmpD__13;
			colontmpD__14 = genTypeInfo__jsgen_u828(p_p0, (*n_p1).typField);
			if (NIM_UNLIKELY(*nimErr_)) goto LA103_;
			T104_[1] = colontmpD__14;
			T105_.len = 0; T105_.p = NIM_NIL;
			T105_ = percent___jsgen_u5021(T104_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T105_); goto LA103_;}
			eqsink___system_u2700((&(*r_p2).res), T105_);
			{
				LA103_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__14);
				eqdestroy___system_u2691(colontmpD__13);
				eqdestroy___jsgen_u570((&x_3));
			}
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA98_: ;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)144):
	{
		genCall__jsgen_u4598(p_p0, n_p1, r_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)152):
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)153):
	{
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)31):
	{
		genOrd__jsgen_u5245(p_p0, n_p1, r_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)37):
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)39):
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)36):
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)38):
	{
		tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ x_4;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__15;
		nimZeroMem((void*)(&x_4), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
		colontmpD__15 = NIM_NIL;
		nimZeroMem((void*)(&x_4), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
		gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], (&x_4));
		if (NIM_UNLIKELY(*nimErr_)) goto LA112_;
		{
			tyTuple__UV3llMMYFckfui8YMBuUZA tmpTuple_2;
			NimStringV2 a_2;
			NimStringV2 tmp_2;
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T117_;
			NimStringV2 T118_;
			colontmpD__15 = skipTypes__ast_u5379((*(*n_p1)._kind_6.sons.p->data[((NI)1)]).typField, TM__BxLwT0mhrtgTPodf1v3xjg_175);
			if (NIM_UNLIKELY(*nimErr_)) goto LA112_;
			if (!((*colontmpD__15).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)29))) goto LA115_;
			nimZeroMem((void*)(&tmpTuple_2), sizeof(tyTuple__UV3llMMYFckfui8YMBuUZA));
			a_2.len = 0; a_2.p = NIM_NIL;
			tmp_2.len = 0; tmp_2.p = NIM_NIL;
			maybeMakeTemp__jsgen_u1365(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], (&x_4), (&tmpTuple_2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA112_;
			a_2 = tmpTuple_2.Field0;
			eqwasMoved___system_u2688((&tmpTuple_2.Field0));
			tmp_2 = tmpTuple_2.Field1;
			eqwasMoved___system_u2688((&tmpTuple_2.Field1));
			T117_[0] = a_2;
			T117_[1] = tmp_2;
			T118_.len = 0; T118_.p = NIM_NIL;
			T118_ = percent___jsgen_u5688(T117_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T118_); goto LA112_;}
			eqsink___system_u2700((&(*r_p2).res), T118_);
			eqdestroy___system_u2691(tmp_2);
			eqdestroy___system_u2691(a_2);
			eqdestroy___stdZprivateZospaths2_u306((&tmpTuple_2));
		}
		goto LA113_;
LA115_: ;
		{
			NimStringV2 colontmpD__16;
			tyArray__YgExxhfgKcesA5EOUj1MOA T120_;
			NimStringV2 T121_;
			colontmpD__16.len = 0; colontmpD__16.p = NIM_NIL;
			colontmpD__16 = rdLoc__jsgen_u593((&x_4));
			if (NIM_UNLIKELY(*nimErr_)) goto LA112_;
			T120_[0] = colontmpD__16;
			T121_.len = 0; T121_.p = NIM_NIL;
			T121_ = percent___jsgen_u5693(T120_, 1);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T121_); goto LA112_;}
			eqsink___system_u2700((&(*r_p2).res), T121_);
			eqdestroy___system_u2691(colontmpD__16);
		}
LA113_: ;
		(*r_p2).kind = ((tyEnum_TResKind__UiCSai1lX4RMkJ9bHo9aP2HA)1);
		{
			LA112_:;
		}
		{
			oldNimErrFin112_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3378(colontmpD__15);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			eqdestroy___jsgen_u570((&x_4));
			*nimErr_ = oldNimErrFin112_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)9):
	{
		tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ x_5;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__17;
		nimZeroMem((void*)(&x_5), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
		colontmpD__17 = NIM_NIL;
		nimZeroMem((void*)(&x_5), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
		gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], (&x_5));
		if (NIM_UNLIKELY(*nimErr_)) goto LA125_;
		{
			tyTuple__UV3llMMYFckfui8YMBuUZA tmpTuple_3;
			NimStringV2 a_3;
			NimStringV2 tmp_3;
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T130_;
			NimStringV2 T131_;
			colontmpD__17 = skipTypes__ast_u5379((*(*n_p1)._kind_6.sons.p->data[((NI)1)]).typField, TM__BxLwT0mhrtgTPodf1v3xjg_175);
			if (NIM_UNLIKELY(*nimErr_)) goto LA125_;
			if (!((*colontmpD__17).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)29))) goto LA128_;
			nimZeroMem((void*)(&tmpTuple_3), sizeof(tyTuple__UV3llMMYFckfui8YMBuUZA));
			a_3.len = 0; a_3.p = NIM_NIL;
			tmp_3.len = 0; tmp_3.p = NIM_NIL;
			maybeMakeTemp__jsgen_u1365(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], (&x_5), (&tmpTuple_3));
			if (NIM_UNLIKELY(*nimErr_)) goto LA125_;
			a_3 = tmpTuple_3.Field0;
			eqwasMoved___system_u2688((&tmpTuple_3.Field0));
			tmp_3 = tmpTuple_3.Field1;
			eqwasMoved___system_u2688((&tmpTuple_3.Field1));
			T130_[0] = a_3;
			T130_[1] = tmp_3;
			T131_.len = 0; T131_.p = NIM_NIL;
			T131_ = percent___jsgen_u5710(T130_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T131_); goto LA125_;}
			eqsink___system_u2700((&(*r_p2).res), T131_);
			eqdestroy___system_u2691(tmp_3);
			eqdestroy___system_u2691(a_3);
			eqdestroy___stdZprivateZospaths2_u306((&tmpTuple_3));
		}
		goto LA126_;
LA128_: ;
		{
			NimStringV2 colontmpD__18;
			tyArray__YgExxhfgKcesA5EOUj1MOA T133_;
			NimStringV2 T134_;
			colontmpD__18.len = 0; colontmpD__18.p = NIM_NIL;
			colontmpD__18 = rdLoc__jsgen_u593((&x_5));
			if (NIM_UNLIKELY(*nimErr_)) goto LA125_;
			T133_[0] = colontmpD__18;
			T134_.len = 0; T134_.p = NIM_NIL;
			T134_ = percent___jsgen_u5715(T133_, 1);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T134_); goto LA125_;}
			eqsink___system_u2700((&(*r_p2).res), T134_);
			eqdestroy___system_u2691(colontmpD__18);
		}
LA126_: ;
		(*r_p2).kind = ((tyEnum_TResKind__UiCSai1lX4RMkJ9bHo9aP2HA)1);
		{
			LA125_:;
		}
		{
			oldNimErrFin125_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3378(colontmpD__17);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			eqdestroy___jsgen_u570((&x_5));
			*nimErr_ = oldNimErrFin125_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)29):
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_1;
		typ_1 = NIM_NIL;
		typ_1 = skipTypes__ast_u5379((*(*n_p1)._kind_6.sons.p->data[((NI)1)]).typField, TM__BxLwT0mhrtgTPodf1v3xjg_358);
		if (NIM_UNLIKELY(*nimErr_)) goto LA138_;
		switch ((*typ_1).kind) {
		case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)40) ... ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)43):
		{
			binaryUintExpr__jsgen_u5721(p_p0, n_p1, r_p2, TM__BxLwT0mhrtgTPodf1v3xjg_530);
			if (NIM_UNLIKELY(*nimErr_)) goto LA138_;
		}
		break;
		case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)44):
		{
			{
				tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ xX60gensym1231__1;
				tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ yX60gensym1231__1;
				NimStringV2 aX60gensym1231__1;
				NimStringV2 tmpX60gensym1231__1;
				NimStringV2 bX60gensym1231__1;
				NimStringV2 tmp2X60gensym1231__1;
				tyTuple__UV3llMMYFckfui8YMBuUZA tmpTupleAsgn_2;
				tyArray__Seu7uK9aaOSN0BK3EAjjSHw T146_;
				NimStringV2 T147_;
				if (!(((*(*(*p_p0).module).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)56)))&63U)))!=0)) goto LA143_;
				nimZeroMem((void*)(&xX60gensym1231__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
				nimZeroMem((void*)(&yX60gensym1231__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
				aX60gensym1231__1.len = 0; aX60gensym1231__1.p = NIM_NIL;
				tmpX60gensym1231__1.len = 0; tmpX60gensym1231__1.p = NIM_NIL;
				bX60gensym1231__1.len = 0; bX60gensym1231__1.p = NIM_NIL;
				tmp2X60gensym1231__1.len = 0; tmp2X60gensym1231__1.p = NIM_NIL;
				nimZeroMem((void*)(&tmpTupleAsgn_2), sizeof(tyTuple__UV3llMMYFckfui8YMBuUZA));
				nimZeroMem((void*)(&xX60gensym1231__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
				nimZeroMem((void*)(&yX60gensym1231__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
				useMagic__jsgen_u1172(p_p0, TM__BxLwT0mhrtgTPodf1v3xjg_531);
				if (NIM_UNLIKELY(*nimErr_)) goto LA145_;
				gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], (&xX60gensym1231__1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA145_;
				gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)2)], (&yX60gensym1231__1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA145_;
				aX60gensym1231__1 = rdLoc__jsgen_u593((&xX60gensym1231__1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA145_;
				tmpX60gensym1231__1 = rdLoc__jsgen_u593((&xX60gensym1231__1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA145_;
				bX60gensym1231__1 = rdLoc__jsgen_u593((&yX60gensym1231__1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA145_;
				tmp2X60gensym1231__1 = rdLoc__jsgen_u593((&yX60gensym1231__1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA145_;
				maybeMakeTempAssignable__jsgen_u1399(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], (&xX60gensym1231__1), (&tmpTupleAsgn_2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA145_;
				eqsink___system_u2700((&aX60gensym1231__1), tmpTupleAsgn_2.Field0);
				eqsink___system_u2700((&tmpX60gensym1231__1), tmpTupleAsgn_2.Field1);
				T146_[0] = aX60gensym1231__1;
				T146_[1] = bX60gensym1231__1;
				T146_[2] = tmpX60gensym1231__1;
				T146_[3] = tmp2X60gensym1231__1;
				T147_.len = 0; T147_.p = NIM_NIL;
				T147_ = percent___jsgen_u5782(T146_, 4);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T147_); goto LA145_;}
				eqsink___system_u2700((&(*r_p2).res), T147_);
				(*r_p2).kind = ((tyEnum_TResKind__UiCSai1lX4RMkJ9bHo9aP2HA)1);
				{
					LA145_:;
				}
				{
					eqdestroy___system_u2691(tmp2X60gensym1231__1);
					eqdestroy___system_u2691(bX60gensym1231__1);
					eqdestroy___system_u2691(tmpX60gensym1231__1);
					eqdestroy___system_u2691(aX60gensym1231__1);
					eqdestroy___jsgen_u570((&yX60gensym1231__1));
					eqdestroy___jsgen_u570((&xX60gensym1231__1));
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA138_;
			}
			goto LA141_;
LA143_: ;
			{
				binaryUintExpr__jsgen_u5721(p_p0, n_p1, r_p2, TM__BxLwT0mhrtgTPodf1v3xjg_532);
				if (NIM_UNLIKELY(*nimErr_)) goto LA138_;
			}
LA141_: ;
		}
		break;
		default:
		{
			{
				NIM_BOOL T154_;
				T154_ = (NIM_BOOL)0;
				T154_ = ((*typ_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)35));
				if (!(T154_)) goto LA155_;
				T154_ = (((*(*(*p_p0).module).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)56)))&63U)))!=0);
LA155_: ;
				if (!T154_) goto LA156_;
				{
					tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ xX60gensym1238__1;
					tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ yX60gensym1238__1;
					NimStringV2 aX60gensym1238__1;
					NimStringV2 tmpX60gensym1238__1;
					NimStringV2 bX60gensym1238__1;
					NimStringV2 tmp2X60gensym1238__1;
					tyTuple__UV3llMMYFckfui8YMBuUZA tmpTupleAsgn_3;
					tyArray__Seu7uK9aaOSN0BK3EAjjSHw T163_;
					NimStringV2 T164_;
					if (!!((((*p_p0).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)5)))&31U)))!=0))) goto LA160_;
					nimZeroMem((void*)(&xX60gensym1238__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
					nimZeroMem((void*)(&yX60gensym1238__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
					aX60gensym1238__1.len = 0; aX60gensym1238__1.p = NIM_NIL;
					tmpX60gensym1238__1.len = 0; tmpX60gensym1238__1.p = NIM_NIL;
					bX60gensym1238__1.len = 0; bX60gensym1238__1.p = NIM_NIL;
					tmp2X60gensym1238__1.len = 0; tmp2X60gensym1238__1.p = NIM_NIL;
					nimZeroMem((void*)(&tmpTupleAsgn_3), sizeof(tyTuple__UV3llMMYFckfui8YMBuUZA));
					nimZeroMem((void*)(&xX60gensym1238__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
					nimZeroMem((void*)(&yX60gensym1238__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
					useMagic__jsgen_u1172(p_p0, TM__BxLwT0mhrtgTPodf1v3xjg_533);
					if (NIM_UNLIKELY(*nimErr_)) goto LA162_;
					gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], (&xX60gensym1238__1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA162_;
					gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)2)], (&yX60gensym1238__1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA162_;
					aX60gensym1238__1 = rdLoc__jsgen_u593((&xX60gensym1238__1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA162_;
					tmpX60gensym1238__1 = rdLoc__jsgen_u593((&xX60gensym1238__1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA162_;
					bX60gensym1238__1 = rdLoc__jsgen_u593((&yX60gensym1238__1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA162_;
					tmp2X60gensym1238__1 = rdLoc__jsgen_u593((&yX60gensym1238__1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA162_;
					maybeMakeTempAssignable__jsgen_u1399(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], (&xX60gensym1238__1), (&tmpTupleAsgn_3));
					if (NIM_UNLIKELY(*nimErr_)) goto LA162_;
					eqsink___system_u2700((&aX60gensym1238__1), tmpTupleAsgn_3.Field0);
					eqsink___system_u2700((&tmpX60gensym1238__1), tmpTupleAsgn_3.Field1);
					T163_[0] = aX60gensym1238__1;
					T163_[1] = bX60gensym1238__1;
					T163_[2] = tmpX60gensym1238__1;
					T163_[3] = tmp2X60gensym1238__1;
					T164_.len = 0; T164_.p = NIM_NIL;
					T164_ = percent___jsgen_u5827(T163_, 4);
					if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T164_); goto LA162_;}
					eqsink___system_u2700((&(*r_p2).res), T164_);
					(*r_p2).kind = ((tyEnum_TResKind__UiCSai1lX4RMkJ9bHo9aP2HA)1);
					{
						LA162_:;
					}
					{
						eqdestroy___system_u2691(tmp2X60gensym1238__1);
						eqdestroy___system_u2691(bX60gensym1238__1);
						eqdestroy___system_u2691(tmpX60gensym1238__1);
						eqdestroy___system_u2691(aX60gensym1238__1);
						eqdestroy___jsgen_u570((&yX60gensym1238__1));
						eqdestroy___jsgen_u570((&xX60gensym1238__1));
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA138_;
				}
				goto LA158_;
LA160_: ;
				{
					tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ xX60gensym1242__1;
					tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ yX60gensym1242__1;
					NimStringV2 aX60gensym1242__1;
					NimStringV2 tmpX60gensym1242__1;
					NimStringV2 bX60gensym1242__1;
					NimStringV2 tmp2X60gensym1242__1;
					tyTuple__UV3llMMYFckfui8YMBuUZA tmpTupleAsgn_4;
					tyArray__Seu7uK9aaOSN0BK3EAjjSHw T169_;
					NimStringV2 T170_;
					nimZeroMem((void*)(&xX60gensym1242__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
					nimZeroMem((void*)(&yX60gensym1242__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
					aX60gensym1242__1.len = 0; aX60gensym1242__1.p = NIM_NIL;
					tmpX60gensym1242__1.len = 0; tmpX60gensym1242__1.p = NIM_NIL;
					bX60gensym1242__1.len = 0; bX60gensym1242__1.p = NIM_NIL;
					tmp2X60gensym1242__1.len = 0; tmp2X60gensym1242__1.p = NIM_NIL;
					nimZeroMem((void*)(&tmpTupleAsgn_4), sizeof(tyTuple__UV3llMMYFckfui8YMBuUZA));
					nimZeroMem((void*)(&xX60gensym1242__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
					nimZeroMem((void*)(&yX60gensym1242__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
					useMagic__jsgen_u1172(p_p0, TM__BxLwT0mhrtgTPodf1v3xjg_534);
					if (NIM_UNLIKELY(*nimErr_)) goto LA168_;
					gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], (&xX60gensym1242__1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA168_;
					gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)2)], (&yX60gensym1242__1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA168_;
					aX60gensym1242__1 = rdLoc__jsgen_u593((&xX60gensym1242__1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA168_;
					tmpX60gensym1242__1 = rdLoc__jsgen_u593((&xX60gensym1242__1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA168_;
					bX60gensym1242__1 = rdLoc__jsgen_u593((&yX60gensym1242__1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA168_;
					tmp2X60gensym1242__1 = rdLoc__jsgen_u593((&yX60gensym1242__1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA168_;
					maybeMakeTempAssignable__jsgen_u1399(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], (&xX60gensym1242__1), (&tmpTupleAsgn_4));
					if (NIM_UNLIKELY(*nimErr_)) goto LA168_;
					eqsink___system_u2700((&aX60gensym1242__1), tmpTupleAsgn_4.Field0);
					eqsink___system_u2700((&tmpX60gensym1242__1), tmpTupleAsgn_4.Field1);
					T169_[0] = aX60gensym1242__1;
					T169_[1] = bX60gensym1242__1;
					T169_[2] = tmpX60gensym1242__1;
					T169_[3] = tmp2X60gensym1242__1;
					T170_.len = 0; T170_.p = NIM_NIL;
					T170_ = percent___jsgen_u5853(T169_, 4);
					if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T170_); goto LA168_;}
					eqsink___system_u2700((&(*r_p2).res), T170_);
					(*r_p2).kind = ((tyEnum_TResKind__UiCSai1lX4RMkJ9bHo9aP2HA)1);
					{
						LA168_:;
					}
					{
						eqdestroy___system_u2691(tmp2X60gensym1242__1);
						eqdestroy___system_u2691(bX60gensym1242__1);
						eqdestroy___system_u2691(tmpX60gensym1242__1);
						eqdestroy___system_u2691(aX60gensym1242__1);
						eqdestroy___jsgen_u570((&yX60gensym1242__1));
						eqdestroy___jsgen_u570((&xX60gensym1242__1));
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA138_;
				}
LA158_: ;
			}
			goto LA152_;
LA156_: ;
			{
				{
					tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ xX60gensym1247__1;
					tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ yX60gensym1247__1;
					NimStringV2 aX60gensym1247__1;
					NimStringV2 tmpX60gensym1247__1;
					NimStringV2 bX60gensym1247__1;
					NimStringV2 tmp2X60gensym1247__1;
					tyArray__Seu7uK9aaOSN0BK3EAjjSHw T179_;
					NimStringV2 T180_;
					if (!!((((*p_p0).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)5)))&31U)))!=0))) goto LA176_;
					nimZeroMem((void*)(&xX60gensym1247__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
					nimZeroMem((void*)(&yX60gensym1247__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
					aX60gensym1247__1.len = 0; aX60gensym1247__1.p = NIM_NIL;
					tmpX60gensym1247__1.len = 0; tmpX60gensym1247__1.p = NIM_NIL;
					bX60gensym1247__1.len = 0; bX60gensym1247__1.p = NIM_NIL;
					tmp2X60gensym1247__1.len = 0; tmp2X60gensym1247__1.p = NIM_NIL;
					nimZeroMem((void*)(&xX60gensym1247__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
					nimZeroMem((void*)(&yX60gensym1247__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
					useMagic__jsgen_u1172(p_p0, TM__BxLwT0mhrtgTPodf1v3xjg_535);
					if (NIM_UNLIKELY(*nimErr_)) goto LA178_;
					gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], (&xX60gensym1247__1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA178_;
					gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)2)], (&yX60gensym1247__1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA178_;
					aX60gensym1247__1 = rdLoc__jsgen_u593((&xX60gensym1247__1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA178_;
					tmpX60gensym1247__1 = rdLoc__jsgen_u593((&xX60gensym1247__1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA178_;
					bX60gensym1247__1 = rdLoc__jsgen_u593((&yX60gensym1247__1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA178_;
					tmp2X60gensym1247__1 = rdLoc__jsgen_u593((&yX60gensym1247__1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA178_;
					T179_[0] = aX60gensym1247__1;
					T179_[1] = bX60gensym1247__1;
					T179_[2] = tmpX60gensym1247__1;
					T179_[3] = tmp2X60gensym1247__1;
					T180_.len = 0; T180_.p = NIM_NIL;
					T180_ = percent___jsgen_u5882(T179_, 4);
					if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T180_); goto LA178_;}
					eqsink___system_u2700((&(*r_p2).res), T180_);
					(*r_p2).kind = ((tyEnum_TResKind__UiCSai1lX4RMkJ9bHo9aP2HA)1);
					{
						LA178_:;
					}
					{
						eqdestroy___system_u2691(tmp2X60gensym1247__1);
						eqdestroy___system_u2691(bX60gensym1247__1);
						eqdestroy___system_u2691(tmpX60gensym1247__1);
						eqdestroy___system_u2691(aX60gensym1247__1);
						eqdestroy___jsgen_u570((&yX60gensym1247__1));
						eqdestroy___jsgen_u570((&xX60gensym1247__1));
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA138_;
				}
				goto LA174_;
LA176_: ;
				{
					tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ xX60gensym1252__1;
					tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ yX60gensym1252__1;
					NimStringV2 aX60gensym1252__1;
					NimStringV2 tmpX60gensym1252__1;
					NimStringV2 bX60gensym1252__1;
					NimStringV2 tmp2X60gensym1252__1;
					tyTuple__UV3llMMYFckfui8YMBuUZA tmpTupleAsgn_5;
					tyArray__Seu7uK9aaOSN0BK3EAjjSHw T185_;
					NimStringV2 T186_;
					nimZeroMem((void*)(&xX60gensym1252__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
					nimZeroMem((void*)(&yX60gensym1252__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
					aX60gensym1252__1.len = 0; aX60gensym1252__1.p = NIM_NIL;
					tmpX60gensym1252__1.len = 0; tmpX60gensym1252__1.p = NIM_NIL;
					bX60gensym1252__1.len = 0; bX60gensym1252__1.p = NIM_NIL;
					tmp2X60gensym1252__1.len = 0; tmp2X60gensym1252__1.p = NIM_NIL;
					nimZeroMem((void*)(&tmpTupleAsgn_5), sizeof(tyTuple__UV3llMMYFckfui8YMBuUZA));
					nimZeroMem((void*)(&xX60gensym1252__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
					nimZeroMem((void*)(&yX60gensym1252__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
					useMagic__jsgen_u1172(p_p0, TM__BxLwT0mhrtgTPodf1v3xjg_536);
					if (NIM_UNLIKELY(*nimErr_)) goto LA184_;
					gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], (&xX60gensym1252__1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA184_;
					gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)2)], (&yX60gensym1252__1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA184_;
					aX60gensym1252__1 = rdLoc__jsgen_u593((&xX60gensym1252__1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA184_;
					tmpX60gensym1252__1 = rdLoc__jsgen_u593((&xX60gensym1252__1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA184_;
					bX60gensym1252__1 = rdLoc__jsgen_u593((&yX60gensym1252__1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA184_;
					tmp2X60gensym1252__1 = rdLoc__jsgen_u593((&yX60gensym1252__1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA184_;
					maybeMakeTempAssignable__jsgen_u1399(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], (&xX60gensym1252__1), (&tmpTupleAsgn_5));
					if (NIM_UNLIKELY(*nimErr_)) goto LA184_;
					eqsink___system_u2700((&aX60gensym1252__1), tmpTupleAsgn_5.Field0);
					eqsink___system_u2700((&tmpX60gensym1252__1), tmpTupleAsgn_5.Field1);
					T185_[0] = aX60gensym1252__1;
					T185_[1] = bX60gensym1252__1;
					T185_[2] = tmpX60gensym1252__1;
					T185_[3] = tmp2X60gensym1252__1;
					T186_.len = 0; T186_.p = NIM_NIL;
					T186_ = percent___jsgen_u5908(T185_, 4);
					if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T186_); goto LA184_;}
					eqsink___system_u2700((&(*r_p2).res), T186_);
					(*r_p2).kind = ((tyEnum_TResKind__UiCSai1lX4RMkJ9bHo9aP2HA)1);
					{
						LA184_:;
					}
					{
						eqdestroy___system_u2691(tmp2X60gensym1252__1);
						eqdestroy___system_u2691(bX60gensym1252__1);
						eqdestroy___system_u2691(tmpX60gensym1252__1);
						eqdestroy___system_u2691(aX60gensym1252__1);
						eqdestroy___jsgen_u570((&yX60gensym1252__1));
						eqdestroy___jsgen_u570((&xX60gensym1252__1));
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA138_;
				}
LA174_: ;
			}
LA152_: ;
		}
		break;
		}
		{
			LA138_:;
		}
		{
			oldNimErrFin138_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3378(typ_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin138_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)30):
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_2;
		typ_2 = NIM_NIL;
		typ_2 = skipTypes__ast_u5379((*(*n_p1)._kind_6.sons.p->data[((NI)1)]).typField, TM__BxLwT0mhrtgTPodf1v3xjg_358);
		if (NIM_UNLIKELY(*nimErr_)) goto LA192_;
		switch ((*typ_2).kind) {
		case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)40) ... ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)43):
		{
			binaryUintExpr__jsgen_u5721(p_p0, n_p1, r_p2, TM__BxLwT0mhrtgTPodf1v3xjg_537);
			if (NIM_UNLIKELY(*nimErr_)) goto LA192_;
		}
		break;
		case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)44):
		{
			{
				tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ xX60gensym1260__1;
				tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ yX60gensym1260__1;
				NimStringV2 aX60gensym1260__1;
				NimStringV2 tmpX60gensym1260__1;
				NimStringV2 bX60gensym1260__1;
				NimStringV2 tmp2X60gensym1260__1;
				tyTuple__UV3llMMYFckfui8YMBuUZA tmpTupleAsgn_6;
				tyArray__Seu7uK9aaOSN0BK3EAjjSHw T200_;
				NimStringV2 T201_;
				if (!(((*(*(*p_p0).module).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)56)))&63U)))!=0)) goto LA197_;
				nimZeroMem((void*)(&xX60gensym1260__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
				nimZeroMem((void*)(&yX60gensym1260__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
				aX60gensym1260__1.len = 0; aX60gensym1260__1.p = NIM_NIL;
				tmpX60gensym1260__1.len = 0; tmpX60gensym1260__1.p = NIM_NIL;
				bX60gensym1260__1.len = 0; bX60gensym1260__1.p = NIM_NIL;
				tmp2X60gensym1260__1.len = 0; tmp2X60gensym1260__1.p = NIM_NIL;
				nimZeroMem((void*)(&tmpTupleAsgn_6), sizeof(tyTuple__UV3llMMYFckfui8YMBuUZA));
				nimZeroMem((void*)(&xX60gensym1260__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
				nimZeroMem((void*)(&yX60gensym1260__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
				useMagic__jsgen_u1172(p_p0, TM__BxLwT0mhrtgTPodf1v3xjg_538);
				if (NIM_UNLIKELY(*nimErr_)) goto LA199_;
				gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], (&xX60gensym1260__1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA199_;
				gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)2)], (&yX60gensym1260__1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA199_;
				aX60gensym1260__1 = rdLoc__jsgen_u593((&xX60gensym1260__1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA199_;
				tmpX60gensym1260__1 = rdLoc__jsgen_u593((&xX60gensym1260__1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA199_;
				bX60gensym1260__1 = rdLoc__jsgen_u593((&yX60gensym1260__1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA199_;
				tmp2X60gensym1260__1 = rdLoc__jsgen_u593((&yX60gensym1260__1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA199_;
				maybeMakeTempAssignable__jsgen_u1399(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], (&xX60gensym1260__1), (&tmpTupleAsgn_6));
				if (NIM_UNLIKELY(*nimErr_)) goto LA199_;
				eqsink___system_u2700((&aX60gensym1260__1), tmpTupleAsgn_6.Field0);
				eqsink___system_u2700((&tmpX60gensym1260__1), tmpTupleAsgn_6.Field1);
				T200_[0] = aX60gensym1260__1;
				T200_[1] = bX60gensym1260__1;
				T200_[2] = tmpX60gensym1260__1;
				T200_[3] = tmp2X60gensym1260__1;
				T201_.len = 0; T201_.p = NIM_NIL;
				T201_ = percent___jsgen_u5946(T200_, 4);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T201_); goto LA199_;}
				eqsink___system_u2700((&(*r_p2).res), T201_);
				(*r_p2).kind = ((tyEnum_TResKind__UiCSai1lX4RMkJ9bHo9aP2HA)1);
				{
					LA199_:;
				}
				{
					eqdestroy___system_u2691(tmp2X60gensym1260__1);
					eqdestroy___system_u2691(bX60gensym1260__1);
					eqdestroy___system_u2691(tmpX60gensym1260__1);
					eqdestroy___system_u2691(aX60gensym1260__1);
					eqdestroy___jsgen_u570((&yX60gensym1260__1));
					eqdestroy___jsgen_u570((&xX60gensym1260__1));
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA192_;
			}
			goto LA195_;
LA197_: ;
			{
				binaryUintExpr__jsgen_u5721(p_p0, n_p1, r_p2, TM__BxLwT0mhrtgTPodf1v3xjg_539);
				if (NIM_UNLIKELY(*nimErr_)) goto LA192_;
			}
LA195_: ;
		}
		break;
		default:
		{
			{
				NIM_BOOL T208_;
				T208_ = (NIM_BOOL)0;
				T208_ = ((*typ_2).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)35));
				if (!(T208_)) goto LA209_;
				T208_ = (((*(*(*p_p0).module).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)56)))&63U)))!=0);
LA209_: ;
				if (!T208_) goto LA210_;
				{
					tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ xX60gensym1267__1;
					tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ yX60gensym1267__1;
					NimStringV2 aX60gensym1267__1;
					NimStringV2 tmpX60gensym1267__1;
					NimStringV2 bX60gensym1267__1;
					NimStringV2 tmp2X60gensym1267__1;
					tyTuple__UV3llMMYFckfui8YMBuUZA tmpTupleAsgn_7;
					tyArray__Seu7uK9aaOSN0BK3EAjjSHw T217_;
					NimStringV2 T218_;
					if (!!((((*p_p0).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)5)))&31U)))!=0))) goto LA214_;
					nimZeroMem((void*)(&xX60gensym1267__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
					nimZeroMem((void*)(&yX60gensym1267__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
					aX60gensym1267__1.len = 0; aX60gensym1267__1.p = NIM_NIL;
					tmpX60gensym1267__1.len = 0; tmpX60gensym1267__1.p = NIM_NIL;
					bX60gensym1267__1.len = 0; bX60gensym1267__1.p = NIM_NIL;
					tmp2X60gensym1267__1.len = 0; tmp2X60gensym1267__1.p = NIM_NIL;
					nimZeroMem((void*)(&tmpTupleAsgn_7), sizeof(tyTuple__UV3llMMYFckfui8YMBuUZA));
					nimZeroMem((void*)(&xX60gensym1267__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
					nimZeroMem((void*)(&yX60gensym1267__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
					useMagic__jsgen_u1172(p_p0, TM__BxLwT0mhrtgTPodf1v3xjg_540);
					if (NIM_UNLIKELY(*nimErr_)) goto LA216_;
					gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], (&xX60gensym1267__1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA216_;
					gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)2)], (&yX60gensym1267__1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA216_;
					aX60gensym1267__1 = rdLoc__jsgen_u593((&xX60gensym1267__1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA216_;
					tmpX60gensym1267__1 = rdLoc__jsgen_u593((&xX60gensym1267__1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA216_;
					bX60gensym1267__1 = rdLoc__jsgen_u593((&yX60gensym1267__1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA216_;
					tmp2X60gensym1267__1 = rdLoc__jsgen_u593((&yX60gensym1267__1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA216_;
					maybeMakeTempAssignable__jsgen_u1399(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], (&xX60gensym1267__1), (&tmpTupleAsgn_7));
					if (NIM_UNLIKELY(*nimErr_)) goto LA216_;
					eqsink___system_u2700((&aX60gensym1267__1), tmpTupleAsgn_7.Field0);
					eqsink___system_u2700((&tmpX60gensym1267__1), tmpTupleAsgn_7.Field1);
					T217_[0] = aX60gensym1267__1;
					T217_[1] = bX60gensym1267__1;
					T217_[2] = tmpX60gensym1267__1;
					T217_[3] = tmp2X60gensym1267__1;
					T218_.len = 0; T218_.p = NIM_NIL;
					T218_ = percent___jsgen_u5991(T217_, 4);
					if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T218_); goto LA216_;}
					eqsink___system_u2700((&(*r_p2).res), T218_);
					(*r_p2).kind = ((tyEnum_TResKind__UiCSai1lX4RMkJ9bHo9aP2HA)1);
					{
						LA216_:;
					}
					{
						eqdestroy___system_u2691(tmp2X60gensym1267__1);
						eqdestroy___system_u2691(bX60gensym1267__1);
						eqdestroy___system_u2691(tmpX60gensym1267__1);
						eqdestroy___system_u2691(aX60gensym1267__1);
						eqdestroy___jsgen_u570((&yX60gensym1267__1));
						eqdestroy___jsgen_u570((&xX60gensym1267__1));
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA192_;
				}
				goto LA212_;
LA214_: ;
				{
					tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ xX60gensym1271__1;
					tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ yX60gensym1271__1;
					NimStringV2 aX60gensym1271__1;
					NimStringV2 tmpX60gensym1271__1;
					NimStringV2 bX60gensym1271__1;
					NimStringV2 tmp2X60gensym1271__1;
					tyTuple__UV3llMMYFckfui8YMBuUZA tmpTupleAsgn_8;
					tyArray__Seu7uK9aaOSN0BK3EAjjSHw T223_;
					NimStringV2 T224_;
					nimZeroMem((void*)(&xX60gensym1271__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
					nimZeroMem((void*)(&yX60gensym1271__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
					aX60gensym1271__1.len = 0; aX60gensym1271__1.p = NIM_NIL;
					tmpX60gensym1271__1.len = 0; tmpX60gensym1271__1.p = NIM_NIL;
					bX60gensym1271__1.len = 0; bX60gensym1271__1.p = NIM_NIL;
					tmp2X60gensym1271__1.len = 0; tmp2X60gensym1271__1.p = NIM_NIL;
					nimZeroMem((void*)(&tmpTupleAsgn_8), sizeof(tyTuple__UV3llMMYFckfui8YMBuUZA));
					nimZeroMem((void*)(&xX60gensym1271__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
					nimZeroMem((void*)(&yX60gensym1271__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
					useMagic__jsgen_u1172(p_p0, TM__BxLwT0mhrtgTPodf1v3xjg_541);
					if (NIM_UNLIKELY(*nimErr_)) goto LA222_;
					gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], (&xX60gensym1271__1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA222_;
					gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)2)], (&yX60gensym1271__1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA222_;
					aX60gensym1271__1 = rdLoc__jsgen_u593((&xX60gensym1271__1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA222_;
					tmpX60gensym1271__1 = rdLoc__jsgen_u593((&xX60gensym1271__1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA222_;
					bX60gensym1271__1 = rdLoc__jsgen_u593((&yX60gensym1271__1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA222_;
					tmp2X60gensym1271__1 = rdLoc__jsgen_u593((&yX60gensym1271__1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA222_;
					maybeMakeTempAssignable__jsgen_u1399(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], (&xX60gensym1271__1), (&tmpTupleAsgn_8));
					if (NIM_UNLIKELY(*nimErr_)) goto LA222_;
					eqsink___system_u2700((&aX60gensym1271__1), tmpTupleAsgn_8.Field0);
					eqsink___system_u2700((&tmpX60gensym1271__1), tmpTupleAsgn_8.Field1);
					T223_[0] = aX60gensym1271__1;
					T223_[1] = bX60gensym1271__1;
					T223_[2] = tmpX60gensym1271__1;
					T223_[3] = tmp2X60gensym1271__1;
					T224_.len = 0; T224_.p = NIM_NIL;
					T224_ = percent___jsgen_u6017(T223_, 4);
					if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T224_); goto LA222_;}
					eqsink___system_u2700((&(*r_p2).res), T224_);
					(*r_p2).kind = ((tyEnum_TResKind__UiCSai1lX4RMkJ9bHo9aP2HA)1);
					{
						LA222_:;
					}
					{
						eqdestroy___system_u2691(tmp2X60gensym1271__1);
						eqdestroy___system_u2691(bX60gensym1271__1);
						eqdestroy___system_u2691(tmpX60gensym1271__1);
						eqdestroy___system_u2691(aX60gensym1271__1);
						eqdestroy___jsgen_u570((&yX60gensym1271__1));
						eqdestroy___jsgen_u570((&xX60gensym1271__1));
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA192_;
				}
LA212_: ;
			}
			goto LA206_;
LA210_: ;
			{
				{
					tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ xX60gensym1276__1;
					tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ yX60gensym1276__1;
					NimStringV2 aX60gensym1276__1;
					NimStringV2 tmpX60gensym1276__1;
					NimStringV2 bX60gensym1276__1;
					NimStringV2 tmp2X60gensym1276__1;
					tyArray__Seu7uK9aaOSN0BK3EAjjSHw T233_;
					NimStringV2 T234_;
					if (!!((((*p_p0).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)5)))&31U)))!=0))) goto LA230_;
					nimZeroMem((void*)(&xX60gensym1276__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
					nimZeroMem((void*)(&yX60gensym1276__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
					aX60gensym1276__1.len = 0; aX60gensym1276__1.p = NIM_NIL;
					tmpX60gensym1276__1.len = 0; tmpX60gensym1276__1.p = NIM_NIL;
					bX60gensym1276__1.len = 0; bX60gensym1276__1.p = NIM_NIL;
					tmp2X60gensym1276__1.len = 0; tmp2X60gensym1276__1.p = NIM_NIL;
					nimZeroMem((void*)(&xX60gensym1276__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
					nimZeroMem((void*)(&yX60gensym1276__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
					useMagic__jsgen_u1172(p_p0, TM__BxLwT0mhrtgTPodf1v3xjg_542);
					if (NIM_UNLIKELY(*nimErr_)) goto LA232_;
					gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], (&xX60gensym1276__1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA232_;
					gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)2)], (&yX60gensym1276__1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA232_;
					aX60gensym1276__1 = rdLoc__jsgen_u593((&xX60gensym1276__1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA232_;
					tmpX60gensym1276__1 = rdLoc__jsgen_u593((&xX60gensym1276__1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA232_;
					bX60gensym1276__1 = rdLoc__jsgen_u593((&yX60gensym1276__1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA232_;
					tmp2X60gensym1276__1 = rdLoc__jsgen_u593((&yX60gensym1276__1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA232_;
					T233_[0] = aX60gensym1276__1;
					T233_[1] = bX60gensym1276__1;
					T233_[2] = tmpX60gensym1276__1;
					T233_[3] = tmp2X60gensym1276__1;
					T234_.len = 0; T234_.p = NIM_NIL;
					T234_ = percent___jsgen_u6046(T233_, 4);
					if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T234_); goto LA232_;}
					eqsink___system_u2700((&(*r_p2).res), T234_);
					(*r_p2).kind = ((tyEnum_TResKind__UiCSai1lX4RMkJ9bHo9aP2HA)1);
					{
						LA232_:;
					}
					{
						eqdestroy___system_u2691(tmp2X60gensym1276__1);
						eqdestroy___system_u2691(bX60gensym1276__1);
						eqdestroy___system_u2691(tmpX60gensym1276__1);
						eqdestroy___system_u2691(aX60gensym1276__1);
						eqdestroy___jsgen_u570((&yX60gensym1276__1));
						eqdestroy___jsgen_u570((&xX60gensym1276__1));
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA192_;
				}
				goto LA228_;
LA230_: ;
				{
					tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ xX60gensym1281__1;
					tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ yX60gensym1281__1;
					NimStringV2 aX60gensym1281__1;
					NimStringV2 tmpX60gensym1281__1;
					NimStringV2 bX60gensym1281__1;
					NimStringV2 tmp2X60gensym1281__1;
					tyTuple__UV3llMMYFckfui8YMBuUZA tmpTupleAsgn_9;
					tyArray__Seu7uK9aaOSN0BK3EAjjSHw T239_;
					NimStringV2 T240_;
					nimZeroMem((void*)(&xX60gensym1281__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
					nimZeroMem((void*)(&yX60gensym1281__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
					aX60gensym1281__1.len = 0; aX60gensym1281__1.p = NIM_NIL;
					tmpX60gensym1281__1.len = 0; tmpX60gensym1281__1.p = NIM_NIL;
					bX60gensym1281__1.len = 0; bX60gensym1281__1.p = NIM_NIL;
					tmp2X60gensym1281__1.len = 0; tmp2X60gensym1281__1.p = NIM_NIL;
					nimZeroMem((void*)(&tmpTupleAsgn_9), sizeof(tyTuple__UV3llMMYFckfui8YMBuUZA));
					nimZeroMem((void*)(&xX60gensym1281__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
					nimZeroMem((void*)(&yX60gensym1281__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
					useMagic__jsgen_u1172(p_p0, TM__BxLwT0mhrtgTPodf1v3xjg_543);
					if (NIM_UNLIKELY(*nimErr_)) goto LA238_;
					gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], (&xX60gensym1281__1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA238_;
					gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)2)], (&yX60gensym1281__1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA238_;
					aX60gensym1281__1 = rdLoc__jsgen_u593((&xX60gensym1281__1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA238_;
					tmpX60gensym1281__1 = rdLoc__jsgen_u593((&xX60gensym1281__1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA238_;
					bX60gensym1281__1 = rdLoc__jsgen_u593((&yX60gensym1281__1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA238_;
					tmp2X60gensym1281__1 = rdLoc__jsgen_u593((&yX60gensym1281__1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA238_;
					maybeMakeTempAssignable__jsgen_u1399(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], (&xX60gensym1281__1), (&tmpTupleAsgn_9));
					if (NIM_UNLIKELY(*nimErr_)) goto LA238_;
					eqsink___system_u2700((&aX60gensym1281__1), tmpTupleAsgn_9.Field0);
					eqsink___system_u2700((&tmpX60gensym1281__1), tmpTupleAsgn_9.Field1);
					T239_[0] = aX60gensym1281__1;
					T239_[1] = bX60gensym1281__1;
					T239_[2] = tmpX60gensym1281__1;
					T239_[3] = tmp2X60gensym1281__1;
					T240_.len = 0; T240_.p = NIM_NIL;
					T240_ = percent___jsgen_u6072(T239_, 4);
					if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T240_); goto LA238_;}
					eqsink___system_u2700((&(*r_p2).res), T240_);
					(*r_p2).kind = ((tyEnum_TResKind__UiCSai1lX4RMkJ9bHo9aP2HA)1);
					{
						LA238_:;
					}
					{
						eqdestroy___system_u2691(tmp2X60gensym1281__1);
						eqdestroy___system_u2691(bX60gensym1281__1);
						eqdestroy___system_u2691(tmpX60gensym1281__1);
						eqdestroy___system_u2691(aX60gensym1281__1);
						eqdestroy___jsgen_u570((&yX60gensym1281__1));
						eqdestroy___jsgen_u570((&xX60gensym1281__1));
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA192_;
				}
LA228_: ;
			}
LA206_: ;
		}
		break;
		}
		{
			LA192_:;
		}
		{
			oldNimErrFin192_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3378(typ_2);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin192_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)135):
	{
		tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ xX60gensym1285__1;
		tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ yX60gensym1285__1;
		NimStringV2 aX60gensym1285__1;
		NimStringV2 tmpX60gensym1285__1;
		NimStringV2 bX60gensym1285__1;
		NimStringV2 tmp2X60gensym1285__1;
		tyTuple__UV3llMMYFckfui8YMBuUZA tmpTupleAsgn_10;
		tyTuple__UV3llMMYFckfui8YMBuUZA tmpTupleAsgn_11;
		tyArray__Seu7uK9aaOSN0BK3EAjjSHw T247_;
		NimStringV2 T248_;
		nimZeroMem((void*)(&xX60gensym1285__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
		nimZeroMem((void*)(&yX60gensym1285__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
		aX60gensym1285__1.len = 0; aX60gensym1285__1.p = NIM_NIL;
		tmpX60gensym1285__1.len = 0; tmpX60gensym1285__1.p = NIM_NIL;
		bX60gensym1285__1.len = 0; bX60gensym1285__1.p = NIM_NIL;
		tmp2X60gensym1285__1.len = 0; tmp2X60gensym1285__1.p = NIM_NIL;
		nimZeroMem((void*)(&tmpTupleAsgn_10), sizeof(tyTuple__UV3llMMYFckfui8YMBuUZA));
		nimZeroMem((void*)(&tmpTupleAsgn_11), sizeof(tyTuple__UV3llMMYFckfui8YMBuUZA));
		nimZeroMem((void*)(&xX60gensym1285__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
		nimZeroMem((void*)(&yX60gensym1285__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
		useMagic__jsgen_u1172(p_p0, TM__BxLwT0mhrtgTPodf1v3xjg_545);
		if (NIM_UNLIKELY(*nimErr_)) goto LA246_;
		gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], (&xX60gensym1285__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA246_;
		gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)2)], (&yX60gensym1285__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA246_;
		aX60gensym1285__1 = rdLoc__jsgen_u593((&xX60gensym1285__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA246_;
		tmpX60gensym1285__1 = rdLoc__jsgen_u593((&xX60gensym1285__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA246_;
		bX60gensym1285__1 = rdLoc__jsgen_u593((&yX60gensym1285__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA246_;
		tmp2X60gensym1285__1 = rdLoc__jsgen_u593((&yX60gensym1285__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA246_;
		maybeMakeTemp__jsgen_u1365(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], (&xX60gensym1285__1), (&tmpTupleAsgn_10));
		if (NIM_UNLIKELY(*nimErr_)) goto LA246_;
		eqsink___system_u2700((&aX60gensym1285__1), tmpTupleAsgn_10.Field0);
		eqsink___system_u2700((&tmpX60gensym1285__1), tmpTupleAsgn_10.Field1);
		maybeMakeTemp__jsgen_u1365(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)2)], (&yX60gensym1285__1), (&tmpTupleAsgn_11));
		if (NIM_UNLIKELY(*nimErr_)) goto LA246_;
		eqsink___system_u2700((&bX60gensym1285__1), tmpTupleAsgn_11.Field0);
		eqsink___system_u2700((&tmp2X60gensym1285__1), tmpTupleAsgn_11.Field1);
		T247_[0] = aX60gensym1285__1;
		T247_[1] = bX60gensym1285__1;
		T247_[2] = tmpX60gensym1285__1;
		T247_[3] = tmp2X60gensym1285__1;
		T248_.len = 0; T248_.p = NIM_NIL;
		T248_ = percent___jsgen_u6099(T247_, 4);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T248_); goto LA246_;}
		eqsink___system_u2700((&(*r_p2).res), T248_);
		(*r_p2).kind = ((tyEnum_TResKind__UiCSai1lX4RMkJ9bHo9aP2HA)1);
		{
			LA246_:;
		}
		{
			eqdestroy___system_u2691(tmp2X60gensym1285__1);
			eqdestroy___system_u2691(bX60gensym1285__1);
			eqdestroy___system_u2691(tmpX60gensym1285__1);
			eqdestroy___system_u2691(aX60gensym1285__1);
			eqdestroy___jsgen_u570((&yX60gensym1285__1));
			eqdestroy___jsgen_u570((&xX60gensym1285__1));
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)136):
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)137):
	{
		tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ x_6;
		tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ y_2;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_1;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__19;
		tyTuple__UV3llMMYFckfui8YMBuUZA tmpTuple_4;
		NimStringV2 a_4;
		NimStringV2 tmp_4;
		tyTuple__UV3llMMYFckfui8YMBuUZA tmpTuple_5;
		NimStringV2 b_2;
		NimStringV2 tmp2_1;
		NimStringV2 colontmpD__20;
		tyArray__awn6UrBeChh9cVy9ccoluuYg T253_;
		NimStringV2 T254_;
		nimZeroMem((void*)(&x_6), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
		nimZeroMem((void*)(&y_2), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
		t_1 = NIM_NIL;
		colontmpD__19 = NIM_NIL;
		nimZeroMem((void*)(&tmpTuple_4), sizeof(tyTuple__UV3llMMYFckfui8YMBuUZA));
		a_4.len = 0; a_4.p = NIM_NIL;
		tmp_4.len = 0; tmp_4.p = NIM_NIL;
		nimZeroMem((void*)(&tmpTuple_5), sizeof(tyTuple__UV3llMMYFckfui8YMBuUZA));
		b_2.len = 0; b_2.p = NIM_NIL;
		tmp2_1.len = 0; tmp2_1.p = NIM_NIL;
		colontmpD__20.len = 0; colontmpD__20.p = NIM_NIL;
		nimZeroMem((void*)(&x_6), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
		nimZeroMem((void*)(&y_2), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
		gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], (&x_6));
		if (NIM_UNLIKELY(*nimErr_)) goto LA252_;
		gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)2)], (&y_2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA252_;
		colontmpD__19 = skipTypes__ast_u5379((*(*n_p1)._kind_6.sons.p->data[((NI)1)]).typField, TM__BxLwT0mhrtgTPodf1v3xjg_504);
		if (NIM_UNLIKELY(*nimErr_)) goto LA252_;
		eqcopy___ast_u3381(&t_1, (*colontmpD__19).sons.p->data[((NI)0)]);
		if (NIM_UNLIKELY(*nimErr_)) goto LA252_;
		maybeMakeTemp__jsgen_u1365(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], (&x_6), (&tmpTuple_4));
		if (NIM_UNLIKELY(*nimErr_)) goto LA252_;
		a_4 = tmpTuple_4.Field0;
		eqwasMoved___system_u2688((&tmpTuple_4.Field0));
		tmp_4 = tmpTuple_4.Field1;
		eqwasMoved___system_u2688((&tmpTuple_4.Field1));
		maybeMakeTemp__jsgen_u1365(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)2)], (&y_2), (&tmpTuple_5));
		if (NIM_UNLIKELY(*nimErr_)) goto LA252_;
		b_2 = tmpTuple_5.Field0;
		eqwasMoved___system_u2688((&tmpTuple_5.Field0));
		tmp2_1 = tmpTuple_5.Field1;
		eqwasMoved___system_u2688((&tmpTuple_5.Field1));
		T253_[0] = a_4;
		T253_[1] = b_2;
		colontmpD__20 = createVar__jsgen_u4648(p_p0, t_1, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA252_;
		T253_[2] = colontmpD__20;
		T253_[3] = tmp_4;
		T253_[4] = tmp2_1;
		T254_.len = 0; T254_.p = NIM_NIL;
		T254_ = percent___jsgen_u6121(T253_, 5);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T254_); goto LA252_;}
		eqsink___system_u2700((&(*r_p2).res), T254_);
		(*r_p2).kind = ((tyEnum_TResKind__UiCSai1lX4RMkJ9bHo9aP2HA)1);
		{
			LA252_:;
		}
		{
			oldNimErrFin252_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___system_u2691(colontmpD__20);
			eqdestroy___system_u2691(tmp2_1);
			eqdestroy___system_u2691(b_2);
			eqdestroy___stdZprivateZospaths2_u306((&tmpTuple_5));
			eqdestroy___system_u2691(tmp_4);
			eqdestroy___system_u2691(a_4);
			eqdestroy___stdZprivateZospaths2_u306((&tmpTuple_4));
			eqdestroy___ast_u3378(colontmpD__19);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			eqdestroy___ast_u3378(t_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			eqdestroy___jsgen_u570((&y_2));
			eqdestroy___jsgen_u570((&x_6));
			*nimErr_ = oldNimErrFin252_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)42):
	{
		NimStringV2 aX60gensym1299__1;
		NimStringV2 tmpX60gensym1299__1;
		tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T264_;
		NimStringV2 T265_;
		aX60gensym1299__1.len = 0; aX60gensym1299__1.p = NIM_NIL;
		tmpX60gensym1299__1.len = 0; tmpX60gensym1299__1.p = NIM_NIL;
		useMagic__jsgen_u1172(p_p0, TM__BxLwT0mhrtgTPodf1v3xjg_547);
		if (NIM_UNLIKELY(*nimErr_)) goto LA258_;
		gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], r_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA258_;
		aX60gensym1299__1 = rdLoc__jsgen_u593((&(*r_p2)));
		if (NIM_UNLIKELY(*nimErr_)) goto LA258_;
		tmpX60gensym1299__1 = rdLoc__jsgen_u593((&(*r_p2)));
		if (NIM_UNLIKELY(*nimErr_)) goto LA258_;
		{
			NIM_BOOL T261_;
			tyTuple__UV3llMMYFckfui8YMBuUZA tmpTupleAsgn_12;
			T261_ = (NIM_BOOL)0;
			T261_ = contains__pureZstrutils_u1833(TM__BxLwT0mhrtgTPodf1v3xjg_549, TM__BxLwT0mhrtgTPodf1v3xjg_550);
			if (NIM_UNLIKELY(*nimErr_)) goto LA258_;
			if (!T261_) goto LA262_;
			nimZeroMem((void*)(&tmpTupleAsgn_12), sizeof(tyTuple__UV3llMMYFckfui8YMBuUZA));
			maybeMakeTemp__jsgen_u1365(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], (&(*r_p2)), (&tmpTupleAsgn_12));
			if (NIM_UNLIKELY(*nimErr_)) goto LA258_;
			eqsink___system_u2700((&aX60gensym1299__1), tmpTupleAsgn_12.Field0);
			eqsink___system_u2700((&tmpX60gensym1299__1), tmpTupleAsgn_12.Field1);
		}
LA262_: ;
		T264_[0] = aX60gensym1299__1;
		T264_[1] = tmpX60gensym1299__1;
		T265_.len = 0; T265_.p = NIM_NIL;
		T265_ = percent___jsgen_u6131(T264_, 2);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T265_); goto LA258_;}
		eqsink___system_u2700((&(*r_p2).res), T265_);
		(*r_p2).kind = ((tyEnum_TResKind__UiCSai1lX4RMkJ9bHo9aP2HA)1);
		{
			LA258_:;
		}
		{
			eqdestroy___system_u2691(tmpX60gensym1299__1);
			eqdestroy___system_u2691(aX60gensym1299__1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)118):
	{
		tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ xX60gensym1303__1;
		tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ yX60gensym1303__1;
		NimStringV2 aX60gensym1303__1;
		NimStringV2 tmpX60gensym1303__1;
		NimStringV2 bX60gensym1303__1;
		NimStringV2 tmp2X60gensym1303__1;
		tyArray__Seu7uK9aaOSN0BK3EAjjSHw T270_;
		NimStringV2 T271_;
		nimZeroMem((void*)(&xX60gensym1303__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
		nimZeroMem((void*)(&yX60gensym1303__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
		aX60gensym1303__1.len = 0; aX60gensym1303__1.p = NIM_NIL;
		tmpX60gensym1303__1.len = 0; tmpX60gensym1303__1.p = NIM_NIL;
		bX60gensym1303__1.len = 0; bX60gensym1303__1.p = NIM_NIL;
		tmp2X60gensym1303__1.len = 0; tmp2X60gensym1303__1.p = NIM_NIL;
		nimZeroMem((void*)(&xX60gensym1303__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
		nimZeroMem((void*)(&yX60gensym1303__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
		useMagic__jsgen_u1172(p_p0, TM__BxLwT0mhrtgTPodf1v3xjg_552);
		if (NIM_UNLIKELY(*nimErr_)) goto LA269_;
		gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], (&xX60gensym1303__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA269_;
		gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)2)], (&yX60gensym1303__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA269_;
		aX60gensym1303__1 = rdLoc__jsgen_u593((&xX60gensym1303__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA269_;
		tmpX60gensym1303__1 = rdLoc__jsgen_u593((&xX60gensym1303__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA269_;
		bX60gensym1303__1 = rdLoc__jsgen_u593((&yX60gensym1303__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA269_;
		tmp2X60gensym1303__1 = rdLoc__jsgen_u593((&yX60gensym1303__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA269_;
		T270_[0] = aX60gensym1303__1;
		T270_[1] = bX60gensym1303__1;
		T270_[2] = tmpX60gensym1303__1;
		T270_[3] = tmp2X60gensym1303__1;
		T271_.len = 0; T271_.p = NIM_NIL;
		T271_ = percent___jsgen_u6156(T270_, 4);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T271_); goto LA269_;}
		eqsink___system_u2700((&(*r_p2).res), T271_);
		(*r_p2).kind = ((tyEnum_TResKind__UiCSai1lX4RMkJ9bHo9aP2HA)1);
		{
			LA269_:;
		}
		{
			eqdestroy___system_u2691(tmp2X60gensym1303__1);
			eqdestroy___system_u2691(bX60gensym1303__1);
			eqdestroy___system_u2691(tmpX60gensym1303__1);
			eqdestroy___system_u2691(aX60gensym1303__1);
			eqdestroy___jsgen_u570((&yX60gensym1303__1));
			eqdestroy___jsgen_u570((&xX60gensym1303__1));
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)117):
	{
		tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ xX60gensym1308__1;
		tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ yX60gensym1308__1;
		NimStringV2 aX60gensym1308__1;
		NimStringV2 tmpX60gensym1308__1;
		NimStringV2 bX60gensym1308__1;
		NimStringV2 tmp2X60gensym1308__1;
		tyArray__Seu7uK9aaOSN0BK3EAjjSHw T276_;
		NimStringV2 T277_;
		nimZeroMem((void*)(&xX60gensym1308__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
		nimZeroMem((void*)(&yX60gensym1308__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
		aX60gensym1308__1.len = 0; aX60gensym1308__1.p = NIM_NIL;
		tmpX60gensym1308__1.len = 0; tmpX60gensym1308__1.p = NIM_NIL;
		bX60gensym1308__1.len = 0; bX60gensym1308__1.p = NIM_NIL;
		tmp2X60gensym1308__1.len = 0; tmp2X60gensym1308__1.p = NIM_NIL;
		nimZeroMem((void*)(&xX60gensym1308__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
		nimZeroMem((void*)(&yX60gensym1308__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
		useMagic__jsgen_u1172(p_p0, TM__BxLwT0mhrtgTPodf1v3xjg_554);
		if (NIM_UNLIKELY(*nimErr_)) goto LA275_;
		gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], (&xX60gensym1308__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA275_;
		gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)2)], (&yX60gensym1308__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA275_;
		aX60gensym1308__1 = rdLoc__jsgen_u593((&xX60gensym1308__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA275_;
		tmpX60gensym1308__1 = rdLoc__jsgen_u593((&xX60gensym1308__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA275_;
		bX60gensym1308__1 = rdLoc__jsgen_u593((&yX60gensym1308__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA275_;
		tmp2X60gensym1308__1 = rdLoc__jsgen_u593((&yX60gensym1308__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA275_;
		T276_[0] = aX60gensym1308__1;
		T276_[1] = bX60gensym1308__1;
		T276_[2] = tmpX60gensym1308__1;
		T276_[3] = tmp2X60gensym1308__1;
		T277_.len = 0; T277_.p = NIM_NIL;
		T277_ = percent___jsgen_u6181(T276_, 4);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T277_); goto LA275_;}
		eqsink___system_u2700((&(*r_p2).res), T277_);
		(*r_p2).kind = ((tyEnum_TResKind__UiCSai1lX4RMkJ9bHo9aP2HA)1);
		{
			LA275_:;
		}
		{
			eqdestroy___system_u2691(tmp2X60gensym1308__1);
			eqdestroy___system_u2691(bX60gensym1308__1);
			eqdestroy___system_u2691(tmpX60gensym1308__1);
			eqdestroy___system_u2691(aX60gensym1308__1);
			eqdestroy___jsgen_u570((&yX60gensym1308__1));
			eqdestroy___jsgen_u570((&xX60gensym1308__1));
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)116):
	{
		tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ xX60gensym1313__1;
		tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ yX60gensym1313__1;
		NimStringV2 aX60gensym1313__1;
		NimStringV2 tmpX60gensym1313__1;
		NimStringV2 bX60gensym1313__1;
		NimStringV2 tmp2X60gensym1313__1;
		tyArray__Seu7uK9aaOSN0BK3EAjjSHw T282_;
		NimStringV2 T283_;
		nimZeroMem((void*)(&xX60gensym1313__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
		nimZeroMem((void*)(&yX60gensym1313__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
		aX60gensym1313__1.len = 0; aX60gensym1313__1.p = NIM_NIL;
		tmpX60gensym1313__1.len = 0; tmpX60gensym1313__1.p = NIM_NIL;
		bX60gensym1313__1.len = 0; bX60gensym1313__1.p = NIM_NIL;
		tmp2X60gensym1313__1.len = 0; tmp2X60gensym1313__1.p = NIM_NIL;
		nimZeroMem((void*)(&xX60gensym1313__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
		nimZeroMem((void*)(&yX60gensym1313__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
		useMagic__jsgen_u1172(p_p0, TM__BxLwT0mhrtgTPodf1v3xjg_556);
		if (NIM_UNLIKELY(*nimErr_)) goto LA281_;
		gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], (&xX60gensym1313__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA281_;
		gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)2)], (&yX60gensym1313__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA281_;
		aX60gensym1313__1 = rdLoc__jsgen_u593((&xX60gensym1313__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA281_;
		tmpX60gensym1313__1 = rdLoc__jsgen_u593((&xX60gensym1313__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA281_;
		bX60gensym1313__1 = rdLoc__jsgen_u593((&yX60gensym1313__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA281_;
		tmp2X60gensym1313__1 = rdLoc__jsgen_u593((&yX60gensym1313__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA281_;
		T282_[0] = aX60gensym1313__1;
		T282_[1] = bX60gensym1313__1;
		T282_[2] = tmpX60gensym1313__1;
		T282_[3] = tmp2X60gensym1313__1;
		T283_.len = 0; T283_.p = NIM_NIL;
		T283_ = percent___jsgen_u6206(T282_, 4);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T283_); goto LA281_;}
		eqsink___system_u2700((&(*r_p2).res), T283_);
		(*r_p2).kind = ((tyEnum_TResKind__UiCSai1lX4RMkJ9bHo9aP2HA)1);
		{
			LA281_:;
		}
		{
			eqdestroy___system_u2691(tmp2X60gensym1313__1);
			eqdestroy___system_u2691(bX60gensym1313__1);
			eqdestroy___system_u2691(tmpX60gensym1313__1);
			eqdestroy___system_u2691(aX60gensym1313__1);
			eqdestroy___jsgen_u570((&yX60gensym1313__1));
			eqdestroy___jsgen_u570((&xX60gensym1313__1));
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)119):
	{
		tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ xX60gensym1318__1;
		tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ yX60gensym1318__1;
		NimStringV2 aX60gensym1318__1;
		NimStringV2 tmpX60gensym1318__1;
		NimStringV2 bX60gensym1318__1;
		NimStringV2 tmp2X60gensym1318__1;
		tyArray__Seu7uK9aaOSN0BK3EAjjSHw T288_;
		NimStringV2 T289_;
		nimZeroMem((void*)(&xX60gensym1318__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
		nimZeroMem((void*)(&yX60gensym1318__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
		aX60gensym1318__1.len = 0; aX60gensym1318__1.p = NIM_NIL;
		tmpX60gensym1318__1.len = 0; tmpX60gensym1318__1.p = NIM_NIL;
		bX60gensym1318__1.len = 0; bX60gensym1318__1.p = NIM_NIL;
		tmp2X60gensym1318__1.len = 0; tmp2X60gensym1318__1.p = NIM_NIL;
		nimZeroMem((void*)(&xX60gensym1318__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
		nimZeroMem((void*)(&yX60gensym1318__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
		useMagic__jsgen_u1172(p_p0, TM__BxLwT0mhrtgTPodf1v3xjg_558);
		if (NIM_UNLIKELY(*nimErr_)) goto LA287_;
		gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], (&xX60gensym1318__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA287_;
		gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)2)], (&yX60gensym1318__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA287_;
		aX60gensym1318__1 = rdLoc__jsgen_u593((&xX60gensym1318__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA287_;
		tmpX60gensym1318__1 = rdLoc__jsgen_u593((&xX60gensym1318__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA287_;
		bX60gensym1318__1 = rdLoc__jsgen_u593((&yX60gensym1318__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA287_;
		tmp2X60gensym1318__1 = rdLoc__jsgen_u593((&yX60gensym1318__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA287_;
		T288_[0] = aX60gensym1318__1;
		T288_[1] = bX60gensym1318__1;
		T288_[2] = tmpX60gensym1318__1;
		T288_[3] = tmp2X60gensym1318__1;
		T289_.len = 0; T289_.p = NIM_NIL;
		T289_ = percent___jsgen_u6231(T288_, 4);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T289_); goto LA287_;}
		eqsink___system_u2700((&(*r_p2).res), T289_);
		(*r_p2).kind = ((tyEnum_TResKind__UiCSai1lX4RMkJ9bHo9aP2HA)1);
		{
			LA287_:;
		}
		{
			eqdestroy___system_u2691(tmp2X60gensym1318__1);
			eqdestroy___system_u2691(bX60gensym1318__1);
			eqdestroy___system_u2691(tmpX60gensym1318__1);
			eqdestroy___system_u2691(aX60gensym1318__1);
			eqdestroy___jsgen_u570((&yX60gensym1318__1));
			eqdestroy___jsgen_u570((&xX60gensym1318__1));
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)120):
	{
		tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ xX60gensym1323__1;
		tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ yX60gensym1323__1;
		NimStringV2 aX60gensym1323__1;
		NimStringV2 tmpX60gensym1323__1;
		NimStringV2 bX60gensym1323__1;
		NimStringV2 tmp2X60gensym1323__1;
		tyArray__Seu7uK9aaOSN0BK3EAjjSHw T294_;
		NimStringV2 T295_;
		nimZeroMem((void*)(&xX60gensym1323__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
		nimZeroMem((void*)(&yX60gensym1323__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
		aX60gensym1323__1.len = 0; aX60gensym1323__1.p = NIM_NIL;
		tmpX60gensym1323__1.len = 0; tmpX60gensym1323__1.p = NIM_NIL;
		bX60gensym1323__1.len = 0; bX60gensym1323__1.p = NIM_NIL;
		tmp2X60gensym1323__1.len = 0; tmp2X60gensym1323__1.p = NIM_NIL;
		nimZeroMem((void*)(&xX60gensym1323__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
		nimZeroMem((void*)(&yX60gensym1323__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
		useMagic__jsgen_u1172(p_p0, TM__BxLwT0mhrtgTPodf1v3xjg_560);
		if (NIM_UNLIKELY(*nimErr_)) goto LA293_;
		gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], (&xX60gensym1323__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA293_;
		gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)2)], (&yX60gensym1323__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA293_;
		aX60gensym1323__1 = rdLoc__jsgen_u593((&xX60gensym1323__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA293_;
		tmpX60gensym1323__1 = rdLoc__jsgen_u593((&xX60gensym1323__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA293_;
		bX60gensym1323__1 = rdLoc__jsgen_u593((&yX60gensym1323__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA293_;
		tmp2X60gensym1323__1 = rdLoc__jsgen_u593((&yX60gensym1323__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA293_;
		T294_[0] = aX60gensym1323__1;
		T294_[1] = bX60gensym1323__1;
		T294_[2] = tmpX60gensym1323__1;
		T294_[3] = tmp2X60gensym1323__1;
		T295_.len = 0; T295_.p = NIM_NIL;
		T295_ = percent___jsgen_u6256(T294_, 4);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T295_); goto LA293_;}
		eqsink___system_u2700((&(*r_p2).res), T295_);
		(*r_p2).kind = ((tyEnum_TResKind__UiCSai1lX4RMkJ9bHo9aP2HA)1);
		{
			LA293_:;
		}
		{
			eqdestroy___system_u2691(tmp2X60gensym1323__1);
			eqdestroy___system_u2691(bX60gensym1323__1);
			eqdestroy___system_u2691(tmpX60gensym1323__1);
			eqdestroy___system_u2691(aX60gensym1323__1);
			eqdestroy___jsgen_u570((&yX60gensym1323__1));
			eqdestroy___jsgen_u570((&xX60gensym1323__1));
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)121):
	{
		tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ xX60gensym1328__1;
		tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ yX60gensym1328__1;
		NimStringV2 aX60gensym1328__1;
		NimStringV2 tmpX60gensym1328__1;
		NimStringV2 bX60gensym1328__1;
		NimStringV2 tmp2X60gensym1328__1;
		tyArray__Seu7uK9aaOSN0BK3EAjjSHw T300_;
		NimStringV2 T301_;
		nimZeroMem((void*)(&xX60gensym1328__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
		nimZeroMem((void*)(&yX60gensym1328__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
		aX60gensym1328__1.len = 0; aX60gensym1328__1.p = NIM_NIL;
		tmpX60gensym1328__1.len = 0; tmpX60gensym1328__1.p = NIM_NIL;
		bX60gensym1328__1.len = 0; bX60gensym1328__1.p = NIM_NIL;
		tmp2X60gensym1328__1.len = 0; tmp2X60gensym1328__1.p = NIM_NIL;
		nimZeroMem((void*)(&xX60gensym1328__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
		nimZeroMem((void*)(&yX60gensym1328__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
		useMagic__jsgen_u1172(p_p0, TM__BxLwT0mhrtgTPodf1v3xjg_562);
		if (NIM_UNLIKELY(*nimErr_)) goto LA299_;
		gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], (&xX60gensym1328__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA299_;
		gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)2)], (&yX60gensym1328__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA299_;
		aX60gensym1328__1 = rdLoc__jsgen_u593((&xX60gensym1328__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA299_;
		tmpX60gensym1328__1 = rdLoc__jsgen_u593((&xX60gensym1328__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA299_;
		bX60gensym1328__1 = rdLoc__jsgen_u593((&yX60gensym1328__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA299_;
		tmp2X60gensym1328__1 = rdLoc__jsgen_u593((&yX60gensym1328__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA299_;
		T300_[0] = aX60gensym1328__1;
		T300_[1] = bX60gensym1328__1;
		T300_[2] = tmpX60gensym1328__1;
		T300_[3] = tmp2X60gensym1328__1;
		T301_.len = 0; T301_.p = NIM_NIL;
		T301_ = percent___jsgen_u6281(T300_, 4);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T301_); goto LA299_;}
		eqsink___system_u2700((&(*r_p2).res), T301_);
		(*r_p2).kind = ((tyEnum_TResKind__UiCSai1lX4RMkJ9bHo9aP2HA)1);
		{
			LA299_:;
		}
		{
			eqdestroy___system_u2691(tmp2X60gensym1328__1);
			eqdestroy___system_u2691(bX60gensym1328__1);
			eqdestroy___system_u2691(tmpX60gensym1328__1);
			eqdestroy___system_u2691(aX60gensym1328__1);
			eqdestroy___jsgen_u570((&yX60gensym1328__1));
			eqdestroy___jsgen_u570((&xX60gensym1328__1));
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)122):
	{
		tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ xX60gensym1333__1;
		tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ yX60gensym1333__1;
		NimStringV2 aX60gensym1333__1;
		NimStringV2 tmpX60gensym1333__1;
		NimStringV2 bX60gensym1333__1;
		NimStringV2 tmp2X60gensym1333__1;
		tyArray__Seu7uK9aaOSN0BK3EAjjSHw T306_;
		NimStringV2 T307_;
		nimZeroMem((void*)(&xX60gensym1333__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
		nimZeroMem((void*)(&yX60gensym1333__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
		aX60gensym1333__1.len = 0; aX60gensym1333__1.p = NIM_NIL;
		tmpX60gensym1333__1.len = 0; tmpX60gensym1333__1.p = NIM_NIL;
		bX60gensym1333__1.len = 0; bX60gensym1333__1.p = NIM_NIL;
		tmp2X60gensym1333__1.len = 0; tmp2X60gensym1333__1.p = NIM_NIL;
		nimZeroMem((void*)(&xX60gensym1333__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
		nimZeroMem((void*)(&yX60gensym1333__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
		useMagic__jsgen_u1172(p_p0, TM__BxLwT0mhrtgTPodf1v3xjg_564);
		if (NIM_UNLIKELY(*nimErr_)) goto LA305_;
		gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], (&xX60gensym1333__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA305_;
		gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)2)], (&yX60gensym1333__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA305_;
		aX60gensym1333__1 = rdLoc__jsgen_u593((&xX60gensym1333__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA305_;
		tmpX60gensym1333__1 = rdLoc__jsgen_u593((&xX60gensym1333__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA305_;
		bX60gensym1333__1 = rdLoc__jsgen_u593((&yX60gensym1333__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA305_;
		tmp2X60gensym1333__1 = rdLoc__jsgen_u593((&yX60gensym1333__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA305_;
		T306_[0] = aX60gensym1333__1;
		T306_[1] = bX60gensym1333__1;
		T306_[2] = tmpX60gensym1333__1;
		T306_[3] = tmp2X60gensym1333__1;
		T307_.len = 0; T307_.p = NIM_NIL;
		T307_ = percent___jsgen_u6306(T306_, 4);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T307_); goto LA305_;}
		eqsink___system_u2700((&(*r_p2).res), T307_);
		(*r_p2).kind = ((tyEnum_TResKind__UiCSai1lX4RMkJ9bHo9aP2HA)1);
		{
			LA305_:;
		}
		{
			eqdestroy___system_u2691(tmp2X60gensym1333__1);
			eqdestroy___system_u2691(bX60gensym1333__1);
			eqdestroy___system_u2691(tmpX60gensym1333__1);
			eqdestroy___system_u2691(aX60gensym1333__1);
			eqdestroy___jsgen_u570((&yX60gensym1333__1));
			eqdestroy___jsgen_u570((&xX60gensym1333__1));
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)40):
	{
		tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ xX60gensym1338__1;
		tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ yX60gensym1338__1;
		NimStringV2 aX60gensym1338__1;
		NimStringV2 tmpX60gensym1338__1;
		NimStringV2 bX60gensym1338__1;
		NimStringV2 tmp2X60gensym1338__1;
		tyArray__Seu7uK9aaOSN0BK3EAjjSHw T312_;
		NimStringV2 T313_;
		nimZeroMem((void*)(&xX60gensym1338__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
		nimZeroMem((void*)(&yX60gensym1338__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
		aX60gensym1338__1.len = 0; aX60gensym1338__1.p = NIM_NIL;
		tmpX60gensym1338__1.len = 0; tmpX60gensym1338__1.p = NIM_NIL;
		bX60gensym1338__1.len = 0; bX60gensym1338__1.p = NIM_NIL;
		tmp2X60gensym1338__1.len = 0; tmp2X60gensym1338__1.p = NIM_NIL;
		nimZeroMem((void*)(&xX60gensym1338__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
		nimZeroMem((void*)(&yX60gensym1338__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
		useMagic__jsgen_u1172(p_p0, TM__BxLwT0mhrtgTPodf1v3xjg_565);
		if (NIM_UNLIKELY(*nimErr_)) goto LA311_;
		gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], (&xX60gensym1338__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA311_;
		gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)2)], (&yX60gensym1338__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA311_;
		aX60gensym1338__1 = rdLoc__jsgen_u593((&xX60gensym1338__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA311_;
		tmpX60gensym1338__1 = rdLoc__jsgen_u593((&xX60gensym1338__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA311_;
		bX60gensym1338__1 = rdLoc__jsgen_u593((&yX60gensym1338__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA311_;
		tmp2X60gensym1338__1 = rdLoc__jsgen_u593((&yX60gensym1338__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA311_;
		T312_[0] = aX60gensym1338__1;
		T312_[1] = bX60gensym1338__1;
		T312_[2] = tmpX60gensym1338__1;
		T312_[3] = tmp2X60gensym1338__1;
		T313_.len = 0; T313_.p = NIM_NIL;
		T313_ = percent___jsgen_u6331(T312_, 4);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T313_); goto LA311_;}
		eqsink___system_u2700((&(*r_p2).res), T313_);
		(*r_p2).kind = ((tyEnum_TResKind__UiCSai1lX4RMkJ9bHo9aP2HA)1);
		{
			LA311_:;
		}
		{
			eqdestroy___system_u2691(tmp2X60gensym1338__1);
			eqdestroy___system_u2691(bX60gensym1338__1);
			eqdestroy___system_u2691(tmpX60gensym1338__1);
			eqdestroy___system_u2691(aX60gensym1338__1);
			eqdestroy___jsgen_u570((&yX60gensym1338__1));
			eqdestroy___jsgen_u570((&xX60gensym1338__1));
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)41):
	{
		tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ xX60gensym1343__1;
		tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ yX60gensym1343__1;
		NimStringV2 aX60gensym1343__1;
		NimStringV2 tmpX60gensym1343__1;
		NimStringV2 bX60gensym1343__1;
		NimStringV2 tmp2X60gensym1343__1;
		tyArray__Seu7uK9aaOSN0BK3EAjjSHw T318_;
		NimStringV2 T319_;
		nimZeroMem((void*)(&xX60gensym1343__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
		nimZeroMem((void*)(&yX60gensym1343__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
		aX60gensym1343__1.len = 0; aX60gensym1343__1.p = NIM_NIL;
		tmpX60gensym1343__1.len = 0; tmpX60gensym1343__1.p = NIM_NIL;
		bX60gensym1343__1.len = 0; bX60gensym1343__1.p = NIM_NIL;
		tmp2X60gensym1343__1.len = 0; tmp2X60gensym1343__1.p = NIM_NIL;
		nimZeroMem((void*)(&xX60gensym1343__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
		nimZeroMem((void*)(&yX60gensym1343__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
		useMagic__jsgen_u1172(p_p0, TM__BxLwT0mhrtgTPodf1v3xjg_566);
		if (NIM_UNLIKELY(*nimErr_)) goto LA317_;
		gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], (&xX60gensym1343__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA317_;
		gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)2)], (&yX60gensym1343__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA317_;
		aX60gensym1343__1 = rdLoc__jsgen_u593((&xX60gensym1343__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA317_;
		tmpX60gensym1343__1 = rdLoc__jsgen_u593((&xX60gensym1343__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA317_;
		bX60gensym1343__1 = rdLoc__jsgen_u593((&yX60gensym1343__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA317_;
		tmp2X60gensym1343__1 = rdLoc__jsgen_u593((&yX60gensym1343__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA317_;
		T318_[0] = aX60gensym1343__1;
		T318_[1] = bX60gensym1343__1;
		T318_[2] = tmpX60gensym1343__1;
		T318_[3] = tmp2X60gensym1343__1;
		T319_.len = 0; T319_.p = NIM_NIL;
		T319_ = percent___jsgen_u6356(T318_, 4);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T319_); goto LA317_;}
		eqsink___system_u2700((&(*r_p2).res), T319_);
		(*r_p2).kind = ((tyEnum_TResKind__UiCSai1lX4RMkJ9bHo9aP2HA)1);
		{
			LA317_:;
		}
		{
			eqdestroy___system_u2691(tmp2X60gensym1343__1);
			eqdestroy___system_u2691(bX60gensym1343__1);
			eqdestroy___system_u2691(tmpX60gensym1343__1);
			eqdestroy___system_u2691(aX60gensym1343__1);
			eqdestroy___jsgen_u570((&yX60gensym1343__1));
			eqdestroy___jsgen_u570((&xX60gensym1343__1));
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)132):
	{
		tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ xX60gensym1348__1;
		tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ yX60gensym1348__1;
		NimStringV2 aX60gensym1348__1;
		NimStringV2 tmpX60gensym1348__1;
		NimStringV2 bX60gensym1348__1;
		NimStringV2 tmp2X60gensym1348__1;
		tyArray__Seu7uK9aaOSN0BK3EAjjSHw T324_;
		NimStringV2 T325_;
		nimZeroMem((void*)(&xX60gensym1348__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
		nimZeroMem((void*)(&yX60gensym1348__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
		aX60gensym1348__1.len = 0; aX60gensym1348__1.p = NIM_NIL;
		tmpX60gensym1348__1.len = 0; tmpX60gensym1348__1.p = NIM_NIL;
		bX60gensym1348__1.len = 0; bX60gensym1348__1.p = NIM_NIL;
		tmp2X60gensym1348__1.len = 0; tmp2X60gensym1348__1.p = NIM_NIL;
		nimZeroMem((void*)(&xX60gensym1348__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
		nimZeroMem((void*)(&yX60gensym1348__1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
		useMagic__jsgen_u1172(p_p0, TM__BxLwT0mhrtgTPodf1v3xjg_567);
		if (NIM_UNLIKELY(*nimErr_)) goto LA323_;
		gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], (&xX60gensym1348__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA323_;
		gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)2)], (&yX60gensym1348__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA323_;
		aX60gensym1348__1 = rdLoc__jsgen_u593((&xX60gensym1348__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA323_;
		tmpX60gensym1348__1 = rdLoc__jsgen_u593((&xX60gensym1348__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA323_;
		bX60gensym1348__1 = rdLoc__jsgen_u593((&yX60gensym1348__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA323_;
		tmp2X60gensym1348__1 = rdLoc__jsgen_u593((&yX60gensym1348__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA323_;
		T324_[0] = aX60gensym1348__1;
		T324_[1] = bX60gensym1348__1;
		T324_[2] = tmpX60gensym1348__1;
		T324_[3] = tmp2X60gensym1348__1;
		T325_.len = 0; T325_.p = NIM_NIL;
		T325_ = percent___jsgen_u6381(T324_, 4);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T325_); goto LA323_;}
		eqsink___system_u2700((&(*r_p2).res), T325_);
		(*r_p2).kind = ((tyEnum_TResKind__UiCSai1lX4RMkJ9bHo9aP2HA)1);
		{
			LA323_:;
		}
		{
			eqdestroy___system_u2691(tmp2X60gensym1348__1);
			eqdestroy___system_u2691(bX60gensym1348__1);
			eqdestroy___system_u2691(tmpX60gensym1348__1);
			eqdestroy___system_u2691(aX60gensym1348__1);
			eqdestroy___jsgen_u570((&yX60gensym1348__1));
			eqdestroy___jsgen_u570((&xX60gensym1348__1));
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)34):
	{
		genNewSeq__jsgen_u5226(p_p0, n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)35):
	{
		NimStringV2 aX60gensym1353__1;
		NimStringV2 tmpX60gensym1353__1;
		tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T336_;
		NimStringV2 T337_;
		aX60gensym1353__1.len = 0; aX60gensym1353__1.p = NIM_NIL;
		tmpX60gensym1353__1.len = 0; tmpX60gensym1353__1.p = NIM_NIL;
		useMagic__jsgen_u1172(p_p0, TM__BxLwT0mhrtgTPodf1v3xjg_568);
		if (NIM_UNLIKELY(*nimErr_)) goto LA330_;
		gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], r_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA330_;
		aX60gensym1353__1 = rdLoc__jsgen_u593((&(*r_p2)));
		if (NIM_UNLIKELY(*nimErr_)) goto LA330_;
		tmpX60gensym1353__1 = rdLoc__jsgen_u593((&(*r_p2)));
		if (NIM_UNLIKELY(*nimErr_)) goto LA330_;
		{
			NIM_BOOL T333_;
			tyTuple__UV3llMMYFckfui8YMBuUZA tmpTupleAsgn_13;
			T333_ = (NIM_BOOL)0;
			T333_ = contains__pureZstrutils_u1833(TM__BxLwT0mhrtgTPodf1v3xjg_569, TM__BxLwT0mhrtgTPodf1v3xjg_570);
			if (NIM_UNLIKELY(*nimErr_)) goto LA330_;
			if (!T333_) goto LA334_;
			nimZeroMem((void*)(&tmpTupleAsgn_13), sizeof(tyTuple__UV3llMMYFckfui8YMBuUZA));
			maybeMakeTemp__jsgen_u1365(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], (&(*r_p2)), (&tmpTupleAsgn_13));
			if (NIM_UNLIKELY(*nimErr_)) goto LA330_;
			eqsink___system_u2700((&aX60gensym1353__1), tmpTupleAsgn_13.Field0);
			eqsink___system_u2700((&tmpX60gensym1353__1), tmpTupleAsgn_13.Field1);
		}
LA334_: ;
		T336_[0] = aX60gensym1353__1;
		T336_[1] = tmpX60gensym1353__1;
		T337_.len = 0; T337_.p = NIM_NIL;
		T337_ = percent___jsgen_u6391(T336_, 2);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T337_); goto LA330_;}
		eqsink___system_u2700((&(*r_p2).res), T337_);
		(*r_p2).kind = ((tyEnum_TResKind__UiCSai1lX4RMkJ9bHo9aP2HA)1);
		{
			LA330_:;
		}
		{
			eqdestroy___system_u2691(tmpX60gensym1353__1);
			eqdestroy___system_u2691(aX60gensym1353__1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)15):
	{
		genOf__jsgen_u5353(p_p0, n_p1, r_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)154):
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)277):
	{
		genDefault__jsgen_u5381(p_p0, n_p1, r_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)150):
	{
		genWasMoved__jsgen_u5385(p_p0, n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)20):
	{
		genEcho__jsgen_u4620(p_p0, n_p1, r_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)213) ... ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)259):
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)22):
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)23):
	{
		NimStringV2 colontmpD__21;
		colontmpD__21.len = 0; colontmpD__21.p = NIM_NIL;
		colontmpD__21 = nsuFormatSingleElem(TM__BxLwT0mhrtgTPodf1v3xjg_584, (*(*(*(*n_p1)._kind_6.sons.p->data[((NI)0)])._kind_4.sym).name).s);
		if (NIM_UNLIKELY(*nimErr_)) goto LA345_;
		liMessage__msgs_u1227((*(*p_p0).module).config, (*n_p1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), colontmpD__21, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__BxLwT0mhrtgTPodf1v3xjg_585), NIM_FALSE, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA345_;
		{
			LA345_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__21);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)145):
	{
		NimStringV2 aX60gensym1361__1;
		NimStringV2 tmpX60gensym1361__1;
		tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T355_;
		NimStringV2 T356_;
		aX60gensym1361__1.len = 0; aX60gensym1361__1.p = NIM_NIL;
		tmpX60gensym1361__1.len = 0; tmpX60gensym1361__1.p = NIM_NIL;
		useMagic__jsgen_u1172(p_p0, TM__BxLwT0mhrtgTPodf1v3xjg_586);
		if (NIM_UNLIKELY(*nimErr_)) goto LA349_;
		gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], r_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA349_;
		aX60gensym1361__1 = rdLoc__jsgen_u593((&(*r_p2)));
		if (NIM_UNLIKELY(*nimErr_)) goto LA349_;
		tmpX60gensym1361__1 = rdLoc__jsgen_u593((&(*r_p2)));
		if (NIM_UNLIKELY(*nimErr_)) goto LA349_;
		{
			NIM_BOOL T352_;
			tyTuple__UV3llMMYFckfui8YMBuUZA tmpTupleAsgn_14;
			T352_ = (NIM_BOOL)0;
			T352_ = contains__pureZstrutils_u1833(TM__BxLwT0mhrtgTPodf1v3xjg_588, TM__BxLwT0mhrtgTPodf1v3xjg_589);
			if (NIM_UNLIKELY(*nimErr_)) goto LA349_;
			if (!T352_) goto LA353_;
			nimZeroMem((void*)(&tmpTupleAsgn_14), sizeof(tyTuple__UV3llMMYFckfui8YMBuUZA));
			maybeMakeTemp__jsgen_u1365(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], (&(*r_p2)), (&tmpTupleAsgn_14));
			if (NIM_UNLIKELY(*nimErr_)) goto LA349_;
			eqsink___system_u2700((&aX60gensym1361__1), tmpTupleAsgn_14.Field0);
			eqsink___system_u2700((&tmpX60gensym1361__1), tmpTupleAsgn_14.Field1);
		}
LA353_: ;
		T355_[0] = aX60gensym1361__1;
		T355_[1] = tmpX60gensym1361__1;
		T356_.len = 0; T356_.p = NIM_NIL;
		T356_ = percent___jsgen_u6401(T355_, 2);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T356_); goto LA349_;}
		eqsink___system_u2700((&(*r_p2).res), T356_);
		(*r_p2).kind = ((tyEnum_TResKind__UiCSai1lX4RMkJ9bHo9aP2HA)1);
		{
			LA349_:;
		}
		{
			eqdestroy___system_u2691(tmpX60gensym1361__1);
			eqdestroy___system_u2691(aX60gensym1361__1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)146):
	{
		NimStringV2 aX60gensym1365__1;
		NimStringV2 tmpX60gensym1365__1;
		tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T366_;
		NimStringV2 T367_;
		aX60gensym1365__1.len = 0; aX60gensym1365__1.p = NIM_NIL;
		tmpX60gensym1365__1.len = 0; tmpX60gensym1365__1.p = NIM_NIL;
		useMagic__jsgen_u1172(p_p0, TM__BxLwT0mhrtgTPodf1v3xjg_590);
		if (NIM_UNLIKELY(*nimErr_)) goto LA360_;
		gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], r_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA360_;
		aX60gensym1365__1 = rdLoc__jsgen_u593((&(*r_p2)));
		if (NIM_UNLIKELY(*nimErr_)) goto LA360_;
		tmpX60gensym1365__1 = rdLoc__jsgen_u593((&(*r_p2)));
		if (NIM_UNLIKELY(*nimErr_)) goto LA360_;
		{
			NIM_BOOL T363_;
			tyTuple__UV3llMMYFckfui8YMBuUZA tmpTupleAsgn_15;
			T363_ = (NIM_BOOL)0;
			T363_ = contains__pureZstrutils_u1833(TM__BxLwT0mhrtgTPodf1v3xjg_592, TM__BxLwT0mhrtgTPodf1v3xjg_593);
			if (NIM_UNLIKELY(*nimErr_)) goto LA360_;
			if (!T363_) goto LA364_;
			nimZeroMem((void*)(&tmpTupleAsgn_15), sizeof(tyTuple__UV3llMMYFckfui8YMBuUZA));
			maybeMakeTemp__jsgen_u1365(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], (&(*r_p2)), (&tmpTupleAsgn_15));
			if (NIM_UNLIKELY(*nimErr_)) goto LA360_;
			eqsink___system_u2700((&aX60gensym1365__1), tmpTupleAsgn_15.Field0);
			eqsink___system_u2700((&tmpX60gensym1365__1), tmpTupleAsgn_15.Field1);
		}
LA364_: ;
		T366_[0] = aX60gensym1365__1;
		T366_[1] = tmpX60gensym1365__1;
		T367_.len = 0; T367_.p = NIM_NIL;
		T367_ = percent___jsgen_u6411(T366_, 2);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T367_); goto LA360_;}
		eqsink___system_u2700((&(*r_p2).res), T367_);
		(*r_p2).kind = ((tyEnum_TResKind__UiCSai1lX4RMkJ9bHo9aP2HA)1);
		{
			LA360_:;
		}
		{
			eqdestroy___system_u2691(tmpX60gensym1365__1);
			eqdestroy___system_u2691(aX60gensym1365__1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)125):
	{
		genProcForSymIfNeeded__jsgen_u4084(p_p0, (*(*n_p1)._kind_6.sons.p->data[((NI)0)])._kind_4.sym);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		genCall__jsgen_u4598(p_p0, n_p1, r_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)147):
	{
		useMagic__jsgen_u1172(p_p0, TM__BxLwT0mhrtgTPodf1v3xjg_595);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		genCall__jsgen_u4598(p_p0, n_p1, r_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)124):
	{
		tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ x_7;
		tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ y_3;
		tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ z_1;
		NimStringV2 colontmpD__22;
		NimStringV2 colontmpD__23;
		NimStringV2 colontmpD__24;
		tyArray__dyW7vpmfeTYw8kX3EXuaJA T374_;
		NimStringV2 T375_;
		nimZeroMem((void*)(&x_7), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
		nimZeroMem((void*)(&y_3), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
		nimZeroMem((void*)(&z_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
		colontmpD__22.len = 0; colontmpD__22.p = NIM_NIL;
		colontmpD__23.len = 0; colontmpD__23.p = NIM_NIL;
		colontmpD__24.len = 0; colontmpD__24.p = NIM_NIL;
		nimZeroMem((void*)(&x_7), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
		nimZeroMem((void*)(&y_3), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
		nimZeroMem((void*)(&z_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
		gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], (&x_7));
		if (NIM_UNLIKELY(*nimErr_)) goto LA373_;
		gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)2)], (&y_3));
		if (NIM_UNLIKELY(*nimErr_)) goto LA373_;
		gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)3)], (&z_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA373_;
		colontmpD__22 = rdLoc__jsgen_u593((&x_7));
		if (NIM_UNLIKELY(*nimErr_)) goto LA373_;
		T374_[0] = colontmpD__22;
		colontmpD__23 = rdLoc__jsgen_u593((&y_3));
		if (NIM_UNLIKELY(*nimErr_)) goto LA373_;
		T374_[1] = colontmpD__23;
		colontmpD__24 = rdLoc__jsgen_u593((&z_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA373_;
		T374_[2] = colontmpD__24;
		T375_.len = 0; T375_.p = NIM_NIL;
		T375_ = percent___jsgen_u6431(T374_, 3);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T375_); goto LA373_;}
		eqsink___system_u2700((&(*r_p2).res), T375_);
		(*r_p2).kind = ((tyEnum_TResKind__UiCSai1lX4RMkJ9bHo9aP2HA)1);
		{
			LA373_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__24);
			eqdestroy___system_u2691(colontmpD__23);
			eqdestroy___system_u2691(colontmpD__22);
			eqdestroy___jsgen_u570((&z_1));
			eqdestroy___jsgen_u570((&y_3));
			eqdestroy___jsgen_u570((&x_7));
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)148):
	{
		genMove__jsgen_u5413(p_p0, n_p1, r_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)151):
	{
		genDup__jsgen_u5426(p_p0, n_p1, r_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)149):
	{
		gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], r_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	default:
	{
		genCall__jsgen_u4598(p_p0, n_p1, r_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genOtherArg__jsgen_u4489)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, NI i_p2, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p3, NI* generated_p4, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* r_p5) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* it_1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* paramType_1;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	it_1 = NIM_NIL;
	paramType_1 = NIM_NIL;
	{
		NI T4_;
		NimStringV2 colontmpD_;
		NimStringV2 colontmpD__2;
		NimStringV2 colontmpD__3;
		NimStringV2 T8_;
		NI T9_;
		T4_ = (NI)0;
		T4_ = len__ast_u3190(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!(T4_ <= i_p2)) goto LA5_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
		T8_.len = 0; T8_.p = NIM_NIL;
		colontmpD_ = dollar___systemZdollars_u9(i_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		T9_ = (NI)0;
		T9_ = len__ast_u3190(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		colontmpD__2 = dollar___systemZdollars_u9((NI)(T9_ - ((NI)1)));
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		T8_ = rawNewString(colontmpD_.len + colontmpD__2.len + 71);
appendString((&T8_), TM__BxLwT0mhrtgTPodf1v3xjg_600);
appendString((&T8_), colontmpD_);
appendString((&T8_), TM__BxLwT0mhrtgTPodf1v3xjg_602);
appendString((&T8_), colontmpD__2);
		colontmpD__3 = T8_;
		liMessage__msgs_u1227((*(*p_p0).module).config, (*n_p1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), colontmpD__3, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)2), (&TM__BxLwT0mhrtgTPodf1v3xjg_603), NIM_FALSE, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		{
			LA7_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__3);
			eqdestroy___system_u2691(colontmpD__2);
			eqdestroy___system_u2691(colontmpD_);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA5_: ;
	eqcopy___ast_u3255(&it_1, (*n_p1)._kind_6.sons.p->data[i_p2]);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	paramType_1 = ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL);
	{
		NI T14_;
		T14_ = (NI)0;
		T14_ = len__ast_u5502(typ_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!(i_p2 < T14_)) goto LA15_;
		eqcopy___ast_u3255(&paramType_1, (*(*typ_p3).n)._kind_6.sons.p->data[i_p2]);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		{
			NIM_BOOL T19_;
			T19_ = (NIM_BOOL)0;
			T19_ = isCompileTimeOnly__types_u3655((*paramType_1).typField);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			if (!T19_) goto LA20_;
			eqdestroy___ast_u3252(paramType_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			eqdestroy___ast_u3252(it_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			goto BeforeRet_;
		}
LA20_: ;
	}
LA15_: ;
	{
		if (!(paramType_1 == 0)) goto LA24_;
		genArgNoParam__jsgen_u4373(p_p0, it_1, r_p5);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA22_;
LA24_: ;
	{
		genArg__jsgen_u4386(p_p0, it_1, (*paramType_1)._kind_4.sym, r_p5, ((NI*) NIM_NIL));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA22_: ;
	(*generated_p4) += ((NI)1);
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3252(paramType_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3252(it_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genPatternCall__jsgen_u4513)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, NimStringV2 pat_p2, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p3, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* r_p4) {
	NI i_1;
	NI j_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	i_1 = ((NI)0);
	j_1 = ((NI)1);
	(*r_p4).kind = ((tyEnum_TResKind__UiCSai1lX4RMkJ9bHo9aP2HA)1);
	{
		while (1) {
			if (!(i_1 < pat_p2.len)) goto LA2;
			switch (((NU8)(pat_p2.p->data[i_1]))) {
			case 64:
			{
				NI generated_1;
				generated_1 = ((NI)0);
				{
					NI k_1;
					NI colontmp_;
					NI i_2;
					k_1 = (NI)0;
					colontmp_ = (NI)0;
					colontmp_ = len__ast_u3190(n_p1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					i_2 = j_1;
					{
						while (1) {
							if (!(i_2 < colontmp_)) goto LA6;
							k_1 = i_2;
							{
								if (!(((NI)0) < generated_1)) goto LA9_;
								prepareAdd((&(*r_p4).res), 2);
appendString((&(*r_p4).res), TM__BxLwT0mhrtgTPodf1v3xjg_598);
							}
LA9_: ;
							genOtherArg__jsgen_u4489(p_p0, n_p1, k_1, typ_p3, (&generated_1), r_p4);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
							i_2 += ((NI)1);
						} LA6: ;
					}
				}
				i_1 += ((NI)1);
			}
			break;
			case 35:
			{
				NI generated_2;
				generated_2 = ((NI)0);
				genOtherArg__jsgen_u4489(p_p0, n_p1, j_1, typ_p3, (&generated_2), r_p4);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				j_1 += ((NI)1);
				i_1 += ((NI)1);
			}
			break;
			case 31:
			{
				prepareAdd((&(*r_p4).res), 1);
appendString((&(*r_p4).res), TM__BxLwT0mhrtgTPodf1v3xjg_605);
				i_1 += ((NI)1);
			}
			break;
			case 29:
			{
				prepareAdd((&(*r_p4).res), 1);
appendString((&(*r_p4).res), TM__BxLwT0mhrtgTPodf1v3xjg_607);
				i_1 += ((NI)1);
			}
			break;
			default:
			{
				NI start_1;
				start_1 = i_1;
				{
					while (1) {
						if (!(i_1 < pat_p2.len)) goto LA16;
						{
							if (!!((((NU8)(pat_p2.p->data[i_1])) == ((NU8)(64)) || ((NU8)(pat_p2.p->data[i_1])) == ((NU8)(35)) || ((NU8)(pat_p2.p->data[i_1])) == ((NU8)(31)) || ((NU8)(pat_p2.p->data[i_1])) == ((NU8)(29))))) goto LA19_;
							i_1 += ((NI)1);
						}
						goto LA17_;
LA19_: ;
						{
							goto LA15;
						}
LA17_: ;
					} LA16: ;
				} LA15: ;
				{
					NimStringV2 colontmpD_;
					if (!(start_1 <= (NI)(i_1 - ((NI)1)))) goto LA24_;
					colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
					colontmpD_ = substr__system_u8654(pat_p2, start_1, (NI)(i_1 - ((NI)1)));
					prepareAdd((&(*r_p4).res), colontmpD_.len + 0);
appendString((&(*r_p4).res), colontmpD_);
					eqdestroy___system_u2691(colontmpD_);
				}
LA24_: ;
			}
			break;
			}
		} LA2: ;
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genInfixCall__jsgen_u4563)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* r_p2) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* f_1;
	tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ op_1;
NIM_BOOL oldNimErrFin24_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	f_1 = NIM_NIL;
	nimZeroMem((void*)(&op_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
	eqcopy___ast_u4577(&f_1, (*(*n_p1)._kind_6.sons.p->data[((NI)0)])._kind_4.sym);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NimStringV2 T6_;
		if (!((*f_1).loc.snippet.len == 0)) goto LA4_;
		T6_.len = 0; T6_.p = NIM_NIL;
		T6_ = mangleName__jsgen_u702((*p_p0).module, f_1);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T6_); goto LA1_;}
		eqsink___system_u2700((&(*f_1).loc.snippet), T6_);
	}
LA4_: ;
	{
		NimStringV2 pat_1;
		if (!(((*f_1).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)32)))&63U)))!=0)) goto LA9_;
		pat_1.len = 0; pat_1.p = NIM_NIL;
		eqcopy___system_u2694((&pat_1), (*(*(*n_p1)._kind_6.sons.p->data[((NI)0)])._kind_4.sym).loc.snippet);
		{
			NimStringV2 argX60gensym959__1;
			if (!!((((NI)0) < pat_1.len))) goto LA14_;
			argX60gensym959__1.len = 0; argX60gensym959__1.p = NIM_NIL;
			argX60gensym959__1 = toFileLineCol__msgs_u701((&TM__BxLwT0mhrtgTPodf1v3xjg_596));
			if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
			internalErrorImpl__msgs_u1598((*(*p_p0).module).config, unknownLineInfo__lineinfos_u364, argX60gensym959__1, (&TM__BxLwT0mhrtgTPodf1v3xjg_596));
			if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
			{
				LA16_:;
			}
			{
				eqdestroy___system_u2691(argX60gensym959__1);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
		}
LA14_: ;
		{
			NIM_BOOL T21_;
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_1;
			T21_ = (NIM_BOOL)0;
			T21_ = contains__pureZstrutils_u1837(pat_1, TM__BxLwT0mhrtgTPodf1v3xjg_597);
			if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
			if (!T21_) goto LA22_;
			typ_1 = NIM_NIL;
			typ_1 = skipTypes__ast_u5379((*(*n_p1)._kind_6.sons.p->data[((NI)0)]).typField, TM__BxLwT0mhrtgTPodf1v3xjg_175);
			if (NIM_UNLIKELY(*nimErr_)) goto LA24_;
			genPatternCall__jsgen_u4513(p_p0, n_p1, pat_1, typ_1, r_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA24_;
			eqdestroy___ast_u3378(typ_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
			eqdestroy___system_u2691(pat_1);
			eqdestroy___jsgen_u570((&op_1));
			eqdestroy___ast_u4574(f_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			goto BeforeRet_;
			{
				LA24_:;
			}
			{
				oldNimErrFin24_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u3378(typ_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
				*nimErr_ = oldNimErrFin24_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
		}
LA22_: ;
		{
			LA11_:;
		}
		{
			eqdestroy___system_u2691(pat_1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA9_: ;
	{
		NI T31_;
		T31_ = (NI)0;
		T31_ = len__ast_u3190(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!!((T31_ == ((NI)1)))) goto LA32_;
		gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], r_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		{
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T42_;
			NimStringV2 T43_;
			if (!((*r_p2).typ == ((tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)9))) goto LA36_;
			{
				if (!((*r_p2).address.len == 0)) goto LA40_;
				liMessage__msgs_u1227((*(*p_p0).module).config, (*n_p1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), TM__BxLwT0mhrtgTPodf1v3xjg_609, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)2), (&TM__BxLwT0mhrtgTPodf1v3xjg_610), NIM_FALSE, NIM_FALSE);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
LA40_: ;
			T42_[0] = (*r_p2).address;
			T42_[1] = (*r_p2).res;
			T43_.len = 0; T43_.p = NIM_NIL;
			T43_ = percent___cgen_u9083(T42_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T43_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T43_);
			eqsink___system_u2700((&(*r_p2).address), TM__BxLwT0mhrtgTPodf1v3xjg_611);
			(*r_p2).typ = ((tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)0);
		}
LA36_: ;
		prepareAdd((&(*r_p2).res), 1);
appendString((&(*r_p2).res), TM__BxLwT0mhrtgTPodf1v3xjg_613);
	}
LA32_: ;
	nimZeroMem((void*)(&op_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
	gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)0)], (&op_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&(*r_p2).res), op_1.res.len + 0);
appendString((&(*r_p2).res), op_1.res);
	genArgs__jsgen_u4449(p_p0, n_p1, r_p2, ((NI)2));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___jsgen_u570((&op_1));
		eqdestroy___ast_u4574(f_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genSetConstr__jsgen_u6436)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* r_p2) {
	tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ a_1;
	tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ b_1;
NIM_BOOL oldNimErrFin5_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&a_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
	nimZeroMem((void*)(&b_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
	nimZeroMem((void*)(&a_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
	nimZeroMem((void*)(&b_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
	useMagic__jsgen_u1172(p_p0, TM__BxLwT0mhrtgTPodf1v3xjg_615);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	eqsink___system_u2700((&(*r_p2).res), TM__BxLwT0mhrtgTPodf1v3xjg_617);
	(*r_p2).kind = ((tyEnum_TResKind__UiCSai1lX4RMkJ9bHo9aP2HA)1);
	{
		NI i_1;
		NI colontmp_;
		NI i_2;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_u3190(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		i_2 = ((NI)0);
		{
			while (1) {
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* it_1;
				if (!(i_2 < colontmp_)) goto LA4;
				it_1 = NIM_NIL;
				i_1 = i_2;
				{
					if (!(((NI)0) < i_1)) goto LA8_;
					prepareAdd((&(*r_p2).res), 2);
appendString((&(*r_p2).res), TM__BxLwT0mhrtgTPodf1v3xjg_618);
				}
LA8_: ;
				eqcopy___ast_u3255(&it_1, (*n_p1)._kind_6.sons.p->data[i_1]);
				if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
				{
					if (!((*it_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)44))) goto LA12_;
					gen__jsgen_u1159(p_p0, (*it_1)._kind_6.sons.p->data[((NI)0)], (&a_1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
					gen__jsgen_u1159(p_p0, (*it_1)._kind_6.sons.p->data[((NI)1)], (&b_1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
					{
						NimStringV2 colontmpD_;
						tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T18_;
						if (!((*(*(*it_1)._kind_6.sons.p->data[((NI)0)]).typField).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)1))) goto LA16_;
						colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
						T18_[0] = a_1.res;
						T18_[1] = b_1.res;
						colontmpD_ = percent___cgen_u14643(T18_, 2);
						if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
						prepareAdd((&(*r_p2).res), colontmpD_.len + 0);
appendString((&(*r_p2).res), colontmpD_);
						eqdestroy___system_u2691(colontmpD_);
					}
					goto LA14_;
LA16_: ;
					{
						NimStringV2 colontmpD__2;
						tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T20_;
						colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
						T20_[0] = a_1.res;
						T20_[1] = b_1.res;
						colontmpD__2 = percent___jsgen_u873(T20_, 2);
						if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
						prepareAdd((&(*r_p2).res), colontmpD__2.len + 0);
appendString((&(*r_p2).res), colontmpD__2);
						eqdestroy___system_u2691(colontmpD__2);
					}
LA14_: ;
				}
				goto LA10_;
LA12_: ;
				{
					gen__jsgen_u1159(p_p0, it_1, (&a_1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
					prepareAdd((&(*r_p2).res), a_1.res.len + 0);
appendString((&(*r_p2).res), a_1.res);
				}
LA10_: ;
				i_2 += ((NI)1);
				{
					LA5_:;
				}
				{
					oldNimErrFin5_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3252(it_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin5_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			} LA4: ;
		}
	}
	prepareAdd((&(*r_p2).res), 1);
appendString((&(*r_p2).res), TM__BxLwT0mhrtgTPodf1v3xjg_619);
	{
		NIM_BOOL T26_;
		NimStringV2 tmp_1;
		NimStringV2 colontmpD__3;
		NimStringV2 colontmpD__4;
		NimStringV2 T29_;
		tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T30_;
		T26_ = (NIM_BOOL)0;
		T26_ = isDeepConstExpr__trees_u153(n_p1, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!T26_) goto LA27_;
		tmp_1.len = 0; tmp_1.p = NIM_NIL;
		colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
		colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
		(*(*p_p0).g).unique += ((NI)1);
		T29_.len = 0; T29_.p = NIM_NIL;
		colontmpD__3 = rope__ropes_u15(((NI64) ((*(*p_p0).g).unique)));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T29_ = rawNewString(colontmpD__3.len + 8);
appendString((&T29_), TM__BxLwT0mhrtgTPodf1v3xjg_621);
appendString((&T29_), colontmpD__3);
		tmp_1 = T29_;
		T30_[0] = tmp_1;
		T30_[1] = (*r_p2).res;
		colontmpD__4 = percent___jsgen_u3818(T30_, 2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		prepareAdd((&(*(*p_p0).g).constants), colontmpD__4.len + 0);
appendString((&(*(*p_p0).g).constants), colontmpD__4);
		eqsink___system_u2700((&(*r_p2).res), tmp_1);
		eqdestroy___system_u2691(colontmpD__4);
		eqdestroy___system_u2691(colontmpD__3);
	}
LA27_: ;
	{
		LA1_:;
	}
	{
		eqdestroy___jsgen_u570((&b_1));
		eqdestroy___jsgen_u570((&a_1));
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genArrayConstr__jsgen_u6482)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* r_p2) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* e_1;
	NimStringV2 jsTyp_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	t_1 = NIM_NIL;
	e_1 = NIM_NIL;
	jsTyp_1.len = 0; jsTyp_1.p = NIM_NIL;
	colontmpD_ = NIM_NIL;
	t_1 = skipTypes__ast_u5379((*n_p1).typField, TM__BxLwT0mhrtgTPodf1v3xjg_175);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	e_1 = elemType__types_u254(t_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	jsTyp_1 = arrayTypeForElemType__jsgen_u4808((*(*p_p0).module).config, e_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NIM_BOOL T4_;
		tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ a_1;
		tyArray__YgExxhfgKcesA5EOUj1MOA T9_;
		NimStringV2 T10_;
		T4_ = (NIM_BOOL)0;
		colontmpD_ = skipTypes__ast_u5379((*n_p1).typField, TM__BxLwT0mhrtgTPodf1v3xjg_358);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T4_ = !(((*colontmpD_).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)24)));
		if (!(T4_)) goto LA5_;
		T4_ = (((NI)0) < jsTyp_1.len);
LA5_: ;
		if (!T4_) goto LA6_;
		nimZeroMem((void*)(&a_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
		nimZeroMem((void*)(&a_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
		T9_[0] = jsTyp_1;
		T10_.len = 0; T10_.p = NIM_NIL;
		T10_ = percent___jsgen_u6498(T9_, 1);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T10_); goto LA8_;}
		eqsink___system_u2700((&(*r_p2).res), T10_);
		(*r_p2).kind = ((tyEnum_TResKind__UiCSai1lX4RMkJ9bHo9aP2HA)1);
		{
			NI i_1;
			NI colontmp_;
			NI i_2;
			i_1 = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__ast_u3190(n_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
			i_2 = ((NI)0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA13;
					i_1 = i_2;
					{
						if (!(((NI)0) < i_1)) goto LA16_;
						prepareAdd((&(*r_p2).res), 2);
appendString((&(*r_p2).res), TM__BxLwT0mhrtgTPodf1v3xjg_622);
					}
LA16_: ;
					gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[i_1], (&a_1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
					prepareAdd((&(*r_p2).res), a_1.res.len + 0);
appendString((&(*r_p2).res), a_1.res);
					i_2 += ((NI)1);
				} LA13: ;
			}
		}
		prepareAdd((&(*r_p2).res), 2);
appendString((&(*r_p2).res), TM__BxLwT0mhrtgTPodf1v3xjg_624);
		{
			LA8_:;
		}
		{
			eqdestroy___jsgen_u570((&a_1));
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA2_;
LA6_: ;
	{
		genJSArrayConstr__jsgen_u5439(p_p0, n_p1, r_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA2_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___system_u2691(jsTyp_1);
		eqdestroy___ast_u3378(e_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(t_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genTupleConstr__jsgen_u6508)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* r_p2) {
	tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ a_1;
NIM_BOOL oldNimErrFin5_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&a_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
	nimZeroMem((void*)(&a_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
	eqsink___system_u2700((&(*r_p2).res), TM__BxLwT0mhrtgTPodf1v3xjg_625);
	(*r_p2).kind = ((tyEnum_TResKind__UiCSai1lX4RMkJ9bHo9aP2HA)1);
	{
		NI i_1;
		NI colontmp_;
		NI i_2;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_u3190(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		i_2 = ((NI)0);
		{
			while (1) {
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* it_1;
				tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_1;
				if (!(i_2 < colontmp_)) goto LA4;
				it_1 = NIM_NIL;
				typ_1 = NIM_NIL;
				i_1 = i_2;
				{
					if (!(((NI)0) < i_1)) goto LA8_;
					prepareAdd((&(*r_p2).res), 2);
appendString((&(*r_p2).res), TM__BxLwT0mhrtgTPodf1v3xjg_626);
				}
LA8_: ;
				eqcopy___ast_u3255(&it_1, (*n_p1)._kind_6.sons.p->data[i_1]);
				if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
				{
					if (!((*it_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)34))) goto LA12_;
					eqcopy___ast_u3255(&it_1, (*it_1)._kind_6.sons.p->data[((NI)1)]);
					if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
				}
LA12_: ;
				gen__jsgen_u1159(p_p0, it_1, (&a_1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
				typ_1 = skipTypes__ast_u5379((*it_1).typField, TM__BxLwT0mhrtgTPodf1v3xjg_175);
				if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
				{
					NimStringV2 colontmpD_;
					NimStringV2 colontmpD__2;
					tyArray__dyW7vpmfeTYw8kX3EXuaJA T18_;
					if (!(a_1.typ == ((tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)9))) goto LA16_;
					colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
					colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
					colontmpD_ = rope__ropes_u15(((NI64) (i_1)));
					if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
					T18_[0] = colontmpD_;
					T18_[1] = a_1.address;
					T18_[2] = a_1.res;
					colontmpD__2 = percent___jsgen_u6532(T18_, 3);
					if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
					prepareAdd((&(*r_p2).res), colontmpD__2.len + 0);
appendString((&(*r_p2).res), colontmpD__2);
					eqdestroy___system_u2691(colontmpD__2);
					eqdestroy___system_u2691(colontmpD_);
				}
				goto LA14_;
LA16_: ;
				{
					NimStringV2 colontmpD__3;
					NimStringV2 colontmpD__4;
					tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T31_;
					colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
					colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
					{
						NIM_BOOL T23_;
						NimStringV2 colontmpD__5;
						NimStringV2 colontmpD__6;
						tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T27_;
						NimStringV2 T28_;
						T23_ = (NIM_BOOL)0;
						T23_ = needsNoCopy__jsgen_u3374(p_p0, it_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA20_;
						if (!!(T23_)) goto LA24_;
						colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
						colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
						useMagic__jsgen_u1172(p_p0, TM__BxLwT0mhrtgTPodf1v3xjg_627);
						if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
						colontmpD__5 = rdLoc__jsgen_u593((&a_1));
						if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
						T27_[0] = colontmpD__5;
						colontmpD__6 = genTypeInfo__jsgen_u828(p_p0, typ_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
						T27_[1] = colontmpD__6;
						T28_.len = 0; T28_.p = NIM_NIL;
						T28_ = percent___jsgen_u5021(T27_, 2);
						if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T28_); goto LA26_;}
						eqsink___system_u2700((&a_1.res), T28_);
						{
							LA26_:;
						}
						{
							eqdestroy___system_u2691(colontmpD__6);
							eqdestroy___system_u2691(colontmpD__5);
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA20_;
					}
LA24_: ;
					colontmpD__3 = rope__ropes_u15(((NI64) (i_1)));
					if (NIM_UNLIKELY(*nimErr_)) goto LA20_;
					T31_[0] = colontmpD__3;
					T31_[1] = a_1.res;
					colontmpD__4 = percent___jsgen_u6541(T31_, 2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA20_;
					prepareAdd((&(*r_p2).res), colontmpD__4.len + 0);
appendString((&(*r_p2).res), colontmpD__4);
					{
						LA20_:;
					}
					{
						eqdestroy___system_u2691(colontmpD__4);
						eqdestroy___system_u2691(colontmpD__3);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
				}
LA14_: ;
				i_2 += ((NI)1);
				{
					LA5_:;
				}
				{
					oldNimErrFin5_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3378(typ_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___ast_u3252(it_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin5_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			} LA4: ;
		}
	}
	prepareAdd((&(*r_p2).res), 1);
appendString((&(*r_p2).res), TM__BxLwT0mhrtgTPodf1v3xjg_628);
	{
		LA1_:;
	}
	{
		eqdestroy___jsgen_u570((&a_1));
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genObjConstr__jsgen_u6546)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* r_p2) {
	tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ a_1;
	NimStringV2 initList_1;
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA fieldIDs_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* nTyp_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_1;
NIM_BOOL oldNimErrFin5_;
	tyArray__YgExxhfgKcesA5EOUj1MOA T44_;
	NimStringV2 T45_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&a_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
	initList_1.len = 0; initList_1.p = NIM_NIL;
	nimZeroMem((void*)(&fieldIDs_1), sizeof(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA));
	nTyp_1 = NIM_NIL;
	t_1 = NIM_NIL;
	nimZeroMem((void*)(&a_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
	(*r_p2).kind = ((tyEnum_TResKind__UiCSai1lX4RMkJ9bHo9aP2HA)1);
	initList_1 = TM__BxLwT0mhrtgTPodf1v3xjg_629;
	initIntSet__pureZcollectionsZintsets_u598((&fieldIDs_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	nTyp_1 = skipTypes__ast_u5379((*n_p1).typField, TM__BxLwT0mhrtgTPodf1v3xjg_175);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NI i_1;
		NI colontmp_;
		NI i_2;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_u3190(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		i_2 = ((NI)1);
		{
			while (1) {
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* it_1;
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* val_1;
				tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* f_1;
				tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
				tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD__2;
				tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_1;
				tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA xX60gensym1410__1;
				if (!(i_2 < colontmp_)) goto LA4;
				it_1 = NIM_NIL;
				val_1 = NIM_NIL;
				f_1 = NIM_NIL;
				colontmpD_ = NIM_NIL;
				colontmpD__2 = NIM_NIL;
				typ_1 = NIM_NIL;
				i_1 = i_2;
				{
					if (!(((NI)1) < i_1)) goto LA8_;
					prepareAdd((&initList_1), 2);
appendString((&initList_1), TM__BxLwT0mhrtgTPodf1v3xjg_630);
				}
LA8_: ;
				eqcopy___ast_u3255(&it_1, (*n_p1)._kind_6.sons.p->data[i_1]);
				if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
				{
					NimStringV2 argX60gensym1404__1;
					if (!!(((*it_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)34)))) goto LA12_;
					argX60gensym1404__1.len = 0; argX60gensym1404__1.p = NIM_NIL;
					argX60gensym1404__1 = toFileLineCol__msgs_u701((&TM__BxLwT0mhrtgTPodf1v3xjg_631));
					if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
					internalErrorImpl__msgs_u1598((*(*p_p0).module).config, unknownLineInfo__lineinfos_u364, argX60gensym1404__1, (&TM__BxLwT0mhrtgTPodf1v3xjg_631));
					if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
					{
						LA14_:;
					}
					{
						eqdestroy___system_u2691(argX60gensym1404__1);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
				}
LA12_: ;
				eqcopy___ast_u3255(&val_1, (*it_1)._kind_6.sons.p->data[((NI)1)]);
				if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
				gen__jsgen_u1159(p_p0, val_1, (&a_1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
				eqcopy___ast_u4577(&f_1, (*(*it_1)._kind_6.sons.p->data[((NI)0)])._kind_4.sym);
				if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
				{
					NimStringV2 T21_;
					if (!((*f_1).loc.snippet.len == 0)) goto LA19_;
					T21_.len = 0; T21_.p = NIM_NIL;
					T21_ = mangleName__jsgen_u702((*p_p0).module, f_1);
					if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T21_); goto LA5_;}
					eqsink___system_u2700((&(*f_1).loc.snippet), T21_);
				}
LA19_: ;
				colontmpD_ = skipTypes__ast_u5379((*n_p1).typField, TM__BxLwT0mhrtgTPodf1v3xjg_632);
				if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
				colontmpD__2 = lookupFieldAgain__types_u4208(colontmpD_, f_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
				xX60gensym1410__1 = (*colontmpD__2).itemId;
				incl__pureZcollectionsZintsets_u366((&fieldIDs_1), (NI)((NI)((NU64)(((NI) (xX60gensym1410__1.module))) << (NU64)(((NI)24) & (64 - 1))) + ((NI) (xX60gensym1410__1.item))));
				if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
				typ_1 = skipTypes__ast_u5379((*val_1).typField, TM__BxLwT0mhrtgTPodf1v3xjg_175);
				if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
				{
					NimStringV2 colontmpD__3;
					tyArray__dyW7vpmfeTYw8kX3EXuaJA T26_;
					if (!(a_1.typ == ((tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)9))) goto LA24_;
					colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
					T26_[0] = (*f_1).loc.snippet;
					T26_[1] = a_1.address;
					T26_[2] = a_1.res;
					colontmpD__3 = percent___jsgen_u6646(T26_, 3);
					if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
					prepareAdd((&initList_1), colontmpD__3.len + 0);
appendString((&initList_1), colontmpD__3);
					eqdestroy___system_u2691(colontmpD__3);
				}
				goto LA22_;
LA24_: ;
				{
					NimStringV2 colontmpD__4;
					tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T39_;
					colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
					{
						NIM_BOOL T31_;
						NimStringV2 colontmpD__5;
						NimStringV2 colontmpD__6;
						tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T35_;
						NimStringV2 T36_;
						T31_ = (NIM_BOOL)0;
						T31_ = needsNoCopy__jsgen_u3374(p_p0, val_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA28_;
						if (!!(T31_)) goto LA32_;
						colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
						colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
						useMagic__jsgen_u1172(p_p0, TM__BxLwT0mhrtgTPodf1v3xjg_633);
						if (NIM_UNLIKELY(*nimErr_)) goto LA34_;
						colontmpD__5 = rdLoc__jsgen_u593((&a_1));
						if (NIM_UNLIKELY(*nimErr_)) goto LA34_;
						T35_[0] = colontmpD__5;
						colontmpD__6 = genTypeInfo__jsgen_u828(p_p0, typ_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA34_;
						T35_[1] = colontmpD__6;
						T36_.len = 0; T36_.p = NIM_NIL;
						T36_ = percent___jsgen_u5021(T35_, 2);
						if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T36_); goto LA34_;}
						eqsink___system_u2700((&a_1.res), T36_);
						{
							LA34_:;
						}
						{
							eqdestroy___system_u2691(colontmpD__6);
							eqdestroy___system_u2691(colontmpD__5);
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA28_;
					}
LA32_: ;
					T39_[0] = (*f_1).loc.snippet;
					T39_[1] = a_1.res;
					colontmpD__4 = percent___jsgen_u6655(T39_, 2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA28_;
					prepareAdd((&initList_1), colontmpD__4.len + 0);
appendString((&initList_1), colontmpD__4);
					{
						LA28_:;
					}
					{
						eqdestroy___system_u2691(colontmpD__4);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
				}
LA22_: ;
				i_2 += ((NI)1);
				{
					LA5_:;
				}
				{
					oldNimErrFin5_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3378(typ_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___ast_u4574(colontmpD__2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___ast_u3378(colontmpD_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___ast_u4574(f_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___ast_u3252(val_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___ast_u3252(it_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin5_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			} LA4: ;
		}
	}
	t_1 = skipTypes__ast_u5379((*n_p1).typField, TM__BxLwT0mhrtgTPodf1v3xjg_634);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	createObjInitList__jsgen_u4793(p_p0, t_1, (&fieldIDs_1), (&initList_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T44_[0] = initList_1;
	T45_.len = 0; T45_.p = NIM_NIL;
	T45_ = percent___jsgen_u6665(T44_, 1);
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T45_); goto LA1_;}
	eqsink___system_u2700((&(*r_p2).res), T45_);
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(t_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(nTyp_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___pureZcollectionsZintsets_u230((&fieldIDs_1));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___system_u2691(initList_1);
		eqdestroy___jsgen_u570((&a_1));
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(NIM_BOOL, contains__semfold_u1019)(tyObject_HSlice__Td0KDtM8kU0p7CVwrbJeww s_p0, tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg value_p1) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	T1_ = (NIM_BOOL)0;
	T1_ = (s_p0.a <= value_p1);
	if (!(T1_)) goto LA2_;
	T1_ = (value_p1 <= s_p0.b);
LA2_: ;
	result = T1_;
	return result;
}
static N_INLINE(tyObject_HSlice__Td0KDtM8kU0p7CVwrbJeww, dotdot___semfold_u987)(tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg a_p0, tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg b_p1) {
	tyObject_HSlice__Td0KDtM8kU0p7CVwrbJeww result;
	result.a = a_p0;
	result.b = b_p1;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genConv__jsgen_u6670)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* r_p2) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* dest_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* src_1;
	NIM_BOOL toInt_1;
	tyObject_HSlice__Td0KDtM8kU0p7CVwrbJeww T6_;
	NIM_BOOL fromInt_1;
	tyObject_HSlice__Td0KDtM8kU0p7CVwrbJeww T7_;
	NIM_BOOL toUint_1;
	tyObject_HSlice__Td0KDtM8kU0p7CVwrbJeww T8_;
	NIM_BOOL fromUint_1;
	tyObject_HSlice__Td0KDtM8kU0p7CVwrbJeww T9_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	dest_1 = NIM_NIL;
	src_1 = NIM_NIL;
	dest_1 = skipTypes__ast_u5379((*n_p1).typField, TM__BxLwT0mhrtgTPodf1v3xjg_358);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	src_1 = skipTypes__ast_u5379((*(*n_p1)._kind_6.sons.p->data[((NI)1)]).typField, TM__BxLwT0mhrtgTPodf1v3xjg_358);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], r_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		if (!((*dest_1).kind == (*src_1).kind)) goto LA4_;
		eqdestroy___ast_u3378(src_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(dest_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		goto BeforeRet_;
	}
LA4_: ;
	T6_ = dotdot___semfold_u987(((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)31), ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)34));
	toInt_1 = contains__semfold_u1019(T6_, (*dest_1).kind);
	T7_ = dotdot___semfold_u987(((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)31), ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)34));
	fromInt_1 = contains__semfold_u1019(T7_, (*src_1).kind);
	T8_ = dotdot___semfold_u987(((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)40), ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)43));
	toUint_1 = contains__semfold_u1019(T8_, (*dest_1).kind);
	T9_ = dotdot___semfold_u987(((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)40), ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)43));
	fromUint_1 = contains__semfold_u1019(T9_, (*src_1).kind);
	{
		NIM_BOOL T12_;
		NIM_BOOL T14_;
		NimStringV2 trimmer_1;
		tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T18_;
		NimStringV2 T19_;
		T12_ = (NIM_BOOL)0;
		T12_ = toUint_1;
		if (!(T12_)) goto LA13_;
		T14_ = (NIM_BOOL)0;
		T14_ = fromInt_1;
		if (T14_) goto LA15_;
		T14_ = fromUint_1;
LA15_: ;
		T12_ = T14_;
LA13_: ;
		if (!T12_) goto LA16_;
		trimmer_1.len = 0; trimmer_1.p = NIM_NIL;
		trimmer_1 = unsignedTrimmer__jsgen_u1494((*dest_1).size);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T18_[0] = (*r_p2).res;
		T18_[1] = trimmer_1;
		T19_.len = 0; T19_.p = NIM_NIL;
		T19_ = percent___jsgen_u6949(T18_, 2);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T19_); goto LA1_;}
		eqsink___system_u2700((&(*r_p2).res), T19_);
		eqdestroy___system_u2691(trimmer_1);
	}
	goto LA10_;
LA16_: ;
	{
		tyArray__YgExxhfgKcesA5EOUj1MOA T23_;
		NimStringV2 T24_;
		if (!((*dest_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)1))) goto LA21_;
		T23_[0] = (*r_p2).res;
		T24_.len = 0; T24_.p = NIM_NIL;
		T24_ = percent___jsgen_u6958(T23_, 1);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T24_); goto LA1_;}
		eqsink___system_u2700((&(*r_p2).res), T24_);
		(*r_p2).kind = ((tyEnum_TResKind__UiCSai1lX4RMkJ9bHo9aP2HA)1);
	}
	goto LA10_;
LA21_: ;
	{
		if (!toInt_1) goto LA26_;
		{
			NIM_BOOL T30_;
			tyArray__YgExxhfgKcesA5EOUj1MOA T34_;
			NimStringV2 T35_;
			T30_ = (NIM_BOOL)0;
			T30_ = ((*src_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)35) || (*src_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)44));
			if (!(T30_)) goto LA31_;
			T30_ = (((*(*(*p_p0).module).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)56)))&63U)))!=0);
LA31_: ;
			if (!T30_) goto LA32_;
			T34_[0] = (*r_p2).res;
			T35_.len = 0; T35_.p = NIM_NIL;
			T35_ = percent___jsgen_u5262(T34_, 1);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T35_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T35_);
		}
		goto LA28_;
LA32_: ;
		{
			tyArray__YgExxhfgKcesA5EOUj1MOA T37_;
			NimStringV2 T38_;
			T37_[0] = (*r_p2).res;
			T38_.len = 0; T38_.p = NIM_NIL;
			T38_ = percent___jsgen_u6975(T37_, 1);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T38_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T38_);
		}
LA28_: ;
	}
	goto LA10_;
LA26_: ;
	{
		NIM_BOOL T40_;
		T40_ = (NIM_BOOL)0;
		T40_ = ((*dest_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)35));
		if (!(T40_)) goto LA41_;
		T40_ = (((*(*(*p_p0).module).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)56)))&63U)))!=0);
LA41_: ;
		if (!T40_) goto LA42_;
		{
			NIM_BOOL T46_;
			NIM_BOOL T47_;
			tyArray__YgExxhfgKcesA5EOUj1MOA T52_;
			NimStringV2 T53_;
			T46_ = (NIM_BOOL)0;
			T47_ = (NIM_BOOL)0;
			T47_ = fromInt_1;
			if (T47_) goto LA48_;
			T47_ = fromUint_1;
LA48_: ;
			T46_ = T47_;
			if (T46_) goto LA49_;
			T46_ = ((*src_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)1) || (*src_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)2) || (*src_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)14));
LA49_: ;
			if (!T46_) goto LA50_;
			T52_[0] = (*r_p2).res;
			T53_.len = 0; T53_.p = NIM_NIL;
			T53_ = percent___jsgen_u6992(T52_, 1);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T53_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T53_);
		}
		goto LA44_;
LA50_: ;
		{
			tyArray__YgExxhfgKcesA5EOUj1MOA T57_;
			NimStringV2 T58_;
			if (!((*src_1).kind >= ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)36) && (*src_1).kind <= ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)38))) goto LA55_;
			T57_[0] = (*r_p2).res;
			T58_.len = 0; T58_.p = NIM_NIL;
			T58_ = percent___jsgen_u7001(T57_, 1);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T58_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T58_);
		}
		goto LA44_;
LA55_: ;
		{
			tyArray__YgExxhfgKcesA5EOUj1MOA T62_;
			NimStringV2 T63_;
			if (!((*src_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)44))) goto LA60_;
			T62_[0] = (*r_p2).res;
			T63_.len = 0; T63_.p = NIM_NIL;
			T63_ = percent___jsgen_u7010(T62_, 1);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T63_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T63_);
		}
		goto LA44_;
LA60_: ;
LA44_: ;
	}
	goto LA10_;
LA42_: ;
	{
		NIM_BOOL T65_;
		T65_ = (NIM_BOOL)0;
		T65_ = ((*dest_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)44));
		if (!(T65_)) goto LA66_;
		T65_ = (((*(*(*p_p0).module).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)56)))&63U)))!=0);
LA66_: ;
		if (!T65_) goto LA67_;
		{
			NIM_BOOL T71_;
			tyArray__YgExxhfgKcesA5EOUj1MOA T75_;
			NimStringV2 T76_;
			T71_ = (NIM_BOOL)0;
			T71_ = fromUint_1;
			if (T71_) goto LA72_;
			T71_ = ((*src_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)1) || (*src_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)2) || (*src_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)14));
LA72_: ;
			if (!T71_) goto LA73_;
			T75_[0] = (*r_p2).res;
			T76_.len = 0; T76_.p = NIM_NIL;
			T76_ = percent___jsgen_u6992(T75_, 1);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T76_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T76_);
		}
		goto LA69_;
LA73_: ;
		{
			tyArray__YgExxhfgKcesA5EOUj1MOA T80_;
			NimStringV2 T81_;
			if (!fromInt_1) goto LA78_;
			T80_[0] = (*r_p2).res;
			T81_.len = 0; T81_.p = NIM_NIL;
			T81_ = percent___jsgen_u7031(T80_, 1);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T81_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T81_);
		}
		goto LA69_;
LA78_: ;
		{
			tyArray__YgExxhfgKcesA5EOUj1MOA T85_;
			NimStringV2 T86_;
			if (!((*src_1).kind >= ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)36) && (*src_1).kind <= ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)38))) goto LA83_;
			T85_[0] = (*r_p2).res;
			T86_.len = 0; T86_.p = NIM_NIL;
			T86_ = percent___jsgen_u7040(T85_, 1);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T86_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T86_);
		}
		goto LA69_;
LA83_: ;
		{
			tyArray__YgExxhfgKcesA5EOUj1MOA T90_;
			NimStringV2 T91_;
			if (!((*src_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)35))) goto LA88_;
			T90_[0] = (*r_p2).res;
			T91_.len = 0; T91_.p = NIM_NIL;
			T91_ = percent___jsgen_u7049(T90_, 1);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T91_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T91_);
		}
		goto LA69_;
LA88_: ;
LA69_: ;
	}
	goto LA10_;
LA67_: ;
	{
		NIM_BOOL T93_;
		tyObject_HSlice__Td0KDtM8kU0p7CVwrbJeww T95_;
		T93_ = (NIM_BOOL)0;
		T93_ = toUint_1;
		if (T93_) goto LA94_;
		T95_ = dotdot___semfold_u987(((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)36), ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)38));
		T93_ = contains__semfold_u1019(T95_, (*dest_1).kind);
LA94_: ;
		if (!T93_) goto LA96_;
		{
			NIM_BOOL T100_;
			tyArray__YgExxhfgKcesA5EOUj1MOA T104_;
			NimStringV2 T105_;
			T100_ = (NIM_BOOL)0;
			T100_ = ((*src_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)35) || (*src_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)44));
			if (!(T100_)) goto LA101_;
			T100_ = (((*(*(*p_p0).module).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)56)))&63U)))!=0);
LA101_: ;
			if (!T100_) goto LA102_;
			T104_[0] = (*r_p2).res;
			T105_.len = 0; T105_.p = NIM_NIL;
			T105_ = percent___jsgen_u5262(T104_, 1);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T105_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T105_);
		}
LA102_: ;
	}
	goto LA10_;
LA96_: ;
	{
	}
LA10_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(src_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(dest_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genSymAddr__jsgen_u3939)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p2, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* r_p3) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_1;
NIM_BOOL oldNimErrFin8_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	s_1 = NIM_NIL;
	eqcopy___ast_u4577(&s_1, (*n_p1)._kind_4.sym);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		if (!((*s_1).loc.snippet.len == 0)) goto LA4_;
		internalErrorImpl__msgs_u1598((*(*p_p0).module).config, (*n_p1).info, TM__BxLwT0mhrtgTPodf1v3xjg_636, (&TM__BxLwT0mhrtgTPodf1v3xjg_637));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA4_: ;
	switch ((*s_1).kind) {
	case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)3):
	{
		eqcopy___system_u2694((&(*r_p3).res), (*s_1).loc.snippet);
		eqsink___system_u2700((&(*r_p3).address), TM__BxLwT0mhrtgTPodf1v3xjg_638);
		(*r_p3).typ = ((tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)0);
	}
	break;
	case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)8):
	case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)9):
	case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)11):
	case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)5):
	case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)21):
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__2;
		tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg jsType_1;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* T9_;
		colontmpD_ = NIM_NIL;
		colontmpD__2 = NIM_NIL;
		(*r_p3).kind = ((tyEnum_TResKind__UiCSai1lX4RMkJ9bHo9aP2HA)1);
		T9_ = NIM_NIL;
		{
			if (!(typ_p2 == 0)) goto LA12_;
			eqcopy___ast_u3381(&colontmpD_, (*n_p1).typField);
			if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
			T9_ = colontmpD_;
		}
		goto LA10_;
LA12_: ;
		{
			eqcopy___ast_u3381(&colontmpD__2, typ_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
			T9_ = colontmpD__2;
		}
LA10_: ;
		jsType_1 = mapType__jsgen_u698(p_p0, T9_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		{
			tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* vX60gensym811__1;
			if (!(jsType_1 == ((tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)8))) goto LA17_;
			vX60gensym811__1 = NIM_NIL;
			(*r_p3).typ = ((tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)0);
			{
				NIM_BOOL T21_;
				NIM_BOOL T22_;
				tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg T23_;
				tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg T25_;
				NimStringV2 T29_;
				vX60gensym811__1 = s_1;
				T21_ = (NIM_BOOL)0;
				T22_ = (NIM_BOOL)0;
				T23_ = 0;
				T22_ = !(((131080 & (*vX60gensym811__1).flags) == T23_));
				if (!(T22_)) goto LA24_;
				T25_ = 0;
				T22_ = ((192 & (*vX60gensym811__1).flags) == T25_);
LA24_: ;
				T21_ = T22_;
				if (!(T21_)) goto LA26_;
				T21_ = !(((*vX60gensym811__1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)12) || (*vX60gensym811__1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)13) || (*vX60gensym811__1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)16) || (*vX60gensym811__1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)14) || (*vX60gensym811__1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)15) || (*vX60gensym811__1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)10) || (*vX60gensym811__1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)5) || (*vX60gensym811__1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)9)));
LA26_: ;
				if (!T21_) goto LA27_;
				T29_.len = 0; T29_.p = NIM_NIL;
				T29_ = rawNewString((*s_1).loc.snippet.len + 3);
appendString((&T29_), (*s_1).loc.snippet);
appendString((&T29_), TM__BxLwT0mhrtgTPodf1v3xjg_640);
				eqsink___system_u2700((&(*r_p3).res), T29_);
			}
			goto LA19_;
LA27_: ;
			{
				eqcopy___system_u2694((&(*r_p3).res), (*s_1).loc.snippet);
			}
LA19_: ;
			eqsink___system_u2700((&(*r_p3).address), TM__BxLwT0mhrtgTPodf1v3xjg_641);
		}
		goto LA15_;
LA17_: ;
		{
			NIM_BOOL T32_;
			tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg T33_;
			T32_ = (NIM_BOOL)0;
			T33_ = 0;
			T32_ = !(((131080 & (*s_1).flags) == T33_));
			if (T32_) goto LA34_;
			T32_ = (jsType_1 == ((tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)9));
LA34_: ;
			if (!T32_) goto LA35_;
			(*r_p3).typ = ((tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)9);
			eqcopy___system_u2694((&(*r_p3).address), (*s_1).loc.snippet);
			eqsink___system_u2700((&(*r_p3).res), TM__BxLwT0mhrtgTPodf1v3xjg_642);
		}
		goto LA15_;
LA35_: ;
		{
			gen__jsgen_u1159(p_p0, n_p1, r_p3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		}
LA15_: ;
		{
			LA8_:;
		}
		{
			oldNimErrFin8_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3378(colontmpD__2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___ast_u3378(colontmpD_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin8_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	default:
	{
		NimStringV2 colontmpD__3;
		tyTuple__RICk09aVWvF6a15iJKyZfFQ T42_;
		colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
		T42_.Field0 = TM__BxLwT0mhrtgTPodf1v3xjg_644;
		T42_.Field1 = (*s_1).kind;
		colontmpD__3 = dollar___jsgen_u3987(T42_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA41_;
		internalErrorImpl__msgs_u1598((*(*p_p0).module).config, (*n_p1).info, colontmpD__3, (&TM__BxLwT0mhrtgTPodf1v3xjg_645));
		if (NIM_UNLIKELY(*nimErr_)) goto LA41_;
		{
			LA41_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__3);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	}
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u4574(s_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genCheckedFieldOp__jsgen_u3769)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* addrTyp_p2, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* r_p3) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* accessExpr_1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* checkExpr_1;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* field_1;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* disc_1;
	tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ setx_1;
	tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ obj_1;
	NimStringV2 tmp_1;
	NimStringV2 colontmpD_;
	NimStringV2 colontmpD__2;
	NimStringV2 msg_1;
	NimStringV2 colontmpD__3;
	NimStringV2 colontmpD__4;
	NimStringV2 colontmpD__5;
	NimStringV2 colontmpD__6;
	NimStringV2 colontmpD__7;
	NimStringV2 colontmpD__8;
	NIM_BOOL negCheck_1;
	tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T38_;
	tyArray__A2YC0h9cZydgH7zGAndH9bLg T39_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	accessExpr_1 = NIM_NIL;
	checkExpr_1 = NIM_NIL;
	field_1 = NIM_NIL;
	disc_1 = NIM_NIL;
	nimZeroMem((void*)(&setx_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
	nimZeroMem((void*)(&obj_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
	tmp_1.len = 0; tmp_1.p = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	msg_1.len = 0; msg_1.p = NIM_NIL;
	colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
	colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
	colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
	colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
	colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
	colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
	{
		NimStringV2 argX60gensym765__1;
		if (!!(((*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)46)))) goto LA4_;
		argX60gensym765__1.len = 0; argX60gensym765__1.p = NIM_NIL;
		argX60gensym765__1 = toFileLineCol__msgs_u701((&TM__BxLwT0mhrtgTPodf1v3xjg_646));
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		internalErrorImpl__msgs_u1598((*(*p_p0).module).config, unknownLineInfo__lineinfos_u364, argX60gensym765__1, (&TM__BxLwT0mhrtgTPodf1v3xjg_646));
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		{
			LA6_:;
		}
		{
			eqdestroy___system_u2691(argX60gensym765__1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA4_: ;
	eqcopy___ast_u3255(&accessExpr_1, (*n_p1)._kind_6.sons.p->data[((NI)0)]);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	eqcopy___ast_u3255(&checkExpr_1, (*n_p1)._kind_6.sons.p->data[((NI)1)]);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	negCheck_1 = ((*(*(*checkExpr_1)._kind_6.sons.p->data[((NI)0)])._kind_4.sym).magic == ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)96));
	{
		NI T13_;
		if (!negCheck_1) goto LA11_;
		T13_ = (NI)0;
		T13_ = len__ast_u3190(checkExpr_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		eqcopy___ast_u3255(&checkExpr_1, (*checkExpr_1)._kind_6.sons.p->data[(NI)(T13_ - ((NI)1))]);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA11_: ;
	eqcopy___ast_u4577(&field_1, (*(*accessExpr_1)._kind_6.sons.p->data[((NI)1)])._kind_4.sym);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NimStringV2 argX60gensym775__1;
		if (!!(((*field_1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)19)))) goto LA16_;
		argX60gensym775__1.len = 0; argX60gensym775__1.p = NIM_NIL;
		argX60gensym775__1 = toFileLineCol__msgs_u701((&TM__BxLwT0mhrtgTPodf1v3xjg_647));
		if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
		internalErrorImpl__msgs_u1598((*(*p_p0).module).config, unknownLineInfo__lineinfos_u364, argX60gensym775__1, (&TM__BxLwT0mhrtgTPodf1v3xjg_647));
		if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
		{
			LA18_:;
		}
		{
			eqdestroy___system_u2691(argX60gensym775__1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA16_: ;
	{
		NimStringV2 T25_;
		if (!((*field_1).loc.snippet.len == 0)) goto LA23_;
		T25_.len = 0; T25_.p = NIM_NIL;
		T25_ = mangleName__jsgen_u702((*p_p0).module, field_1);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T25_); goto LA1_;}
		eqsink___system_u2700((&(*field_1).loc.snippet), T25_);
	}
LA23_: ;
	eqcopy___ast_u4577(&disc_1, (*(*checkExpr_1)._kind_6.sons.p->data[((NI)2)])._kind_4.sym);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NimStringV2 argX60gensym779__1;
		if (!!(((*disc_1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)19)))) goto LA28_;
		argX60gensym779__1.len = 0; argX60gensym779__1.p = NIM_NIL;
		argX60gensym779__1 = toFileLineCol__msgs_u701((&TM__BxLwT0mhrtgTPodf1v3xjg_648));
		if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
		internalErrorImpl__msgs_u1598((*(*p_p0).module).config, unknownLineInfo__lineinfos_u364, argX60gensym779__1, (&TM__BxLwT0mhrtgTPodf1v3xjg_648));
		if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
		{
			LA30_:;
		}
		{
			eqdestroy___system_u2691(argX60gensym779__1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA28_: ;
	{
		NimStringV2 T37_;
		if (!((*disc_1).loc.snippet.len == 0)) goto LA35_;
		T37_.len = 0; T37_.p = NIM_NIL;
		T37_ = mangleName__jsgen_u702((*p_p0).module, disc_1);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T37_); goto LA1_;}
		eqsink___system_u2700((&(*disc_1).loc.snippet), T37_);
	}
LA35_: ;
	nimZeroMem((void*)(&setx_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
	gen__jsgen_u1159(p_p0, (*checkExpr_1)._kind_6.sons.p->data[((NI)1)], (&setx_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	nimZeroMem((void*)(&obj_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
	gen__jsgen_u1159(p_p0, (*accessExpr_1)._kind_6.sons.p->data[((NI)0)], (&obj_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	tmp_1 = getTemp__jsgen_u1235(p_p0, NIM_TRUE);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T38_[0] = tmp_1;
	T38_[1] = obj_1.res;
	colontmpD_ = percent___jsgen_u3818(T38_, 2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__2 = indentLine__jsgen_u102(p_p0, colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&(*p_p0).body), colontmpD__2.len + 0);
appendString((&(*p_p0).body), colontmpD__2);
	useMagic__jsgen_u1172(p_p0, TM__BxLwT0mhrtgTPodf1v3xjg_650);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	useMagic__jsgen_u1172(p_p0, TM__BxLwT0mhrtgTPodf1v3xjg_651);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	useMagic__jsgen_u1172(p_p0, TM__BxLwT0mhrtgTPodf1v3xjg_653);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	msg_1 = genFieldDefect__astmsgs_u68((*(*p_p0).module).config, (*(*field_1).name).s, disc_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T39_[0] = setx_1.res;
	T39_[1] = tmp_1;
	T39_[2] = (*disc_1).loc.snippet;
	{
		if (!negCheck_1) goto LA42_;
		colontmpD__3 = TM__BxLwT0mhrtgTPodf1v3xjg_655;
		T39_[3] = colontmpD__3;
	}
	goto LA40_;
LA42_: ;
	{
		colontmpD__4 = TM__BxLwT0mhrtgTPodf1v3xjg_657;
		T39_[3] = colontmpD__4;
	}
LA40_: ;
	colontmpD__5 = makeJSString__jsgen_u806(msg_1, NIM_TRUE);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T39_[4] = colontmpD__5;
	colontmpD__6 = genTypeInfo__jsgen_u828(p_p0, (*disc_1).typ);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T39_[5] = colontmpD__6;
	colontmpD__7 = percent___jsgen_u3824(T39_, 6);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__8 = indentLine__jsgen_u102(p_p0, colontmpD__7);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&(*p_p0).body), colontmpD__8.len + 0);
appendString((&(*p_p0).body), colontmpD__8);
	{
		NIM_BOOL T47_;
		tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg T49_;
		NimStringV2 T52_;
		T47_ = (NIM_BOOL)0;
		T47_ = !((addrTyp_p2 == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL)));
		if (!(T47_)) goto LA48_;
		T49_ = (tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)0;
		T49_ = mapType__jsgen_u698(p_p0, addrTyp_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T47_ = (T49_ == ((tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)9));
LA48_: ;
		if (!T47_) goto LA50_;
		(*r_p3).typ = ((tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)9);
		T52_.len = 0; T52_.p = NIM_NIL;
		T52_ = makeJSString__jsgen_u806((*field_1).loc.snippet, NIM_TRUE);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T52_); goto LA1_;}
		eqsink___system_u2700((&(*r_p3).res), T52_);
		eqsink___system_u2700((&(*r_p3).address), tmp_1);
		eqwasMoved___system_u2688((&tmp_1));
	}
	goto LA45_;
LA50_: ;
	{
		tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T54_;
		NimStringV2 T55_;
		(*r_p3).typ = ((tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)0);
		T54_[0] = tmp_1;
		T54_[1] = (*field_1).loc.snippet;
		T55_.len = 0; T55_.p = NIM_NIL;
		T55_ = percent___cgen_u9620(T54_, 2);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T55_); goto LA1_;}
		eqsink___system_u2700((&(*r_p3).res), T55_);
	}
LA45_: ;
	(*r_p3).kind = ((tyEnum_TResKind__UiCSai1lX4RMkJ9bHo9aP2HA)1);
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___system_u2691(colontmpD__8);
		eqdestroy___system_u2691(colontmpD__7);
		eqdestroy___system_u2691(colontmpD__6);
		eqdestroy___system_u2691(colontmpD__5);
		eqdestroy___system_u2691(colontmpD__4);
		eqdestroy___system_u2691(colontmpD__3);
		eqdestroy___system_u2691(msg_1);
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___system_u2691(tmp_1);
		eqdestroy___jsgen_u570((&obj_1));
		eqdestroy___jsgen_u570((&setx_1));
		eqdestroy___ast_u4574(disc_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u4574(field_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3252(checkExpr_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3252(accessExpr_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NI, getFieldPosition__jsgen_u3654)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* f_p1) {
	NI result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	switch ((*f_p1).kind) {
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)6) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)15):
	{
		result = ((NI) ((*f_p1)._kind_1.intVal));
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3):
	{
		result = (*(*f_p1)._kind_4.sym).position;
	}
	break;
	default:
	{
		result = ((NI)0);
		internalErrorImpl__msgs_u1598((*(*p_p0).module).config, (*f_p1).info, TM__BxLwT0mhrtgTPodf1v3xjg_662, (&TM__BxLwT0mhrtgTPodf1v3xjg_663));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genFieldAddr__jsgen_u3658)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* r_p2) {
	tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ a_1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* b_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T2_;
NIM_BOOL oldNimErrFin19_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&a_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
	b_1 = NIM_NIL;
	colontmpD_ = NIM_NIL;
	nimZeroMem((void*)(&a_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
	(*r_p2).typ = ((tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)9);
	T2_ = NIM_NIL;
	{
		if (!((*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)64))) goto LA5_;
		eqcopy___ast_u3255(&b_1, (*n_p1)._kind_6.sons.p->data[((NI)0)]);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA3_;
LA5_: ;
	{
		eqcopy___ast_u3255(&b_1, n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA3_: ;
	gen__jsgen_u1159(p_p0, (*b_1)._kind_6.sons.p->data[((NI)0)], (&a_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NimStringV2 colontmpD__2;
		NimStringV2 colontmpD__3;
		NimStringV2 T13_;
		NI T14_;
		NimStringV2 T15_;
		colontmpD_ = skipTypes__ast_u5379((*(*b_1)._kind_6.sons.p->data[((NI)0)]).typField, TM__BxLwT0mhrtgTPodf1v3xjg_658);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!((*colontmpD_).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)18))) goto LA10_;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
		T13_.len = 0; T13_.p = NIM_NIL;
		T14_ = (NI)0;
		T14_ = getFieldPosition__jsgen_u3654(p_p0, (*b_1)._kind_6.sons.p->data[((NI)1)]);
		if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
		colontmpD__2 = dollar___systemZdollars_u9(T14_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
		T13_ = rawNewString(colontmpD__2.len + 5);
appendString((&T13_), TM__BxLwT0mhrtgTPodf1v3xjg_660);
appendString((&T13_), colontmpD__2);
		colontmpD__3 = T13_;
		T15_.len = 0; T15_.p = NIM_NIL;
		T15_ = makeJSString__jsgen_u806(colontmpD__3, NIM_TRUE);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T15_); goto LA12_;}
		eqsink___system_u2700((&(*r_p2).res), T15_);
		{
			LA12_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__3);
			eqdestroy___system_u2691(colontmpD__2);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA8_;
LA10_: ;
	{
		tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* f_1;
		NimStringV2 T29_;
		f_1 = NIM_NIL;
		{
			if (!!(((*(*b_1)._kind_6.sons.p->data[((NI)1)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3)))) goto LA22_;
			internalErrorImpl__msgs_u1598((*(*p_p0).module).config, (*(*b_1)._kind_6.sons.p->data[((NI)1)]).info, TM__BxLwT0mhrtgTPodf1v3xjg_665, (&TM__BxLwT0mhrtgTPodf1v3xjg_666));
			if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
		}
LA22_: ;
		eqcopy___ast_u4577(&f_1, (*(*b_1)._kind_6.sons.p->data[((NI)1)])._kind_4.sym);
		if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
		{
			NimStringV2 T28_;
			if (!((*f_1).loc.snippet.len == 0)) goto LA26_;
			T28_.len = 0; T28_.p = NIM_NIL;
			T28_ = mangleName__jsgen_u702((*p_p0).module, f_1);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T28_); goto LA19_;}
			eqsink___system_u2700((&(*f_1).loc.snippet), T28_);
		}
LA26_: ;
		T29_.len = 0; T29_.p = NIM_NIL;
		T29_ = makeJSString__jsgen_u806((*f_1).loc.snippet, NIM_TRUE);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T29_); goto LA19_;}
		eqsink___system_u2700((&(*r_p2).res), T29_);
		{
			LA19_:;
		}
		{
			oldNimErrFin19_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u4574(f_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin19_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA8_: ;
	{
		NimStringV2 argX60gensym746__1;
		if (!!(!((a_1.typ == ((tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)9))))) goto LA34_;
		argX60gensym746__1.len = 0; argX60gensym746__1.p = NIM_NIL;
		argX60gensym746__1 = toFileLineCol__msgs_u701((&TM__BxLwT0mhrtgTPodf1v3xjg_667));
		if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
		internalErrorImpl__msgs_u1598((*(*p_p0).module).config, unknownLineInfo__lineinfos_u364, argX60gensym746__1, (&TM__BxLwT0mhrtgTPodf1v3xjg_667));
		if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
		{
			LA36_:;
		}
		{
			eqdestroy___system_u2691(argX60gensym746__1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA34_: ;
	eqsink___system_u2700((&(*r_p2).address), a_1.res);
	eqwasMoved___system_u2688((&a_1.res));
	(*r_p2).kind = ((tyEnum_TResKind__UiCSai1lX4RMkJ9bHo9aP2HA)1);
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3252(b_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___jsgen_u570((&a_1));
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genFieldAccess__jsgen_u3693)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* r_p2) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* otyp_1;
	tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg T2_;
NIM_BOOL oldNimErrFin32_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	otyp_1 = NIM_NIL;
	gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)0)], r_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T2_ = (tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)0;
	T2_ = mapType__jsgen_u686((*n_p1).typField);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	(*r_p2).typ = T2_;
	otyp_1 = skipTypes__ast_u5379((*(*n_p1)._kind_6.sons.p->data[((NI)0)]).typField, TM__BxLwT0mhrtgTPodf1v3xjg_358);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NimStringV2 colontmpD_;
		tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T8_;
		NI T9_;
		NimStringV2 T10_;
		if (!((*otyp_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)18))) goto LA5_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		T8_[0] = (*r_p2).res;
		T9_ = (NI)0;
		T9_ = getFieldPosition__jsgen_u3654(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)]);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		colontmpD_ = rope__ropes_u15(((NI64) (T9_)));
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		T8_[1] = colontmpD_;
		T10_.len = 0; T10_.p = NIM_NIL;
		T10_ = percent___cgen_u15846(T8_, 2);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T10_); goto LA7_;}
		eqsink___system_u2700((&(*r_p2).res), T10_);
		{
			if (!((*r_p2).typ == ((tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)9))) goto LA13_;
			{
				NIM_BOOL T17_;
				NimStringV2 tmpX60gensym753__1;
				tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T20_;
				NimStringV2 T21_;
				tyArray__YgExxhfgKcesA5EOUj1MOA T22_;
				NimStringV2 T23_;
				T17_ = (NIM_BOOL)0;
				T17_ = needsTemp__jsgen_u1352(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)0)]);
				if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
				if (!T17_) goto LA18_;
				tmpX60gensym753__1.len = 0; tmpX60gensym753__1.p = NIM_NIL;
				tmpX60gensym753__1 = getTemp__jsgen_u1235(p_p0, NIM_TRUE);
				if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
				T20_[0] = tmpX60gensym753__1;
				T20_[1] = (*r_p2).res;
				T21_.len = 0; T21_.p = NIM_NIL;
				T21_ = percent___jsgen_u3715(T20_, 2);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T21_); goto LA7_;}
				eqsink___system_u2700((&(*r_p2).address), T21_);
				T22_[0] = tmpX60gensym753__1;
				T23_.len = 0; T23_.p = NIM_NIL;
				T23_ = percent___jsgen_u3720(T22_, 1);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T23_); goto LA7_;}
				eqsink___system_u2700((&(*r_p2).res), T23_);
				eqsink___system_u2700((&(*r_p2).tmpLoc), tmpX60gensym753__1);
			}
			goto LA15_;
LA18_: ;
			{
				tyArray__YgExxhfgKcesA5EOUj1MOA T25_;
				NimStringV2 T26_;
				tyArray__YgExxhfgKcesA5EOUj1MOA T27_;
				NimStringV2 T28_;
				T25_[0] = (*r_p2).res;
				T26_.len = 0; T26_.p = NIM_NIL;
				T26_ = percent___jsgen_u3725(T25_, 1);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T26_); goto LA7_;}
				eqsink___system_u2700((&(*r_p2).address), T26_);
				T27_[0] = (*r_p2).res;
				T28_.len = 0; T28_.p = NIM_NIL;
				T28_ = percent___jsgen_u3720(T27_, 1);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T28_); goto LA7_;}
				eqsink___system_u2700((&(*r_p2).res), T28_);
			}
LA15_: ;
		}
LA13_: ;
		{
			LA7_:;
		}
		{
			eqdestroy___system_u2691(colontmpD_);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA3_;
LA5_: ;
	{
		tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* f_1;
		tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T42_;
		NimStringV2 T43_;
		f_1 = NIM_NIL;
		{
			if (!!(((*(*n_p1)._kind_6.sons.p->data[((NI)1)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3)))) goto LA35_;
			internalErrorImpl__msgs_u1598((*(*p_p0).module).config, (*(*n_p1)._kind_6.sons.p->data[((NI)1)]).info, TM__BxLwT0mhrtgTPodf1v3xjg_669, (&TM__BxLwT0mhrtgTPodf1v3xjg_670));
			if (NIM_UNLIKELY(*nimErr_)) goto LA32_;
		}
LA35_: ;
		eqcopy___ast_u4577(&f_1, (*(*n_p1)._kind_6.sons.p->data[((NI)1)])._kind_4.sym);
		if (NIM_UNLIKELY(*nimErr_)) goto LA32_;
		{
			NimStringV2 T41_;
			if (!((*f_1).loc.snippet.len == 0)) goto LA39_;
			T41_.len = 0; T41_.p = NIM_NIL;
			T41_ = mangleName__jsgen_u702((*p_p0).module, f_1);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T41_); goto LA32_;}
			eqsink___system_u2700((&(*f_1).loc.snippet), T41_);
		}
LA39_: ;
		T42_[0] = (*r_p2).res;
		T42_[1] = (*f_1).loc.snippet;
		T43_.len = 0; T43_.p = NIM_NIL;
		T43_ = percent___cgen_u9620(T42_, 2);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T43_); goto LA32_;}
		eqsink___system_u2700((&(*r_p2).res), T43_);
		{
			if (!((*r_p2).typ == ((tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)9))) goto LA46_;
			{
				NIM_BOOL T50_;
				NimStringV2 tmpX60gensym762__1;
				tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T53_;
				NimStringV2 T54_;
				tyArray__YgExxhfgKcesA5EOUj1MOA T55_;
				NimStringV2 T56_;
				T50_ = (NIM_BOOL)0;
				T50_ = needsTemp__jsgen_u1352(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)]);
				if (NIM_UNLIKELY(*nimErr_)) goto LA32_;
				if (!T50_) goto LA51_;
				tmpX60gensym762__1.len = 0; tmpX60gensym762__1.p = NIM_NIL;
				tmpX60gensym762__1 = getTemp__jsgen_u1235(p_p0, NIM_TRUE);
				if (NIM_UNLIKELY(*nimErr_)) goto LA32_;
				T53_[0] = tmpX60gensym762__1;
				T53_[1] = (*r_p2).res;
				T54_.len = 0; T54_.p = NIM_NIL;
				T54_ = percent___jsgen_u3715(T53_, 2);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T54_); goto LA32_;}
				eqsink___system_u2700((&(*r_p2).address), T54_);
				T55_[0] = tmpX60gensym762__1;
				T56_.len = 0; T56_.p = NIM_NIL;
				T56_ = percent___jsgen_u3720(T55_, 1);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T56_); goto LA32_;}
				eqsink___system_u2700((&(*r_p2).res), T56_);
				eqsink___system_u2700((&(*r_p2).tmpLoc), tmpX60gensym762__1);
			}
			goto LA48_;
LA51_: ;
			{
				tyArray__YgExxhfgKcesA5EOUj1MOA T58_;
				NimStringV2 T59_;
				tyArray__YgExxhfgKcesA5EOUj1MOA T60_;
				NimStringV2 T61_;
				T58_[0] = (*r_p2).res;
				T59_.len = 0; T59_.p = NIM_NIL;
				T59_ = percent___jsgen_u3725(T58_, 1);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T59_); goto LA32_;}
				eqsink___system_u2700((&(*r_p2).address), T59_);
				T60_[0] = (*r_p2).res;
				T61_.len = 0; T61_.p = NIM_NIL;
				T61_ = percent___jsgen_u3720(T60_, 1);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T61_); goto LA32_;}
				eqsink___system_u2700((&(*r_p2).res), T61_);
			}
LA48_: ;
		}
LA46_: ;
		{
			LA32_:;
		}
		{
			oldNimErrFin32_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u4574(f_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin32_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA3_: ;
	(*r_p2).kind = ((tyEnum_TResKind__UiCSai1lX4RMkJ9bHo9aP2HA)1);
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(otyp_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genArrayAddr__jsgen_u3841)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* r_p2) {
	tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ a_1;
	tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ b_1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* m_1;
	tyTuple__UV3llMMYFckfui8YMBuUZA tmpTuple_1;
	NimStringV2 x_1;
	NimStringV2 tmp_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_1;
	tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg first_1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T2_;
NIM_BOOL oldNimErrFin12_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&a_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
	nimZeroMem((void*)(&b_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
	m_1 = NIM_NIL;
	nimZeroMem((void*)(&tmpTuple_1), sizeof(tyTuple__UV3llMMYFckfui8YMBuUZA));
	x_1.len = 0; x_1.p = NIM_NIL;
	tmp_1.len = 0; tmp_1.p = NIM_NIL;
	typ_1 = NIM_NIL;
	nimZeroMem((void*)(&a_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
	nimZeroMem((void*)(&b_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
	first_1 = Zero__int128_u8;
	(*r_p2).typ = ((tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)9);
	T2_ = NIM_NIL;
	{
		if (!((*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)64))) goto LA5_;
		eqcopy___ast_u3255(&m_1, (*n_p1)._kind_6.sons.p->data[((NI)0)]);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA3_;
LA5_: ;
	{
		eqcopy___ast_u3255(&m_1, n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA3_: ;
	gen__jsgen_u1159(p_p0, (*m_1)._kind_6.sons.p->data[((NI)0)], (&a_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	gen__jsgen_u1159(p_p0, (*m_1)._kind_6.sons.p->data[((NI)1)], (&b_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	maybeMakeTemp__jsgen_u1365(p_p0, (*m_1)._kind_6.sons.p->data[((NI)0)], (&a_1), (&tmpTuple_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	x_1 = tmpTuple_1.Field0;
	eqwasMoved___system_u2688((&tmpTuple_1.Field0));
	tmp_1 = tmpTuple_1.Field1;
	eqwasMoved___system_u2688((&tmpTuple_1.Field1));
	eqsink___system_u2700((&(*r_p2).address), x_1);
	eqwasMoved___system_u2688((&x_1));
	typ_1 = skipTypes__ast_u5379((*(*m_1)._kind_6.sons.p->data[((NI)0)]).typField, TM__BxLwT0mhrtgTPodf1v3xjg_527);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
		if (!((*typ_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)16))) goto LA10_;
		colontmpD_ = NIM_NIL;
		colontmpD_ = indexType__ast_u5345(typ_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
		first_1 = firstOrd__types_u1182((*(*p_p0).module).config, colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
		{
			LA12_:;
		}
		{
			oldNimErrFin12_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3378(colontmpD_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin12_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA10_: ;
	{
		if (!(((*p_p0).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)4)))&31U)))!=0)) goto LA17_;
		useMagic__jsgen_u1172(p_p0, TM__BxLwT0mhrtgTPodf1v3xjg_672);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		{
			NIM_BOOL T21_;
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T24_;
			NimStringV2 T25_;
			T21_ = (NIM_BOOL)0;
			T21_ = eqeq___int128_u980(first_1, IL64(0));
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			if (!T21_) goto LA22_;
			T24_[0] = b_1.res;
			T24_[1] = tmp_1;
			T25_.len = 0; T25_.p = NIM_NIL;
			T25_ = percent___jsgen_u1449(T24_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T25_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T25_);
		}
		goto LA19_;
LA22_: ;
		{
			NimStringV2 colontmpD__2;
			tyArray__dyW7vpmfeTYw8kX3EXuaJA T27_;
			NimStringV2 T28_;
			colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
			T27_[0] = b_1.res;
			colontmpD__2 = rope__jsgen_u825(first_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			T27_[1] = colontmpD__2;
			T27_[2] = tmp_1;
			T28_.len = 0; T28_.p = NIM_NIL;
			T28_ = percent___jsgen_u1454(T27_, 3);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T28_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T28_);
			eqdestroy___system_u2691(colontmpD__2);
		}
LA19_: ;
	}
	goto LA15_;
LA17_: ;
	{
		NIM_BOOL T30_;
		NimStringV2 colontmpD__3;
		tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T33_;
		NimStringV2 T34_;
		T30_ = (NIM_BOOL)0;
		T30_ = eqeq___int128_u980(first_1, IL64(0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!!(T30_)) goto LA31_;
		colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
		T33_[0] = b_1.res;
		colontmpD__3 = rope__jsgen_u825(first_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T33_[1] = colontmpD__3;
		T34_.len = 0; T34_.p = NIM_NIL;
		T34_ = percent___jsgen_u1459(T33_, 2);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T34_); goto LA1_;}
		eqsink___system_u2700((&(*r_p2).res), T34_);
		eqdestroy___system_u2691(colontmpD__3);
	}
	goto LA15_;
LA31_: ;
	{
		eqsink___system_u2700((&(*r_p2).res), b_1.res);
		eqwasMoved___system_u2688((&b_1.res));
	}
LA15_: ;
	(*r_p2).kind = ((tyEnum_TResKind__UiCSai1lX4RMkJ9bHo9aP2HA)1);
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(typ_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___system_u2691(tmp_1);
		eqdestroy___system_u2691(x_1);
		eqdestroy___stdZprivateZospaths2_u306((&tmpTuple_1));
		eqdestroy___ast_u3252(m_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___jsgen_u570((&b_1));
		eqdestroy___jsgen_u570((&a_1));
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genAddr__jsgen_u3765)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* r_p2) {
NIM_BOOL oldNimErrFin22_;
NIM_BOOL oldNimErrFin16_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!((*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3))) goto LA3_;
		genSymAddr__jsgen_u3939(p_p0, n_p1, ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL), r_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA3_: ;
	{
		switch ((*(*n_p1)._kind_6.sons.p->data[((NI)0)]).kind) {
		case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3):
		{
			genSymAddr__jsgen_u3939(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)0)], (*n_p1).typField, r_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		break;
		case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)46):
		{
			genCheckedFieldOp__jsgen_u3769(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)0)], (*n_p1).typField, r_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		break;
		case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)45):
		{
			{
				tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg T11_;
				T11_ = (tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)0;
				T11_ = mapType__jsgen_u698(p_p0, (*n_p1).typField);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				if (!(T11_ == ((tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)9))) goto LA12_;
				genFieldAddr__jsgen_u3658(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)0)], r_p2);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			}
			goto LA9_;
LA12_: ;
			{
				genFieldAccess__jsgen_u3693(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)0)], r_p2);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			}
LA9_: ;
		}
		break;
		case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)42):
		{
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* ty_1;
			ty_1 = NIM_NIL;
			ty_1 = skipTypes__ast_u5379((*(*n_p1)._kind_6.sons.p->data[((NI)0)]).typField, TM__BxLwT0mhrtgTPodf1v3xjg_358);
			if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
			{
				if (!((*ty_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)17) || (*ty_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)16) || (*ty_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)18) || (*ty_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)27) || (*ty_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)19) || (*ty_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)48))) goto LA19_;
				gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)0)], r_p2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
			}
			goto LA17_;
LA19_: ;
			{
				tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
				tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg kindOfIndexedExpr_1;
				colontmpD_ = NIM_NIL;
				colontmpD_ = skipTypes__ast_u5379((*(*(*n_p1)._kind_6.sons.p->data[((NI)0)])._kind_6.sons.p->data[((NI)0)]).typField, TM__BxLwT0mhrtgTPodf1v3xjg_671);
				if (NIM_UNLIKELY(*nimErr_)) goto LA22_;
				kindOfIndexedExpr_1 = (*colontmpD_).kind;
				switch (kindOfIndexedExpr_1) {
				case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)16):
				case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)27):
				case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)24):
				case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)28):
				case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)29):
				case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)48):
				{
					genArrayAddr__jsgen_u3841(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)0)], r_p2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA22_;
				}
				break;
				case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)18):
				{
					genFieldAddr__jsgen_u3658(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)0)], r_p2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA22_;
				}
				break;
				case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)10):
				{
					NI T26_;
					T26_ = (NI)0;
					T26_ = len__ast_u3190(n_p1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA22_;
					genAddr__jsgen_u3765(p_p0, (*n_p1)._kind_6.sons.p->data[(NI)(T26_ - ((NI)1))], r_p2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA22_;
				}
				break;
				default:
				{
					NimStringV2 colontmpD__2;
					NimStringV2 colontmpD__3;
					NimStringV2 T29_;
					colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
					colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
					T29_.len = 0; T29_.p = NIM_NIL;
					colontmpD__2 = dollar___ast_u182(kindOfIndexedExpr_1);
					T29_ = rawNewString(colontmpD__2.len + 21);
appendString((&T29_), TM__BxLwT0mhrtgTPodf1v3xjg_674);
appendString((&T29_), colontmpD__2);
appendChar((&T29_), 41);
					colontmpD__3 = T29_;
					internalErrorImpl__msgs_u1598((*(*p_p0).module).config, (*(*n_p1)._kind_6.sons.p->data[((NI)0)]).info, colontmpD__3, (&TM__BxLwT0mhrtgTPodf1v3xjg_675));
					if (NIM_UNLIKELY(*nimErr_)) goto LA28_;
					{
						LA28_:;
					}
					{
						eqdestroy___system_u2691(colontmpD__3);
						eqdestroy___system_u2691(colontmpD__2);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA22_;
				}
				break;
				}
				{
					LA22_:;
				}
				{
					oldNimErrFin22_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3378(colontmpD_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
					*nimErr_ = oldNimErrFin22_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
			}
LA17_: ;
			{
				LA16_:;
			}
			{
				oldNimErrFin16_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u3378(ty_1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				*nimErr_ = oldNimErrFin16_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		break;
		case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)66):
		{
			gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)0)], r_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		break;
		case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)65):
		case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)47):
		{
			{
				if (!((*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)63) || (*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)64))) goto LA40_;
				gen__jsgen_u1159(p_p0, (*(*n_p1)._kind_6.sons.p->data[((NI)0)])._kind_6.sons.p->data[((NI)0)], r_p2);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			}
			goto LA38_;
LA40_: ;
			{
				gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)0)], r_p2);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			}
LA38_: ;
		}
		break;
		case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)64):
		{
			gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)0)], r_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		break;
		case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)60):
		{
			genAddr__jsgen_u3765(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)0)], r_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		break;
		case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)126):
		{
			{
				NI T48_;
				T48_ = (NI)0;
				T48_ = len__ast_u3190(n_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				if (!(T48_ == ((NI)1))) goto LA49_;
				gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)0)], r_p2);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			}
			goto LA46_;
LA49_: ;
			{
				internalErrorImpl__msgs_u1598((*(*p_p0).module).config, (*(*n_p1)._kind_6.sons.p->data[((NI)0)]).info, TM__BxLwT0mhrtgTPodf1v3xjg_677, (&TM__BxLwT0mhrtgTPodf1v3xjg_678));
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			}
LA46_: ;
		}
		break;
		case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)26) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)32):
		{
			{
				if (!((*(*(*n_p1)._kind_6.sons.p->data[((NI)0)]).typField).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)27))) goto LA55_;
				gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)0)], r_p2);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			}
			goto LA53_;
LA55_: ;
			{
				NimStringV2 colontmpD__4;
				NimStringV2 colontmpD__5;
				NimStringV2 T59_;
				colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
				colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
				T59_.len = 0; T59_.p = NIM_NIL;
				colontmpD__4 = dollar___nodekinds_u168((*(*n_p1)._kind_6.sons.p->data[((NI)0)]).kind);
				T59_ = rawNewString(colontmpD__4.len + 9);
appendString((&T59_), TM__BxLwT0mhrtgTPodf1v3xjg_680);
appendString((&T59_), colontmpD__4);
				colontmpD__5 = T59_;
				internalErrorImpl__msgs_u1598((*(*p_p0).module).config, (*(*n_p1)._kind_6.sons.p->data[((NI)0)]).info, colontmpD__5, (&TM__BxLwT0mhrtgTPodf1v3xjg_681));
				if (NIM_UNLIKELY(*nimErr_)) goto LA58_;
				{
					LA58_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__5);
					eqdestroy___system_u2691(colontmpD__4);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			}
LA53_: ;
		}
		break;
		default:
		{
			NimStringV2 colontmpD__6;
			NimStringV2 colontmpD__7;
			NimStringV2 T64_;
			colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
			colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
			T64_.len = 0; T64_.p = NIM_NIL;
			colontmpD__6 = dollar___nodekinds_u168((*(*n_p1)._kind_6.sons.p->data[((NI)0)]).kind);
			T64_ = rawNewString(colontmpD__6.len + 9);
appendString((&T64_), TM__BxLwT0mhrtgTPodf1v3xjg_682);
appendString((&T64_), colontmpD__6);
			colontmpD__7 = T64_;
			internalErrorImpl__msgs_u1598((*(*p_p0).module).config, (*(*n_p1)._kind_6.sons.p->data[((NI)0)]).info, colontmpD__7, (&TM__BxLwT0mhrtgTPodf1v3xjg_683));
			if (NIM_UNLIKELY(*nimErr_)) goto LA63_;
			{
				LA63_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__7);
				eqdestroy___system_u2691(colontmpD__6);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		break;
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genDeref__jsgen_u4337)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* r_p2) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* it_1;
	tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg t_1;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	it_1 = NIM_NIL;
	eqcopy___ast_u3255(&it_1, (*n_p1)._kind_6.sons.p->data[((NI)0)]);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	t_1 = mapType__jsgen_u698(p_p0, (*it_1).typField);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NIM_BOOL T4_;
		T4_ = (NIM_BOOL)0;
		T4_ = (t_1 == ((tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)8));
		if (T4_) goto LA5_;
		T4_ = ((*(*it_1).typField).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)47));
LA5_: ;
		if (!T4_) goto LA6_;
		gen__jsgen_u1159(p_p0, it_1, r_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA2_;
LA6_: ;
	{
		tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ a_1;
		tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg T10_;
		nimZeroMem((void*)(&a_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
		nimZeroMem((void*)(&a_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
		gen__jsgen_u1159(p_p0, it_1, (&a_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
		(*r_p2).kind = a_1.kind;
		T10_ = (tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)0;
		T10_ = mapType__jsgen_u698(p_p0, (*n_p1).typField);
		if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
		(*r_p2).typ = T10_;
		{
			NimStringV2 tmp_1;
			NimStringV2 colontmpD_;
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T15_;
			NimStringV2 T16_;
			tyArray__YgExxhfgKcesA5EOUj1MOA T17_;
			NimStringV2 T18_;
			if (!((*r_p2).typ == ((tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)9))) goto LA13_;
			tmp_1.len = 0; tmp_1.p = NIM_NIL;
			colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
			tmp_1 = getTemp__jsgen_u1235(p_p0, NIM_TRUE);
			if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
			T15_[0] = tmp_1;
			colontmpD_ = rdLoc__jsgen_u593((&a_1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
			T15_[1] = colontmpD_;
			T16_.len = 0; T16_.p = NIM_NIL;
			T16_ = percent___jsgen_u3715(T15_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T16_); goto LA9_;}
			eqsink___system_u2700((&(*r_p2).address), T16_);
			T17_[0] = tmp_1;
			T18_.len = 0; T18_.p = NIM_NIL;
			T18_ = percent___jsgen_u3720(T17_, 1);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T18_); goto LA9_;}
			eqsink___system_u2700((&(*r_p2).res), T18_);
			eqsink___system_u2700((&(*r_p2).tmpLoc), tmp_1);
			eqdestroy___system_u2691(colontmpD_);
		}
		goto LA11_;
LA13_: ;
		{
			NimStringV2 T26_;
			if (!(a_1.typ == ((tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)9))) goto LA20_;
			{
				if (!!((a_1.tmpLoc.len == 0))) goto LA24_;
				eqcopy___system_u2694((&(*r_p2).tmpLoc), a_1.tmpLoc);
			}
LA24_: ;
			T26_.len = 0; T26_.p = NIM_NIL;
			T26_ = rdLoc__jsgen_u593((&a_1));
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T26_); goto LA9_;}
			eqsink___system_u2700((&(*r_p2).res), T26_);
		}
		goto LA11_;
LA20_: ;
		{
			internalErrorImpl__msgs_u1598((*(*p_p0).module).config, (*n_p1).info, TM__BxLwT0mhrtgTPodf1v3xjg_685, (&TM__BxLwT0mhrtgTPodf1v3xjg_686));
			if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
		}
LA11_: ;
		{
			LA9_:;
		}
		{
			eqdestroy___jsgen_u570((&a_1));
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA2_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3252(it_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genArrayAccess__jsgen_u3885)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* r_p2) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* ty_1;
	tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg T14_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	ty_1 = NIM_NIL;
	ty_1 = skipTypes__ast_u5379((*(*n_p1)._kind_6.sons.p->data[((NI)0)]).typField, TM__BxLwT0mhrtgTPodf1v3xjg_671);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* T6_;
		if (!((*ty_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)22) || (*ty_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)21) || (*ty_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)47) || (*ty_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)45))) goto LA4_;
		colontmpD_ = NIM_NIL;
		colontmpD_ = elementType__ast_u5331(ty_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T6_ = NIM_NIL;
		T6_ = skipTypes__ast_u5379(colontmpD_, TM__BxLwT0mhrtgTPodf1v3xjg_358);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3378(T6_); goto LA1_;}
		eqsink___ast_u3387(&ty_1, T6_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		eqdestroy___ast_u3378(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA4_: ;
	switch ((*ty_1).kind) {
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)16):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)27):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)24):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)28):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)29):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)48):
	{
		genArrayAddr__jsgen_u3841(p_p0, n_p1, r_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)18):
	{
		genFieldAddr__jsgen_u3658(p_p0, n_p1, r_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	default:
	{
		NimStringV2 colontmpD__2;
		NimStringV2 colontmpD__3;
		NimStringV2 T11_;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
		T11_.len = 0; T11_.p = NIM_NIL;
		colontmpD__2 = dollar___ast_u182((*ty_1).kind);
		T11_ = rawNewString(colontmpD__2.len + 21);
appendString((&T11_), TM__BxLwT0mhrtgTPodf1v3xjg_687);
appendString((&T11_), colontmpD__2);
appendChar((&T11_), 41);
		colontmpD__3 = T11_;
		internalErrorImpl__msgs_u1598((*(*p_p0).module).config, (*n_p1).info, colontmpD__3, (&TM__BxLwT0mhrtgTPodf1v3xjg_688));
		if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		{
			LA10_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__3);
			eqdestroy___system_u2691(colontmpD__2);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	}
	T14_ = (tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)0;
	T14_ = mapType__jsgen_u686((*n_p1).typField);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	(*r_p2).typ = T14_;
	{
		if (!((*r_p2).res.len == 0)) goto LA17_;
		internalErrorImpl__msgs_u1598((*(*p_p0).module).config, (*n_p1).info, TM__BxLwT0mhrtgTPodf1v3xjg_690, (&TM__BxLwT0mhrtgTPodf1v3xjg_691));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA17_: ;
	{
		tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T23_;
		NimStringV2 T24_;
		if (!((*ty_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)29))) goto LA21_;
		T23_[0] = (*r_p2).address;
		T23_[1] = (*r_p2).res;
		T24_.len = 0; T24_.p = NIM_NIL;
		T24_ = percent___jsgen_u3905(T23_, 2);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T24_); goto LA1_;}
		eqsink___system_u2700((&(*r_p2).res), T24_);
	}
	goto LA19_;
LA21_: ;
	{
		if (!((*r_p2).typ == ((tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)9))) goto LA26_;
		{
			NIM_BOOL T30_;
			NimStringV2 tmp_1;
			NimStringV2 colontmpD__4;
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T33_;
			NimStringV2 T34_;
			tyArray__YgExxhfgKcesA5EOUj1MOA T35_;
			NimStringV2 T36_;
			T30_ = (NIM_BOOL)0;
			T30_ = needsTemp__jsgen_u1352(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)0)]);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			if (!T30_) goto LA31_;
			tmp_1.len = 0; tmp_1.p = NIM_NIL;
			colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
			tmp_1 = getTemp__jsgen_u1235(p_p0, NIM_TRUE);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			T33_[0] = tmp_1;
			colontmpD__4 = rdLoc__jsgen_u593((&(*r_p2)));
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			T33_[1] = colontmpD__4;
			T34_.len = 0; T34_.p = NIM_NIL;
			T34_ = percent___jsgen_u3715(T33_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T34_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).address), T34_);
			T35_[0] = tmp_1;
			T36_.len = 0; T36_.p = NIM_NIL;
			T36_ = percent___jsgen_u3720(T35_, 1);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T36_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T36_);
			eqsink___system_u2700((&(*r_p2).tmpLoc), tmp_1);
			eqdestroy___system_u2691(colontmpD__4);
		}
		goto LA28_;
LA31_: ;
		{
			NimStringV2 x_1;
			tyArray__YgExxhfgKcesA5EOUj1MOA T38_;
			NimStringV2 T39_;
			tyArray__YgExxhfgKcesA5EOUj1MOA T40_;
			NimStringV2 T41_;
			x_1.len = 0; x_1.p = NIM_NIL;
			x_1 = rdLoc__jsgen_u593((&(*r_p2)));
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			T38_[0] = x_1;
			T39_.len = 0; T39_.p = NIM_NIL;
			T39_ = percent___jsgen_u3725(T38_, 1);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T39_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).address), T39_);
			T40_[0] = x_1;
			T41_.len = 0; T41_.p = NIM_NIL;
			T41_ = percent___jsgen_u3720(T40_, 1);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T41_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T41_);
			eqdestroy___system_u2691(x_1);
		}
LA28_: ;
	}
	goto LA19_;
LA26_: ;
	{
		tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T43_;
		NimStringV2 T44_;
		T43_[0] = (*r_p2).address;
		T43_[1] = (*r_p2).res;
		T44_.len = 0; T44_.p = NIM_NIL;
		T44_ = percent___cgen_u9083(T43_, 2);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T44_); goto LA1_;}
		eqsink___system_u2700((&(*r_p2).res), T44_);
	}
LA19_: ;
	(*r_p2).kind = ((tyEnum_TResKind__UiCSai1lX4RMkJ9bHo9aP2HA)1);
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(ty_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, upConv__jsgen_u7132)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* r_p2) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)0)], r_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genCast__jsgen_u7479)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* r_p2) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* dest_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* src_1;
	NIM_BOOL toInt_1;
	tyObject_HSlice__Td0KDtM8kU0p7CVwrbJeww T6_;
	NIM_BOOL toUint_1;
	tyObject_HSlice__Td0KDtM8kU0p7CVwrbJeww T7_;
	NIM_BOOL fromInt_1;
	tyObject_HSlice__Td0KDtM8kU0p7CVwrbJeww T8_;
	NIM_BOOL fromUint_1;
	tyObject_HSlice__Td0KDtM8kU0p7CVwrbJeww T9_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	dest_1 = NIM_NIL;
	src_1 = NIM_NIL;
	dest_1 = skipTypes__ast_u5379((*n_p1).typField, TM__BxLwT0mhrtgTPodf1v3xjg_358);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	src_1 = skipTypes__ast_u5379((*(*n_p1)._kind_6.sons.p->data[((NI)1)]).typField, TM__BxLwT0mhrtgTPodf1v3xjg_358);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], r_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		if (!((*dest_1).kind == (*src_1).kind)) goto LA4_;
		eqdestroy___ast_u3378(src_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(dest_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		goto BeforeRet_;
	}
LA4_: ;
	T6_ = dotdot___semfold_u987(((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)31), ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)34));
	toInt_1 = contains__semfold_u1019(T6_, (*dest_1).kind);
	T7_ = dotdot___semfold_u987(((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)40), ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)43));
	toUint_1 = contains__semfold_u1019(T7_, (*dest_1).kind);
	T8_ = dotdot___semfold_u987(((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)31), ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)34));
	fromInt_1 = contains__semfold_u1019(T8_, (*src_1).kind);
	T9_ = dotdot___semfold_u987(((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)40), ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)43));
	fromUint_1 = contains__semfold_u1019(T9_, (*src_1).kind);
	{
		if (!toUint_1) goto LA12_;
		{
			NIM_BOOL T16_;
			NimStringV2 colontmpD_;
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T20_;
			NimStringV2 T21_;
			T16_ = (NIM_BOOL)0;
			T16_ = fromInt_1;
			if (T16_) goto LA17_;
			T16_ = fromUint_1;
LA17_: ;
			if (!T16_) goto LA18_;
			colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
			colontmpD_ = dollar___systemZdollars_u29((NI64)((*dest_1).size * IL64(8)));
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			T20_[0] = colontmpD_;
			T20_[1] = (*r_p2).res;
			T21_.len = 0; T21_.p = NIM_NIL;
			T21_ = percent___jsgen_u7757(T20_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T21_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T21_);
			eqdestroy___system_u2691(colontmpD_);
		}
		goto LA14_;
LA18_: ;
		{
			NIM_BOOL T23_;
			NimStringV2 colontmpD__2;
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T27_;
			NimStringV2 T28_;
			T23_ = (NIM_BOOL)0;
			T23_ = ((*src_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)35) || (*src_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)44));
			if (!(T23_)) goto LA24_;
			T23_ = (((*(*(*p_p0).module).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)56)))&63U)))!=0);
LA24_: ;
			if (!T23_) goto LA25_;
			colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
			colontmpD__2 = dollar___systemZdollars_u29((NI64)((*dest_1).size * IL64(8)));
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			T27_[0] = colontmpD__2;
			T27_[1] = (*r_p2).res;
			T28_.len = 0; T28_.p = NIM_NIL;
			T28_ = percent___jsgen_u7770(T27_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T28_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T28_);
			eqdestroy___system_u2691(colontmpD__2);
		}
		goto LA14_;
LA25_: ;
LA14_: ;
	}
	goto LA10_;
LA12_: ;
	{
		if (!toInt_1) goto LA30_;
		{
			NIM_BOOL T34_;
			NimStringV2 colontmpD__3;
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T38_;
			NimStringV2 T39_;
			T34_ = (NIM_BOOL)0;
			T34_ = fromInt_1;
			if (T34_) goto LA35_;
			T34_ = fromUint_1;
LA35_: ;
			if (!T34_) goto LA36_;
			colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
			colontmpD__3 = dollar___systemZdollars_u29((NI64)((*dest_1).size * IL64(8)));
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			T38_[0] = colontmpD__3;
			T38_[1] = (*r_p2).res;
			T39_.len = 0; T39_.p = NIM_NIL;
			T39_ = percent___jsgen_u7775(T38_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T39_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T39_);
			eqdestroy___system_u2691(colontmpD__3);
		}
		goto LA32_;
LA36_: ;
		{
			NIM_BOOL T41_;
			NimStringV2 colontmpD__4;
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T45_;
			NimStringV2 T46_;
			T41_ = (NIM_BOOL)0;
			T41_ = ((*src_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)35) || (*src_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)44));
			if (!(T41_)) goto LA42_;
			T41_ = (((*(*(*p_p0).module).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)56)))&63U)))!=0);
LA42_: ;
			if (!T41_) goto LA43_;
			colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
			colontmpD__4 = dollar___systemZdollars_u29((NI64)((*dest_1).size * IL64(8)));
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			T45_[0] = colontmpD__4;
			T45_[1] = (*r_p2).res;
			T46_.len = 0; T46_.p = NIM_NIL;
			T46_ = percent___jsgen_u7788(T45_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T46_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T46_);
			eqdestroy___system_u2691(colontmpD__4);
		}
		goto LA32_;
LA43_: ;
LA32_: ;
	}
	goto LA10_;
LA30_: ;
	{
		NIM_BOOL T48_;
		T48_ = (NIM_BOOL)0;
		T48_ = ((*dest_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)35));
		if (!(T48_)) goto LA49_;
		T48_ = (((*(*(*p_p0).module).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)56)))&63U)))!=0);
LA49_: ;
		if (!T48_) goto LA50_;
		{
			NIM_BOOL T54_;
			NIM_BOOL T55_;
			tyArray__YgExxhfgKcesA5EOUj1MOA T60_;
			NimStringV2 T61_;
			T54_ = (NIM_BOOL)0;
			T55_ = (NIM_BOOL)0;
			T55_ = fromInt_1;
			if (T55_) goto LA56_;
			T55_ = fromUint_1;
LA56_: ;
			T54_ = T55_;
			if (T54_) goto LA57_;
			T54_ = ((*src_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)1) || (*src_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)2) || (*src_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)14));
LA57_: ;
			if (!T54_) goto LA58_;
			T60_[0] = (*r_p2).res;
			T61_.len = 0; T61_.p = NIM_NIL;
			T61_ = percent___jsgen_u6992(T60_, 1);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T61_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T61_);
		}
		goto LA52_;
LA58_: ;
		{
			tyArray__YgExxhfgKcesA5EOUj1MOA T65_;
			NimStringV2 T66_;
			if (!((*src_1).kind >= ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)36) && (*src_1).kind <= ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)38))) goto LA63_;
			T65_[0] = (*r_p2).res;
			T66_.len = 0; T66_.p = NIM_NIL;
			T66_ = percent___jsgen_u7001(T65_, 1);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T66_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T66_);
		}
		goto LA52_;
LA63_: ;
		{
			tyArray__YgExxhfgKcesA5EOUj1MOA T70_;
			NimStringV2 T71_;
			if (!((*src_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)44))) goto LA68_;
			T70_[0] = (*r_p2).res;
			T71_.len = 0; T71_.p = NIM_NIL;
			T71_ = percent___jsgen_u7010(T70_, 1);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T71_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T71_);
		}
		goto LA52_;
LA68_: ;
LA52_: ;
	}
	goto LA10_;
LA50_: ;
	{
		NIM_BOOL T73_;
		T73_ = (NIM_BOOL)0;
		T73_ = ((*dest_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)44));
		if (!(T73_)) goto LA74_;
		T73_ = (((*(*(*p_p0).module).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)56)))&63U)))!=0);
LA74_: ;
		if (!T73_) goto LA75_;
		{
			NIM_BOOL T79_;
			tyArray__YgExxhfgKcesA5EOUj1MOA T83_;
			NimStringV2 T84_;
			T79_ = (NIM_BOOL)0;
			T79_ = fromUint_1;
			if (T79_) goto LA80_;
			T79_ = ((*src_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)1) || (*src_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)2) || (*src_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)14));
LA80_: ;
			if (!T79_) goto LA81_;
			T83_[0] = (*r_p2).res;
			T84_.len = 0; T84_.p = NIM_NIL;
			T84_ = percent___jsgen_u6992(T83_, 1);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T84_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T84_);
		}
		goto LA77_;
LA81_: ;
		{
			tyArray__YgExxhfgKcesA5EOUj1MOA T88_;
			NimStringV2 T89_;
			if (!fromInt_1) goto LA86_;
			T88_[0] = (*r_p2).res;
			T89_.len = 0; T89_.p = NIM_NIL;
			T89_ = percent___jsgen_u7031(T88_, 1);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T89_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T89_);
		}
		goto LA77_;
LA86_: ;
		{
			tyArray__YgExxhfgKcesA5EOUj1MOA T93_;
			NimStringV2 T94_;
			if (!((*src_1).kind >= ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)36) && (*src_1).kind <= ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)38))) goto LA91_;
			T93_[0] = (*r_p2).res;
			T94_.len = 0; T94_.p = NIM_NIL;
			T94_ = percent___jsgen_u7040(T93_, 1);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T94_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T94_);
		}
		goto LA77_;
LA91_: ;
		{
			tyArray__YgExxhfgKcesA5EOUj1MOA T98_;
			NimStringV2 T99_;
			if (!((*src_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)35))) goto LA96_;
			T98_[0] = (*r_p2).res;
			T99_.len = 0; T99_.p = NIM_NIL;
			T99_ = percent___jsgen_u7049(T98_, 1);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T99_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T99_);
		}
		goto LA77_;
LA96_: ;
LA77_: ;
	}
	goto LA10_;
LA75_: ;
	{
		tyObject_HSlice__Td0KDtM8kU0p7CVwrbJeww T101_;
		NIM_BOOL T102_;
		T101_ = dotdot___semfold_u987(((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)36), ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)38));
		T102_ = (NIM_BOOL)0;
		T102_ = contains__semfold_u1019(T101_, (*dest_1).kind);
		if (!T102_) goto LA103_;
		{
			NIM_BOOL T107_;
			tyArray__YgExxhfgKcesA5EOUj1MOA T111_;
			NimStringV2 T112_;
			T107_ = (NIM_BOOL)0;
			T107_ = ((*src_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)35) || (*src_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)44));
			if (!(T107_)) goto LA108_;
			T107_ = (((*(*(*p_p0).module).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)56)))&63U)))!=0);
LA108_: ;
			if (!T107_) goto LA109_;
			T111_[0] = (*r_p2).res;
			T112_.len = 0; T112_.p = NIM_NIL;
			T112_ = percent___jsgen_u5262(T111_, 1);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T112_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T112_);
		}
LA109_: ;
	}
	goto LA10_;
LA103_: ;
	{
		NIM_BOOL T114_;
		NIM_BOOL T116_;
		tyArray__YgExxhfgKcesA5EOUj1MOA T120_;
		NimStringV2 T121_;
		T114_ = (NIM_BOOL)0;
		T114_ = ((*dest_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)2));
		if (!(T114_)) goto LA115_;
		T116_ = (NIM_BOOL)0;
		T116_ = fromInt_1;
		if (T116_) goto LA117_;
		T116_ = fromUint_1;
LA117_: ;
		T114_ = T116_;
LA115_: ;
		if (!T114_) goto LA118_;
		T120_[0] = (*r_p2).res;
		T121_.len = 0; T121_.p = NIM_NIL;
		T121_ = percent___jsgen_u7943(T120_, 1);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T121_); goto LA1_;}
		eqsink___system_u2700((&(*r_p2).res), T121_);
	}
	goto LA10_;
LA118_: ;
	{
		NIM_BOOL T123_;
		NIM_BOOL T124_;
		tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg T126_;
		T123_ = (NIM_BOOL)0;
		T124_ = (NIM_BOOL)0;
		T124_ = ((*src_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)21));
		if (!(T124_)) goto LA125_;
		T126_ = (tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)0;
		T126_ = mapType__jsgen_u698(p_p0, src_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T124_ = (T126_ == ((tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)8));
LA125_: ;
		T123_ = T124_;
		if (!(T123_)) goto LA127_;
		T123_ = ((*dest_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)26));
LA127_: ;
		if (!T123_) goto LA128_;
		eqcopy___system_u2694((&(*r_p2).address), (*r_p2).res);
		eqsink___system_u2700((&(*r_p2).res), TM__BxLwT0mhrtgTPodf1v3xjg_692);
		(*r_p2).typ = ((tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)9);
	}
	goto LA10_;
LA128_: ;
	{
		NIM_BOOL T131_;
		NIM_BOOL T132_;
		tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg T134_;
		T131_ = (NIM_BOOL)0;
		T132_ = (NIM_BOOL)0;
		T132_ = ((*dest_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)21));
		if (!(T132_)) goto LA133_;
		T134_ = (tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)0;
		T134_ = mapType__jsgen_u698(p_p0, dest_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T132_ = (T134_ == ((tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)8));
LA133_: ;
		T131_ = T132_;
		if (!(T131_)) goto LA135_;
		T131_ = ((*src_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)26));
LA135_: ;
		if (!T131_) goto LA136_;
		eqcopy___system_u2694((&(*r_p2).res), (*r_p2).address);
		(*r_p2).typ = ((tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)8);
	}
	goto LA10_;
LA136_: ;
LA10_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(src_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(dest_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genRangeChck__jsgen_u7136)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* r_p2, NimStringV2 magic_p3) {
	tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ a_1;
	tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ b_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* src_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* dest_1;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&a_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
	nimZeroMem((void*)(&b_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
	src_1 = NIM_NIL;
	dest_1 = NIM_NIL;
	nimZeroMem((void*)(&a_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
	nimZeroMem((void*)(&b_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
	gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)0)], r_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	src_1 = skipTypes__ast_u5379((*(*n_p1)._kind_6.sons.p->data[((NI)0)]).typField, TM__BxLwT0mhrtgTPodf1v3xjg_358);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	dest_1 = skipTypes__ast_u5379((*n_p1).typField, TM__BxLwT0mhrtgTPodf1v3xjg_358);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		if (!!((((*p_p0).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)3)))&31U)))!=0))) goto LA4_;
		{
			NIM_BOOL T8_;
			NIM_BOOL T9_;
			tyArray__YgExxhfgKcesA5EOUj1MOA T14_;
			NimStringV2 T15_;
			T8_ = (NIM_BOOL)0;
			T9_ = (NIM_BOOL)0;
			T9_ = (((*(*(*p_p0).module).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)56)))&63U)))!=0);
			if (!(T9_)) goto LA10_;
			T9_ = ((*dest_1).kind >= ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)40) && (*dest_1).kind <= ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)43) || (*dest_1).kind >= ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)31) && (*dest_1).kind <= ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)34));
LA10_: ;
			T8_ = T9_;
			if (!(T8_)) goto LA11_;
			T8_ = ((*src_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)35) || (*src_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)44));
LA11_: ;
			if (!T8_) goto LA12_;
			T14_[0] = (*r_p2).res;
			T15_.len = 0; T15_.p = NIM_NIL;
			T15_ = percent___jsgen_u5262(T14_, 1);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T15_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T15_);
		}
		goto LA6_;
LA12_: ;
		{
		}
LA6_: ;
	}
	goto LA2_;
LA4_: ;
	{
		NIM_BOOL T18_;
		T18_ = (NIM_BOOL)0;
		T18_ = ((*dest_1).kind >= ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)40) && (*dest_1).kind <= ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)44));
		if (!(T18_)) goto LA19_;
		T18_ = !((((*(*(*p_p0).module).config).legacyFeatures &((NU8)1<<((NU)((((tyEnum_LegacyFeature__yvNVqOQTgcxHpvo1MvfBfA)1)))&7U)))!=0));
LA19_: ;
		if (!T18_) goto LA20_;
		{
			NIM_BOOL T24_;
			NimStringV2 colontmpD_;
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T28_;
			NimStringV2 T29_;
			T24_ = (NIM_BOOL)0;
			T24_ = ((*src_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)35) || (*src_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)44));
			if (!(T24_)) goto LA25_;
			T24_ = (((*(*(*p_p0).module).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)56)))&63U)))!=0);
LA25_: ;
			if (!T24_) goto LA26_;
			colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
			colontmpD_ = dollar___systemZdollars_u29((NI64)((*dest_1).size * IL64(8)));
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			T28_[0] = colontmpD_;
			T28_[1] = (*r_p2).res;
			T29_.len = 0; T29_.p = NIM_NIL;
			T29_ = percent___jsgen_u7189(T28_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T29_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T29_);
			eqdestroy___system_u2691(colontmpD_);
		}
		goto LA22_;
LA26_: ;
		{
			NimStringV2 colontmpD__2;
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T31_;
			NimStringV2 T32_;
			colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
			colontmpD__2 = dollar___systemZdollars_u29((NI64)((*dest_1).size * IL64(8)));
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			T31_[0] = colontmpD__2;
			T31_[1] = (*r_p2).res;
			T32_.len = 0; T32_.p = NIM_NIL;
			T32_ = percent___jsgen_u7194(T31_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T32_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T32_);
			eqdestroy___system_u2691(colontmpD__2);
		}
LA22_: ;
		{
			NIM_BOOL T35_;
			tyArray__YgExxhfgKcesA5EOUj1MOA T39_;
			NimStringV2 T40_;
			T35_ = (NIM_BOOL)0;
			T35_ = ((*dest_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)44));
			if (!(T35_)) goto LA36_;
			T35_ = (((*(*(*p_p0).module).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)56)))&63U)))!=0);
LA36_: ;
			if (!!(T35_)) goto LA37_;
			T39_[0] = (*r_p2).res;
			T40_.len = 0; T40_.p = NIM_NIL;
			T40_ = percent___jsgen_u5262(T39_, 1);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T40_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T40_);
		}
LA37_: ;
	}
	goto LA2_;
LA20_: ;
	{
		tyArray__dyW7vpmfeTYw8kX3EXuaJA T52_;
		NimStringV2 T53_;
		{
			NIM_BOOL T44_;
			NIM_BOOL T45_;
			tyArray__YgExxhfgKcesA5EOUj1MOA T50_;
			NimStringV2 T51_;
			T44_ = (NIM_BOOL)0;
			T45_ = (NIM_BOOL)0;
			T45_ = ((*src_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)35) || (*src_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)44));
			if (!(T45_)) goto LA46_;
			T45_ = !(((*dest_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)35) || (*dest_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)44)));
LA46_: ;
			T44_ = T45_;
			if (!(T44_)) goto LA47_;
			T44_ = (((*(*(*p_p0).module).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)56)))&63U)))!=0);
LA47_: ;
			if (!T44_) goto LA48_;
			T50_[0] = (*r_p2).res;
			T51_.len = 0; T51_.p = NIM_NIL;
			T51_ = percent___jsgen_u5262(T50_, 1);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T51_); goto LA1_;}
			eqsink___system_u2700((&(*r_p2).res), T51_);
		}
LA48_: ;
		gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], (&a_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)2)], (&b_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		useMagic__jsgen_u1172(p_p0, TM__BxLwT0mhrtgTPodf1v3xjg_694);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T52_[0] = (*r_p2).res;
		T52_[1] = a_1.res;
		T52_[2] = b_1.res;
		T53_.len = 0; T53_.p = NIM_NIL;
		T53_ = percent___jsgen_u7227(T52_, 3);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T53_); goto LA1_;}
		eqsink___system_u2700((&(*r_p2).res), T53_);
		(*r_p2).kind = ((tyEnum_TResKind__UiCSai1lX4RMkJ9bHo9aP2HA)1);
	}
LA2_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(dest_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(src_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___jsgen_u570((&b_1));
		eqdestroy___jsgen_u570((&a_1));
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, convStrToCStr__jsgen_u7232)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* r_p2) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!((*(*n_p1)._kind_6.sons.p->data[((NI)0)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)72))) goto LA3_;
		gen__jsgen_u1159(p_p0, (*(*n_p1)._kind_6.sons.p->data[((NI)0)])._kind_6.sons.p->data[((NI)0)], r_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA3_: ;
	{
		tyArray__YgExxhfgKcesA5EOUj1MOA T10_;
		NimStringV2 T11_;
		gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)0)], r_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		{
			if (!((*r_p2).res.len == 0)) goto LA8_;
			internalErrorImpl__msgs_u1598((*(*p_p0).module).config, (*n_p1).info, TM__BxLwT0mhrtgTPodf1v3xjg_701, (&TM__BxLwT0mhrtgTPodf1v3xjg_702));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA8_: ;
		useMagic__jsgen_u1172(p_p0, TM__BxLwT0mhrtgTPodf1v3xjg_703);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T10_[0] = (*r_p2).res;
		T11_.len = 0; T11_.p = NIM_NIL;
		T11_ = percent___jsgen_u7240(T10_, 1);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T11_); goto BeforeRet_;}
		eqsink___system_u2700((&(*r_p2).res), T11_);
		(*r_p2).kind = ((tyEnum_TResKind__UiCSai1lX4RMkJ9bHo9aP2HA)1);
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, convCStrToStr__jsgen_u7245)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* r_p2) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!((*(*n_p1)._kind_6.sons.p->data[((NI)0)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)71))) goto LA3_;
		gen__jsgen_u1159(p_p0, (*(*n_p1)._kind_6.sons.p->data[((NI)0)])._kind_6.sons.p->data[((NI)0)], r_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA3_: ;
	{
		tyArray__YgExxhfgKcesA5EOUj1MOA T10_;
		NimStringV2 T11_;
		gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)0)], r_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		{
			if (!((*r_p2).res.len == 0)) goto LA8_;
			internalErrorImpl__msgs_u1598((*(*p_p0).module).config, (*n_p1).info, TM__BxLwT0mhrtgTPodf1v3xjg_705, (&TM__BxLwT0mhrtgTPodf1v3xjg_706));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA8_: ;
		useMagic__jsgen_u1172(p_p0, TM__BxLwT0mhrtgTPodf1v3xjg_707);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T10_[0] = (*r_p2).res;
		T11_.len = 0; T11_.p = NIM_NIL;
		T11_ = percent___jsgen_u2485(T10_, 1);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T11_); goto BeforeRet_;}
		eqsink___system_u2700((&(*r_p2).res), T11_);
		(*r_p2).kind = ((tyEnum_TResKind__UiCSai1lX4RMkJ9bHo9aP2HA)1);
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genBlock__jsgen_u3130)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* r_p2) {
	NimStringV2 colontmpD_;
	NimStringV2 colontmpD__2;
	NimStringV2 colontmpD__3;
	NimStringV2 colontmpD__4;
	NimStringV2 colontmpD__5;
	NimStringV2 colontmpD__6;
	NI idx_1;
	NI T2_;
NIM_BOOL oldNimErrFin7_;
	NI labl_1;
	tyArray__YgExxhfgKcesA5EOUj1MOA T14_;
	tyArray__YgExxhfgKcesA5EOUj1MOA T15_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
	colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
	colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
	colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
	(*p_p0).unique += ((NI)1);
	T2_ = (*p_p0).blocks.len;
	idx_1 = T2_;
	{
		tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_1;
		if (!!(((*(*n_p1)._kind_6.sons.p->data[((NI)0)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)1)))) goto LA5_;
		sym_1 = NIM_NIL;
		{
			if (!!(((*(*n_p1)._kind_6.sons.p->data[((NI)0)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3)))) goto LA10_;
			internalErrorImpl__msgs_u1598((*(*p_p0).module).config, (*n_p1).info, TM__BxLwT0mhrtgTPodf1v3xjg_709, (&TM__BxLwT0mhrtgTPodf1v3xjg_710));
			if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		}
LA10_: ;
		eqcopy___ast_u4577(&sym_1, (*(*n_p1)._kind_6.sons.p->data[((NI)0)])._kind_4.sym);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		(*sym_1).loc.k = ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)10);
		(*sym_1).position = (NI)(idx_1 + ((NI)1));
		{
			LA7_:;
		}
		{
			oldNimErrFin7_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u4574(sym_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin7_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA5_: ;
	labl_1 = (*p_p0).unique;
	colontmpD_ = rope__ropes_u15(((NI64) (labl_1)));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T14_[0] = colontmpD_;
	colontmpD__2 = percent___jsgen_u3153(T14_, 1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__3 = indentLine__jsgen_u102(p_p0, colontmpD__2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&(*p_p0).body), colontmpD__3.len + 0);
appendString((&(*p_p0).body), colontmpD__3);
	setLen__jsgen_u339((&(*p_p0).blocks), ((NI)(idx_1 + ((NI)1))));
	(*p_p0).blocks.p->data[idx_1].id = ((NI64)-((*p_p0).unique));
	gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], r_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	setLen__jsgen_u339((&(*p_p0).blocks), (idx_1));
	colontmpD__4 = rope__ropes_u15(((NI64) (labl_1)));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T15_[0] = colontmpD__4;
	colontmpD__5 = percent___jsgen_u3166(T15_, 1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__6 = indentLine__jsgen_u102(p_p0, colontmpD__5);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&(*p_p0).body), colontmpD__6.len + 0);
appendString((&(*p_p0).body), colontmpD__6);
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD__6);
		eqdestroy___system_u2691(colontmpD__5);
		eqdestroy___system_u2691(colontmpD__4);
		eqdestroy___system_u2691(colontmpD__3);
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(colontmpD_);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, moveInto__jsgen_u2802)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* src_p1, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* dest_p2) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!(((*src_p1).kind == ((tyEnum_TResKind__UiCSai1lX4RMkJ9bHo9aP2HA)0)))) goto LA3_;
		{
			NimStringV2 colontmpD_;
			NimStringV2 colontmpD__2;
			NimStringV2 colontmpD__3;
			NimStringV2 colontmpD__4;
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T9_;
			if (!!(((*dest_p2).kind == ((tyEnum_TResKind__UiCSai1lX4RMkJ9bHo9aP2HA)0)))) goto LA7_;
			colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
			colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
			colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
			colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
			colontmpD_ = rdLoc__jsgen_u593(dest_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			T9_[0] = colontmpD_;
			colontmpD__2 = rdLoc__jsgen_u593((&(*src_p1)));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			T9_[1] = colontmpD__2;
			colontmpD__3 = percent___jsgen_u2814(T9_, 2);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			colontmpD__4 = indentLine__jsgen_u102(p_p0, colontmpD__3);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			prepareAdd((&(*p_p0).body), colontmpD__4.len + 0);
appendString((&(*p_p0).body), colontmpD__4);
			eqdestroy___system_u2691(colontmpD__4);
			eqdestroy___system_u2691(colontmpD__3);
			eqdestroy___system_u2691(colontmpD__2);
			eqdestroy___system_u2691(colontmpD_);
		}
		goto LA5_;
LA7_: ;
		{
			NimStringV2 colontmpD__5;
			NimStringV2 colontmpD__6;
			NimStringV2 colontmpD__7;
			tyArray__YgExxhfgKcesA5EOUj1MOA T11_;
			colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
			colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
			colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
			colontmpD__5 = rdLoc__jsgen_u593((&(*src_p1)));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			T11_[0] = colontmpD__5;
			colontmpD__6 = percent___cgen_u5386(T11_, 1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			colontmpD__7 = indentLine__jsgen_u102(p_p0, colontmpD__6);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			prepareAdd((&(*p_p0).body), colontmpD__7.len + 0);
appendString((&(*p_p0).body), colontmpD__7);
			eqdestroy___system_u2691(colontmpD__7);
			eqdestroy___system_u2691(colontmpD__6);
			eqdestroy___system_u2691(colontmpD__5);
		}
LA5_: ;
		(*src_p1).kind = ((tyEnum_TResKind__UiCSai1lX4RMkJ9bHo9aP2HA)0);
		eqsink___system_u2700((&(*src_p1).res), TM__BxLwT0mhrtgTPodf1v3xjg_711);
	}
LA3_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genIf__jsgen_u3241)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* r_p2) {
	tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ cond_1;
	tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ stmt_1;
	NimStringV2 colontmpD_;
	NimStringV2 colontmpD__2;
	NimStringV2 colontmpD__3;
	NI toClose_1;
NIM_BOOL oldNimErrFin11_;
	NimStringV2 T34_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&cond_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
	nimZeroMem((void*)(&stmt_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
	nimZeroMem((void*)(&cond_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
	nimZeroMem((void*)(&stmt_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
	toClose_1 = ((NI)0);
	{
		NIM_BOOL T4_;
		NimStringV2 T7_;
		T4_ = (NIM_BOOL)0;
		T4_ = isEmptyType__ast_u7234((*n_p1).typField);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!!(T4_)) goto LA5_;
		(*r_p2).kind = ((tyEnum_TResKind__UiCSai1lX4RMkJ9bHo9aP2HA)2);
		T7_.len = 0; T7_.p = NIM_NIL;
		T7_ = getTemp__jsgen_u1235(p_p0, NIM_TRUE);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T7_); goto LA1_;}
		eqsink___system_u2700((&(*r_p2).res), T7_);
	}
LA5_: ;
	{
		NI i_1;
		NI colontmp_;
		NI i_2;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_u3190(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		i_2 = ((NI)0);
		{
			while (1) {
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* it_1;
				NimStringV2 colontmpD__4;
				NimStringV2 colontmpD__5;
				tyArray__TonP9cxJgj8gXu71dWIyNlA T31_;
				if (!(i_2 < colontmp_)) goto LA10;
				it_1 = NIM_NIL;
				colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
				colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
				i_1 = i_2;
				eqcopy___ast_u3255(&it_1, (*n_p1)._kind_6.sons.p->data[i_1]);
				if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
				{
					NI T14_;
					NimStringV2 colontmpD__6;
					NimStringV2 colontmpD__7;
					NimStringV2 colontmpD__8;
					tyArray__YgExxhfgKcesA5EOUj1MOA T23_;
					T14_ = (NI)0;
					T14_ = len__ast_u3190(it_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
					if (!!((T14_ == ((NI)1)))) goto LA15_;
					colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
					colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
					colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
					{
						NimStringV2 colontmpD__9;
						NimStringV2 colontmpD__10;
						tyArray__TonP9cxJgj8gXu71dWIyNlA T22_;
						if (!(((NI)0) < i_1)) goto LA20_;
						colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
						colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
						colontmpD__9 = percent___jsgen_u2864(T22_, 0);
						if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
						colontmpD__10 = indentLine__jsgen_u102(p_p0, colontmpD__9);
						if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
						prepareAdd((&(*p_p0).body), colontmpD__10.len + 0);
appendString((&(*p_p0).body), colontmpD__10);
						toClose_1 += ((NI)1);
						eqdestroy___system_u2691(colontmpD__10);
						eqdestroy___system_u2691(colontmpD__9);
					}
LA20_: ;
					(*p_p0).extraIndent += ((NI)1);
					gen__jsgen_u1159(p_p0, (*it_1)._kind_6.sons.p->data[((NI)0)], (&cond_1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
					(*p_p0).extraIndent -= ((NI)1);
					colontmpD__6 = rdLoc__jsgen_u593((&cond_1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
					T23_[0] = colontmpD__6;
					colontmpD__7 = percent___jsgen_u3281(T23_, 1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
					colontmpD__8 = indentLine__jsgen_u102(p_p0, colontmpD__7);
					if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
					prepareAdd((&(*p_p0).body), colontmpD__8.len + 0);
appendString((&(*p_p0).body), colontmpD__8);
					gen__jsgen_u1159(p_p0, (*it_1)._kind_6.sons.p->data[((NI)1)], (&stmt_1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
					{
						LA17_:;
					}
					{
						eqdestroy___system_u2691(colontmpD__8);
						eqdestroy___system_u2691(colontmpD__7);
						eqdestroy___system_u2691(colontmpD__6);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
				}
				goto LA12_;
LA15_: ;
				{
					NimStringV2 colontmpD__11;
					NimStringV2 colontmpD__12;
					tyArray__TonP9cxJgj8gXu71dWIyNlA T28_;
					colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
					colontmpD__12.len = 0; colontmpD__12.p = NIM_NIL;
					colontmpD__11 = percent___jsgen_u2864(T28_, 0);
					if (NIM_UNLIKELY(*nimErr_)) goto LA27_;
					colontmpD__12 = indentLine__jsgen_u102(p_p0, colontmpD__11);
					if (NIM_UNLIKELY(*nimErr_)) goto LA27_;
					prepareAdd((&(*p_p0).body), colontmpD__12.len + 0);
appendString((&(*p_p0).body), colontmpD__12);
					(*p_p0).extraIndent += ((NI)1);
					gen__jsgen_u1159(p_p0, (*it_1)._kind_6.sons.p->data[((NI)0)], (&stmt_1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA27_;
					(*p_p0).extraIndent -= ((NI)1);
					{
						LA27_:;
					}
					{
						eqdestroy___system_u2691(colontmpD__12);
						eqdestroy___system_u2691(colontmpD__11);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
				}
LA12_: ;
				moveInto__jsgen_u2802(p_p0, (&stmt_1), (&(*r_p2)));
				if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
				colontmpD__4 = percent___cgen_u9681(T31_, 0);
				if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
				colontmpD__5 = indentLine__jsgen_u102(p_p0, colontmpD__4);
				if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
				prepareAdd((&(*p_p0).body), colontmpD__5.len + 0);
appendString((&(*p_p0).body), colontmpD__5);
				i_2 += ((NI)1);
				{
					LA11_:;
				}
				{
					oldNimErrFin11_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___system_u2691(colontmpD__5);
					eqdestroy___system_u2691(colontmpD__4);
					eqdestroy___ast_u3252(it_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin11_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			} LA10: ;
		}
	}
	T34_.len = 0; T34_.p = NIM_NIL;
	colontmpD_ = nsuRepeatChar(125, (toClose_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T34_ = rawNewString(colontmpD_.len + 1);
appendString((&T34_), colontmpD_);
appendString((&T34_), TM__BxLwT0mhrtgTPodf1v3xjg_712);
	colontmpD__2 = T34_;
	colontmpD__3 = indentLine__jsgen_u102(p_p0, colontmpD__2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&(*p_p0).body), colontmpD__3.len + 0);
appendString((&(*p_p0).body), colontmpD__3);
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD__3);
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___jsgen_u570((&stmt_1));
		eqdestroy___jsgen_u570((&cond_1));
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(tyObject_TBlock__e4aohBvIZbqlrYGhrE9cgpw*, X5BX5D___jsgen_u2710)(tyObject_TBlock__e4aohBvIZbqlrYGhrE9cgpw* s_p0, NI s_p0Len_0, NI i_p1) {
	tyObject_TBlock__e4aohBvIZbqlrYGhrE9cgpw* result;
	result = (&s_p0[(NI)(s_p0Len_0 - i_p1)]);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genWhileStmt__jsgen_u2686)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
	tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ cond_1;
	NimStringV2 labl_1;
	NimStringV2 colontmpD_;
	NimStringV2 colontmpD__2;
	NimStringV2 colontmpD__3;
	NimStringV2 colontmpD__4;
	NimStringV2 colontmpD__5;
	NimStringV2 colontmpD__6;
	NI T10_;
	tyObject_TBlock__e4aohBvIZbqlrYGhrE9cgpw* T11_;
	tyObject_TBlock__e4aohBvIZbqlrYGhrE9cgpw* T12_;
	tyArray__YgExxhfgKcesA5EOUj1MOA T13_;
	tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T14_;
	tyArray__YgExxhfgKcesA5EOUj1MOA T15_;
	NI T16_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&cond_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
	labl_1.len = 0; labl_1.p = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
	colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
	colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
	colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
	nimZeroMem((void*)(&cond_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
	{
		NIM_BOOL T4_;
		NimStringV2 argX60gensym471__1;
		T4_ = (NIM_BOOL)0;
		T4_ = isEmptyType__ast_u7234((*n_p1).typField);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!!(T4_)) goto LA5_;
		argX60gensym471__1.len = 0; argX60gensym471__1.p = NIM_NIL;
		argX60gensym471__1 = toFileLineCol__msgs_u701((&TM__BxLwT0mhrtgTPodf1v3xjg_713));
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		internalErrorImpl__msgs_u1598((*(*p_p0).module).config, unknownLineInfo__lineinfos_u364, argX60gensym471__1, (&TM__BxLwT0mhrtgTPodf1v3xjg_713));
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		{
			LA7_:;
		}
		{
			eqdestroy___system_u2691(argX60gensym471__1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA5_: ;
	genLineDir__jsgen_u2646(p_p0, n_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	(*p_p0).unique += ((NI)1);
	T10_ = (*p_p0).blocks.len;
	setLen__jsgen_u339((&(*p_p0).blocks), ((NI)(T10_ + ((NI)1))));
	T11_ = (tyObject_TBlock__e4aohBvIZbqlrYGhrE9cgpw*)0;
	T11_ = X5BX5D___jsgen_u2710((((*p_p0).blocks).p) ? ((*p_p0).blocks.p->data) : NIM_NIL, (*p_p0).blocks.len, ((NI)1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	(*T11_).id = ((NI64)-((*p_p0).unique));
	T12_ = (tyObject_TBlock__e4aohBvIZbqlrYGhrE9cgpw*)0;
	T12_ = X5BX5D___jsgen_u2710((((*p_p0).blocks).p) ? ((*p_p0).blocks.p->data) : NIM_NIL, (*p_p0).blocks.len, ((NI)1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	(*T12_).isLoop = NIM_TRUE;
	labl_1 = rope__ropes_u15(((NI64) ((*p_p0).unique)));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T13_[0] = labl_1;
	colontmpD_ = percent___jsgen_u2743(T13_, 1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__2 = indentLine__jsgen_u102(p_p0, colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&(*p_p0).body), colontmpD__2.len + 0);
appendString((&(*p_p0).body), colontmpD__2);
	(*p_p0).extraIndent += ((NI)1);
	gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)0)], (&cond_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	(*p_p0).extraIndent -= ((NI)1);
	T14_[0] = cond_1.res;
	T14_[1] = labl_1;
	colontmpD__3 = percent___jsgen_u2758(T14_, 2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__4 = indentLine__jsgen_u102(p_p0, colontmpD__3);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&(*p_p0).body), colontmpD__4.len + 0);
appendString((&(*p_p0).body), colontmpD__4);
	(*p_p0).extraIndent += ((NI)1);
	genStmt__jsgen_u1163(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)]);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	(*p_p0).extraIndent -= ((NI)1);
	T15_[0] = labl_1;
	colontmpD__5 = percent___cgen_u9681(T15_, 1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__6 = indentLine__jsgen_u102(p_p0, colontmpD__5);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&(*p_p0).body), colontmpD__6.len + 0);
appendString((&(*p_p0).body), colontmpD__6);
	T16_ = (*p_p0).blocks.len;
	setLen__jsgen_u339((&(*p_p0).blocks), ((NI)(T16_ - ((NI)1))));
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD__6);
		eqdestroy___system_u2691(colontmpD__5);
		eqdestroy___system_u2691(colontmpD__4);
		eqdestroy___system_u2691(colontmpD__3);
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___system_u2691(labl_1);
		eqdestroy___jsgen_u570((&cond_1));
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___jsgen_u58)(tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg e_p0) {
	NimStringV2 result;
	switch (e_p0) {
	case ((tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)0):
	{
		result = TM__BxLwT0mhrtgTPodf1v3xjg_721;
	}
	break;
	case ((tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)1):
	{
		result = TM__BxLwT0mhrtgTPodf1v3xjg_723;
	}
	break;
	case ((tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)2):
	{
		result = TM__BxLwT0mhrtgTPodf1v3xjg_725;
	}
	break;
	case ((tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)3):
	{
		result = TM__BxLwT0mhrtgTPodf1v3xjg_727;
	}
	break;
	case ((tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)4):
	{
		result = TM__BxLwT0mhrtgTPodf1v3xjg_729;
	}
	break;
	case ((tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)5):
	{
		result = TM__BxLwT0mhrtgTPodf1v3xjg_731;
	}
	break;
	case ((tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)6):
	{
		result = TM__BxLwT0mhrtgTPodf1v3xjg_733;
	}
	break;
	case ((tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)7):
	{
		result = TM__BxLwT0mhrtgTPodf1v3xjg_735;
	}
	break;
	case ((tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)8):
	{
		result = TM__BxLwT0mhrtgTPodf1v3xjg_737;
	}
	break;
	case ((tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)9):
	{
		result = TM__BxLwT0mhrtgTPodf1v3xjg_739;
	}
	break;
	default:
	{
		result = TM__BxLwT0mhrtgTPodf1v3xjg_741;
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genAsgnAux__jsgen_u3406)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* x_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* y_p2, NIM_BOOL noCopyNeeded_p3) {
	tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ a_1;
	tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ b_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__2;
	tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg xtyp_1;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&a_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
	nimZeroMem((void*)(&b_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
	colontmpD_ = NIM_NIL;
	colontmpD__2 = NIM_NIL;
	nimZeroMem((void*)(&a_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
	nimZeroMem((void*)(&b_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
	xtyp_1 = mapType__jsgen_u698(p_p0, (*x_p1).typField);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NIM_BOOL T4_;
		NIM_BOOL T5_;
		NI T7_;
		T4_ = (NIM_BOOL)0;
		T5_ = (NIM_BOOL)0;
		T5_ = ((*x_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)42));
		if (!(T5_)) goto LA6_;
		T7_ = (NI)0;
		T7_ = len__ast_u3190(x_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T5_ = (((NI)2) <= T7_);
LA6_: ;
		T4_ = T5_;
		if (!(T4_)) goto LA8_;
		colontmpD_ = skipTypes__ast_u5379((*(*x_p1)._kind_6.sons.p->data[((NI)0)]).typField, TM__BxLwT0mhrtgTPodf1v3xjg_175);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T4_ = ((*colontmpD_).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)29));
LA8_: ;
		if (!T4_) goto LA9_;
		liMessage__msgs_u1227((*(*p_p0).module).config, (*x_p1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), TM__BxLwT0mhrtgTPodf1v3xjg_715, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__BxLwT0mhrtgTPodf1v3xjg_716), NIM_FALSE, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA9_: ;
	gen__jsgen_u1159(p_p0, x_p1, (&a_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	genLineDir__jsgen_u2646(p_p0, y_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	gen__jsgen_u1159(p_p0, y_p2, (&b_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		colontmpD__2 = skipTypes__ast_u5379((*x_p1).typField, TM__BxLwT0mhrtgTPodf1v3xjg_175);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!((*colontmpD__2).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)24) || (*colontmpD__2).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)28))) goto LA13_;
		xtyp_1 = ((tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)4);
	}
LA13_: ;
	switch (xtyp_1) {
	case ((tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)4):
	{
		{
			NIM_BOOL T18_;
			NIM_BOOL T19_;
			NIM_BOOL T21_;
			NimStringV2 colontmpD__3;
			NimStringV2 colontmpD__4;
			NimStringV2 colontmpD__5;
			NimStringV2 colontmpD__6;
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T26_;
			T18_ = (NIM_BOOL)0;
			T19_ = (NIM_BOOL)0;
			T19_ = ((*(*x_p1).typField).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)23) || (*(*x_p1).typField).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)47));
			if (T19_) goto LA20_;
			T21_ = (NIM_BOOL)0;
			T21_ = needsNoCopy__jsgen_u3374(p_p0, y_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			if (!(T21_)) goto LA22_;
			T21_ = needsNoCopy__jsgen_u3374(p_p0, x_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
LA22_: ;
			T19_ = T21_;
LA20_: ;
			T18_ = T19_;
			if (T18_) goto LA23_;
			T18_ = noCopyNeeded_p3;
LA23_: ;
			if (!T18_) goto LA24_;
			colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
			colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
			colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
			colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
			colontmpD__3 = rdLoc__jsgen_u593((&a_1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			T26_[0] = colontmpD__3;
			colontmpD__4 = rdLoc__jsgen_u593((&b_1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			T26_[1] = colontmpD__4;
			colontmpD__5 = percent___jsgen_u2814(T26_, 2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			colontmpD__6 = indentLine__jsgen_u102(p_p0, colontmpD__5);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			prepareAdd((&(*p_p0).body), colontmpD__6.len + 0);
appendString((&(*p_p0).body), colontmpD__6);
			eqdestroy___system_u2691(colontmpD__6);
			eqdestroy___system_u2691(colontmpD__5);
			eqdestroy___system_u2691(colontmpD__4);
			eqdestroy___system_u2691(colontmpD__3);
		}
		goto LA16_;
LA24_: ;
		{
			NimStringV2 colontmpD__7;
			NimStringV2 colontmpD__8;
			NimStringV2 colontmpD__9;
			NimStringV2 colontmpD__10;
			tyArray__dyW7vpmfeTYw8kX3EXuaJA T29_;
			colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
			colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
			colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
			colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
			useMagic__jsgen_u1172(p_p0, TM__BxLwT0mhrtgTPodf1v3xjg_717);
			if (NIM_UNLIKELY(*nimErr_)) goto LA28_;
			colontmpD__7 = rdLoc__jsgen_u593((&a_1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA28_;
			T29_[0] = colontmpD__7;
			T29_[1] = b_1.res;
			colontmpD__8 = genTypeInfo__jsgen_u828(p_p0, (*y_p2).typField);
			if (NIM_UNLIKELY(*nimErr_)) goto LA28_;
			T29_[2] = colontmpD__8;
			colontmpD__9 = percent___jsgen_u3442(T29_, 3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA28_;
			colontmpD__10 = indentLine__jsgen_u102(p_p0, colontmpD__9);
			if (NIM_UNLIKELY(*nimErr_)) goto LA28_;
			prepareAdd((&(*p_p0).body), colontmpD__10.len + 0);
appendString((&(*p_p0).body), colontmpD__10);
			{
				LA28_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__10);
				eqdestroy___system_u2691(colontmpD__9);
				eqdestroy___system_u2691(colontmpD__8);
				eqdestroy___system_u2691(colontmpD__7);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA16_: ;
	}
	break;
	case ((tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)8):
	{
		{
			NIM_BOOL T35_;
			NIM_BOOL T36_;
			NIM_BOOL T38_;
			NimStringV2 colontmpD__11;
			NimStringV2 colontmpD__12;
			NimStringV2 colontmpD__13;
			NimStringV2 colontmpD__14;
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T43_;
			T35_ = (NIM_BOOL)0;
			T36_ = (NIM_BOOL)0;
			T36_ = ((*(*x_p1).typField).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)23) || (*(*x_p1).typField).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)47) || (*(*x_p1).typField).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)27) || (*(*x_p1).typField).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)48));
			if (T36_) goto LA37_;
			T38_ = (NIM_BOOL)0;
			T38_ = needsNoCopy__jsgen_u3374(p_p0, y_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			if (!(T38_)) goto LA39_;
			T38_ = needsNoCopy__jsgen_u3374(p_p0, x_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
LA39_: ;
			T36_ = T38_;
LA37_: ;
			T35_ = T36_;
			if (T35_) goto LA40_;
			T35_ = noCopyNeeded_p3;
LA40_: ;
			if (!T35_) goto LA41_;
			colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
			colontmpD__12.len = 0; colontmpD__12.p = NIM_NIL;
			colontmpD__13.len = 0; colontmpD__13.p = NIM_NIL;
			colontmpD__14.len = 0; colontmpD__14.p = NIM_NIL;
			colontmpD__11 = rdLoc__jsgen_u593((&a_1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			T43_[0] = colontmpD__11;
			colontmpD__12 = rdLoc__jsgen_u593((&b_1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			T43_[1] = colontmpD__12;
			colontmpD__13 = percent___jsgen_u2814(T43_, 2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			colontmpD__14 = indentLine__jsgen_u102(p_p0, colontmpD__13);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			prepareAdd((&(*p_p0).body), colontmpD__14.len + 0);
appendString((&(*p_p0).body), colontmpD__14);
			eqdestroy___system_u2691(colontmpD__14);
			eqdestroy___system_u2691(colontmpD__13);
			eqdestroy___system_u2691(colontmpD__12);
			eqdestroy___system_u2691(colontmpD__11);
		}
		goto LA33_;
LA41_: ;
		{
			useMagic__jsgen_u1172(p_p0, TM__BxLwT0mhrtgTPodf1v3xjg_718);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			{
				NIM_BOOL T47_;
				NimStringV2 colontmpD__15;
				NimStringV2 colontmpD__16;
				NimStringV2 colontmpD__17;
				tyArray__dyW7vpmfeTYw8kX3EXuaJA T52_;
				T47_ = (NIM_BOOL)0;
				T47_ = ((*x_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)65) || (*x_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)47));
				if (!(T47_)) goto LA48_;
				T47_ = ((*(*x_p1)._kind_6.sons.p->data[((NI)0)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)27) || (*(*x_p1)._kind_6.sons.p->data[((NI)0)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)29) || (*(*x_p1)._kind_6.sons.p->data[((NI)0)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)30) || (*(*x_p1)._kind_6.sons.p->data[((NI)0)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)31) || (*(*x_p1)._kind_6.sons.p->data[((NI)0)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)26) || (*(*x_p1)._kind_6.sons.p->data[((NI)0)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)28) || (*(*x_p1)._kind_6.sons.p->data[((NI)0)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)32));
LA48_: ;
				if (!T47_) goto LA49_;
				colontmpD__15.len = 0; colontmpD__15.p = NIM_NIL;
				colontmpD__16.len = 0; colontmpD__16.p = NIM_NIL;
				colontmpD__17.len = 0; colontmpD__17.p = NIM_NIL;
				T52_[0] = a_1.res;
				T52_[1] = b_1.res;
				colontmpD__15 = genTypeInfo__jsgen_u828(p_p0, (*x_p1).typField);
				if (NIM_UNLIKELY(*nimErr_)) goto LA51_;
				T52_[2] = colontmpD__15;
				colontmpD__16 = percent___jsgen_u3463(T52_, 3);
				if (NIM_UNLIKELY(*nimErr_)) goto LA51_;
				colontmpD__17 = indentLine__jsgen_u102(p_p0, colontmpD__16);
				if (NIM_UNLIKELY(*nimErr_)) goto LA51_;
				prepareAdd((&(*p_p0).body), colontmpD__17.len + 0);
appendString((&(*p_p0).body), colontmpD__17);
				{
					LA51_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__17);
					eqdestroy___system_u2691(colontmpD__16);
					eqdestroy___system_u2691(colontmpD__15);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			goto LA45_;
LA49_: ;
			{
				NimStringV2 colontmpD__18;
				NimStringV2 colontmpD__19;
				NimStringV2 colontmpD__20;
				tyArray__dyW7vpmfeTYw8kX3EXuaJA T57_;
				colontmpD__18.len = 0; colontmpD__18.p = NIM_NIL;
				colontmpD__19.len = 0; colontmpD__19.p = NIM_NIL;
				colontmpD__20.len = 0; colontmpD__20.p = NIM_NIL;
				T57_[0] = a_1.res;
				T57_[1] = b_1.res;
				colontmpD__18 = genTypeInfo__jsgen_u828(p_p0, (*x_p1).typField);
				if (NIM_UNLIKELY(*nimErr_)) goto LA56_;
				T57_[2] = colontmpD__18;
				colontmpD__19 = percent___jsgen_u3468(T57_, 3);
				if (NIM_UNLIKELY(*nimErr_)) goto LA56_;
				colontmpD__20 = indentLine__jsgen_u102(p_p0, colontmpD__19);
				if (NIM_UNLIKELY(*nimErr_)) goto LA56_;
				prepareAdd((&(*p_p0).body), colontmpD__20.len + 0);
appendString((&(*p_p0).body), colontmpD__20);
				{
					LA56_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__20);
					eqdestroy___system_u2691(colontmpD__19);
					eqdestroy___system_u2691(colontmpD__18);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
LA45_: ;
		}
LA33_: ;
	}
	break;
	case ((tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)9):
	{
		{
			NIM_BOOL T63_;
			T63_ = (NIM_BOOL)0;
			T63_ = !((a_1.typ == ((tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)9)));
			if (T63_) goto LA64_;
			T63_ = !((b_1.typ == ((tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)9)));
LA64_: ;
			if (!T63_) goto LA65_;
			{
				NimStringV2 tmp_1;
				NimStringV2 colontmpD__21;
				NimStringV2 colontmpD__22;
				NimStringV2 colontmpD__23;
				tyArray__Seu7uK9aaOSN0BK3EAjjSHw T71_;
				if (!((*y_p2).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)27))) goto LA69_;
				tmp_1.len = 0; tmp_1.p = NIM_NIL;
				colontmpD__21.len = 0; colontmpD__21.p = NIM_NIL;
				colontmpD__22.len = 0; colontmpD__22.p = NIM_NIL;
				colontmpD__23.len = 0; colontmpD__23.p = NIM_NIL;
				tmp_1 = getTemp__jsgen_u1235(p_p0, NIM_FALSE);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				T71_[0] = tmp_1;
				T71_[1] = a_1.address;
				T71_[2] = a_1.res;
				colontmpD__21 = rdLoc__jsgen_u593((&b_1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				T71_[3] = colontmpD__21;
				colontmpD__22 = percent___jsgen_u3486(T71_, 4);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				colontmpD__23 = indentLine__jsgen_u102(p_p0, colontmpD__22);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				prepareAdd((&(*p_p0).body), colontmpD__23.len + 0);
appendString((&(*p_p0).body), colontmpD__23);
				eqdestroy___system_u2691(colontmpD__23);
				eqdestroy___system_u2691(colontmpD__22);
				eqdestroy___system_u2691(colontmpD__21);
				eqdestroy___system_u2691(tmp_1);
			}
			goto LA67_;
LA69_: ;
			{
				NimStringV2 colontmpD__24;
				NimStringV2 colontmpD__25;
				tyArray__dyW7vpmfeTYw8kX3EXuaJA T75_;
				if (!(b_1.typ == ((tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)9))) goto LA73_;
				colontmpD__24.len = 0; colontmpD__24.p = NIM_NIL;
				colontmpD__25.len = 0; colontmpD__25.p = NIM_NIL;
				T75_[0] = a_1.res;
				T75_[1] = b_1.address;
				T75_[2] = b_1.res;
				colontmpD__24 = percent___jsgen_u3495(T75_, 3);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				colontmpD__25 = indentLine__jsgen_u102(p_p0, colontmpD__24);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				prepareAdd((&(*p_p0).body), colontmpD__25.len + 0);
appendString((&(*p_p0).body), colontmpD__25);
				eqdestroy___system_u2691(colontmpD__25);
				eqdestroy___system_u2691(colontmpD__24);
			}
			goto LA67_;
LA73_: ;
			{
				NimStringV2 colontmpD__26;
				NimStringV2 colontmpD__27;
				tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T87_;
				if (!(b_1.typ == ((tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)0))) goto LA77_;
				colontmpD__26.len = 0; colontmpD__26.p = NIM_NIL;
				colontmpD__27.len = 0; colontmpD__27.p = NIM_NIL;
				{
					NimStringV2 argX60gensym690__1;
					if (!!((b_1.address.len == 0))) goto LA82_;
					argX60gensym690__1.len = 0; argX60gensym690__1.p = NIM_NIL;
					argX60gensym690__1 = toFileLineCol__msgs_u701((&TM__BxLwT0mhrtgTPodf1v3xjg_719));
					if (NIM_UNLIKELY(*nimErr_)) goto LA84_;
					internalErrorImpl__msgs_u1598((*(*p_p0).module).config, unknownLineInfo__lineinfos_u364, argX60gensym690__1, (&TM__BxLwT0mhrtgTPodf1v3xjg_719));
					if (NIM_UNLIKELY(*nimErr_)) goto LA84_;
					{
						LA84_:;
					}
					{
						eqdestroy___system_u2691(argX60gensym690__1);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA79_;
				}
LA82_: ;
				T87_[0] = a_1.address;
				T87_[1] = b_1.res;
				colontmpD__26 = percent___jsgen_u3508(T87_, 2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA79_;
				colontmpD__27 = indentLine__jsgen_u102(p_p0, colontmpD__26);
				if (NIM_UNLIKELY(*nimErr_)) goto LA79_;
				prepareAdd((&(*p_p0).body), colontmpD__27.len + 0);
appendString((&(*p_p0).body), colontmpD__27);
				{
					LA79_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__27);
					eqdestroy___system_u2691(colontmpD__26);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			goto LA67_;
LA77_: ;
			{
				NIM_BOOL T91_;
				NimStringV2 colontmpD__28;
				NimStringV2 colontmpD__29;
				NimStringV2 colontmpD__30;
				NimStringV2 colontmpD__31;
				NimStringV2 colontmpD__32;
				NimStringV2 colontmpD__33;
				NimStringV2 colontmpD__34;
				NimStringV2 colontmpD__35;
				tyArray__dyW7vpmfeTYw8kX3EXuaJA T95_;
				tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T96_;
				tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T97_;
				T91_ = (NIM_BOOL)0;
				T91_ = ((*(*x_p1).typField).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)23));
				if (!(T91_)) goto LA92_;
				T91_ = ((*(*y_p2).typField).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)21));
LA92_: ;
				if (!T91_) goto LA93_;
				colontmpD__28.len = 0; colontmpD__28.p = NIM_NIL;
				colontmpD__29.len = 0; colontmpD__29.p = NIM_NIL;
				colontmpD__30.len = 0; colontmpD__30.p = NIM_NIL;
				colontmpD__31.len = 0; colontmpD__31.p = NIM_NIL;
				colontmpD__32.len = 0; colontmpD__32.p = NIM_NIL;
				colontmpD__33.len = 0; colontmpD__33.p = NIM_NIL;
				colontmpD__34.len = 0; colontmpD__34.p = NIM_NIL;
				colontmpD__35.len = 0; colontmpD__35.p = NIM_NIL;
				T95_[0] = a_1.res;
				T95_[1] = b_1.address;
				T95_[2] = b_1.res;
				colontmpD__28 = percent___jsgen_u3495(T95_, 3);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				colontmpD__29 = indentLine__jsgen_u102(p_p0, colontmpD__28);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				prepareAdd((&(*p_p0).body), colontmpD__29.len + 0);
appendString((&(*p_p0).body), colontmpD__29);
				T96_[0] = a_1.address;
				T96_[1] = b_1.res;
				colontmpD__30 = percent___jsgen_u2814(T96_, 2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				colontmpD__31 = indentLine__jsgen_u102(p_p0, colontmpD__30);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				prepareAdd((&(*p_p0).body), colontmpD__31.len + 0);
appendString((&(*p_p0).body), colontmpD__31);
				colontmpD__32 = rdLoc__jsgen_u593((&a_1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				T97_[0] = colontmpD__32;
				colontmpD__33 = rdLoc__jsgen_u593((&b_1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				T97_[1] = colontmpD__33;
				colontmpD__34 = percent___jsgen_u2814(T97_, 2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				colontmpD__35 = indentLine__jsgen_u102(p_p0, colontmpD__34);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				prepareAdd((&(*p_p0).body), colontmpD__35.len + 0);
appendString((&(*p_p0).body), colontmpD__35);
				eqdestroy___system_u2691(colontmpD__35);
				eqdestroy___system_u2691(colontmpD__34);
				eqdestroy___system_u2691(colontmpD__33);
				eqdestroy___system_u2691(colontmpD__32);
				eqdestroy___system_u2691(colontmpD__31);
				eqdestroy___system_u2691(colontmpD__30);
				eqdestroy___system_u2691(colontmpD__29);
				eqdestroy___system_u2691(colontmpD__28);
			}
			goto LA67_;
LA93_: ;
			{
				if (!(a_1.typ == ((tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)9))) goto LA99_;
				{
					NimStringV2 colontmpD__36;
					NimStringV2 colontmpD__37;
					tyArray__Seu7uK9aaOSN0BK3EAjjSHw T105_;
					if (!!((b_1.address.len == 0))) goto LA103_;
					colontmpD__36.len = 0; colontmpD__36.p = NIM_NIL;
					colontmpD__37.len = 0; colontmpD__37.p = NIM_NIL;
					T105_[0] = a_1.address;
					T105_[1] = b_1.address;
					T105_[2] = a_1.res;
					T105_[3] = b_1.res;
					colontmpD__36 = percent___jsgen_u3537(T105_, 4);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					colontmpD__37 = indentLine__jsgen_u102(p_p0, colontmpD__36);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					prepareAdd((&(*p_p0).body), colontmpD__37.len + 0);
appendString((&(*p_p0).body), colontmpD__37);
					eqdestroy___system_u2691(colontmpD__37);
					eqdestroy___system_u2691(colontmpD__36);
				}
				goto LA101_;
LA103_: ;
				{
					NimStringV2 colontmpD__38;
					NimStringV2 colontmpD__39;
					tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T107_;
					colontmpD__38.len = 0; colontmpD__38.p = NIM_NIL;
					colontmpD__39.len = 0; colontmpD__39.p = NIM_NIL;
					T107_[0] = a_1.address;
					T107_[1] = b_1.res;
					colontmpD__38 = percent___jsgen_u2814(T107_, 2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					colontmpD__39 = indentLine__jsgen_u102(p_p0, colontmpD__38);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					prepareAdd((&(*p_p0).body), colontmpD__39.len + 0);
appendString((&(*p_p0).body), colontmpD__39);
					eqdestroy___system_u2691(colontmpD__39);
					eqdestroy___system_u2691(colontmpD__38);
				}
LA101_: ;
			}
			goto LA67_;
LA99_: ;
			{
				NimStringV2 colontmpD__40;
				tyTuple__axVdnKAd4XGmBNrMsqQ7kw T110_;
				colontmpD__40.len = 0; colontmpD__40.p = NIM_NIL;
				T110_.Field0 = TM__BxLwT0mhrtgTPodf1v3xjg_743;
				T110_.Field1 = b_1.typ;
				T110_.Field2 = a_1.typ;
				colontmpD__40 = dollar___jsgen_u3546(T110_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA109_;
				internalErrorImpl__msgs_u1598((*(*p_p0).module).config, (*x_p1).info, colontmpD__40, (&TM__BxLwT0mhrtgTPodf1v3xjg_744));
				if (NIM_UNLIKELY(*nimErr_)) goto LA109_;
				{
					LA109_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__40);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
LA67_: ;
		}
		goto LA61_;
LA65_: ;
		{
			NimStringV2 colontmpD__41;
			NimStringV2 colontmpD__42;
			tyArray__Seu7uK9aaOSN0BK3EAjjSHw T116_;
			if (!!((b_1.address.len == 0))) goto LA114_;
			colontmpD__41.len = 0; colontmpD__41.p = NIM_NIL;
			colontmpD__42.len = 0; colontmpD__42.p = NIM_NIL;
			T116_[0] = a_1.address;
			T116_[1] = b_1.address;
			T116_[2] = a_1.res;
			T116_[3] = b_1.res;
			colontmpD__41 = percent___jsgen_u3537(T116_, 4);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			colontmpD__42 = indentLine__jsgen_u102(p_p0, colontmpD__41);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			prepareAdd((&(*p_p0).body), colontmpD__42.len + 0);
appendString((&(*p_p0).body), colontmpD__42);
			eqdestroy___system_u2691(colontmpD__42);
			eqdestroy___system_u2691(colontmpD__41);
		}
		goto LA61_;
LA114_: ;
		{
			NimStringV2 colontmpD__43;
			NimStringV2 colontmpD__44;
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T118_;
			colontmpD__43.len = 0; colontmpD__43.p = NIM_NIL;
			colontmpD__44.len = 0; colontmpD__44.p = NIM_NIL;
			T118_[0] = a_1.address;
			T118_[1] = b_1.res;
			colontmpD__43 = percent___jsgen_u2814(T118_, 2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			colontmpD__44 = indentLine__jsgen_u102(p_p0, colontmpD__43);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			prepareAdd((&(*p_p0).body), colontmpD__44.len + 0);
appendString((&(*p_p0).body), colontmpD__44);
			eqdestroy___system_u2691(colontmpD__44);
			eqdestroy___system_u2691(colontmpD__43);
		}
LA61_: ;
	}
	break;
	default:
	{
		NimStringV2 colontmpD__45;
		NimStringV2 colontmpD__46;
		NimStringV2 colontmpD__47;
		NimStringV2 colontmpD__48;
		tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T120_;
		colontmpD__45.len = 0; colontmpD__45.p = NIM_NIL;
		colontmpD__46.len = 0; colontmpD__46.p = NIM_NIL;
		colontmpD__47.len = 0; colontmpD__47.p = NIM_NIL;
		colontmpD__48.len = 0; colontmpD__48.p = NIM_NIL;
		colontmpD__45 = rdLoc__jsgen_u593((&a_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T120_[0] = colontmpD__45;
		colontmpD__46 = rdLoc__jsgen_u593((&b_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T120_[1] = colontmpD__46;
		colontmpD__47 = percent___jsgen_u2814(T120_, 2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		colontmpD__48 = indentLine__jsgen_u102(p_p0, colontmpD__47);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		prepareAdd((&(*p_p0).body), colontmpD__48.len + 0);
appendString((&(*p_p0).body), colontmpD__48);
		eqdestroy___system_u2691(colontmpD__48);
		eqdestroy___system_u2691(colontmpD__47);
		eqdestroy___system_u2691(colontmpD__46);
		eqdestroy___system_u2691(colontmpD__45);
	}
	break;
	}
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(colontmpD__2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___jsgen_u570((&b_1));
		eqdestroy___jsgen_u570((&a_1));
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genClosureVar__jsgen_u5098)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!(((*(*n_p1)._kind_6.sons.p->data[((NI)2)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)1)))) goto LA3_;
		genAsgnAux__jsgen_u3406(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)0)], (*n_p1)._kind_6.sons.p->data[((NI)2)], NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA3_: ;
	{
		tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ a_1;
		NimStringV2 colontmpD_;
		NimStringV2 colontmpD__2;
		NimStringV2 colontmpD__3;
		NimStringV2 colontmpD__4;
		tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T7_;
		nimZeroMem((void*)(&a_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
		colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
		nimZeroMem((void*)(&a_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
		gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)0)], (&a_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		colontmpD_ = rdLoc__jsgen_u593((&a_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		T7_[0] = colontmpD_;
		colontmpD__2 = createVar__jsgen_u4648(p_p0, (*(*n_p1)._kind_6.sons.p->data[((NI)0)]).typField, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		T7_[1] = colontmpD__2;
		colontmpD__3 = runtimeFormat__ropes_u39(TM__BxLwT0mhrtgTPodf1v3xjg_746, T7_, 2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		colontmpD__4 = indentLine__jsgen_u102(p_p0, colontmpD__3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		prepareAdd((&(*p_p0).body), colontmpD__4.len + 0);
appendString((&(*p_p0).body), colontmpD__4);
		{
			LA6_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__4);
			eqdestroy___system_u2691(colontmpD__3);
			eqdestroy___system_u2691(colontmpD__2);
			eqdestroy___system_u2691(colontmpD_);
			eqdestroy___jsgen_u570((&a_1));
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genVarStmt__jsgen_u5110)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
NIM_BOOL oldNimErrFin13_;
NIM_BOOL oldNimErrFin21_;
NIM_BOOL oldNimErrFin4_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NI i_1;
		NI colontmp_;
		NI i_2;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_u3190(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		i_2 = ((NI)0);
		{
			while (1) {
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_1;
				if (!(i_2 < colontmp_)) goto LA3;
				a_1 = NIM_NIL;
				i_1 = i_2;
				eqcopy___ast_u3255(&a_1, (*n_p1)._kind_6.sons.p->data[i_1]);
				if (NIM_UNLIKELY(*nimErr_)) goto LA4_;
				{
					if (!!(((*a_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)125)))) goto LA7_;
					{
						tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* unpacked_1;
						if (!((*a_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)36))) goto LA11_;
						unpacked_1 = NIM_NIL;
						unpacked_1 = lowerTupleUnpacking__lowerings_u56((*(*p_p0).module).graph, a_1, (*(*p_p0).module).Sup.idgen, (*p_p0).prc);
						if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
						genStmt__jsgen_u1163(p_p0, unpacked_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
						{
							LA13_:;
						}
						{
							oldNimErrFin13_ = *nimErr_; *nimErr_ = NIM_FALSE;
							eqdestroy___ast_u3252(unpacked_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA4_;
							*nimErr_ = oldNimErrFin13_;
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA4_;
					}
					goto LA9_;
LA11_: ;
					{
						{
							tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* v_1;
							if (!((*(*a_1)._kind_6.sons.p->data[((NI)0)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3))) goto LA19_;
							v_1 = NIM_NIL;
							eqcopy___ast_u4577(&v_1, (*(*a_1)._kind_6.sons.p->data[((NI)0)])._kind_4.sym);
							if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
							{
								NIM_BOOL T24_;
								T24_ = (NIM_BOOL)0;
								T24_ = !((((*v_1).loc.flags &((NU16)1<<((NU)((((tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg)2)))&15U)))!=0));
								if (!(T24_)) goto LA25_;
								T24_ = !((((*v_1).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)6)))&63U)))!=0));
LA25_: ;
								if (!T24_) goto LA26_;
								genLineDir__jsgen_u2646(p_p0, a_1);
								if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
								{
									if (!!((((*v_1).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)28)))&63U)))!=0))) goto LA30_;
									genVarInit__jsgen_u4193(p_p0, v_1, (*a_1)._kind_6.sons.p->data[((NI)2)]);
									if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
								}
								goto LA28_;
LA30_: ;
								{
									{
										if (!((*v_1).ast == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL))) goto LA35_;
										eqcopy___ast_u3255(&(*v_1).ast, (*a_1)._kind_6.sons.p->data[((NI)2)]);
										if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
									}
LA35_: ;
								}
LA28_: ;
							}
LA26_: ;
							{
								LA21_:;
							}
							{
								oldNimErrFin21_ = *nimErr_; *nimErr_ = NIM_FALSE;
								eqdestroy___ast_u4574(v_1);
								if (NIM_UNLIKELY(*nimErr_)) goto LA4_;
								*nimErr_ = oldNimErrFin21_;
							}
							if (NIM_UNLIKELY(*nimErr_)) goto LA4_;
						}
						goto LA17_;
LA19_: ;
						{
							genClosureVar__jsgen_u5098(p_p0, a_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA4_;
						}
LA17_: ;
					}
LA9_: ;
				}
LA7_: ;
				i_2 += ((NI)1);
				{
					LA4_:;
				}
				{
					oldNimErrFin4_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3252(a_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					*nimErr_ = oldNimErrFin4_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			} LA3: ;
		}
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genCaseJS__jsgen_u2955)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* r_p2) {
	tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ a_1;
	tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ b_1;
	tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ cond_1;
	tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ stmt_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
	tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg typeKind_1;
	NIM_BOOL transferRange_1;
	NIM_BOOL anyString_1;
NIM_BOOL oldNimErrFin53_;
NIM_BOOL oldNimErrFin36_;
NIM_BOOL oldNimErrFin21_;
NIM_BOOL oldNimErrFin19_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&a_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
	nimZeroMem((void*)(&b_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
	nimZeroMem((void*)(&cond_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
	nimZeroMem((void*)(&stmt_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
	colontmpD_ = NIM_NIL;
	nimZeroMem((void*)(&a_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
	nimZeroMem((void*)(&b_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
	nimZeroMem((void*)(&cond_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
	nimZeroMem((void*)(&stmt_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
	genLineDir__jsgen_u2646(p_p0, n_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)0)], (&cond_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD_ = skipTypes__ast_u5379((*(*n_p1)._kind_6.sons.p->data[((NI)0)]).typField, TM__BxLwT0mhrtgTPodf1v3xjg_515);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	typeKind_1 = (*colontmpD_).kind;
	transferRange_1 = NIM_FALSE;
	anyString_1 = (typeKind_1 == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)28) || typeKind_1 == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)29));
	switch (typeKind_1) {
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)28):
	{
		NimStringV2 colontmpD__2;
		NimStringV2 colontmpD__3;
		NimStringV2 colontmpD__4;
		tyArray__YgExxhfgKcesA5EOUj1MOA T4_;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
		colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
		useMagic__jsgen_u1172(p_p0, TM__BxLwT0mhrtgTPodf1v3xjg_750);
		if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
		colontmpD__2 = rdLoc__jsgen_u593((&cond_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
		T4_[0] = colontmpD__2;
		colontmpD__3 = percent___jsgen_u2990(T4_, 1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
		colontmpD__4 = indentLine__jsgen_u102(p_p0, colontmpD__3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
		prepareAdd((&(*p_p0).body), colontmpD__4.len + 0);
appendString((&(*p_p0).body), colontmpD__4);
		{
			LA3_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__4);
			eqdestroy___system_u2691(colontmpD__3);
			eqdestroy___system_u2691(colontmpD__2);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)36) ... ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)39):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)31) ... ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)35):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)40) ... ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)44):
	{
		transferRange_1 = NIM_TRUE;
	}
	break;
	default:
	{
		NimStringV2 colontmpD__5;
		NimStringV2 colontmpD__6;
		NimStringV2 colontmpD__7;
		tyArray__YgExxhfgKcesA5EOUj1MOA T9_;
		colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
		colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
		colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
		colontmpD__5 = rdLoc__jsgen_u593((&cond_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T9_[0] = colontmpD__5;
		colontmpD__6 = percent___cgen_u16453(T9_, 1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		colontmpD__7 = indentLine__jsgen_u102(p_p0, colontmpD__6);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		prepareAdd((&(*p_p0).body), colontmpD__7.len + 0);
appendString((&(*p_p0).body), colontmpD__7);
		eqdestroy___system_u2691(colontmpD__7);
		eqdestroy___system_u2691(colontmpD__6);
		eqdestroy___system_u2691(colontmpD__5);
	}
	break;
	}
	{
		NIM_BOOL T12_;
		NimStringV2 T15_;
		T12_ = (NIM_BOOL)0;
		T12_ = isEmptyType__ast_u7234((*n_p1).typField);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!!(T12_)) goto LA13_;
		(*r_p2).kind = ((tyEnum_TResKind__UiCSai1lX4RMkJ9bHo9aP2HA)2);
		T15_.len = 0; T15_.p = NIM_NIL;
		T15_ = getTemp__jsgen_u1235(p_p0, NIM_TRUE);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T15_); goto LA1_;}
		eqsink___system_u2700((&(*r_p2).res), T15_);
	}
LA13_: ;
	{
		NI i_1;
		NI colontmp_;
		NI i_2;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_u3190(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		i_2 = ((NI)1);
		{
			while (1) {
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* it_1;
				NI itLen_1;
				if (!(i_2 < colontmp_)) goto LA18;
				it_1 = NIM_NIL;
				i_1 = i_2;
				eqcopy___ast_u3255(&it_1, (*n_p1)._kind_6.sons.p->data[i_1]);
				if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
				itLen_1 = len__ast_u3190(it_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
				switch ((*it_1).kind) {
				case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)85):
				{
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__8;
					colontmpD__8 = NIM_NIL;
					{
						if (!transferRange_1) goto LA24_;
						{
							NimStringV2 colontmpD__9;
							NimStringV2 colontmpD__10;
							tyArray__TonP9cxJgj8gXu71dWIyNlA T30_;
							if (!(i_1 == ((NI)1))) goto LA28_;
							colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
							colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
							colontmpD__9 = percent___jsgen_u3006(T30_, 0);
							if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
							colontmpD__10 = indentLine__jsgen_u102(p_p0, colontmpD__9);
							if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
							prepareAdd((&(*p_p0).body), colontmpD__10.len + 0);
appendString((&(*p_p0).body), colontmpD__10);
							eqdestroy___system_u2691(colontmpD__10);
							eqdestroy___system_u2691(colontmpD__9);
						}
						goto LA26_;
LA28_: ;
						{
							NimStringV2 colontmpD__11;
							NimStringV2 colontmpD__12;
							tyArray__TonP9cxJgj8gXu71dWIyNlA T32_;
							colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
							colontmpD__12.len = 0; colontmpD__12.p = NIM_NIL;
							colontmpD__11 = percent___jsgen_u3011(T32_, 0);
							if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
							colontmpD__12 = indentLine__jsgen_u102(p_p0, colontmpD__11);
							if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
							prepareAdd((&(*p_p0).body), colontmpD__12.len + 0);
appendString((&(*p_p0).body), colontmpD__12);
							eqdestroy___system_u2691(colontmpD__12);
							eqdestroy___system_u2691(colontmpD__11);
						}
LA26_: ;
					}
LA24_: ;
					{
						NI j_1;
						NI colontmp__2;
						NI i_3;
						j_1 = (NI)0;
						colontmp__2 = (NI)0;
						colontmp__2 = (NI)(itLen_1 - ((NI)1));
						i_3 = ((NI)0);
						{
							while (1) {
								tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_1;
								if (!(i_3 < colontmp__2)) goto LA35;
								e_1 = NIM_NIL;
								j_1 = i_3;
								eqcopy___ast_u3255(&e_1, (*it_1)._kind_6.sons.p->data[j_1]);
								if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
								{
									if (!((*e_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)44))) goto LA39_;
									{
										if (!transferRange_1) goto LA43_;
										gen__jsgen_u1159(p_p0, (*e_1)._kind_6.sons.p->data[((NI)0)], (&a_1));
										if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
										gen__jsgen_u1159(p_p0, (*e_1)._kind_6.sons.p->data[((NI)1)], (&b_1));
										if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
										{
											NimStringV2 colontmpD__13;
											NimStringV2 colontmpD__14;
											NimStringV2 colontmpD__15;
											NimStringV2 colontmpD__16;
											NimStringV2 colontmpD__17;
											tyArray__dyW7vpmfeTYw8kX3EXuaJA T49_;
											if (!!((j_1 == (NI)(itLen_1 - ((NI)2))))) goto LA47_;
											colontmpD__13.len = 0; colontmpD__13.p = NIM_NIL;
											colontmpD__14.len = 0; colontmpD__14.p = NIM_NIL;
											colontmpD__15.len = 0; colontmpD__15.p = NIM_NIL;
											colontmpD__16.len = 0; colontmpD__16.p = NIM_NIL;
											colontmpD__17.len = 0; colontmpD__17.p = NIM_NIL;
											colontmpD__13 = rdLoc__jsgen_u593((&cond_1));
											if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
											T49_[0] = colontmpD__13;
											colontmpD__14 = rdLoc__jsgen_u593((&a_1));
											if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
											T49_[1] = colontmpD__14;
											colontmpD__15 = rdLoc__jsgen_u593((&b_1));
											if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
											T49_[2] = colontmpD__15;
											colontmpD__16 = percent___jsgen_u3026(T49_, 3);
											if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
											colontmpD__17 = indentLine__jsgen_u102(p_p0, colontmpD__16);
											if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
											prepareAdd((&(*p_p0).body), colontmpD__17.len + 0);
appendString((&(*p_p0).body), colontmpD__17);
											eqdestroy___system_u2691(colontmpD__17);
											eqdestroy___system_u2691(colontmpD__16);
											eqdestroy___system_u2691(colontmpD__15);
											eqdestroy___system_u2691(colontmpD__14);
											eqdestroy___system_u2691(colontmpD__13);
										}
										goto LA45_;
LA47_: ;
										{
											NimStringV2 colontmpD__18;
											NimStringV2 colontmpD__19;
											NimStringV2 colontmpD__20;
											NimStringV2 colontmpD__21;
											NimStringV2 colontmpD__22;
											tyArray__dyW7vpmfeTYw8kX3EXuaJA T51_;
											colontmpD__18.len = 0; colontmpD__18.p = NIM_NIL;
											colontmpD__19.len = 0; colontmpD__19.p = NIM_NIL;
											colontmpD__20.len = 0; colontmpD__20.p = NIM_NIL;
											colontmpD__21.len = 0; colontmpD__21.p = NIM_NIL;
											colontmpD__22.len = 0; colontmpD__22.p = NIM_NIL;
											colontmpD__18 = rdLoc__jsgen_u593((&cond_1));
											if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
											T51_[0] = colontmpD__18;
											colontmpD__19 = rdLoc__jsgen_u593((&a_1));
											if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
											T51_[1] = colontmpD__19;
											colontmpD__20 = rdLoc__jsgen_u593((&b_1));
											if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
											T51_[2] = colontmpD__20;
											colontmpD__21 = percent___cgen_u24580(T51_, 3);
											if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
											colontmpD__22 = indentLine__jsgen_u102(p_p0, colontmpD__21);
											if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
											prepareAdd((&(*p_p0).body), colontmpD__22.len + 0);
appendString((&(*p_p0).body), colontmpD__22);
											eqdestroy___system_u2691(colontmpD__22);
											eqdestroy___system_u2691(colontmpD__21);
											eqdestroy___system_u2691(colontmpD__20);
											eqdestroy___system_u2691(colontmpD__19);
											eqdestroy___system_u2691(colontmpD__18);
										}
LA45_: ;
									}
									goto LA41_;
LA43_: ;
									{
										tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* v_1;
										v_1 = NIM_NIL;
										v_1 = copyNode__ast_u6736((*e_1)._kind_6.sons.p->data[((NI)0)]);
										if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
										{
											while (1) {
												NimStringV2 colontmpD__23;
												NimStringV2 colontmpD__24;
												NimStringV2 colontmpD__25;
												tyArray__YgExxhfgKcesA5EOUj1MOA T57_;
												if (!((*v_1)._kind_1.intVal <= (*(*e_1)._kind_6.sons.p->data[((NI)1)])._kind_1.intVal)) goto LA55;
												colontmpD__23.len = 0; colontmpD__23.p = NIM_NIL;
												colontmpD__24.len = 0; colontmpD__24.p = NIM_NIL;
												colontmpD__25.len = 0; colontmpD__25.p = NIM_NIL;
												gen__jsgen_u1159(p_p0, v_1, (&cond_1));
												if (NIM_UNLIKELY(*nimErr_)) goto LA56_;
												colontmpD__23 = rdLoc__jsgen_u593((&cond_1));
												if (NIM_UNLIKELY(*nimErr_)) goto LA56_;
												T57_[0] = colontmpD__23;
												colontmpD__24 = percent___cgen_u18073(T57_, 1);
												if (NIM_UNLIKELY(*nimErr_)) goto LA56_;
												colontmpD__25 = indentLine__jsgen_u102(p_p0, colontmpD__24);
												if (NIM_UNLIKELY(*nimErr_)) goto LA56_;
												prepareAdd((&(*p_p0).body), colontmpD__25.len + 0);
appendString((&(*p_p0).body), colontmpD__25);
												(*v_1)._kind_1.intVal += ((NI)1);
												{
													LA56_:;
												}
												{
													eqdestroy___system_u2691(colontmpD__25);
													eqdestroy___system_u2691(colontmpD__24);
													eqdestroy___system_u2691(colontmpD__23);
												}
												if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
											} LA55: ;
										}
										{
											LA53_:;
										}
										{
											oldNimErrFin53_ = *nimErr_; *nimErr_ = NIM_FALSE;
											eqdestroy___ast_u3252(v_1);
											if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
											*nimErr_ = oldNimErrFin53_;
										}
										if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
									}
LA41_: ;
								}
								goto LA37_;
LA39_: ;
								{
									{
										if (!anyString_1) goto LA65_;
										switch ((*e_1).kind) {
										case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)20) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)22):
										{
											NimStringV2 colontmpD__26;
											NimStringV2 colontmpD__27;
											NimStringV2 colontmpD__28;
											tyArray__YgExxhfgKcesA5EOUj1MOA T68_;
											colontmpD__26.len = 0; colontmpD__26.p = NIM_NIL;
											colontmpD__27.len = 0; colontmpD__27.p = NIM_NIL;
											colontmpD__28.len = 0; colontmpD__28.p = NIM_NIL;
											colontmpD__26 = makeJSString__jsgen_u806((*e_1)._kind_3.strVal, NIM_FALSE);
											if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
											T68_[0] = colontmpD__26;
											colontmpD__27 = percent___cgen_u18073(T68_, 1);
											if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
											colontmpD__28 = indentLine__jsgen_u102(p_p0, colontmpD__27);
											if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
											prepareAdd((&(*p_p0).body), colontmpD__28.len + 0);
appendString((&(*p_p0).body), colontmpD__28);
											eqdestroy___system_u2691(colontmpD__28);
											eqdestroy___system_u2691(colontmpD__27);
											eqdestroy___system_u2691(colontmpD__26);
										}
										break;
										case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)23):
										{
											NimStringV2 colontmpD__29;
											NimStringV2 colontmpD__30;
											tyArray__TonP9cxJgj8gXu71dWIyNlA T70_;
											colontmpD__29.len = 0; colontmpD__29.p = NIM_NIL;
											colontmpD__30.len = 0; colontmpD__30.p = NIM_NIL;
											colontmpD__29 = percent___jsgen_u3049(T70_, 0);
											if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
											colontmpD__30 = indentLine__jsgen_u102(p_p0, colontmpD__29);
											if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
											prepareAdd((&(*p_p0).body), colontmpD__30.len + 0);
appendString((&(*p_p0).body), colontmpD__30);
											eqdestroy___system_u2691(colontmpD__30);
											eqdestroy___system_u2691(colontmpD__29);
										}
										break;
										default:
										{
											internalErrorImpl__msgs_u1598((*(*p_p0).module).config, (*e_1).info, TM__BxLwT0mhrtgTPodf1v3xjg_752, (&TM__BxLwT0mhrtgTPodf1v3xjg_753));
											if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
										}
										break;
										}
									}
									goto LA63_;
LA65_: ;
									{
										{
											if (!transferRange_1) goto LA75_;
											gen__jsgen_u1159(p_p0, e_1, (&a_1));
											if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
											{
												NimStringV2 colontmpD__31;
												NimStringV2 colontmpD__32;
												NimStringV2 colontmpD__33;
												NimStringV2 colontmpD__34;
												tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T81_;
												if (!!((j_1 == (NI)(itLen_1 - ((NI)2))))) goto LA79_;
												colontmpD__31.len = 0; colontmpD__31.p = NIM_NIL;
												colontmpD__32.len = 0; colontmpD__32.p = NIM_NIL;
												colontmpD__33.len = 0; colontmpD__33.p = NIM_NIL;
												colontmpD__34.len = 0; colontmpD__34.p = NIM_NIL;
												colontmpD__31 = rdLoc__jsgen_u593((&cond_1));
												if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
												T81_[0] = colontmpD__31;
												colontmpD__32 = rdLoc__jsgen_u593((&a_1));
												if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
												T81_[1] = colontmpD__32;
												colontmpD__33 = percent___jsgen_u3054(T81_, 2);
												if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
												colontmpD__34 = indentLine__jsgen_u102(p_p0, colontmpD__33);
												if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
												prepareAdd((&(*p_p0).body), colontmpD__34.len + 0);
appendString((&(*p_p0).body), colontmpD__34);
												eqdestroy___system_u2691(colontmpD__34);
												eqdestroy___system_u2691(colontmpD__33);
												eqdestroy___system_u2691(colontmpD__32);
												eqdestroy___system_u2691(colontmpD__31);
											}
											goto LA77_;
LA79_: ;
											{
												NimStringV2 colontmpD__35;
												NimStringV2 colontmpD__36;
												NimStringV2 colontmpD__37;
												NimStringV2 colontmpD__38;
												tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T83_;
												colontmpD__35.len = 0; colontmpD__35.p = NIM_NIL;
												colontmpD__36.len = 0; colontmpD__36.p = NIM_NIL;
												colontmpD__37.len = 0; colontmpD__37.p = NIM_NIL;
												colontmpD__38.len = 0; colontmpD__38.p = NIM_NIL;
												colontmpD__35 = rdLoc__jsgen_u593((&cond_1));
												if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
												T83_[0] = colontmpD__35;
												colontmpD__36 = rdLoc__jsgen_u593((&a_1));
												if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
												T83_[1] = colontmpD__36;
												colontmpD__37 = percent___cgen_u24585(T83_, 2);
												if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
												colontmpD__38 = indentLine__jsgen_u102(p_p0, colontmpD__37);
												if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
												prepareAdd((&(*p_p0).body), colontmpD__38.len + 0);
appendString((&(*p_p0).body), colontmpD__38);
												eqdestroy___system_u2691(colontmpD__38);
												eqdestroy___system_u2691(colontmpD__37);
												eqdestroy___system_u2691(colontmpD__36);
												eqdestroy___system_u2691(colontmpD__35);
											}
LA77_: ;
										}
										goto LA73_;
LA75_: ;
										{
											NimStringV2 colontmpD__39;
											NimStringV2 colontmpD__40;
											NimStringV2 colontmpD__41;
											tyArray__YgExxhfgKcesA5EOUj1MOA T86_;
											colontmpD__39.len = 0; colontmpD__39.p = NIM_NIL;
											colontmpD__40.len = 0; colontmpD__40.p = NIM_NIL;
											colontmpD__41.len = 0; colontmpD__41.p = NIM_NIL;
											gen__jsgen_u1159(p_p0, e_1, (&a_1));
											if (NIM_UNLIKELY(*nimErr_)) goto LA85_;
											colontmpD__39 = rdLoc__jsgen_u593((&a_1));
											if (NIM_UNLIKELY(*nimErr_)) goto LA85_;
											T86_[0] = colontmpD__39;
											colontmpD__40 = percent___cgen_u18073(T86_, 1);
											if (NIM_UNLIKELY(*nimErr_)) goto LA85_;
											colontmpD__41 = indentLine__jsgen_u102(p_p0, colontmpD__40);
											if (NIM_UNLIKELY(*nimErr_)) goto LA85_;
											prepareAdd((&(*p_p0).body), colontmpD__41.len + 0);
appendString((&(*p_p0).body), colontmpD__41);
											{
												LA85_:;
											}
											{
												eqdestroy___system_u2691(colontmpD__41);
												eqdestroy___system_u2691(colontmpD__40);
												eqdestroy___system_u2691(colontmpD__39);
											}
											if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
										}
LA73_: ;
									}
LA63_: ;
								}
LA37_: ;
								i_3 += ((NI)1);
								{
									LA36_:;
								}
								{
									oldNimErrFin36_ = *nimErr_; *nimErr_ = NIM_FALSE;
									eqdestroy___ast_u3252(e_1);
									if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
									*nimErr_ = oldNimErrFin36_;
								}
								if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
							} LA35: ;
						}
					}
					{
						NimStringV2 colontmpD__42;
						NimStringV2 colontmpD__43;
						tyArray__TonP9cxJgj8gXu71dWIyNlA T95_;
						if (!transferRange_1) goto LA93_;
						colontmpD__42.len = 0; colontmpD__42.p = NIM_NIL;
						colontmpD__43.len = 0; colontmpD__43.p = NIM_NIL;
						colontmpD__42 = percent___jsgen_u3067(T95_, 0);
						if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
						colontmpD__43 = indentLine__jsgen_u102(p_p0, colontmpD__42);
						if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
						prepareAdd((&(*p_p0).body), colontmpD__43.len + 0);
appendString((&(*p_p0).body), colontmpD__43);
						eqdestroy___system_u2691(colontmpD__43);
						eqdestroy___system_u2691(colontmpD__42);
					}
LA93_: ;
					(*p_p0).extraIndent += ((NI)1);
					colontmpD__8 = lastSon__ast_u5208(it_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
					gen__jsgen_u1159(p_p0, colontmpD__8, (&stmt_1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
					moveInto__jsgen_u2802(p_p0, (&stmt_1), (&(*r_p2)));
					if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
					{
						NimStringV2 colontmpD__44;
						NimStringV2 colontmpD__45;
						tyArray__TonP9cxJgj8gXu71dWIyNlA T100_;
						if (!transferRange_1) goto LA98_;
						colontmpD__44.len = 0; colontmpD__44.p = NIM_NIL;
						colontmpD__45.len = 0; colontmpD__45.p = NIM_NIL;
						colontmpD__44 = percent___cgen_u9681(T100_, 0);
						if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
						colontmpD__45 = indentLine__jsgen_u102(p_p0, colontmpD__44);
						if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
						prepareAdd((&(*p_p0).body), colontmpD__45.len + 0);
appendString((&(*p_p0).body), colontmpD__45);
						eqdestroy___system_u2691(colontmpD__45);
						eqdestroy___system_u2691(colontmpD__44);
					}
					goto LA96_;
LA98_: ;
					{
						NimStringV2 colontmpD__46;
						NimStringV2 colontmpD__47;
						tyArray__TonP9cxJgj8gXu71dWIyNlA T102_;
						colontmpD__46.len = 0; colontmpD__46.p = NIM_NIL;
						colontmpD__47.len = 0; colontmpD__47.p = NIM_NIL;
						colontmpD__46 = percent___cgen_u9601(T102_, 0);
						if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
						colontmpD__47 = indentLine__jsgen_u102(p_p0, colontmpD__46);
						if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
						prepareAdd((&(*p_p0).body), colontmpD__47.len + 0);
appendString((&(*p_p0).body), colontmpD__47);
						eqdestroy___system_u2691(colontmpD__47);
						eqdestroy___system_u2691(colontmpD__46);
					}
LA96_: ;
					(*p_p0).extraIndent -= ((NI)1);
					{
						LA21_:;
					}
					{
						oldNimErrFin21_ = *nimErr_; *nimErr_ = NIM_FALSE;
						eqdestroy___ast_u3252(colontmpD__8);
						if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
						*nimErr_ = oldNimErrFin21_;
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
				}
				break;
				case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)88):
				{
					{
						if (!transferRange_1) goto LA108_;
						{
							NI T112_;
							NimStringV2 colontmpD__48;
							NimStringV2 colontmpD__49;
							NimStringV2 colontmpD__50;
							NimStringV2 colontmpD__51;
							NimStringV2 colontmpD__52;
							tyArray__YgExxhfgKcesA5EOUj1MOA T115_;
							tyArray__TonP9cxJgj8gXu71dWIyNlA T116_;
							T112_ = (NI)0;
							T112_ = len__ast_u3190(n_p1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
							if (!(T112_ == ((NI)2))) goto LA113_;
							colontmpD__48.len = 0; colontmpD__48.p = NIM_NIL;
							colontmpD__49.len = 0; colontmpD__49.p = NIM_NIL;
							colontmpD__50.len = 0; colontmpD__50.p = NIM_NIL;
							colontmpD__51.len = 0; colontmpD__51.p = NIM_NIL;
							colontmpD__52.len = 0; colontmpD__52.p = NIM_NIL;
							transferRange_1 = NIM_FALSE;
							colontmpD__48 = rdLoc__jsgen_u593((&cond_1));
							if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
							T115_[0] = colontmpD__48;
							colontmpD__49 = percent___cgen_u16453(T115_, 1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
							colontmpD__50 = indentLine__jsgen_u102(p_p0, colontmpD__49);
							if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
							prepareAdd((&(*p_p0).body), colontmpD__50.len + 0);
appendString((&(*p_p0).body), colontmpD__50);
							colontmpD__51 = percent___jsgen_u3094(T116_, 0);
							if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
							colontmpD__52 = indentLine__jsgen_u102(p_p0, colontmpD__51);
							if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
							prepareAdd((&(*p_p0).body), colontmpD__52.len + 0);
appendString((&(*p_p0).body), colontmpD__52);
							eqdestroy___system_u2691(colontmpD__52);
							eqdestroy___system_u2691(colontmpD__51);
							eqdestroy___system_u2691(colontmpD__50);
							eqdestroy___system_u2691(colontmpD__49);
							eqdestroy___system_u2691(colontmpD__48);
						}
						goto LA110_;
LA113_: ;
						{
							NimStringV2 colontmpD__53;
							NimStringV2 colontmpD__54;
							tyArray__TonP9cxJgj8gXu71dWIyNlA T118_;
							colontmpD__53.len = 0; colontmpD__53.p = NIM_NIL;
							colontmpD__54.len = 0; colontmpD__54.p = NIM_NIL;
							colontmpD__53 = percent___jsgen_u3099(T118_, 0);
							if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
							colontmpD__54 = indentLine__jsgen_u102(p_p0, colontmpD__53);
							if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
							prepareAdd((&(*p_p0).body), colontmpD__54.len + 0);
appendString((&(*p_p0).body), colontmpD__54);
							eqdestroy___system_u2691(colontmpD__54);
							eqdestroy___system_u2691(colontmpD__53);
						}
LA110_: ;
					}
					goto LA106_;
LA108_: ;
					{
						NimStringV2 colontmpD__55;
						NimStringV2 colontmpD__56;
						tyArray__TonP9cxJgj8gXu71dWIyNlA T120_;
						colontmpD__55.len = 0; colontmpD__55.p = NIM_NIL;
						colontmpD__56.len = 0; colontmpD__56.p = NIM_NIL;
						colontmpD__55 = percent___jsgen_u3094(T120_, 0);
						if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
						colontmpD__56 = indentLine__jsgen_u102(p_p0, colontmpD__55);
						if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
						prepareAdd((&(*p_p0).body), colontmpD__56.len + 0);
appendString((&(*p_p0).body), colontmpD__56);
						eqdestroy___system_u2691(colontmpD__56);
						eqdestroy___system_u2691(colontmpD__55);
					}
LA106_: ;
					(*p_p0).extraIndent += ((NI)1);
					gen__jsgen_u1159(p_p0, (*it_1)._kind_6.sons.p->data[((NI)0)], (&stmt_1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
					moveInto__jsgen_u2802(p_p0, (&stmt_1), (&(*r_p2)));
					if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
					{
						NimStringV2 colontmpD__57;
						NimStringV2 colontmpD__58;
						tyArray__TonP9cxJgj8gXu71dWIyNlA T125_;
						if (!transferRange_1) goto LA123_;
						colontmpD__57.len = 0; colontmpD__57.p = NIM_NIL;
						colontmpD__58.len = 0; colontmpD__58.p = NIM_NIL;
						colontmpD__57 = percent___cgen_u9681(T125_, 0);
						if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
						colontmpD__58 = indentLine__jsgen_u102(p_p0, colontmpD__57);
						if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
						prepareAdd((&(*p_p0).body), colontmpD__58.len + 0);
appendString((&(*p_p0).body), colontmpD__58);
						eqdestroy___system_u2691(colontmpD__58);
						eqdestroy___system_u2691(colontmpD__57);
					}
					goto LA121_;
LA123_: ;
					{
						NimStringV2 colontmpD__59;
						NimStringV2 colontmpD__60;
						tyArray__TonP9cxJgj8gXu71dWIyNlA T127_;
						colontmpD__59.len = 0; colontmpD__59.p = NIM_NIL;
						colontmpD__60.len = 0; colontmpD__60.p = NIM_NIL;
						colontmpD__59 = percent___cgen_u9601(T127_, 0);
						if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
						colontmpD__60 = indentLine__jsgen_u102(p_p0, colontmpD__59);
						if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
						prepareAdd((&(*p_p0).body), colontmpD__60.len + 0);
appendString((&(*p_p0).body), colontmpD__60);
						eqdestroy___system_u2691(colontmpD__60);
						eqdestroy___system_u2691(colontmpD__59);
					}
LA121_: ;
					(*p_p0).extraIndent -= ((NI)1);
				}
				break;
				default:
				{
					internalErrorImpl__msgs_u1598((*(*p_p0).module).config, (*it_1).info, TM__BxLwT0mhrtgTPodf1v3xjg_755, (&TM__BxLwT0mhrtgTPodf1v3xjg_756));
					if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
				}
				break;
				}
				i_2 += ((NI)1);
				{
					LA19_:;
				}
				{
					oldNimErrFin19_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3252(it_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin19_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			} LA18: ;
		}
	}
	{
		NimStringV2 colontmpD__61;
		NimStringV2 colontmpD__62;
		tyArray__TonP9cxJgj8gXu71dWIyNlA T135_;
		if (!!(transferRange_1)) goto LA133_;
		colontmpD__61.len = 0; colontmpD__61.p = NIM_NIL;
		colontmpD__62.len = 0; colontmpD__62.p = NIM_NIL;
		colontmpD__61 = percent___cgen_u9681(T135_, 0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		colontmpD__62 = indentLine__jsgen_u102(p_p0, colontmpD__61);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		prepareAdd((&(*p_p0).body), colontmpD__62.len + 0);
appendString((&(*p_p0).body), colontmpD__62);
		eqdestroy___system_u2691(colontmpD__62);
		eqdestroy___system_u2691(colontmpD__61);
	}
LA133_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___jsgen_u570((&stmt_1));
		eqdestroy___jsgen_u570((&cond_1));
		eqdestroy___jsgen_u570((&b_1));
		eqdestroy___jsgen_u570((&a_1));
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genReturnStmt__jsgen_u7257)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
	NimStringV2 colontmpD_;
	NimStringV2 colontmpD__2;
	tyArray__TonP9cxJgj8gXu71dWIyNlA T11_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	{
		if (!((*p_p0).procDef == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL))) goto LA4_;
		internalErrorImpl__msgs_u1598((*(*p_p0).module).config, (*n_p1).info, TM__BxLwT0mhrtgTPodf1v3xjg_758, (&TM__BxLwT0mhrtgTPodf1v3xjg_759));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA4_: ;
	(*p_p0).beforeRetNeeded = NIM_TRUE;
	{
		if (!!(((*(*n_p1)._kind_6.sons.p->data[((NI)0)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)1)))) goto LA8_;
		genStmt__jsgen_u1163(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)0)]);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA6_;
LA8_: ;
	{
		genLineDir__jsgen_u2646(p_p0, n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA6_: ;
	colontmpD_ = percent___jsgen_u7268(T11_, 0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__2 = indentLine__jsgen_u102(p_p0, colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&(*p_p0).body), colontmpD__2.len + 0);
appendString((&(*p_p0).body), colontmpD__2);
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(colontmpD_);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genBreakStmt__jsgen_u3171)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
	NimStringV2 colontmpD_;
	NimStringV2 colontmpD__2;
	NimStringV2 colontmpD__3;
	NI idx_1;
	tyArray__YgExxhfgKcesA5EOUj1MOA T18_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
	idx_1 = (NI)0;
	genLineDir__jsgen_u2646(p_p0, n_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_1;
		if (!!(((*(*n_p1)._kind_6.sons.p->data[((NI)0)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)1)))) goto LA4_;
		sym_1 = NIM_NIL;
		sym_1 = (*(*n_p1)._kind_6.sons.p->data[((NI)0)])._kind_4.sym;
		idx_1 = (NI)((*sym_1).position - ((NI)1));
	}
	goto LA2_;
LA4_: ;
	{
		NI T7_;
		T7_ = (*p_p0).blocks.len;
		idx_1 = (NI)(T7_ - ((NI)1));
		{
			while (1) {
				NIM_BOOL T10_;
				T10_ = (NIM_BOOL)0;
				T10_ = (((NI)0) <= idx_1);
				if (!(T10_)) goto LA11_;
				T10_ = !((*p_p0).blocks.p->data[idx_1].isLoop);
LA11_: ;
				if (!T10_) goto LA9;
				idx_1 -= ((NI)1);
			} LA9: ;
		}
		{
			NIM_BOOL T14_;
			T14_ = (NIM_BOOL)0;
			T14_ = (idx_1 < ((NI)0));
			if (T14_) goto LA15_;
			T14_ = !((*p_p0).blocks.p->data[idx_1].isLoop);
LA15_: ;
			if (!T14_) goto LA16_;
			internalErrorImpl__msgs_u1598((*(*p_p0).module).config, (*n_p1).info, TM__BxLwT0mhrtgTPodf1v3xjg_761, (&TM__BxLwT0mhrtgTPodf1v3xjg_762));
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA16_: ;
	}
LA2_: ;
	(*p_p0).blocks.p->data[idx_1].id = ((*p_p0).blocks.p->data[idx_1].id > 0? ((*p_p0).blocks.p->data[idx_1].id) : -((*p_p0).blocks.p->data[idx_1].id));
	colontmpD_ = rope__ropes_u15(((NI64) ((*p_p0).blocks.p->data[idx_1].id)));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T18_[0] = colontmpD_;
	colontmpD__2 = percent___jsgen_u3202(T18_, 1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__3 = indentLine__jsgen_u102(p_p0, colontmpD__2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&(*p_p0).body), colontmpD__3.len + 0);
appendString((&(*p_p0).body), colontmpD__3);
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD__3);
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(colontmpD_);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genAsgn__jsgen_u3623)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	genAsgnAux__jsgen_u3406(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)0)], (*n_p1)._kind_6.sons.p->data[((NI)1)], NIM_FALSE);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genFastAsgn__jsgen_u3626)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
	NIM_BOOL noCopy_1;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_ = NIM_NIL;
	colontmpD_ = skipTypes__ast_u5379((*(*n_p1)._kind_6.sons.p->data[((NI)0)]).typField, TM__BxLwT0mhrtgTPodf1v3xjg_175);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	noCopy_1 = ((*colontmpD_).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)24) || (*colontmpD_).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)28));
	genAsgnAux__jsgen_u3406(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)0)], (*n_p1)._kind_6.sons.p->data[((NI)1)], noCopy_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(void, warningDeprecated__msgs_u1572)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, NimStringV2 msg_p2) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	liMessage__msgs_u1227(conf_p0, info_p1, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)24), msg_p2, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__BxLwT0mhrtgTPodf1v3xjg_765), NIM_FALSE, NIM_FALSE);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genAsmOrEmitStmt__jsgen_u3207)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, NIM_BOOL isAsmStmt_p2) {
	NimStringV2 colontmpD_;
	NI colontmpD__2;
	NI colontmpD__3;
	NI offset_1;
NIM_BOOL oldNimErrFin13_;
NIM_BOOL oldNimErrFin10_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD__2 = (NI)0;
	colontmpD__3 = (NI)0;
	genLineDir__jsgen_u2646(p_p0, n_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD_ = indentLine__jsgen_u102(p_p0, TM__BxLwT0mhrtgTPodf1v3xjg_769);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&(*p_p0).body), colontmpD_.len + 0);
appendString((&(*p_p0).body), colontmpD_);
	{
		if (!isAsmStmt_p2) goto LA4_;
		colontmpD__2 = ((NI)1);
		offset_1 = colontmpD__2;
	}
	goto LA2_;
LA4_: ;
	{
		colontmpD__3 = ((NI)0);
		offset_1 = colontmpD__3;
	}
LA2_: ;
	{
		NI i_1;
		NI colontmp_;
		NI i_2;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_u3190(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		i_2 = offset_1;
		{
			while (1) {
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* it_1;
				if (!(i_2 < colontmp_)) goto LA9;
				it_1 = NIM_NIL;
				i_1 = i_2;
				eqcopy___ast_u3255(&it_1, (*n_p1)._kind_6.sons.p->data[i_1]);
				if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
				switch ((*it_1).kind) {
				case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)20) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)22):
				{
					prepareAdd((&(*p_p0).body), (*it_1)._kind_3.strVal.len + 0);
appendString((&(*p_p0).body), (*it_1)._kind_3.strVal);
				}
				break;
				case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3):
				{
					tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* v_1;
					v_1 = NIM_NIL;
					eqcopy___ast_u4577(&v_1, (*it_1)._kind_4.sym);
					if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
					{
						if (!NIM_FALSE) goto LA16_;
					}
					goto LA14_;
LA16_: ;
					{
						tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ r_1;
						NimStringV2 colontmpD__4;
						nimZeroMem((void*)(&r_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
						colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
						nimZeroMem((void*)(&r_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
						gen__jsgen_u1159(p_p0, it_1, (&r_1));
						if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
						{
							if (!((*(*it_1).typField).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)26))) goto LA22_;
							eqsink___system_u2700((&r_1.res), r_1.address);
							eqwasMoved___system_u2688((&r_1.address));
							eqsink___system_u2700((&r_1.address), TM__BxLwT0mhrtgTPodf1v3xjg_770);
							r_1.typ = ((tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)0);
						}
						goto LA20_;
LA22_: ;
						{
							tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T27_;
							NimStringV2 T28_;
							if (!(r_1.typ == ((tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)9))) goto LA25_;
							T27_[0] = r_1.address;
							T27_[1] = r_1.res;
							T28_.len = 0; T28_.p = NIM_NIL;
							T28_ = percent___cgen_u9083(T27_, 2);
							if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T28_); goto LA19_;}
							eqsink___system_u2700((&r_1.res), T28_);
							eqsink___system_u2700((&r_1.address), TM__BxLwT0mhrtgTPodf1v3xjg_771);
							r_1.typ = ((tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)0);
						}
						goto LA20_;
LA25_: ;
LA20_: ;
						colontmpD__4 = rdLoc__jsgen_u593((&r_1));
						if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
						prepareAdd((&(*p_p0).body), colontmpD__4.len + 0);
appendString((&(*p_p0).body), colontmpD__4);
						{
							LA19_:;
						}
						{
							eqdestroy___system_u2691(colontmpD__4);
							eqdestroy___jsgen_u570((&r_1));
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
					}
LA14_: ;
					{
						LA13_:;
					}
					{
						oldNimErrFin13_ = *nimErr_; *nimErr_ = NIM_FALSE;
						eqdestroy___ast_u4574(v_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
						*nimErr_ = oldNimErrFin13_;
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
				}
				break;
				default:
				{
					tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ r_2;
					NimStringV2 colontmpD__5;
					nimZeroMem((void*)(&r_2), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
					colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
					nimZeroMem((void*)(&r_2), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
					gen__jsgen_u1159(p_p0, it_1, (&r_2));
					if (NIM_UNLIKELY(*nimErr_)) goto LA34_;
					colontmpD__5 = rdLoc__jsgen_u593((&r_2));
					if (NIM_UNLIKELY(*nimErr_)) goto LA34_;
					prepareAdd((&(*p_p0).body), colontmpD__5.len + 0);
appendString((&(*p_p0).body), colontmpD__5);
					{
						LA34_:;
					}
					{
						eqdestroy___system_u2691(colontmpD__5);
						eqdestroy___jsgen_u570((&r_2));
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
				}
				break;
				}
				i_2 += ((NI)1);
				{
					LA10_:;
				}
				{
					oldNimErrFin10_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3252(it_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin10_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			} LA9: ;
		}
	}
	prepareAdd((&(*p_p0).body), 1);
appendString((&(*p_p0).body), TM__BxLwT0mhrtgTPodf1v3xjg_772);
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD_);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genTry__jsgen_u2823)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* r_p2) {
	NimStringV2 tmpFramePtr_1;
	NimStringV2 colontmpD_;
	NimStringV2 colontmpD__2;
	tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ a_1;
	NimStringV2 colontmpD__3;
	NimStringV2 colontmpD__4;
	NI i_1;
	NIM_BOOL catchBranchesExist_1;
	NIM_BOOL T8_;
	NI T9_;
	tyArray__TonP9cxJgj8gXu71dWIyNlA T15_;
	NIM_BOOL generalCatchBranchExists_1;
NIM_BOOL oldNimErrFin53_;
NIM_BOOL oldNimErrFin48_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	tmpFramePtr_1.len = 0; tmpFramePtr_1.p = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	nimZeroMem((void*)(&a_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
	colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
	colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
	genLineDir__jsgen_u2646(p_p0, n_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NIM_BOOL T4_;
		NimStringV2 T7_;
		T4_ = (NIM_BOOL)0;
		T4_ = isEmptyType__ast_u7234((*n_p1).typField);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!!(T4_)) goto LA5_;
		(*r_p2).kind = ((tyEnum_TResKind__UiCSai1lX4RMkJ9bHo9aP2HA)2);
		T7_.len = 0; T7_.p = NIM_NIL;
		T7_ = getTemp__jsgen_u1235(p_p0, NIM_TRUE);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T7_); goto LA1_;}
		eqsink___system_u2700((&(*r_p2).res), T7_);
	}
LA5_: ;
	(*p_p0).unique += ((NI)1);
	i_1 = ((NI)1);
	T8_ = (NIM_BOOL)0;
	T9_ = (NI)0;
	T9_ = len__ast_u3190(n_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T8_ = (((NI)1) < T9_);
	if (!(T8_)) goto LA10_;
	T8_ = ((*(*n_p1)._kind_6.sons.p->data[i_1]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)87));
LA10_: ;
	catchBranchesExist_1 = T8_;
	{
		if (!catchBranchesExist_1) goto LA13_;
		prepareAdd((&(*p_p0).body), 14);
appendString((&(*p_p0).body), TM__BxLwT0mhrtgTPodf1v3xjg_774);
	}
LA13_: ;
	tmpFramePtr_1 = TM__BxLwT0mhrtgTPodf1v3xjg_776;
	colontmpD_ = percent___jsgen_u2839(T15_, 0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__2 = indentLine__jsgen_u102(p_p0, colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&(*p_p0).body), colontmpD__2.len + 0);
appendString((&(*p_p0).body), colontmpD__2);
	nimZeroMem((void*)(&a_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
	gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)0)], (&a_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	moveInto__jsgen_u2802(p_p0, (&a_1), (&(*r_p2)));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	generalCatchBranchExists_1 = NIM_FALSE;
	{
		NimStringV2 colontmpD__5;
		tyArray__TonP9cxJgj8gXu71dWIyNlA T20_;
		if (!catchBranchesExist_1) goto LA18_;
		colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
		colontmpD__5 = percent___jsgen_u2850(T20_, 0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		prepareAdd((&(*p_p0).body), colontmpD__5.len + 0);
appendString((&(*p_p0).body), colontmpD__5);
		{
			NIM_BOOL T23_;
			NimStringV2 colontmpD__6;
			NimStringV2 colontmpD__7;
			tyArray__YgExxhfgKcesA5EOUj1MOA T26_;
			T23_ = (NIM_BOOL)0;
			T23_ = hasFrameInfo__jsgen_u2617(p_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			if (!T23_) goto LA24_;
			colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
			colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
			T26_[0] = tmpFramePtr_1;
			colontmpD__6 = percent___jsgen_u2855(T26_, 1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			colontmpD__7 = indentLine__jsgen_u102(p_p0, colontmpD__6);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			prepareAdd((&(*p_p0).body), colontmpD__7.len + 0);
appendString((&(*p_p0).body), colontmpD__7);
			eqdestroy___system_u2691(colontmpD__7);
			eqdestroy___system_u2691(colontmpD__6);
		}
LA24_: ;
		eqdestroy___system_u2691(colontmpD__5);
	}
LA18_: ;
	{
		while (1) {
			NIM_BOOL T29_;
			NI T30_;
			T29_ = (NIM_BOOL)0;
			T30_ = (NI)0;
			T30_ = len__ast_u3190(n_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			T29_ = (i_1 < T30_);
			if (!(T29_)) goto LA31_;
			T29_ = ((*(*n_p1)._kind_6.sons.p->data[i_1]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)87));
LA31_: ;
			if (!T29_) goto LA28;
			{
				NI T34_;
				T34_ = (NI)0;
				T34_ = len__ast_u3190((*n_p1)._kind_6.sons.p->data[i_1]);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				if (!(T34_ == ((NI)1))) goto LA35_;
				generalCatchBranchExists_1 = NIM_TRUE;
				{
					NimStringV2 colontmpD__8;
					NimStringV2 colontmpD__9;
					tyArray__TonP9cxJgj8gXu71dWIyNlA T41_;
					if (!(((NI)1) < i_1)) goto LA39_;
					colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
					colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
					colontmpD__8 = percent___jsgen_u2864(T41_, 0);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					colontmpD__9 = indentLine__jsgen_u102(p_p0, colontmpD__8);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					prepareAdd((&(*p_p0).body), colontmpD__9.len + 0);
appendString((&(*p_p0).body), colontmpD__9);
					eqdestroy___system_u2691(colontmpD__9);
					eqdestroy___system_u2691(colontmpD__8);
				}
LA39_: ;
				gen__jsgen_u1159(p_p0, (*(*n_p1)._kind_6.sons.p->data[i_1])._kind_6.sons.p->data[((NI)0)], (&a_1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				moveInto__jsgen_u2802(p_p0, (&a_1), (&(*r_p2)));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				{
					NimStringV2 colontmpD__10;
					NimStringV2 colontmpD__11;
					tyArray__TonP9cxJgj8gXu71dWIyNlA T46_;
					if (!(((NI)1) < i_1)) goto LA44_;
					colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
					colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
					colontmpD__10 = percent___cgen_u9681(T46_, 0);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					colontmpD__11 = indentLine__jsgen_u102(p_p0, colontmpD__10);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					prepareAdd((&(*p_p0).body), colontmpD__11.len + 0);
appendString((&(*p_p0).body), colontmpD__11);
					eqdestroy___system_u2691(colontmpD__11);
					eqdestroy___system_u2691(colontmpD__10);
				}
LA44_: ;
			}
			goto LA32_;
LA35_: ;
			{
				NimStringV2 orExpr_1;
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* excAlias_1;
				NimStringV2 colontmpD__12;
				NimStringV2 colontmpD__13;
				NimStringV2 colontmpD__14;
				NimStringV2 colontmpD__15;
				tyArray__YgExxhfgKcesA5EOUj1MOA T88_;
				NI T98_;
				tyArray__TonP9cxJgj8gXu71dWIyNlA T99_;
				orExpr_1.len = 0; orExpr_1.p = NIM_NIL;
				excAlias_1 = NIM_NIL;
				colontmpD__12.len = 0; colontmpD__12.p = NIM_NIL;
				colontmpD__13.len = 0; colontmpD__13.p = NIM_NIL;
				colontmpD__14.len = 0; colontmpD__14.p = NIM_NIL;
				colontmpD__15.len = 0; colontmpD__15.p = NIM_NIL;
				orExpr_1 = TM__BxLwT0mhrtgTPodf1v3xjg_777;
				excAlias_1 = ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL);
				useMagic__jsgen_u1172(p_p0, TM__BxLwT0mhrtgTPodf1v3xjg_778);
				if (NIM_UNLIKELY(*nimErr_)) goto LA48_;
				{
					NI j_1;
					NI colontmp_;
					NI T50_;
					NI i_2;
					j_1 = (NI)0;
					colontmp_ = (NI)0;
					T50_ = (NI)0;
					T50_ = len__ast_u3190((*n_p1)._kind_6.sons.p->data[i_1]);
					if (NIM_UNLIKELY(*nimErr_)) goto LA48_;
					colontmp_ = (NI)(T50_ - ((NI)1));
					i_2 = ((NI)0);
					{
						while (1) {
							tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* throwObj_1;
							tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* it_1;
							if (!(i_2 < colontmp_)) goto LA52;
							throwObj_1 = NIM_NIL;
							it_1 = NIM_NIL;
							j_1 = i_2;
							throwObj_1 = 0;
							eqcopy___ast_u3255(&it_1, (*(*n_p1)._kind_6.sons.p->data[i_1])._kind_6.sons.p->data[j_1]);
							if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
							{
								NIM_BOOL T56_;
								T56_ = (NIM_BOOL)0;
								T56_ = isInfixAs__ast_u7333(it_1);
								if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
								if (!T56_) goto LA57_;
								eqcopy___ast_u3255(&throwObj_1, (*it_1)._kind_6.sons.p->data[((NI)1)]);
								if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
								eqcopy___ast_u3255(&excAlias_1, (*it_1)._kind_6.sons.p->data[((NI)2)]);
								if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
								{
									if (!!((orExpr_1.len == 0))) goto LA61_;
									failedAssertImpl__stdZassertions_u79(TM__BxLwT0mhrtgTPodf1v3xjg_780);
									if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
								}
LA61_: ;
							}
							goto LA54_;
LA57_: ;
							{
								if (!((*it_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)4))) goto LA64_;
								throwObj_1 = it_1;
								eqwasMoved___ast_u3249(&it_1);
								if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
							}
							goto LA54_;
LA64_: ;
							{
								throwObj_1 = ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL);
								internalErrorImpl__msgs_u1598((*(*p_p0).module).config, (*n_p1).info, TM__BxLwT0mhrtgTPodf1v3xjg_782, (&TM__BxLwT0mhrtgTPodf1v3xjg_783));
								if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
							}
LA54_: ;
							{
								if (!!((orExpr_1.len == 0))) goto LA69_;
								prepareAdd((&orExpr_1), 2);
appendString((&orExpr_1), TM__BxLwT0mhrtgTPodf1v3xjg_785);
							}
LA69_: ;
							{
								NIM_BOOL T73_;
								NimStringV2 colontmpD__16;
								tyArray__YgExxhfgKcesA5EOUj1MOA T76_;
								T73_ = (NIM_BOOL)0;
								T73_ = isImportedException__ast_u7302((*throwObj_1).typField, (*(*p_p0).module).config);
								if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
								if (!T73_) goto LA74_;
								colontmpD__16.len = 0; colontmpD__16.p = NIM_NIL;
								T76_[0] = (*(*(*throwObj_1).typField).sym).loc.snippet;
								colontmpD__16 = percent___jsgen_u2891(T76_, 1);
								if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
								prepareAdd((&orExpr_1), colontmpD__16.len + 0);
appendString((&orExpr_1), colontmpD__16);
								eqdestroy___system_u2691(colontmpD__16);
							}
							goto LA71_;
LA74_: ;
							{
								NimStringV2 colontmpD__17;
								NimStringV2 colontmpD__18;
								tyArray__YgExxhfgKcesA5EOUj1MOA T79_;
								colontmpD__17.len = 0; colontmpD__17.p = NIM_NIL;
								colontmpD__18.len = 0; colontmpD__18.p = NIM_NIL;
								colontmpD__17 = genTypeInfo__jsgen_u828(p_p0, (*throwObj_1).typField);
								if (NIM_UNLIKELY(*nimErr_)) goto LA78_;
								T79_[0] = colontmpD__17;
								colontmpD__18 = percent___jsgen_u2896(T79_, 1);
								if (NIM_UNLIKELY(*nimErr_)) goto LA78_;
								prepareAdd((&orExpr_1), colontmpD__18.len + 0);
appendString((&orExpr_1), colontmpD__18);
								{
									LA78_:;
								}
								{
									eqdestroy___system_u2691(colontmpD__18);
									eqdestroy___system_u2691(colontmpD__17);
								}
								if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
							}
LA71_: ;
							i_2 += ((NI)1);
							{
								LA53_:;
							}
							{
								oldNimErrFin53_ = *nimErr_; *nimErr_ = NIM_FALSE;
								eqdestroy___ast_u3252(it_1);
								if (NIM_UNLIKELY(*nimErr_)) goto LA48_;
								eqdestroy___ast_u3252(throwObj_1);
								if (NIM_UNLIKELY(*nimErr_)) goto LA48_;
								*nimErr_ = oldNimErrFin53_;
							}
							if (NIM_UNLIKELY(*nimErr_)) goto LA48_;
						} LA52: ;
					}
				}
				{
					NimStringV2 colontmpD__19;
					if (!(((NI)1) < i_1)) goto LA86_;
					colontmpD__19.len = 0; colontmpD__19.p = NIM_NIL;
					colontmpD__19 = indentLine__jsgen_u102(p_p0, TM__BxLwT0mhrtgTPodf1v3xjg_787);
					if (NIM_UNLIKELY(*nimErr_)) goto LA48_;
					prepareAdd((&(*p_p0).body), colontmpD__19.len + 0);
appendString((&(*p_p0).body), colontmpD__19);
					eqdestroy___system_u2691(colontmpD__19);
				}
LA86_: ;
				T88_[0] = orExpr_1;
				colontmpD__12 = percent___jsgen_u2901(T88_, 1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA48_;
				colontmpD__13 = indentLine__jsgen_u102(p_p0, colontmpD__12);
				if (NIM_UNLIKELY(*nimErr_)) goto LA48_;
				prepareAdd((&(*p_p0).body), colontmpD__13.len + 0);
appendString((&(*p_p0).body), colontmpD__13);
				{
					NimStringV2 colontmpD__20;
					NimStringV2 colontmpD__21;
					NimStringV2 T94_;
					tyArray__YgExxhfgKcesA5EOUj1MOA T95_;
					if (!!((excAlias_1 == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL)))) goto LA91_;
					colontmpD__20.len = 0; colontmpD__20.p = NIM_NIL;
					colontmpD__21.len = 0; colontmpD__21.p = NIM_NIL;
					T94_.len = 0; T94_.p = NIM_NIL;
					T94_ = mangleName__jsgen_u702((*p_p0).module, (*excAlias_1)._kind_4.sym);
					if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T94_); goto LA93_;}
					eqsink___system_u2700((&(*(*excAlias_1)._kind_4.sym).loc.snippet), T94_);
					T95_[0] = (*(*excAlias_1)._kind_4.sym).loc.snippet;
					colontmpD__20 = percent___jsgen_u2910(T95_, 1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA93_;
					colontmpD__21 = indentLine__jsgen_u102(p_p0, colontmpD__20);
					if (NIM_UNLIKELY(*nimErr_)) goto LA93_;
					prepareAdd((&(*p_p0).body), colontmpD__21.len + 0);
appendString((&(*p_p0).body), colontmpD__21);
					{
						LA93_:;
					}
					{
						eqdestroy___system_u2691(colontmpD__21);
						eqdestroy___system_u2691(colontmpD__20);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA48_;
				}
LA91_: ;
				T98_ = (NI)0;
				T98_ = len__ast_u3190((*n_p1)._kind_6.sons.p->data[i_1]);
				if (NIM_UNLIKELY(*nimErr_)) goto LA48_;
				gen__jsgen_u1159(p_p0, (*(*n_p1)._kind_6.sons.p->data[i_1])._kind_6.sons.p->data[(NI)(T98_ - ((NI)1))], (&a_1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA48_;
				moveInto__jsgen_u2802(p_p0, (&a_1), (&(*r_p2)));
				if (NIM_UNLIKELY(*nimErr_)) goto LA48_;
				colontmpD__14 = percent___cgen_u9681(T99_, 0);
				if (NIM_UNLIKELY(*nimErr_)) goto LA48_;
				colontmpD__15 = indentLine__jsgen_u102(p_p0, colontmpD__14);
				if (NIM_UNLIKELY(*nimErr_)) goto LA48_;
				prepareAdd((&(*p_p0).body), colontmpD__15.len + 0);
appendString((&(*p_p0).body), colontmpD__15);
				{
					LA48_:;
				}
				{
					oldNimErrFin48_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___system_u2691(colontmpD__15);
					eqdestroy___system_u2691(colontmpD__14);
					eqdestroy___system_u2691(colontmpD__13);
					eqdestroy___system_u2691(colontmpD__12);
					eqdestroy___ast_u3252(excAlias_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___system_u2691(orExpr_1);
					*nimErr_ = oldNimErrFin48_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
LA32_: ;
			i_1 += ((NI)1);
		} LA28: ;
	}
	{
		NimStringV2 colontmpD__22;
		NimStringV2 colontmpD__23;
		tyArray__TonP9cxJgj8gXu71dWIyNlA T114_;
		if (!catchBranchesExist_1) goto LA104_;
		colontmpD__22.len = 0; colontmpD__22.p = NIM_NIL;
		colontmpD__23.len = 0; colontmpD__23.p = NIM_NIL;
		{
			NimStringV2 colontmpD__24;
			NimStringV2 colontmpD__25;
			NimStringV2 colontmpD__26;
			if (!!(generalCatchBranchExists_1)) goto LA109_;
			colontmpD__24.len = 0; colontmpD__24.p = NIM_NIL;
			colontmpD__25.len = 0; colontmpD__25.p = NIM_NIL;
			colontmpD__26.len = 0; colontmpD__26.p = NIM_NIL;
			useMagic__jsgen_u1172(p_p0, TM__BxLwT0mhrtgTPodf1v3xjg_789);
			if (NIM_UNLIKELY(*nimErr_)) goto LA111_;
			colontmpD__24 = indentLine__jsgen_u102(p_p0, TM__BxLwT0mhrtgTPodf1v3xjg_791);
			if (NIM_UNLIKELY(*nimErr_)) goto LA111_;
			prepareAdd((&(*p_p0).body), colontmpD__24.len + 0);
appendString((&(*p_p0).body), colontmpD__24);
			colontmpD__25 = indentLine__jsgen_u102(p_p0, TM__BxLwT0mhrtgTPodf1v3xjg_793);
			if (NIM_UNLIKELY(*nimErr_)) goto LA111_;
			prepareAdd((&(*p_p0).body), colontmpD__25.len + 0);
appendString((&(*p_p0).body), colontmpD__25);
			colontmpD__26 = indentLine__jsgen_u102(p_p0, TM__BxLwT0mhrtgTPodf1v3xjg_794);
			if (NIM_UNLIKELY(*nimErr_)) goto LA111_;
			prepareAdd((&(*p_p0).body), colontmpD__26.len + 0);
appendString((&(*p_p0).body), colontmpD__26);
			{
				LA111_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__26);
				eqdestroy___system_u2691(colontmpD__25);
				eqdestroy___system_u2691(colontmpD__24);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA106_;
		}
LA109_: ;
		colontmpD__22 = percent___jsgen_u2924(T114_, 0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA106_;
		colontmpD__23 = indentLine__jsgen_u102(p_p0, colontmpD__22);
		if (NIM_UNLIKELY(*nimErr_)) goto LA106_;
		prepareAdd((&(*p_p0).body), colontmpD__23.len + 0);
appendString((&(*p_p0).body), colontmpD__23);
		{
			LA106_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__23);
			eqdestroy___system_u2691(colontmpD__22);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA104_: ;
	colontmpD__3 = indentLine__jsgen_u102(p_p0, TM__BxLwT0mhrtgTPodf1v3xjg_796);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&(*p_p0).body), colontmpD__3.len + 0);
appendString((&(*p_p0).body), colontmpD__3);
	{
		NIM_BOOL T119_;
		NimStringV2 colontmpD__27;
		NimStringV2 colontmpD__28;
		tyArray__YgExxhfgKcesA5EOUj1MOA T122_;
		T119_ = (NIM_BOOL)0;
		T119_ = hasFrameInfo__jsgen_u2617(p_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!T119_) goto LA120_;
		colontmpD__27.len = 0; colontmpD__27.p = NIM_NIL;
		colontmpD__28.len = 0; colontmpD__28.p = NIM_NIL;
		T122_[0] = tmpFramePtr_1;
		colontmpD__27 = percent___jsgen_u2855(T122_, 1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		colontmpD__28 = indentLine__jsgen_u102(p_p0, colontmpD__27);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		prepareAdd((&(*p_p0).body), colontmpD__28.len + 0);
appendString((&(*p_p0).body), colontmpD__28);
		eqdestroy___system_u2691(colontmpD__28);
		eqdestroy___system_u2691(colontmpD__27);
	}
LA120_: ;
	{
		NIM_BOOL T125_;
		NI T126_;
		T125_ = (NIM_BOOL)0;
		T126_ = (NI)0;
		T126_ = len__ast_u3190(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T125_ = (i_1 < T126_);
		if (!(T125_)) goto LA127_;
		T125_ = ((*(*n_p1)._kind_6.sons.p->data[i_1]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)107));
LA127_: ;
		if (!T125_) goto LA128_;
		genStmt__jsgen_u1163(p_p0, (*(*n_p1)._kind_6.sons.p->data[i_1])._kind_6.sons.p->data[((NI)0)]);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA128_: ;
	colontmpD__4 = indentLine__jsgen_u102(p_p0, TM__BxLwT0mhrtgTPodf1v3xjg_797);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&(*p_p0).body), colontmpD__4.len + 0);
appendString((&(*p_p0).body), colontmpD__4);
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD__4);
		eqdestroy___system_u2691(colontmpD__3);
		eqdestroy___jsgen_u570((&a_1));
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(colontmpD_);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genRaiseStmt__jsgen_u2937)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
NIM_BOOL oldNimErrFin5_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ a_1;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_1;
		NimStringV2 colontmpD_;
		NimStringV2 colontmpD__2;
		NimStringV2 colontmpD__3;
		NimStringV2 colontmpD__4;
		tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T6_;
		if (!!(((*(*n_p1)._kind_6.sons.p->data[((NI)0)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)1)))) goto LA3_;
		nimZeroMem((void*)(&a_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
		typ_1 = NIM_NIL;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
		colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
		nimZeroMem((void*)(&a_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
		gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)0)], (&a_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		typ_1 = skipTypes__ast_u5379((*(*n_p1)._kind_6.sons.p->data[((NI)0)]).typField, TM__BxLwT0mhrtgTPodf1v3xjg_527);
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		genLineDir__jsgen_u2646(p_p0, n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		useMagic__jsgen_u1172(p_p0, TM__BxLwT0mhrtgTPodf1v3xjg_799);
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		colontmpD_ = rdLoc__jsgen_u593((&a_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		T6_[0] = colontmpD_;
		colontmpD__2 = makeJSString__jsgen_u806((*(*(*typ_1).sym).name).s, NIM_TRUE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		T6_[1] = colontmpD__2;
		colontmpD__3 = percent___jsgen_u2950(T6_, 2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		colontmpD__4 = indentLine__jsgen_u102(p_p0, colontmpD__3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		prepareAdd((&(*p_p0).body), colontmpD__4.len + 0);
appendString((&(*p_p0).body), colontmpD__4);
		{
			LA5_:;
		}
		{
			oldNimErrFin5_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___system_u2691(colontmpD__4);
			eqdestroy___system_u2691(colontmpD__3);
			eqdestroy___system_u2691(colontmpD__2);
			eqdestroy___system_u2691(colontmpD_);
			eqdestroy___ast_u3378(typ_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			eqdestroy___jsgen_u570((&a_1));
			*nimErr_ = oldNimErrFin5_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA3_: ;
	{
		NimStringV2 colontmpD__5;
		colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
		genLineDir__jsgen_u2646(p_p0, n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		useMagic__jsgen_u1172(p_p0, TM__BxLwT0mhrtgTPodf1v3xjg_800);
		if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		colontmpD__5 = indentLine__jsgen_u102(p_p0, TM__BxLwT0mhrtgTPodf1v3xjg_802);
		if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		prepareAdd((&(*p_p0).body), colontmpD__5.len + 0);
appendString((&(*p_p0).body), colontmpD__5);
		{
			LA10_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__5);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genPragma__jsgen_u7470)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
NIM_BOOL oldNimErrFin4_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NI i_1;
		NI colontmp_;
		NI i_2;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_u3190(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		i_2 = ((NI)0);
		{
			while (1) {
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* it_1;
				tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw T5_;
				if (!(i_2 < colontmp_)) goto LA3;
				it_1 = NIM_NIL;
				i_1 = i_2;
				eqcopy___ast_u3255(&it_1, (*n_p1)._kind_6.sons.p->data[i_1]);
				if (NIM_UNLIKELY(*nimErr_)) goto LA4_;
				T5_ = (tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)0;
				T5_ = whichPragma__trees_u218(it_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA4_;
				switch (T5_) {
				case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)217):
				{
					genAsmOrEmitStmt__jsgen_u3207(p_p0, (*it_1)._kind_6.sons.p->data[((NI)1)], NIM_FALSE);
					if (NIM_UNLIKELY(*nimErr_)) goto LA4_;
				}
				break;
				case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)129):
				{
					tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* T8_;
					tySequence__bdNIx7Bah2llfuqeoTJEWQ* T9_;
					T8_ = NIM_NIL;
					T8_ = (*(*p_p0).module).config;
					T9_ = (tySequence__bdNIx7Bah2llfuqeoTJEWQ*)0;
					T9_ = (&(*p_p0).optionsStack);
					processPushBackendOption__pushpoppragmas_u288(T8_, T9_, (&(*p_p0).options), n_p1, (NI)(i_1 + ((NI)1)));
					if (NIM_UNLIKELY(*nimErr_)) goto LA4_;
				}
				break;
				case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)130):
				{
					tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* T11_;
					tySequence__bdNIx7Bah2llfuqeoTJEWQ* T12_;
					T11_ = NIM_NIL;
					T11_ = (*(*p_p0).module).config;
					T12_ = (tySequence__bdNIx7Bah2llfuqeoTJEWQ*)0;
					T12_ = (&(*p_p0).optionsStack);
					popBackendOption__pushpoppragmas_u230(T11_, T12_, (&(*p_p0).options));
					if (NIM_UNLIKELY(*nimErr_)) goto LA4_;
				}
				break;
				default:
				{
				}
				break;
				}
				i_2 += ((NI)1);
				{
					LA4_:;
				}
				{
					oldNimErrFin4_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3252(it_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					*nimErr_ = oldNimErrFin4_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			} LA3: ;
		}
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genBreakState__jsgen_u1536)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* r_p2) {
	tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ a_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&a_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
	nimZeroMem((void*)(&a_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
	{
		NimStringV2 colontmpD_;
		tyArray__YgExxhfgKcesA5EOUj1MOA T7_;
		NimStringV2 T8_;
		if (!((*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)155))) goto LA4_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], (&a_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		colontmpD_ = rdLoc__jsgen_u593((&a_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		T7_[0] = colontmpD_;
		T8_.len = 0; T8_.p = NIM_NIL;
		T8_ = percent___jsgen_u1549(T7_, 1);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T8_); goto LA6_;}
		eqsink___system_u2700((&(*r_p2).res), T8_);
		{
			LA6_:;
		}
		{
			eqdestroy___system_u2691(colontmpD_);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA2_;
LA4_: ;
	{
		NimStringV2 colontmpD__2;
		tyArray__YgExxhfgKcesA5EOUj1MOA T13_;
		NimStringV2 T14_;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		gen__jsgen_u1159(p_p0, n_p1, (&a_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
		colontmpD__2 = rdLoc__jsgen_u593((&a_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
		T13_[0] = colontmpD__2;
		T14_.len = 0; T14_.p = NIM_NIL;
		T14_ = percent___jsgen_u1554(T13_, 1);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T14_); goto LA12_;}
		eqsink___system_u2700((&(*r_p2).res), T14_);
		{
			LA12_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__2);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA2_: ;
	(*r_p2).kind = ((tyEnum_TResKind__UiCSai1lX4RMkJ9bHo9aP2HA)1);
	{
		LA1_:;
	}
	{
		eqdestroy___jsgen_u570((&a_1));
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, gen__jsgen_u1159)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ* r_p2) {
NIM_BOOL oldNimErrFin54_;
NIM_BOOL oldNimErrFin154_;
NIM_BOOL oldNimErrFin182_;
NIM_BOOL oldNimErrFin216_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	(*r_p2).typ = ((tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)0);
	{
		if (!!(((*r_p2).kind == ((tyEnum_TResKind__UiCSai1lX4RMkJ9bHo9aP2HA)3)))) goto LA3_;
		(*r_p2).kind = ((tyEnum_TResKind__UiCSai1lX4RMkJ9bHo9aP2HA)0);
	}
LA3_: ;
	eqsink___system_u2700((&(*r_p2).res), TM__BxLwT0mhrtgTPodf1v3xjg_39);
	switch ((*n_p1).kind) {
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3):
	{
		genSym__jsgen_u4197(p_p0, n_p1, r_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)5) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)15):
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
		colontmpD_ = NIM_NIL;
		colontmpD_ = skipTypes__ast_u5379((*n_p1).typField, TM__BxLwT0mhrtgTPodf1v3xjg_358);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		switch ((*colontmpD_).kind) {
		case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)1):
		{
			NimStringV2 T8_;
			T8_.len = 0; T8_.p = NIM_NIL;
			{
				if (!((*n_p1)._kind_1.intVal == IL64(0))) goto LA11_;
				eqsink___system_u2700((&(*r_p2).res), TM__BxLwT0mhrtgTPodf1v3xjg_360);
			}
			goto LA9_;
LA11_: ;
			{
				eqsink___system_u2700((&(*r_p2).res), TM__BxLwT0mhrtgTPodf1v3xjg_362);
			}
LA9_: ;
		}
		break;
		case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)44):
		{
			NimStringV2 T15_;
			T15_.len = 0; T15_.p = NIM_NIL;
			T15_ = dollar___systemZdollars_u54(((NU64) ((*n_p1)._kind_1.intVal)));
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T15_); goto BeforeRet_;}
			eqsink___system_u2700((&(*r_p2).res), T15_);
			{
				if (!(((*(*(*p_p0).module).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)56)))&63U)))!=0)) goto LA18_;
				nimAddCharV1((&(*r_p2).res), 110);
			}
LA18_: ;
		}
		break;
		case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)35):
		{
			NIM_BOOL wrap_1;
			wrap_1 = ((*n_p1)._kind_1.intVal < IL64(0));
			{
				if (!wrap_1) goto LA23_;
				nimAddCharV1((&(*r_p2).res), 40);
			}
LA23_: ;
			addInt__stdZprivateZdigitsutils_u187((&(*r_p2).res), (*n_p1)._kind_1.intVal);
			{
				if (!(((*(*(*p_p0).module).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)56)))&63U)))!=0)) goto LA27_;
				nimAddCharV1((&(*r_p2).res), 110);
			}
LA27_: ;
			{
				if (!wrap_1) goto LA31_;
				nimAddCharV1((&(*r_p2).res), 41);
			}
LA31_: ;
		}
		break;
		default:
		{
			NIM_BOOL wrap_2;
			wrap_2 = ((*n_p1)._kind_1.intVal < IL64(0));
			{
				if (!wrap_2) goto LA36_;
				nimAddCharV1((&(*r_p2).res), 40);
			}
LA36_: ;
			addInt__stdZprivateZdigitsutils_u187((&(*r_p2).res), (*n_p1)._kind_1.intVal);
			{
				if (!wrap_2) goto LA40_;
				nimAddCharV1((&(*r_p2).res), 41);
			}
LA40_: ;
		}
		break;
		}
		(*r_p2).kind = ((tyEnum_TResKind__UiCSai1lX4RMkJ9bHo9aP2HA)1);
		eqdestroy___ast_u3378(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)23):
	{
		{
			NIM_BOOL T45_;
			T45_ = (NIM_BOOL)0;
			T45_ = isEmptyType__ast_u7234((*n_p1).typField);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T45_) goto LA46_;
		}
		goto LA43_;
LA46_: ;
		{
			tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg T49_;
			T49_ = (tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)0;
			T49_ = mapType__jsgen_u698(p_p0, (*n_p1).typField);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!(T49_ == ((tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)9))) goto LA50_;
			(*r_p2).typ = ((tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg)9);
			eqsink___system_u2700((&(*r_p2).address), TM__BxLwT0mhrtgTPodf1v3xjg_364);
			eqsink___system_u2700((&(*r_p2).res), TM__BxLwT0mhrtgTPodf1v3xjg_366);
			(*r_p2).kind = ((tyEnum_TResKind__UiCSai1lX4RMkJ9bHo9aP2HA)1);
		}
		goto LA43_;
LA50_: ;
		{
			eqsink___system_u2700((&(*r_p2).res), TM__BxLwT0mhrtgTPodf1v3xjg_367);
			(*r_p2).kind = ((tyEnum_TResKind__UiCSai1lX4RMkJ9bHo9aP2HA)1);
		}
LA43_: ;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)20) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)22):
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__2;
		colontmpD__2 = NIM_NIL;
		{
			colontmpD__2 = skipTypes__ast_u5379((*n_p1).typField, TM__BxLwT0mhrtgTPodf1v3xjg_358);
			if (NIM_UNLIKELY(*nimErr_)) goto LA54_;
			if (!((*colontmpD__2).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)28))) goto LA57_;
			{
				NimStringV2 T63_;
				if (!((*n_p1)._kind_3.strVal.len <= ((NI)64))) goto LA61_;
				T63_.len = 0; T63_.p = NIM_NIL;
				T63_ = makeJsNimStrLit__jsgen_u810((*n_p1)._kind_3.strVal);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T63_); goto LA54_;}
				eqsink___system_u2700((&(*r_p2).res), T63_);
			}
			goto LA59_;
LA61_: ;
			{
				NimStringV2 colontmpD__3;
				tyArray__YgExxhfgKcesA5EOUj1MOA T66_;
				NimStringV2 T67_;
				colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
				useMagic__jsgen_u1172(p_p0, TM__BxLwT0mhrtgTPodf1v3xjg_373);
				if (NIM_UNLIKELY(*nimErr_)) goto LA65_;
				colontmpD__3 = makeJSString__jsgen_u806((*n_p1)._kind_3.strVal, NIM_TRUE);
				if (NIM_UNLIKELY(*nimErr_)) goto LA65_;
				T66_[0] = colontmpD__3;
				T67_.len = 0; T67_.p = NIM_NIL;
				T67_ = percent___jsgen_u7998(T66_, 1);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T67_); goto LA65_;}
				eqsink___system_u2700((&(*r_p2).res), T67_);
				{
					LA65_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__3);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA54_;
			}
LA59_: ;
		}
		goto LA55_;
LA57_: ;
		{
			NimStringV2 T71_;
			T71_.len = 0; T71_.p = NIM_NIL;
			T71_ = makeJSString__jsgen_u806((*n_p1)._kind_3.strVal, NIM_FALSE);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T71_); goto LA54_;}
			eqsink___system_u2700((&(*r_p2).res), T71_);
		}
LA55_: ;
		(*r_p2).kind = ((tyEnum_TResKind__UiCSai1lX4RMkJ9bHo9aP2HA)1);
		{
			LA54_:;
		}
		{
			oldNimErrFin54_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3378(colontmpD__2);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin54_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)16) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)18):
	{
		NF f_1;
		tyEnum_FloatClass__gfrWEZTSUZU5OWgwK4wTYw T75_;
		f_1 = (*n_p1)._kind_2.floatVal;
		T75_ = (tyEnum_FloatClass__gfrWEZTSUZU5OWgwK4wTYw)0;
		T75_ = classify__pureZmath_u211(f_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		switch (T75_) {
		case ((tyEnum_FloatClass__gfrWEZTSUZU5OWgwK4wTYw)4):
		{
			{
				NIM_BOOL T79_;
				T79_ = (NIM_BOOL)0;
				T79_ = signbit__astyaml_u680(f_1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				if (!T79_) goto LA80_;
				eqsink___system_u2700((&(*r_p2).res), TM__BxLwT0mhrtgTPodf1v3xjg_375);
			}
			goto LA77_;
LA80_: ;
			{
				eqsink___system_u2700((&(*r_p2).res), TM__BxLwT0mhrtgTPodf1v3xjg_377);
			}
LA77_: ;
		}
		break;
		case ((tyEnum_FloatClass__gfrWEZTSUZU5OWgwK4wTYw)3):
		{
			eqsink___system_u2700((&(*r_p2).res), TM__BxLwT0mhrtgTPodf1v3xjg_379);
		}
		break;
		case ((tyEnum_FloatClass__gfrWEZTSUZU5OWgwK4wTYw)2):
		{
			eqsink___system_u2700((&(*r_p2).res), TM__BxLwT0mhrtgTPodf1v3xjg_381);
		}
		break;
		case ((tyEnum_FloatClass__gfrWEZTSUZU5OWgwK4wTYw)5):
		{
			eqsink___system_u2700((&(*r_p2).res), TM__BxLwT0mhrtgTPodf1v3xjg_383);
		}
		break;
		case ((tyEnum_FloatClass__gfrWEZTSUZU5OWgwK4wTYw)6):
		{
			eqsink___system_u2700((&(*r_p2).res), TM__BxLwT0mhrtgTPodf1v3xjg_385);
		}
		break;
		default:
		{
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__4;
			colontmpD__4 = NIM_NIL;
			{
				colontmpD__4 = skipTypes__ast_u5379((*n_p1).typField, TM__BxLwT0mhrtgTPodf1v3xjg_358);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				if (!((*colontmpD__4).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)37))) goto LA90_;
				addFloatRoundtrip__systemZrepr95v2_u97((&(*r_p2).res), ((NF32) (f_1)));
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			}
			goto LA88_;
LA90_: ;
			{
				addFloatRoundtrip__system_u4742((&(*r_p2).res), f_1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			}
LA88_: ;
			eqdestroy___ast_u3378(colontmpD__4);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		break;
		}
		(*r_p2).kind = ((tyEnum_TResKind__UiCSai1lX4RMkJ9bHo9aP2HA)1);
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)26) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)32):
	{
		{
			NIM_BOOL T96_;
			T96_ = (NIM_BOOL)0;
			T96_ = isEmptyType__ast_u7234((*n_p1).typField);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T96_) goto LA97_;
			genLineDir__jsgen_u2646(p_p0, n_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA97_: ;
		{
			NIM_BOOL T101_;
			T101_ = (NIM_BOOL)0;
			T101_ = ((*(*n_p1)._kind_6.sons.p->data[((NI)0)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3));
			if (!(T101_)) goto LA102_;
			T101_ = !(((*(*(*n_p1)._kind_6.sons.p->data[((NI)0)])._kind_4.sym).magic == ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)0)));
LA102_: ;
			if (!T101_) goto LA103_;
			genMagic__jsgen_u5466(p_p0, n_p1, r_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		goto LA99_;
LA103_: ;
		{
			NIM_BOOL T106_;
			NIM_BOOL T107_;
			NI T110_;
			T106_ = (NIM_BOOL)0;
			T107_ = (NIM_BOOL)0;
			T107_ = ((*(*n_p1)._kind_6.sons.p->data[((NI)0)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3));
			if (!(T107_)) goto LA108_;
			T107_ = (((*(*(*n_p1)._kind_6.sons.p->data[((NI)0)])._kind_4.sym).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)32)))&63U)))!=0);
LA108_: ;
			T106_ = T107_;
			if (!(T106_)) goto LA109_;
			T110_ = (NI)0;
			T110_ = len__ast_u3190(n_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			T106_ = (((NI)1) <= T110_);
LA109_: ;
			if (!T106_) goto LA111_;
			genInfixCall__jsgen_u4563(p_p0, n_p1, r_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		goto LA99_;
LA111_: ;
		{
			genCall__jsgen_u4598(p_p0, n_p1, r_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA99_: ;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)155):
	{
		{
			if (!(((*(*(*p_p0).module).config).legacyFeatures &((NU8)1<<((NU)((((tyEnum_LegacyFeature__yvNVqOQTgcxHpvo1MvfBfA)5)))&7U)))!=0)) goto LA117_;
			gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)0)], r_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		goto LA115_;
LA117_: ;
		{
			NimStringV2 tmp_1;
			tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ a_1;
			tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ b_1;
			NimStringV2 colontmpD__5;
			NimStringV2 colontmpD__6;
			NimStringV2 colontmpD__7;
			NimStringV2 colontmpD__8;
			tyArray__dyW7vpmfeTYw8kX3EXuaJA T121_;
			tmp_1.len = 0; tmp_1.p = NIM_NIL;
			nimZeroMem((void*)(&a_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
			nimZeroMem((void*)(&b_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
			colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
			colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
			colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
			colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
			tmp_1 = getTemp__jsgen_u1235(p_p0, NIM_TRUE);
			if (NIM_UNLIKELY(*nimErr_)) goto LA120_;
			nimZeroMem((void*)(&a_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
			nimZeroMem((void*)(&b_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
			gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)0)], (&a_1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA120_;
			gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], (&b_1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA120_;
			T121_[0] = tmp_1;
			colontmpD__5 = rdLoc__jsgen_u593((&a_1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA120_;
			T121_[1] = colontmpD__5;
			colontmpD__6 = rdLoc__jsgen_u593((&b_1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA120_;
			T121_[2] = colontmpD__6;
			colontmpD__7 = percent___jsgen_u8050(T121_, 3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA120_;
			colontmpD__8 = indentLine__jsgen_u102(p_p0, colontmpD__7);
			if (NIM_UNLIKELY(*nimErr_)) goto LA120_;
			prepareAdd((&(*p_p0).body), colontmpD__8.len + 0);
appendString((&(*p_p0).body), colontmpD__8);
			eqsink___system_u2700((&(*r_p2).res), tmp_1);
			eqwasMoved___system_u2688((&tmp_1));
			(*r_p2).kind = ((tyEnum_TResKind__UiCSai1lX4RMkJ9bHo9aP2HA)2);
			{
				LA120_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__8);
				eqdestroy___system_u2691(colontmpD__7);
				eqdestroy___system_u2691(colontmpD__6);
				eqdestroy___system_u2691(colontmpD__5);
				eqdestroy___jsgen_u570((&b_1));
				eqdestroy___jsgen_u570((&a_1));
				eqdestroy___system_u2691(tmp_1);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA115_: ;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)39):
	{
		genSetConstr__jsgen_u6436(p_p0, n_p1, r_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)41):
	{
		genArrayConstr__jsgen_u6482(p_p0, n_p1, r_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)37):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)160):
	{
		genTupleConstr__jsgen_u6508(p_p0, n_p1, r_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)38):
	{
		genObjConstr__jsgen_u6546(p_p0, n_p1, r_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)58):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)59):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)60):
	{
		genConv__jsgen_u6670(p_p0, n_p1, r_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)63):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)64):
	{
		{
			if (!((*(*n_p1).typField).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)47))) goto LA132_;
			gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)0)], r_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		goto LA130_;
LA132_: ;
		{
			genAddr__jsgen_u3765(p_p0, n_p1, r_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA130_: ;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)47):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)65):
	{
		{
			if (!((*(*n_p1).typField).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)47))) goto LA138_;
			gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)0)], r_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		goto LA136_;
LA138_: ;
		{
			genDeref__jsgen_u4337(p_p0, n_p1, r_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA136_: ;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)42):
	{
		genArrayAccess__jsgen_u3885(p_p0, n_p1, r_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)45):
	{
		genFieldAccess__jsgen_u3693(p_p0, n_p1, r_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)46):
	{
		genCheckedFieldOp__jsgen_u3769(p_p0, n_p1, ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL), r_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)66):
	{
		gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)0)], r_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)67):
	{
		upConv__jsgen_u7132(p_p0, n_p1, r_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)61):
	{
		genCast__jsgen_u7479(p_p0, n_p1, r_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)68):
	{
		genRangeChck__jsgen_u7136(p_p0, n_p1, r_p2, TM__BxLwT0mhrtgTPodf1v3xjg_696);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)69):
	{
		genRangeChck__jsgen_u7136(p_p0, n_p1, r_p2, TM__BxLwT0mhrtgTPodf1v3xjg_698);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)70):
	{
		genRangeChck__jsgen_u7136(p_p0, n_p1, r_p2, TM__BxLwT0mhrtgTPodf1v3xjg_699);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)71):
	{
		convStrToCStr__jsgen_u7232(p_p0, n_p1, r_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)72):
	{
		convCStrToStr__jsgen_u7245(p_p0, n_p1, r_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)1):
	{
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)51) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)52):
	{
		tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_1;
		NimStringV2 colontmpD__9;
		s_1 = NIM_NIL;
		colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
		eqcopy___ast_u4577(&s_1, (*(*n_p1)._kind_6.sons.p->data[((NI)0)])._kind_4.sym);
		if (NIM_UNLIKELY(*nimErr_)) goto LA154_;
		colontmpD__9 = mangleName__jsgen_u702((*p_p0).module, s_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA154_;
		(void)(colontmpD__9);
		eqcopy___system_u2694((&(*r_p2).res), (*s_1).loc.snippet);
		{
			NIM_BOOL T157_;
			T157_ = (NIM_BOOL)0;
			T157_ = (((*s_1).loc.flags &((NU16)1<<((NU)((((tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg)2)))&15U)))!=0);
			if (T157_) goto LA158_;
			T157_ = !(((*s_1).magic == ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)0) || (*s_1).magic == ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)157) || (*s_1).magic == ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)156) || (*s_1).magic == ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)144)));
LA158_: ;
			if (!T157_) goto LA159_;
		}
		goto LA155_;
LA159_: ;
		{
			tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA xX60gensym1583__1;
			NIM_BOOL T162_;
			NimStringV2 colontmpD__10;
			xX60gensym1583__1 = (*s_1).itemId;
			T162_ = (NIM_BOOL)0;
			T162_ = containsOrIncl__astyaml_u223((&(*(*p_p0).g).generatedSyms), (NI)((NI)((NU64)(((NI) (xX60gensym1583__1.module))) << (NU64)(((NI)24) & (64 - 1))) + ((NI) (xX60gensym1583__1.item))));
			if (NIM_UNLIKELY(*nimErr_)) goto LA154_;
			if (!!(T162_)) goto LA163_;
			colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
			colontmpD__10 = genProc__jsgen_u1166(p_p0, s_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA165_;
			prepareAdd((&(*p_p0).locals), colontmpD__10.len + 0);
appendString((&(*p_p0).locals), colontmpD__10);
			{
				LA165_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__10);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA154_;
		}
		goto LA155_;
LA163_: ;
LA155_: ;
		{
			LA154_:;
		}
		{
			oldNimErrFin154_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___system_u2691(colontmpD__9);
			eqdestroy___ast_u4574(s_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin154_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)4):
	{
		NimStringV2 T171_;
		T171_.len = 0; T171_.p = NIM_NIL;
		T171_ = genTypeInfo__jsgen_u828(p_p0, (*n_p1).typField);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T171_); goto BeforeRet_;}
		eqsink___system_u2700((&(*r_p2).res), T171_);
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)115):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)126):
	{
		NIM_BOOL isExpr_1;
		NIM_BOOL T173_;
		T173_ = (NIM_BOOL)0;
		T173_ = isEmptyType__ast_u7234((*n_p1).typField);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		isExpr_1 = !(T173_);
		{
			NI i_1;
			NI colontmp_;
			NI T175_;
			NI i_2;
			i_1 = (NI)0;
			colontmp_ = (NI)0;
			T175_ = (NI)0;
			T175_ = len__ast_u3190(n_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			colontmp_ = (NI)(T175_ - isExpr_1);
			i_2 = ((NI)0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA177;
					i_1 = i_2;
					genStmt__jsgen_u1163(p_p0, (*n_p1)._kind_6.sons.p->data[i_1]);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					i_2 += ((NI)1);
				} LA177: ;
			}
		}
		{
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__11;
			if (!isExpr_1) goto LA180_;
			colontmpD__11 = NIM_NIL;
			colontmpD__11 = lastSon__ast_u5208(n_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA182_;
			gen__jsgen_u1159(p_p0, colontmpD__11, r_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA182_;
			{
				LA182_:;
			}
			{
				oldNimErrFin182_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u3252(colontmpD__11);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				*nimErr_ = oldNimErrFin182_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA180_: ;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)112):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)127):
	{
		genBlock__jsgen_u3130(p_p0, n_p1, r_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)92):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)48):
	{
		genIf__jsgen_u3241(p_p0, n_p1, r_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)93):
	{
		gen__jsgen_u1159(p_p0, (*(*n_p1)._kind_6.sons.p->data[((NI)1)])._kind_6.sons.p->data[((NI)0)], r_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)96):
	{
		genWhileStmt__jsgen_u2686(p_p0, n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)99):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)100):
	{
		genVarStmt__jsgen_u5110(p_p0, n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)101):
	{
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)94):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)95):
	{
		internalErrorImpl__msgs_u1598((*(*p_p0).module).config, (*n_p1).info, TM__BxLwT0mhrtgTPodf1v3xjg_748, (&TM__BxLwT0mhrtgTPodf1v3xjg_749));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)97):
	{
		genCaseJS__jsgen_u2955(p_p0, n_p1, r_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)109):
	{
		genReturnStmt__jsgen_u7257(p_p0, n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)110):
	{
		genBreakStmt__jsgen_u3171(p_p0, n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)73):
	{
		genAsgn__jsgen_u3623(p_p0, n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)74):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)149):
	{
		genFastAsgn__jsgen_u3626(p_p0, n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)114):
	{
		{
			NimStringV2 T202_;
			if (!!(((*(*n_p1)._kind_6.sons.p->data[((NI)0)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)1)))) goto LA200_;
			genLineDir__jsgen_u2646(p_p0, n_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			gen__jsgen_u1159(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)0)], r_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			T202_.len = 0; T202_.p = NIM_NIL;
			T202_ = rawNewString((*r_p2).res.len + 2);
appendString((&T202_), TM__BxLwT0mhrtgTPodf1v3xjg_763);
appendString((&T202_), (*r_p2).res);
appendString((&T202_), TM__BxLwT0mhrtgTPodf1v3xjg_764);
			eqsink___system_u2700((&(*r_p2).res), T202_);
		}
LA200_: ;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)89):
	{
		warningDeprecated__msgs_u1572((*(*p_p0).module).config, (*n_p1).info, TM__BxLwT0mhrtgTPodf1v3xjg_768);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		genAsmOrEmitStmt__jsgen_u3207(p_p0, n_p1, NIM_TRUE);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)106):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)154):
	{
		genTry__jsgen_u2823(p_p0, n_p1, r_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)108):
	{
		genRaiseStmt__jsgen_u2937(p_p0, n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)98):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)125):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)121):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)116):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)117):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)118):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)119):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)120):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)83):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)82):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)84):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)113):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)123):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)122):
	{
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)90):
	{
		genPragma__jsgen_u7470(p_p0, n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)79):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)159):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)80):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)81):
	{
		tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_2;
		s_2 = NIM_NIL;
		s_2 = (*(*n_p1)._kind_6.sons.p->data[((NI)0)])._kind_4.sym;
		{
			if (!((262272 & (*s_2).flags) == 128)) goto LA211_;
			genSym__jsgen_u4197(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)0)], r_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			eqsink___system_u2700((&(*r_p2).res), TM__BxLwT0mhrtgTPodf1v3xjg_803);
		}
LA211_: ;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)156):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)157):
	{
		liMessage__msgs_u1227((*(*p_p0).module).config, (*n_p1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), TM__BxLwT0mhrtgTPodf1v3xjg_805, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)2), (&TM__BxLwT0mhrtgTPodf1v3xjg_806), NIM_FALSE, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)158):
	{
		genBreakState__jsgen_u1536(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)0)], r_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)91):
	{
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__12;
		colontmpD__12 = NIM_NIL;
		colontmpD__12 = lastSon__ast_u5208(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA216_;
		gen__jsgen_u1159(p_p0, colontmpD__12, r_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA216_;
		{
			LA216_:;
		}
		{
			oldNimErrFin216_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3252(colontmpD__12);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin216_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)24):
	{
	}
	break;
	default:
	{
		NimStringV2 colontmpD__13;
		NimStringV2 colontmpD__14;
		NimStringV2 T222_;
		colontmpD__13.len = 0; colontmpD__13.p = NIM_NIL;
		colontmpD__14.len = 0; colontmpD__14.p = NIM_NIL;
		T222_.len = 0; T222_.p = NIM_NIL;
		colontmpD__13 = dollar___nodekinds_u168((*n_p1).kind);
		T222_ = rawNewString(colontmpD__13.len + 24);
appendString((&T222_), TM__BxLwT0mhrtgTPodf1v3xjg_808);
appendString((&T222_), colontmpD__13);
		colontmpD__14 = T222_;
		internalErrorImpl__msgs_u1598((*(*p_p0).module).config, (*n_p1).info, colontmpD__14, (&TM__BxLwT0mhrtgTPodf1v3xjg_809));
		if (NIM_UNLIKELY(*nimErr_)) goto LA221_;
		{
			LA221_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__14);
			eqdestroy___system_u2691(colontmpD__13);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genStmt__jsgen_u1163)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
	tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ r_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&r_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
	nimZeroMem((void*)(&r_1), sizeof(tyObject_TCompRes__OVi9bu9b2NOm8QLDpLQd4oDQ));
	gen__jsgen_u1159(p_p0, n_p1, (&r_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NimStringV2 colontmpD_;
		NimStringV2 colontmpD__2;
		tyArray__YgExxhfgKcesA5EOUj1MOA T6_;
		if (!!((r_1.res.len == 0))) goto LA4_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		T6_[0] = r_1.res;
		colontmpD_ = percent___jsgen_u7465(T6_, 1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		colontmpD__2 = indentLine__jsgen_u102(p_p0, colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		prepareAdd((&(*p_p0).body), colontmpD__2.len + 0);
appendString((&(*p_p0).body), colontmpD__2);
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(colontmpD_);
	}
LA4_: ;
	{
		LA1_:;
	}
	{
		eqdestroy___jsgen_u570((&r_1));
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, addHcrInitGuards__jsgen_u8151)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, NimStringV2 moduleLoadedVar_p2, NIM_BOOL* inInitGuard_p3) {
NIM_BOOL oldNimErrFin6_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!((*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)115))) goto LA3_;
		{
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* child_1;
			child_1 = NIM_NIL;
			{
				NI i_1;
				NI colontmp_;
				NI i_2;
				i_1 = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = safeLen__ast_u3197(n_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
				i_2 = ((NI)0);
				{
					while (1) {
						if (!(i_2 < colontmp_)) goto LA9;
						i_1 = i_2;
						eqcopy___ast_u3255(&child_1, (*n_p1)._kind_6.sons.p->data[i_1]);
						if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
						addHcrInitGuards__jsgen_u8151(p_p0, child_1, moduleLoadedVar_p2, inInitGuard_p3);
						if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
						i_2 += ((NI)1);
					} LA9: ;
				}
			}
			{
				LA6_:;
			}
			{
				oldNimErrFin6_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u3252(child_1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				*nimErr_ = oldNimErrFin6_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
	}
	goto LA1_;
LA3_: ;
	{
		NIM_BOOL stmtShouldExecute_1;
		NIM_BOOL T13_;
		T13_ = (NIM_BOOL)0;
		T13_ = ((*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)79) || (*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)159) || (*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)80) || (*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)81) || (*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)99) || (*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)100));
		if (T13_) goto LA14_;
		T13_ = (((*n_p1).flags &((NU32)1<<((NU)((((tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw)20)))&31U)))!=0);
LA14_: ;
		stmtShouldExecute_1 = T13_;
		{
			if (!(*inInitGuard_p3)) goto LA17_;
			{
				NimStringV2 colontmpD_;
				if (!stmtShouldExecute_1) goto LA21_;
				colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
				(*p_p0).extraIndent -= ((NI)1);
				colontmpD_ = indentLine__jsgen_u102(p_p0, TM__BxLwT0mhrtgTPodf1v3xjg_37);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				prepareAdd((&(*p_p0).body), colontmpD_.len + 0);
appendString((&(*p_p0).body), colontmpD_);
				(*inInitGuard_p3) = NIM_FALSE;
				eqdestroy___system_u2691(colontmpD_);
			}
LA21_: ;
		}
		goto LA15_;
LA17_: ;
		{
			{
				NimStringV2 colontmpD__2;
				NimStringV2 colontmpD__3;
				tyArray__YgExxhfgKcesA5EOUj1MOA T28_;
				if (!!(stmtShouldExecute_1)) goto LA26_;
				colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
				colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
				T28_[0] = moduleLoadedVar_p2;
				colontmpD__2 = percent___jsgen_u8175(T28_, 1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				colontmpD__3 = indentLine__jsgen_u102(p_p0, colontmpD__2);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				prepareAdd((&(*p_p0).body), colontmpD__3.len + 0);
appendString((&(*p_p0).body), colontmpD__3);
				(*p_p0).extraIndent += ((NI)1);
				(*inInitGuard_p3) = NIM_TRUE;
				eqdestroy___system_u2691(colontmpD__3);
				eqdestroy___system_u2691(colontmpD__2);
			}
LA26_: ;
		}
LA15_: ;
		genStmt__jsgen_u1163(p_p0, n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genModule__jsgen_u8185)(tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* transformedN_1;
	tySet_tyEnum_TransformFlag__CzUOfRCXpoYcP43GAlt9cnA T10_;
NIM_BOOL oldNimErrFin22_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	transformedN_1 = NIM_NIL;
	{
		NimStringV2 colontmpD_;
		NimStringV2 colontmpD__2;
		NimStringV2 colontmpD__3;
		NimStringV2 colontmpD__4;
		NimStringV2 colontmpD__5;
		NimStringV2 T7_;
		if (!(((*p_p0).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)17)))&31U)))!=0)) goto LA4_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
		colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
		colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
		T7_.len = 0; T7_.p = NIM_NIL;
		T7_ = rawNewString((*(*(*(*p_p0).module).module).name).s.len + 7);
appendString((&T7_), TM__BxLwT0mhrtgTPodf1v3xjg_33);
appendString((&T7_), (*(*(*(*p_p0).module).module).name).s);
		colontmpD_ = T7_;
		colontmpD__2 = makeJSString__jsgen_u806(colontmpD_, NIM_TRUE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		colontmpD__3 = toFilenameOption__msgs_u676((*(*p_p0).module).config, (*(*(*p_p0).module).module).info.fileIndex, ((tyEnum_FilenameOption__o3jmnnVs6HdBg5KcNAzYiQ)5));
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		colontmpD__4 = makeJSString__jsgen_u806(colontmpD__3, NIM_TRUE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		colontmpD__5 = frameCreate__jsgen_u7273(p_p0, colontmpD__2, colontmpD__4);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		prepareAdd((&(*p_p0).body), colontmpD__5.len + 0);
appendString((&(*p_p0).body), colontmpD__5);
		{
			LA6_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__5);
			eqdestroy___system_u2691(colontmpD__4);
			eqdestroy___system_u2691(colontmpD__3);
			eqdestroy___system_u2691(colontmpD__2);
			eqdestroy___system_u2691(colontmpD_);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA4_: ;
	T10_ = 0;
	transformedN_1 = transformStmt__transf_u3500((*(*p_p0).module).graph, (*(*p_p0).module).Sup.idgen, (*(*p_p0).module).module, n_p1, T10_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T15_;
		if (!(((*(*(*p_p0).module).module).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)42)))&63U)))!=0)) goto LA13_;
		T15_ = NIM_NIL;
		T15_ = injectDestructorCalls__injectdestructors_u3431((*(*p_p0).module).graph, (*(*p_p0).module).Sup.idgen, (*(*p_p0).module).module, transformedN_1);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T15_); goto LA1_;}
		eqsink___ast_u3261(&transformedN_1, T15_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA13_: ;
	{
		NIM_BOOL T18_;
		tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* moduleSym_1;
		NimStringV2 moduleLoadedVar_1;
		NimStringV2 colontmpD__6;
		NimStringV2 colontmpD__7;
		NimStringV2 colontmpD__8;
		NimStringV2 colontmpD__9;
		NimStringV2 colontmpD__10;
		NimStringV2 T23_;
		tyArray__YgExxhfgKcesA5EOUj1MOA T24_;
		NIM_BOOL inGuardedBlock_1;
		tyArray__YgExxhfgKcesA5EOUj1MOA T29_;
		T18_ = (NIM_BOOL)0;
		T18_ = hcrOn__options_u629((*(*p_p0).module).config);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!(T18_)) goto LA19_;
		T18_ = ((*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)115));
LA19_: ;
		if (!T18_) goto LA20_;
		moduleSym_1 = NIM_NIL;
		moduleLoadedVar_1.len = 0; moduleLoadedVar_1.p = NIM_NIL;
		colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
		colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
		colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
		colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
		colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
		eqcopy___ast_u4577(&moduleSym_1, (*(*p_p0).module).module);
		if (NIM_UNLIKELY(*nimErr_)) goto LA22_;
		T23_.len = 0; T23_.p = NIM_NIL;
		colontmpD__6 = idOrSig__sighashes_u2002(moduleSym_1, (*(*moduleSym_1).name).s, (&(*(*p_p0).module).sigConflicts), (*(*p_p0).module).config);
		if (NIM_UNLIKELY(*nimErr_)) goto LA22_;
		T23_ = rawNewString((*(*moduleSym_1).name).s.len + colontmpD__6.len + 7);
appendString((&T23_), (*(*moduleSym_1).name).s);
appendString((&T23_), TM__BxLwT0mhrtgTPodf1v3xjg_35);
appendString((&T23_), colontmpD__6);
		moduleLoadedVar_1 = T23_;
		T24_[0] = moduleLoadedVar_1;
		colontmpD__7 = percent___jsgen_u1249(T24_, 1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA22_;
		colontmpD__8 = indentLine__jsgen_u102(p_p0, colontmpD__7);
		if (NIM_UNLIKELY(*nimErr_)) goto LA22_;
		prepareAdd((&(*p_p0).body), colontmpD__8.len + 0);
appendString((&(*p_p0).body), colontmpD__8);
		inGuardedBlock_1 = NIM_FALSE;
		addHcrInitGuards__jsgen_u8151(p_p0, transformedN_1, moduleLoadedVar_1, (&inGuardedBlock_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA22_;
		{
			NimStringV2 colontmpD__11;
			if (!inGuardedBlock_1) goto LA27_;
			colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
			(*p_p0).extraIndent -= ((NI)1);
			colontmpD__11 = indentLine__jsgen_u102(p_p0, TM__BxLwT0mhrtgTPodf1v3xjg_810);
			if (NIM_UNLIKELY(*nimErr_)) goto LA22_;
			prepareAdd((&(*p_p0).body), colontmpD__11.len + 0);
appendString((&(*p_p0).body), colontmpD__11);
			eqdestroy___system_u2691(colontmpD__11);
		}
LA27_: ;
		T29_[0] = moduleLoadedVar_1;
		colontmpD__9 = percent___jsgen_u8213(T29_, 1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA22_;
		colontmpD__10 = indentLine__jsgen_u102(p_p0, colontmpD__9);
		if (NIM_UNLIKELY(*nimErr_)) goto LA22_;
		prepareAdd((&(*p_p0).body), colontmpD__10.len + 0);
appendString((&(*p_p0).body), colontmpD__10);
		{
			LA22_:;
		}
		{
			oldNimErrFin22_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___system_u2691(colontmpD__10);
			eqdestroy___system_u2691(colontmpD__9);
			eqdestroy___system_u2691(colontmpD__8);
			eqdestroy___system_u2691(colontmpD__7);
			eqdestroy___system_u2691(colontmpD__6);
			eqdestroy___system_u2691(moduleLoadedVar_1);
			eqdestroy___ast_u4574(moduleSym_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin22_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA16_;
LA20_: ;
	{
		genStmt__jsgen_u1163(p_p0, transformedN_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA16_: ;
	{
		NimStringV2 colontmpD__12;
		if (!(((*p_p0).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)17)))&31U)))!=0)) goto LA35_;
		colontmpD__12.len = 0; colontmpD__12.p = NIM_NIL;
		colontmpD__12 = frameDestroy__jsgen_u7289(p_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		prepareAdd((&(*p_p0).body), colontmpD__12.len + 0);
appendString((&(*p_p0).body), colontmpD__12);
		eqdestroy___system_u2691(colontmpD__12);
	}
LA35_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3252(transformedN_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, processJSCodeGen__jsgen_u8222)(tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ* b_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
	tyObject_TJSGen__eMRdF9b1ev54YKlmk5BuCUA* m_1;
	tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ* colontmpD_;
	tyObject_PGlobalscolonObjectType___5ylNBaUZgofS9cIrLp09cbRA* globals_1;
	RootObj* colontmpD__2;
	tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_1;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	m_1 = NIM_NIL;
	globals_1 = NIM_NIL;
	p_1 = NIM_NIL;
	eqcopy___ast_u3255(&result, n_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD_ = eqdup___cgen_u30982(b_p0, NIM_TRUE);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	m_1 = (*((tyObject_TJSGen__eMRdF9b1ev54YKlmk5BuCUA**) (&(colontmpD_))));
	{
		NIM_BOOL T4_;
		T4_ = (NIM_BOOL)0;
		T4_ = skipCodegen__pipelineutils_u8((*m_1).config, n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!T4_) goto LA5_;
		eqcopy___ast_u3255(&result, n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		eqdestroy___jsgen_u139(p_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___jsgen_u506(globals_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___jsgen_u653(m_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		goto BeforeRet_;
	}
LA5_: ;
	{
		if (!((*m_1).module == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL))) goto LA9_;
		internalErrorImpl__msgs_u1598((*m_1).config, (*n_p1).info, TM__BxLwT0mhrtgTPodf1v3xjg_6, (&TM__BxLwT0mhrtgTPodf1v3xjg_7));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA9_: ;
	colontmpD__2 = eqdup___ast_u4951((*(*m_1).graph).backend, NIM_TRUE);
	globals_1 = (*((tyObject_PGlobalscolonObjectType___5ylNBaUZgofS9cIrLp09cbRA**) (&(colontmpD__2))));
	p_1 = newInitProc__jsgen_u681(globals_1, m_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	eqcopy___jsgen_u142(&(*m_1).initProc, p_1, NIM_TRUE);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	(*p_1).unique = (*globals_1).unique;
	genModule__jsgen_u8185(p_1, n_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&(*(*p_1).g).code), (*p_1).locals.len + 0);
appendString((&(*(*p_1).g).code), (*p_1).locals);
	prepareAdd((&(*(*p_1).g).code), (*p_1).body.len + 0);
appendString((&(*(*p_1).g).code), (*p_1).body);
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___jsgen_u139(p_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___jsgen_u506(globals_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___jsgen_u653(m_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, genHeader__jsgen_u8149)(void) {
	NimStringV2 result;
	NimStringV2 colontmpD_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD_ = nsuUnindent(TM__BxLwT0mhrtgTPodf1v3xjg_812, ((NI)IL64(9223372036854775807)), TM__BxLwT0mhrtgTPodf1v3xjg_814);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	result = nsuFormatVarargs(colontmpD_, TM__BxLwT0mhrtgTPodf1v3xjg_815, 1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD_);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, wholeCode__jsgen_u8233)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TJSGen__eMRdF9b1ev54YKlmk5BuCUA* m_p1) {
	NimStringV2 result;
	tyObject_PGlobalscolonObjectType___5ylNBaUZgofS9cIrLp09cbRA* globals_1;
	RootObj* colontmpD_;
NIM_BOOL oldNimErrFin11_;
NIM_BOOL oldNimErrFin26_;
NIM_BOOL oldNimErrFin15_;
	NimStringV2 T31_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	globals_1 = NIM_NIL;
	colontmpD_ = eqdup___ast_u4951((*graph_p0).backend, NIM_TRUE);
	globals_1 = (*((tyObject_PGlobalscolonObjectType___5ylNBaUZgofS9cIrLp09cbRA**) (&(colontmpD_))));
	{
		tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg** prc_1;
		NI i_1;
		NI L_1;
		NI T3_;
		prc_1 = (tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg**)0;
		i_1 = ((NI)0);
		T3_ = (*globals_1).forwarded.len;
		L_1 = T3_;
		{
			while (1) {
				if (!(i_1 < L_1)) goto LA5;
				prc_1 = &(*globals_1).forwarded.p->data[i_1];
				{
					tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA xX60gensym1626__1;
					NIM_BOOL T8_;
					tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_1;
					xX60gensym1626__1 = (*(*prc_1)).itemId;
					T8_ = (NIM_BOOL)0;
					T8_ = containsOrIncl__astyaml_u223((&(*globals_1).generatedSyms), (NI)((NI)((NU64)(((NI) (xX60gensym1626__1.module))) << (NU64)(((NI)24) & (64 - 1))) + ((NI) (xX60gensym1626__1.item))));
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					if (!!(T8_)) goto LA9_;
					p_1 = NIM_NIL;
					p_1 = newInitProc__jsgen_u681(globals_1, m_p1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
					attachProc__jsgen_u4080(p_1, (*prc_1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
					{
						LA11_:;
					}
					{
						oldNimErrFin11_ = *nimErr_; *nimErr_ = NIM_FALSE;
						eqdestroy___jsgen_u139(p_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						*nimErr_ = oldNimErrFin11_;
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				}
LA9_: ;
				i_1 += ((NI)1);
			} LA5: ;
		}
	}
	generateIfMethodDispatchers__cgmeth_u1019(graph_p0, (*m_p1).Sup.idgen);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* prc_2;
		prc_2 = NIM_NIL;
		{
			tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA* i_2;
			NI i_3;
			NI L_2;
			NI T17_;
			i_2 = (tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA*)0;
			i_3 = ((NI)0);
			T17_ = (*graph_p0).dispatchers.len;
			L_2 = T17_;
			{
				while (1) {
					tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* T20_;
					if (!(i_3 < L_2)) goto LA19;
					i_2 = (&(*graph_p0).dispatchers.p->data[i_3]);
					T20_ = NIM_NIL;
					T20_ = resolveSym__modulegraphs_u3497(graph_p0, i_2);
					if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u4574(T20_); goto LA15_;}
					eqsink___ast_u4583(&prc_2, T20_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
					{
						tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA xX60gensym1628__1;
						NIM_BOOL T23_;
						tyObject_TProc__k9cVsoDH6xQeAkEiVEPoauw* p_2;
						xX60gensym1628__1 = (*prc_2).itemId;
						T23_ = (NIM_BOOL)0;
						T23_ = containsOrIncl__astyaml_u223((&(*globals_1).generatedSyms), (NI)((NI)((NU64)(((NI) (xX60gensym1628__1.module))) << (NU64)(((NI)24) & (64 - 1))) + ((NI) (xX60gensym1628__1.item))));
						if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
						if (!!(T23_)) goto LA24_;
						p_2 = NIM_NIL;
						p_2 = newInitProc__jsgen_u681(globals_1, m_p1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
						attachProc__jsgen_u4080(p_2, prc_2);
						if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
						{
							LA26_:;
						}
						{
							oldNimErrFin26_ = *nimErr_; *nimErr_ = NIM_FALSE;
							eqdestroy___jsgen_u139(p_2);
							if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
							*nimErr_ = oldNimErrFin26_;
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
					}
LA24_: ;
					i_3 += ((NI)1);
				} LA19: ;
			}
		}
		{
			LA15_:;
		}
		{
			oldNimErrFin15_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u4574(prc_2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin15_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	T31_.len = 0; T31_.p = NIM_NIL;
	T31_ = rawNewString((*globals_1).typeInfo.len + (*globals_1).constants.len + (*globals_1).code.len + 0);
appendString((&T31_), (*globals_1).typeInfo);
appendString((&T31_), (*globals_1).constants);
appendString((&T31_), (*globals_1).code);
	result = T31_;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___jsgen_u506(globals_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, finalJSCodeGen__jsgen_u8301)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ* b_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p2) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
	tyObject_TJSGen__eMRdF9b1ev54YKlmk5BuCUA* m_1;
	tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ* colontmpD_;
NIM_BOOL oldNimErrFin29_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	m_1 = NIM_NIL;
	colontmpD_ = eqdup___cgen_u30982(b_p1, NIM_TRUE);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	m_1 = (*((tyObject_TJSGen__eMRdF9b1ev54YKlmk5BuCUA**) (&(colontmpD_))));
	{
		if (!(((*(*m_1).module).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)14)))&63U)))!=0)) goto LA4_;
		{
			NI i_1;
			NI colontmp_;
			NI T7_;
			NI res_1;
			i_1 = (NI)0;
			colontmp_ = (NI)0;
			T7_ = ((*graph_p0).globalDestructors.len-1);
			colontmp_ = T7_;
			res_1 = colontmp_;
			{
				while (1) {
					if (!(((NI)0) <= res_1)) goto LA9;
					i_1 = ((NI) (res_1));
					add__ast_u3215(n_p2, (*graph_p0).globalDestructors.p->data[i_1]);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					res_1 -= ((NI)1);
				} LA9: ;
			}
		}
	}
LA4_: ;
	result = processJSCodeGen__jsgen_u8222(b_p1, n_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		if (!(((*(*m_1).module).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)15)))&63U)))!=0)) goto LA12_;
		(*(*((tyObject_PGlobalscolonObjectType___5ylNBaUZgofS9cIrLp09cbRA**) (&((*graph_p0).backend))))).inSystem = NIM_FALSE;
	}
LA12_: ;
	{
		NIM_BOOL T16_;
		T16_ = (NIM_BOOL)0;
		T16_ = skipCodegen__pipelineutils_u8((*m_1).config, n_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!T16_) goto LA17_;
		eqcopy___ast_u3255(&result, n_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		eqdestroy___jsgen_u653(m_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		goto BeforeRet_;
	}
LA17_: ;
	{
		NimStringV2 code_1;
		NimStringV2 colontmpD__2;
		NimStringV2 colontmpD__3;
		NimStringV2 outFile_1;
		NimStringV2 T24_;
		if (!(((*(*m_1).module).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)14)))&63U)))!=0)) goto LA21_;
		code_1.len = 0; code_1.p = NIM_NIL;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
		outFile_1.len = 0; outFile_1.p = NIM_NIL;
		T24_.len = 0; T24_.p = NIM_NIL;
		colontmpD__2 = genHeader__jsgen_u8149();
		if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
		colontmpD__3 = wholeCode__jsgen_u8233(graph_p0, m_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
		T24_ = rawNewString(colontmpD__2.len + colontmpD__3.len + 0);
appendString((&T24_), colontmpD__2);
appendString((&T24_), colontmpD__3);
		code_1 = T24_;
		outFile_1 = prepareToWriteOutput__options_u3642((*m_1).config);
		if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
		{
			tyObject_SourceMap__WQjtp9aU0iILpTcFCDzWLTA map_1;
			NimStringV2 colontmpD__4;
			NimStringV2 colontmpD__5;
			tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* colontmpD__6;
			NimStringV2 colontmpD__7;
			tyArray__YgExxhfgKcesA5EOUj1MOA T30_;
			NimStringV2 T31_;
			if (!(((*(*m_1).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)52)))&63U)))!=0)) goto LA27_;
			nimZeroMem((void*)(&map_1), sizeof(tyObject_SourceMap__WQjtp9aU0iILpTcFCDzWLTA));
			colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
			colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
			colontmpD__6 = NIM_NIL;
			colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
			genSourceMap__sourcemap_u801(code_1, outFile_1, (&map_1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
			T30_[0] = outFile_1;
			colontmpD__4 = percent___jsgen_u8335(T30_, 1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
			prepareAdd((&code_1), colontmpD__4.len + 0);
appendString((&code_1), colontmpD__4);
			T31_.len = 0; T31_.p = NIM_NIL;
			T31_ = rawNewString(outFile_1.len + 4);
appendString((&T31_), outFile_1);
appendString((&T31_), TM__BxLwT0mhrtgTPodf1v3xjg_818);
			colontmpD__5 = T31_;
			colontmpD__6 = percent___jsgen_u8340((&map_1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
			colontmpD__7 = dollar___pureZjson_u4831(colontmpD__6);
			if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
			writeFile__stdZsyncio_u532(colontmpD__5, colontmpD__7);
			if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
			{
				LA29_:;
			}
			{
				oldNimErrFin29_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___system_u2691(colontmpD__7);
				eqdestroy___pureZjson_u324(colontmpD__6);
				if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
				eqdestroy___system_u2691(colontmpD__5);
				eqdestroy___system_u2691(colontmpD__4);
				eqdestroy___sourcemap_u720((&map_1));
				*nimErr_ = oldNimErrFin29_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
		}
LA27_: ;
		{
			NIM_BOOL T36_;
			T36_ = (NIM_BOOL)0;
			T36_ = equalsFile__ropes_u230(code_1, outFile_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
			if (!!(T36_)) goto LA37_;
			{
				NIM_BOOL T41_;
				T41_ = (NIM_BOOL)0;
				T41_ = writeRope__ropes_u27(code_1, outFile_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
				if (!!(T41_)) goto LA42_;
				liMessage__msgs_u1227((*m_1).config, unknownLineInfo__lineinfos_u364, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)4), outFile_1, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)1), (&TM__BxLwT0mhrtgTPodf1v3xjg_819), NIM_FALSE, NIM_FALSE);
				if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
			}
LA42_: ;
		}
LA37_: ;
		{
			LA23_:;
		}
		{
			eqdestroy___system_u2691(outFile_1);
			eqdestroy___system_u2691(colontmpD__3);
			eqdestroy___system_u2691(colontmpD__2);
			eqdestroy___system_u2691(code_1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA21_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___jsgen_u653(m_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
