/* Generated by Nim Compiler v2.2.10 */
#define NIM_INTBITS 64

#include "nimbase.h"
#include <string.h>
#include <glob.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix
typedef struct tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw;
typedef struct tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg;
typedef struct tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ;
typedef struct tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg;
typedef struct tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA;
typedef struct NimStrPayload NimStrPayload;
typedef struct NimStringV2 NimStringV2;
typedef struct tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA;
typedef struct tySequence__9ahcSjIErJohSBBFLwuF56Q tySequence__9ahcSjIErJohSBBFLwuF56Q;
typedef struct tySequence__9ahcSjIErJohSBBFLwuF56Q_Content tySequence__9ahcSjIErJohSBBFLwuF56Q_Content;
typedef struct tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ;
typedef struct RootObj RootObj;
typedef struct TNimTypeV2 TNimTypeV2;
typedef struct tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug;
typedef struct tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww;
typedef struct tySequence__AE2UIxl7EbPzzBnmYsjIcw tySequence__AE2UIxl7EbPzzBnmYsjIcw;
typedef struct tySequence__AE2UIxl7EbPzzBnmYsjIcw_Content tySequence__AE2UIxl7EbPzzBnmYsjIcw_Content;
typedef struct tyObject_TProcCon__ftBtv4UEhPouLts4uXXNLQ tyObject_TProcCon__ftBtv4UEhPouLts4uXXNLQ;
typedef struct tyObject_TMatchedConcept__tvh59a8SIGC9ccJV9atmyb8kg tyObject_TMatchedConcept__tvh59a8SIGC9ccJV9atmyb8kg;
typedef struct tySequence__ZCZaCk14bTmSb6LMW9aWPVA tySequence__ZCZaCk14bTmSb6LMW9aWPVA;
typedef struct tySequence__ZCZaCk14bTmSb6LMW9aWPVA_Content tySequence__ZCZaCk14bTmSb6LMW9aWPVA_Content;
typedef struct tySequence__tsHRsYLyvTCPLlGRExqi7Q tySequence__tsHRsYLyvTCPLlGRExqi7Q;
typedef struct tySequence__tsHRsYLyvTCPLlGRExqi7Q_Content tySequence__tsHRsYLyvTCPLlGRExqi7Q_Content;
typedef struct tySequence__lAikaRQvUF0uwNAz0U4FFA tySequence__lAikaRQvUF0uwNAz0U4FFA;
typedef struct tySequence__lAikaRQvUF0uwNAz0U4FFA_Content tySequence__lAikaRQvUF0uwNAz0U4FFA_Content;
typedef struct tyObject_LayeredIdTableObj__PbmRWgwPdgBZOtiSK65Q7A tyObject_LayeredIdTableObj__PbmRWgwPdgBZOtiSK65Q7A;
typedef struct tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA;
typedef struct tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA;
typedef struct tySequence__ZeWVlH6DqG79b1pTDhrrUYA tySequence__ZeWVlH6DqG79b1pTDhrrUYA;
typedef struct tySequence__ZeWVlH6DqG79b1pTDhrrUYA_Content tySequence__ZeWVlH6DqG79b1pTDhrrUYA_Content;
typedef struct tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg;
typedef struct tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew;
typedef struct tySequence__4zAALtm0xUbRlYWQ2V8K7A tySequence__4zAALtm0xUbRlYWQ2V8K7A;
typedef struct tySequence__4zAALtm0xUbRlYWQ2V8K7A_Content tySequence__4zAALtm0xUbRlYWQ2V8K7A_Content;
typedef struct tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA;
typedef struct tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw;
typedef struct tySequence__9bffTLF0HkxjFCzZL8og4GA tySequence__9bffTLF0HkxjFCzZL8og4GA;
typedef struct tySequence__9bffTLF0HkxjFCzZL8og4GA_Content tySequence__9bffTLF0HkxjFCzZL8og4GA_Content;
typedef struct tyObject_HashSet__cx4zJRA9aTCfmpbY2J9bKwnQ tyObject_HashSet__cx4zJRA9aTCfmpbY2J9bKwnQ;
typedef struct tySequence__Bis5AbpONWcIRrPyPJS8Yw tySequence__Bis5AbpONWcIRrPyPJS8Yw;
typedef struct tySequence__Bis5AbpONWcIRrPyPJS8Yw_Content tySequence__Bis5AbpONWcIRrPyPJS8Yw_Content;
typedef struct tyObject_Table__nBRoNCTSfpfbfAeK9bNW1qw tyObject_Table__nBRoNCTSfpfbfAeK9bNW1qw;
typedef struct tySequence__E8pi9b5QNahsURYzXMjh3qw tySequence__E8pi9b5QNahsURYzXMjh3qw;
typedef struct tySequence__E8pi9b5QNahsURYzXMjh3qw_Content tySequence__E8pi9b5QNahsURYzXMjh3qw_Content;
typedef struct tyObject_Table__g77QNejuRRKraNk8K2YkoA tyObject_Table__g77QNejuRRKraNk8K2YkoA;
typedef struct tySequence__3B6hFqG0Do0FxDvnNucL7w tySequence__3B6hFqG0Do0FxDvnNucL7w;
typedef struct tySequence__3B6hFqG0Do0FxDvnNucL7w_Content tySequence__3B6hFqG0Do0FxDvnNucL7w_Content;
typedef struct tyObject_Table__toCaB3NxiVHPRVLgcez0Xg tyObject_Table__toCaB3NxiVHPRVLgcez0Xg;
typedef struct tySequence__QqvaCqCpEE1QmQZbcZLi5A tySequence__QqvaCqCpEE1QmQZbcZLi5A;
typedef struct tySequence__QqvaCqCpEE1QmQZbcZLi5A_Content tySequence__QqvaCqCpEE1QmQZbcZLi5A_Content;
typedef struct tySequence__TfHJycarvNts8E4mVG4Mfg tySequence__TfHJycarvNts8E4mVG4Mfg;
typedef struct tySequence__TfHJycarvNts8E4mVG4Mfg_Content tySequence__TfHJycarvNts8E4mVG4Mfg_Content;
typedef struct tyObject_PackedModuleGraph__vzv9a6xTiz616FotDgUeo9bg tyObject_PackedModuleGraph__vzv9a6xTiz616FotDgUeo9bg;
typedef struct tySequence__5reviU45axUMPQgL9aoENrg tySequence__5reviU45axUMPQgL9aoENrg;
typedef struct tySequence__5reviU45axUMPQgL9aoENrg_Content tySequence__5reviU45axUMPQgL9aoENrg_Content;
typedef struct tySequence__dtr79aXjHrgHuH79ac55I2aw tySequence__dtr79aXjHrgHuH79ac55I2aw;
typedef struct tySequence__dtr79aXjHrgHuH79ac55I2aw_Content tySequence__dtr79aXjHrgHuH79ac55I2aw_Content;
typedef struct tyObject_Table__EBJpp1hXwvFl9cyekUv4qHg tyObject_Table__EBJpp1hXwvFl9cyekUv4qHg;
typedef struct tySequence__8y0Gi4GwtXi2wk2mK1IOzw tySequence__8y0Gi4GwtXi2wk2mK1IOzw;
typedef struct tySequence__8y0Gi4GwtXi2wk2mK1IOzw_Content tySequence__8y0Gi4GwtXi2wk2mK1IOzw_Content;
typedef struct tyObject_Table__nn0jq9adRZXGGj9assM9c9bR0w tyObject_Table__nn0jq9adRZXGGj9assM9c9bR0w;
typedef struct tySequence__C2ivDnhTZ6IxAdui1rfuqw tySequence__C2ivDnhTZ6IxAdui1rfuqw;
typedef struct tySequence__C2ivDnhTZ6IxAdui1rfuqw_Content tySequence__C2ivDnhTZ6IxAdui1rfuqw_Content;
typedef struct tyObject_Table__ChMwcRY3QzpOEBWbGAfvcA tyObject_Table__ChMwcRY3QzpOEBWbGAfvcA;
typedef struct tySequence__3vEEVfBECLN6NIRA3FIp5g tySequence__3vEEVfBECLN6NIRA3FIp5g;
typedef struct tySequence__3vEEVfBECLN6NIRA3FIp5g_Content tySequence__3vEEVfBECLN6NIRA3FIp5g_Content;
typedef struct tyObject_Table__tEqt8LkShErhjQ9acvGyE7g tyObject_Table__tEqt8LkShErhjQ9acvGyE7g;
typedef struct tySequence__9aSa87aKMiolq9a7z3kC0jTw tySequence__9aSa87aKMiolq9a7z3kC0jTw;
typedef struct tySequence__9aSa87aKMiolq9a7z3kC0jTw_Content tySequence__9aSa87aKMiolq9a7z3kC0jTw_Content;
typedef struct tyObject_Table__QS2Z9cQjmvkp1aaFGq4ippw tyObject_Table__QS2Z9cQjmvkp1aaFGq4ippw;
typedef struct tySequence__N589c2UsUgqqOITU2JfIuAQ tySequence__N589c2UsUgqqOITU2JfIuAQ;
typedef struct tySequence__N589c2UsUgqqOITU2JfIuAQ_Content tySequence__N589c2UsUgqqOITU2JfIuAQ_Content;
typedef struct tyObject_Table__bnfVX2VJ9aUicVujDM0GIhw tyObject_Table__bnfVX2VJ9aUicVujDM0GIhw;
typedef struct tySequence__GYDW6wGgERshoSd16jJ3eQ tySequence__GYDW6wGgERshoSd16jJ3eQ;
typedef struct tySequence__GYDW6wGgERshoSd16jJ3eQ_Content tySequence__GYDW6wGgERshoSd16jJ3eQ_Content;
typedef struct tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw tySequence__7lEisrXlQEzwtUKW5pzRCw;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw_Content tySequence__7lEisrXlQEzwtUKW5pzRCw_Content;
typedef struct tyObject_PackedConfig__Hpn673wkKPDorr1HY9bOaDQ tyObject_PackedConfig__Hpn673wkKPDorr1HY9bOaDQ;
typedef struct tyObject_Table__79b4rr6WWQqgRr9b4NH4UF9cw tyObject_Table__79b4rr6WWQqgRr9b4NH4UF9cw;
typedef struct tySequence__fdmz6VkIf1ewwrssKYqRFg tySequence__fdmz6VkIf1ewwrssKYqRFg;
typedef struct tySequence__fdmz6VkIf1ewwrssKYqRFg_Content tySequence__fdmz6VkIf1ewwrssKYqRFg_Content;
typedef struct tyObject_Table__AC9bec2JdoOuC3xQePGWgmA tyObject_Table__AC9bec2JdoOuC3xQePGWgmA;
typedef struct tySequence__kxu4GK0onha2t9bo86mdVAg tySequence__kxu4GK0onha2t9bo86mdVAg;
typedef struct tySequence__kxu4GK0onha2t9bo86mdVAg_Content tySequence__kxu4GK0onha2t9bo86mdVAg_Content;
typedef struct tySequence__48JTohSgTy339bRxHzUD8KA tySequence__48JTohSgTy339bRxHzUD8KA;
typedef struct tySequence__48JTohSgTy339bRxHzUD8KA_Content tySequence__48JTohSgTy339bRxHzUD8KA_Content;
typedef struct tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg;
typedef struct tyObject_Table__bHTcQUCehDW9clHfFZXI7lQ tyObject_Table__bHTcQUCehDW9clHfFZXI7lQ;
typedef struct tySequence__fz0REU1l0nYmKHXgMLRrIg tySequence__fz0REU1l0nYmKHXgMLRrIg;
typedef struct tySequence__fz0REU1l0nYmKHXgMLRrIg_Content tySequence__fz0REU1l0nYmKHXgMLRrIg_Content;
typedef struct tyObject_Table__w2vCG1OPnHmNolvQVT168g tyObject_Table__w2vCG1OPnHmNolvQVT168g;
typedef struct tySequence__Ip9aV1IKO2gVdheNOM31DCQ tySequence__Ip9aV1IKO2gVdheNOM31DCQ;
typedef struct tySequence__Ip9aV1IKO2gVdheNOM31DCQ_Content tySequence__Ip9aV1IKO2gVdheNOM31DCQ_Content;
typedef struct tySequence__kHjIdgrpmuSn9cUIIKpSiDg tySequence__kHjIdgrpmuSn9cUIIKpSiDg;
typedef struct tySequence__kHjIdgrpmuSn9cUIIKpSiDg_Content tySequence__kHjIdgrpmuSn9cUIIKpSiDg_Content;
typedef struct tyObject_CountTable__qvMelb9coODdwoghoAPc9c9aA tyObject_CountTable__qvMelb9coODdwoghoAPc9c9aA;
typedef struct tySequence__Wd0Vle6gxRCPPoSlNEvfTA tySequence__Wd0Vle6gxRCPPoSlNEvfTA;
typedef struct tySequence__Wd0Vle6gxRCPPoSlNEvfTA_Content tySequence__Wd0Vle6gxRCPPoSlNEvfTA_Content;
typedef struct tyObject_Table__fZyCWkMwhdvr3pauCNDaag tyObject_Table__fZyCWkMwhdvr3pauCNDaag;
typedef struct tySequence__T7nNEWoEbKBa0G5Htr45Xw tySequence__T7nNEWoEbKBa0G5Htr45Xw;
typedef struct tySequence__T7nNEWoEbKBa0G5Htr45Xw_Content tySequence__T7nNEWoEbKBa0G5Htr45Xw_Content;
typedef struct tyObject_Table__5vmBY49areSIlgIs4A1LLKQ tyObject_Table__5vmBY49areSIlgIs4A1LLKQ;
typedef struct tySequence__q9cHvMDDxYU1hSCdG4YwIhA tySequence__q9cHvMDDxYU1hSCdG4YwIhA;
typedef struct tySequence__q9cHvMDDxYU1hSCdG4YwIhA_Content tySequence__q9cHvMDDxYU1hSCdG4YwIhA_Content;
typedef struct tySequence__olFOFaYzOJN9aV5BWqK4b9bA tySequence__olFOFaYzOJN9aV5BWqK4b9bA;
typedef struct tySequence__olFOFaYzOJN9aV5BWqK4b9bA_Content tySequence__olFOFaYzOJN9aV5BWqK4b9bA_Content;
typedef struct tyObject_Table__9bmd0cvHWe1s4FTDn5BPmfw tyObject_Table__9bmd0cvHWe1s4FTDn5BPmfw;
typedef struct tySequence__vJcM7B74R2U5db9cxyXT9coA tySequence__vJcM7B74R2U5db9cxyXT9coA;
typedef struct tySequence__vJcM7B74R2U5db9cxyXT9coA_Content tySequence__vJcM7B74R2U5db9cxyXT9coA_Content;
typedef struct tyObject_Table__GhjCMuklnRqwdX9bZo9bCoNg tyObject_Table__GhjCMuklnRqwdX9bZo9bCoNg;
typedef struct tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg;
typedef struct tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg_Content tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg_Content;
typedef struct tyObject_Table__pI3mJh4Ap2XujSCfcSeUvQ tyObject_Table__pI3mJh4Ap2XujSCfcSeUvQ;
typedef struct tySequence__R9c39btP6BwOBBPnbaNUtMQg tySequence__R9c39btP6BwOBBPnbaNUtMQg;
typedef struct tySequence__R9c39btP6BwOBBPnbaNUtMQg_Content tySequence__R9c39btP6BwOBBPnbaNUtMQg_Content;
typedef struct tyObject_Table__MsPmCuYz1KcEw6lr7P9cGkw tyObject_Table__MsPmCuYz1KcEw6lr7P9cGkw;
typedef struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA tySequence__squ9b9bUH4OLHf6cEMrt6hVA;
typedef struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA_Content tySequence__squ9b9bUH4OLHf6cEMrt6hVA_Content;
typedef struct tyObject_Table__1HJsK7ponJ4Vb1lJgVFVTQ tyObject_Table__1HJsK7ponJ4Vb1lJgVFVTQ;
typedef struct tySequence__3nALyQgqjnfK2Qjc6ny2Uw tySequence__3nALyQgqjnfK2Qjc6ny2Uw;
typedef struct tySequence__3nALyQgqjnfK2Qjc6ny2Uw_Content tySequence__3nALyQgqjnfK2Qjc6ny2Uw_Content;
typedef struct tySequence__WbW5Q8QVks0bQpUJSGmuVg tySequence__WbW5Q8QVks0bQpUJSGmuVg;
typedef struct tySequence__WbW5Q8QVks0bQpUJSGmuVg_Content tySequence__WbW5Q8QVks0bQpUJSGmuVg_Content;
typedef struct tyObject_Operators__yrAfvKhiysDamJlcGNgVfQ tyObject_Operators__yrAfvKhiysDamJlcGNgVfQ;
typedef struct tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg;
typedef struct tyObject_Target__GzbDkV2u8Pgzlf9azvC43FA tyObject_Target__GzbDkV2u8Pgzlf9azvC43FA;
typedef struct tyObject_MsgConfig__E1VAUnnaNIOngCdEgTI2Dw tyObject_MsgConfig__E1VAUnnaNIOngCdEgTI2Dw;
typedef struct tySequence__E0kio2ZnplNTuln9bsnljSA tySequence__E0kio2ZnplNTuln9bsnljSA;
typedef struct tySequence__E0kio2ZnplNTuln9bsnljSA_Content tySequence__E0kio2ZnplNTuln9bsnljSA_Content;
typedef struct tySequence__hTEiKNj3evQAjIXUI21elA tySequence__hTEiKNj3evQAjIXUI21elA;
typedef struct tySequence__hTEiKNj3evQAjIXUI21elA_Content tySequence__hTEiKNj3evQAjIXUI21elA_Content;
typedef struct tyObject_HashSet__8IGL0eIK5PYDsNGVA78Wmw tyObject_HashSet__8IGL0eIK5PYDsNGVA78Wmw;
typedef struct tySequence__4eRCaZmrYLLw2k30GPTiMw tySequence__4eRCaZmrYLLw2k30GPTiMw;
typedef struct tySequence__4eRCaZmrYLLw2k30GPTiMw_Content tySequence__4eRCaZmrYLLw2k30GPTiMw_Content;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ tySequence__sM4lkSb7zS6F7OVMvW9cffQ;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content;
typedef struct tySequence__xOJ2kx2lq9bBfIm3IXnde3Q tySequence__xOJ2kx2lq9bBfIm3IXnde3Q;
typedef struct tySequence__xOJ2kx2lq9bBfIm3IXnde3Q_Content tySequence__xOJ2kx2lq9bBfIm3IXnde3Q_Content;
typedef struct tyObject_SuggestcolonObjectType___UyASNXAqAMRY5zJmcRD9ccA tyObject_SuggestcolonObjectType___UyASNXAqAMRY5zJmcRD9ccA;
typedef struct tyObject_ProfileDatacolonObjectType___R9cEb9cNTzPRldVmD9bCDO0xQ tyObject_ProfileDatacolonObjectType___R9cEb9cNTzPRldVmD9bCDO0xQ;
typedef struct tyTuple__kN8up2W6YKc5YA9avn5mV5w tyTuple__kN8up2W6YKc5YA9avn5mV5w;
typedef struct tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA;
typedef struct tySequence__d8ZV4IMgHt9biik9cS9a0hrmg tySequence__d8ZV4IMgHt9biik9cS9a0hrmg;
typedef struct tySequence__d8ZV4IMgHt9biik9cS9a0hrmg_Content tySequence__d8ZV4IMgHt9biik9cS9a0hrmg_Content;
typedef struct tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw;
typedef struct tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig;
typedef struct tyObject_HSlice__OAVyDXS0QPw7LdXClfU2hA tyObject_HSlice__OAVyDXS0QPw7LdXClfU2hA;
typedef struct Exception Exception;
typedef struct tySequence__S89cE01OvNjsN9c71FKsSrqQ tySequence__S89cE01OvNjsN9c71FKsSrqQ;
typedef struct tySequence__S89cE01OvNjsN9c71FKsSrqQ_Content tySequence__S89cE01OvNjsN9c71FKsSrqQ_Content;
typedef struct tyObject_Env_pragmasdotnim_processEffectsOf___441zjIQZOyCLH68Plk1FJQ tyObject_Env_pragmasdotnim_processEffectsOf___441zjIQZOyCLH68Plk1FJQ;
typedef struct tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A;
typedef struct tyObject_TOptionEntry__KeABxBvAlGa1KroFfkcqAg tyObject_TOptionEntry__KeABxBvAlGa1KroFfkcqAg;
typedef struct tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ;
typedef struct tyObject_PackedModule__sRHd9aQ2ZMII76xRsfAbE9aQ tyObject_PackedModule__sRHd9aQ2ZMII76xRsfAbE9aQ;
typedef struct tyObject_Table__uaQEKxLZNO5fpFluyxnhTg tyObject_Table__uaQEKxLZNO5fpFluyxnhTg;
typedef struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ tySequence__9cnx3zXnWzeclW8Ko4oUgAQ;
typedef struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ_Content tySequence__9cnx3zXnWzeclW8Ko4oUgAQ_Content;
typedef struct tyObject_LoadedModule__7NEKRkz5hkiOxQy5guqIHA tyObject_LoadedModule__7NEKRkz5hkiOxQy5guqIHA;
typedef struct tySequence__PXIzfWocnrafGz5p3CP5LA tySequence__PXIzfWocnrafGz5p3CP5LA;
typedef struct tySequence__PXIzfWocnrafGz5p3CP5LA_Content tySequence__PXIzfWocnrafGz5p3CP5LA_Content;
typedef struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA tySequence__9bAGqSvkAaFL9bWjsEPslrFA;
typedef struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA_Content tySequence__9bAGqSvkAaFL9bWjsEPslrFA_Content;
typedef struct tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w;
typedef struct tySequence__OxRbUT0qZaZN5UjnqQjGPA tySequence__OxRbUT0qZaZN5UjnqQjGPA;
typedef struct tySequence__OxRbUT0qZaZN5UjnqQjGPA_Content tySequence__OxRbUT0qZaZN5UjnqQjGPA_Content;
typedef struct tySequence__ezS5mGPcRfBURJyMgqYVzA tySequence__ezS5mGPcRfBURJyMgqYVzA;
typedef struct tySequence__ezS5mGPcRfBURJyMgqYVzA_Content tySequence__ezS5mGPcRfBURJyMgqYVzA_Content;
typedef struct tySequence__wW7xkohjuUKO9aMaB0nt9cqA tySequence__wW7xkohjuUKO9aMaB0nt9cqA;
typedef struct tySequence__wW7xkohjuUKO9aMaB0nt9cqA_Content tySequence__wW7xkohjuUKO9aMaB0nt9cqA_Content;
typedef struct tySequence__b89aLriiJnVTD186H6zNIgg tySequence__b89aLriiJnVTD186H6zNIgg;
typedef struct tySequence__b89aLriiJnVTD186H6zNIgg_Content tySequence__b89aLriiJnVTD186H6zNIgg_Content;
typedef struct tySequence__hIPTk9aFdaMMVAOzEbnPyqg tySequence__hIPTk9aFdaMMVAOzEbnPyqg;
typedef struct tySequence__hIPTk9aFdaMMVAOzEbnPyqg_Content tySequence__hIPTk9aFdaMMVAOzEbnPyqg_Content;
typedef struct tySequence__YYy1721YAuPF0ajBYHd8Wg tySequence__YYy1721YAuPF0ajBYHd8Wg;
typedef struct tySequence__YYy1721YAuPF0ajBYHd8Wg_Content tySequence__YYy1721YAuPF0ajBYHd8Wg_Content;
typedef struct tySequence__UODJbvzmu39c3Ho9cqhSk9agQ tySequence__UODJbvzmu39c3Ho9cqhSk9agQ;
typedef struct tySequence__UODJbvzmu39c3Ho9cqhSk9agQ_Content tySequence__UODJbvzmu39c3Ho9cqhSk9agQ_Content;
typedef struct tySequence__F1qNdU7m0Czu7Y2q0eksXw tySequence__F1qNdU7m0Czu7Y2q0eksXw;
typedef struct tySequence__F1qNdU7m0Czu7Y2q0eksXw_Content tySequence__F1qNdU7m0Czu7Y2q0eksXw_Content;
typedef struct tySequence__r3Kz9breImOXyFFoJ29aBM8Q tySequence__r3Kz9breImOXyFFoJ29aBM8Q;
typedef struct tySequence__r3Kz9breImOXyFFoJ29aBM8Q_Content tySequence__r3Kz9breImOXyFFoJ29aBM8Q_Content;
typedef struct tySequence__qBes3XzcQQ9cyia9bRwnmbJw tySequence__qBes3XzcQQ9cyia9bRwnmbJw;
typedef struct tySequence__qBes3XzcQQ9cyia9bRwnmbJw_Content tySequence__qBes3XzcQQ9cyia9bRwnmbJw_Content;
typedef struct tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw;
typedef struct tySequence__Vl1abU3gfp0RqCb1KKfmDA tySequence__Vl1abU3gfp0RqCb1KKfmDA;
typedef struct tySequence__Vl1abU3gfp0RqCb1KKfmDA_Content tySequence__Vl1abU3gfp0RqCb1KKfmDA_Content;
typedef struct tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw;
typedef struct tySequence__qyyNkmlc4fzOzelC8spUkQ tySequence__qyyNkmlc4fzOzelC8spUkQ;
typedef struct tySequence__qyyNkmlc4fzOzelC8spUkQ_Content tySequence__qyyNkmlc4fzOzelC8spUkQ_Content;
typedef struct tyObject_BiTable__KR9c7QZguPO3OKZOIcphgcA tyObject_BiTable__KR9c7QZguPO3OKZOIcphgcA;
typedef struct tyObject_BiTable__9aUXwPoJbNPqj9a249c0iSmlg tyObject_BiTable__9aUXwPoJbNPqj9a249c0iSmlg;
typedef struct tySequence__IHUFRsFxZNv7YydiUO2esQ tySequence__IHUFRsFxZNv7YydiUO2esQ;
typedef struct tySequence__IHUFRsFxZNv7YydiUO2esQ_Content tySequence__IHUFRsFxZNv7YydiUO2esQ_Content;
typedef struct tyObject_LineInfoManager__TTy646Kfh1cVyXU9aSMasUQ tyObject_LineInfoManager__TTy646Kfh1cVyXU9aSMasUQ;
typedef struct tySequence__orxtl6CusdjXleqrxi67gw tySequence__orxtl6CusdjXleqrxi67gw;
typedef struct tySequence__orxtl6CusdjXleqrxi67gw_Content tySequence__orxtl6CusdjXleqrxi67gw_Content;
typedef struct tyObject_OrderedTable__h8mIUVGY8LJXF9cakgvB9bqQ tyObject_OrderedTable__h8mIUVGY8LJXF9cakgvB9bqQ;
typedef struct tySequence__K0j67V58u5FW0dCC534FQw tySequence__K0j67V58u5FW0dCC534FQw;
typedef struct tySequence__K0j67V58u5FW0dCC534FQw_Content tySequence__K0j67V58u5FW0dCC534FQw_Content;
typedef struct tyObject_OrderedTable__DED9c7j9bI3Lh5w4GQakK8yQ tyObject_OrderedTable__DED9c7j9bI3Lh5w4GQakK8yQ;
typedef struct tySequence__UE4b6iUkm1b3zTPamTTkDw tySequence__UE4b6iUkm1b3zTPamTTkDw;
typedef struct tySequence__UE4b6iUkm1b3zTPamTTkDw_Content tySequence__UE4b6iUkm1b3zTPamTTkDw_Content;
typedef struct tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg;
typedef struct tySequence__FmsTQiIcS9arxHxs3QY48vA tySequence__FmsTQiIcS9arxHxs3QY48vA;
typedef struct tySequence__FmsTQiIcS9arxHxs3QY48vA_Content tySequence__FmsTQiIcS9arxHxs3QY48vA_Content;
typedef struct tyObject_Env_pragmasdotnim_processCompile___dWXVdC0mxyRcA9cJsc1PdqQ tyObject_Env_pragmasdotnim_processCompile___dWXVdC0mxyRcA9cJsc1PdqQ;
typedef struct tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg;
typedef struct tyTuple__7q7q3E6Oj24ZNVJb9aonhAg tyTuple__7q7q3E6Oj24ZNVJb9aonhAg;
typedef struct tyTuple__Sb9czl1rSUt9cR4FEpnHeteg tyTuple__Sb9czl1rSUt9cR4FEpnHeteg;
typedef struct tyObject_HSlice__JgojxK65oMA6E0HRsL2Wig tyObject_HSlice__JgojxK65oMA6E0HRsL2Wig;
typedef struct tyObject_TIdTable__xRBvhNSbEADzUTJAdtlGtA tyObject_TIdTable__xRBvhNSbEADzUTJAdtlGtA;
typedef struct tySequence__ZUeR9b415wicThQ9cBWO9aYMw tySequence__ZUeR9b415wicThQ9cBWO9aYMw;
typedef struct tySequence__ZUeR9b415wicThQ9cBWO9aYMw_Content tySequence__ZUeR9b415wicThQ9cBWO9aYMw_Content;
typedef struct tySequence__yo9alHJGzX03OXpfmEsBjBQ tySequence__yo9alHJGzX03OXpfmEsBjBQ;
typedef struct tySequence__yo9alHJGzX03OXpfmEsBjBQ_Content tySequence__yo9alHJGzX03OXpfmEsBjBQ_Content;
typedef struct tyObject_ImportedModule__NhRLdOPUbh9bmcDLjImMKWw tyObject_ImportedModule__NhRLdOPUbh9bmcDLjImMKWw;
typedef struct tyObject_TIdTable__XZ9cFaLoittQMULJSfBpHrA tyObject_TIdTable__XZ9cFaLoittQMULJSfBpHrA;
typedef struct tySequence__7OXYQ6bHRkhJpRaiS7kiwQ tySequence__7OXYQ6bHRkhJpRaiS7kiwQ;
typedef struct tySequence__7OXYQ6bHRkhJpRaiS7kiwQ_Content tySequence__7OXYQ6bHRkhJpRaiS7kiwQ_Content;
typedef struct tyObject_TInstantiationPair__bS87nlCVAcAYxO9aJequmYw tyObject_TInstantiationPair__bS87nlCVAcAYxO9aJequmYw;
typedef struct tyObject_TInstantiation__jr8MibvPn2sQBnO7XCoZRQ tyObject_TInstantiation__jr8MibvPn2sQBnO7XCoZRQ;
typedef struct tyTuple__09aD69az7aYn14Gt61AHvLIA tyTuple__09aD69az7aYn14Gt61AHvLIA;
typedef struct tyTuple__NAaJgGVgNmlGoqmiWxdOHQ tyTuple__NAaJgGVgNmlGoqmiWxdOHQ;
typedef struct tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ;
typedef struct tyTuple__47w2DboNEPf69aPgubZdd7Q tyTuple__47w2DboNEPf69aPgubZdd7Q;
typedef struct tyTuple__CH9a39cWKma9c9c9cYqCyX1wBsw tyTuple__CH9a39cWKma9c9c9cYqCyX1wBsw;
typedef struct tySequence__KYLoGmc5aaHsSDjEH1FTxQ tySequence__KYLoGmc5aaHsSDjEH1FTxQ;
typedef struct tySequence__KYLoGmc5aaHsSDjEH1FTxQ_Content tySequence__KYLoGmc5aaHsSDjEH1FTxQ_Content;
typedef struct tyTuple__EbsafWGli8bW2GRJQ9apsjA tyTuple__EbsafWGli8bW2GRJQ9apsjA;
typedef struct tySequence__qwqHTkRvwhrRyENtudHQ7g tySequence__qwqHTkRvwhrRyENtudHQ7g;
typedef struct tySequence__qwqHTkRvwhrRyENtudHQ7g_Content tySequence__qwqHTkRvwhrRyENtudHQ7g_Content;
typedef struct tyObject_Iface__j1FkQxwEAKMJy1o9bap1xow tyObject_Iface__j1FkQxwEAKMJy1o9bap1xow;
typedef struct tyTuple__7TXOq9czx9cn1FWKG5gXNK8Q tyTuple__7TXOq9czx9cn1FWKG5gXNK8Q;
typedef struct tySequence__vb3AGHvMJTxdOSSwMmBmTQ tySequence__vb3AGHvMJTxdOSSwMmBmTQ;
typedef struct tySequence__vb3AGHvMJTxdOSSwMmBmTQ_Content tySequence__vb3AGHvMJTxdOSSwMmBmTQ_Content;
typedef struct tyTuple__F1mMODXmKFMNQ5rLCtcv0Q tyTuple__F1mMODXmKFMNQ5rLCtcv0Q;
typedef struct tySequence__apM9bRAO19cVjhWlxqd1PGeA tySequence__apM9bRAO19cVjhWlxqd1PGeA;
typedef struct tySequence__apM9bRAO19cVjhWlxqd1PGeA_Content tySequence__apM9bRAO19cVjhWlxqd1PGeA_Content;
typedef struct tyTuple__vHfXSpEC1R9b9cKgfFB9a58gw tyTuple__vHfXSpEC1R9b9cKgfFB9a58gw;
typedef struct tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA;
typedef struct tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ;
typedef struct tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig;
typedef struct tyTuple__4iq9bD09amB7Ah0r9cBB0nSPQ tyTuple__4iq9bD09amB7Ah0r9cBB0nSPQ;
typedef struct tySequence__9bW2eTK9b7vXE70Sx5VPH1mw tySequence__9bW2eTK9b7vXE70Sx5VPH1mw;
typedef struct tySequence__9bW2eTK9b7vXE70Sx5VPH1mw_Content tySequence__9bW2eTK9b7vXE70Sx5VPH1mw_Content;
typedef struct tyTuple__bnJwOH0eJlAwCAMbr1inhw tyTuple__bnJwOH0eJlAwCAMbr1inhw;
typedef struct tyTuple__YG7h1OUHzgfgTeH9cl0U0dw tyTuple__YG7h1OUHzgfgTeH9cl0U0dw;
typedef struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw tyTuple__xYhUhS7X82rKTqbT9bRfCnw;
typedef struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q;
typedef struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ tyTuple__xDU9bZmv1ZbZkJDaATBekIQ;
typedef struct tyTuple__tG5yYi8DnD7bl00aT9cgctQ tyTuple__tG5yYi8DnD7bl00aT9cgctQ;
typedef struct tyObject_SuggestFileSymbolDatabase__o0ahEzaLn5a7TdNqH4OVqQ tyObject_SuggestFileSymbolDatabase__o0ahEzaLn5a7TdNqH4OVqQ;
typedef struct tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg;
typedef struct tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg_Content tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg_Content;
typedef struct tySequence__yUWoZehF86MIc40opFgacw tySequence__yUWoZehF86MIc40opFgacw;
typedef struct tySequence__yUWoZehF86MIc40opFgacw_Content tySequence__yUWoZehF86MIc40opFgacw_Content;
typedef struct tyObject_PackedBoolArray__1pk9boftqWMNDE1oh5HcIhw tyObject_PackedBoolArray__1pk9boftqWMNDE1oh5HcIhw;
typedef struct tyTuple__gnRkA1L4XiR4uByriyHW8Q tyTuple__gnRkA1L4XiR4uByriyHW8Q;
typedef struct tySequence__nSO1ltijM4vhc0UrrXKEqA tySequence__nSO1ltijM4vhc0UrrXKEqA;
typedef struct tySequence__nSO1ltijM4vhc0UrrXKEqA_Content tySequence__nSO1ltijM4vhc0UrrXKEqA_Content;
typedef struct tyTuple__CvjVmQeIfivirDme2r5MRw tyTuple__CvjVmQeIfivirDme2r5MRw;
typedef struct tyTuple__2QDyOgS51ZMPO0W1pWCY6g tyTuple__2QDyOgS51ZMPO0W1pWCY6g;
typedef struct tyTuple__UbCNQED4XJUgxOgPHJUcAQ tyTuple__UbCNQED4XJUgxOgPHJUcAQ;
typedef struct tySequence__juxPMVNF1FoR2ltzeQu8NQ tySequence__juxPMVNF1FoR2ltzeQu8NQ;
typedef struct tySequence__juxPMVNF1FoR2ltzeQu8NQ_Content tySequence__juxPMVNF1FoR2ltzeQu8NQ_Content;
typedef struct tyTuple__zExIg9bDTcVf2FHROUpzoow tyTuple__zExIg9bDTcVf2FHROUpzoow;
typedef struct tyTuple__XrHNJHOzS3O7uwF9bvCySiA tyTuple__XrHNJHOzS3O7uwF9bvCySiA;
typedef struct tyTuple__EdLY4EJQ37VFgbAn5g5rXQ tyTuple__EdLY4EJQ37VFgbAn5g5rXQ;
typedef struct tyTuple__OtlgAx3kBps9cOSMNDZSzBA tyTuple__OtlgAx3kBps9cOSMNDZSzBA;
typedef struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg tyTuple__F3gkSrMB1qp2Tvf9bixVXwg;
typedef struct tyTuple__RFOJ4fF7D9bpvmh9birH1JhQ tyTuple__RFOJ4fF7D9bpvmh9birH1JhQ;
typedef struct tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw;
typedef struct tyObject_NodecolonObjectType___U4ON6JZL9cIHezBQjmQzJ8Q tyObject_NodecolonObjectType___U4ON6JZL9cIHezBQjmQzJ8Q;
typedef struct tyTuple__O3g9a8zTXSX36ljWponcAoA tyTuple__O3g9a8zTXSX36ljWponcAoA;
typedef struct tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ;
typedef struct tyObject_TFileInfo__xPdjmgevOVG8T0Aq8BK7jw tyObject_TFileInfo__xPdjmgevOVG8T0Aq8BK7jw;
typedef struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw tyTuple__QeWl6B6ffS4pU6WWrtcrDw;
typedef struct tyObject_StackTraceEntry__RcJz5RXFIYjIseutvVFICA tyObject_StackTraceEntry__RcJz5RXFIYjIseutvVFICA;
typedef struct tyTuple__UvldbCB6B9ayi9bGYW7vJNLA tyTuple__UvldbCB6B9ayi9bGYW7vJNLA;
typedef struct tyTuple__0q9cmhneJEKnQERTpXXdz6Q tyTuple__0q9cmhneJEKnQERTpXXdz6Q;
typedef struct tyObject_PackedNode__YxKk4C732K04CNgtMhmc0w tyObject_PackedNode__YxKk4C732K04CNgtMhmc0w;
typedef struct tyTuple__48iPM3yLBKU5nyEuYwJvuQ tyTuple__48iPM3yLBKU5nyEuYwJvuQ;
typedef struct tyTuple__R3ddFrA0G9buJY57Qhf9cTpg tyTuple__R3ddFrA0G9buJY57Qhf9cTpg;
typedef struct tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ;
typedef struct tyTuple__7rmdAMLZ8fDd79brQn2ixZA tyTuple__7rmdAMLZ8fDd79brQn2ixZA;
typedef struct tyTuple__qPXRCRNQuZLLKto7CIIEzw tyTuple__qPXRCRNQuZLLKto7CIIEzw;
typedef struct tyObject_PackedInstantiation__C3FSePJFY8gUIMObsjT2dg tyObject_PackedInstantiation__C3FSePJFY8gUIMObsjT2dg;
typedef struct tyTuple__6kG8KAxm9aXPdLdlxcxqJJw tyTuple__6kG8KAxm9aXPdLdlxcxqJJw;
typedef struct tyTuple__TRK7rrwoha9bbDAdPWsqJMw tyTuple__TRK7rrwoha9bbDAdPWsqJMw;
typedef struct tyTuple__V1VWX9bHapuzCjpMfFfys5Q tyTuple__V1VWX9bHapuzCjpMfFfys5Q;
typedef struct tyObject_PackedSym__KKnx6w8Cc9aaVsaPOpaqxbw tyObject_PackedSym__KKnx6w8Cc9aaVsaPOpaqxbw;
typedef struct tyObject_PackedLib__EpwVLk0Fuc5Q9agKLMWedbg tyObject_PackedLib__EpwVLk0Fuc5Q9agKLMWedbg;
typedef struct tyTuple__anemVmHCFglLFt6LiEhFvg tyTuple__anemVmHCFglLFt6LiEhFvg;
typedef struct tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ;
typedef struct tyTuple__MaWaKZwaGUqCXKsSK12rVg tyTuple__MaWaKZwaGUqCXKsSK12rVg;
typedef struct tyTuple__nL9cBxaIV4ZA9b9ceY79coA5eA tyTuple__nL9cBxaIV4ZA9b9ceY79coA5eA;
typedef struct tyTuple__1xWeGeoNoZxaLhTUDDWYyA tyTuple__1xWeGeoNoZxaLhTUDDWYyA;
typedef struct tyTuple__MZVSn3SE3XUBJOaMu7ofRQ tyTuple__MZVSn3SE3XUBJOaMu7ofRQ;
typedef struct tyObject_TIdPair__03S6SAVUgd0pzOKFuxkR1A tyObject_TIdPair__03S6SAVUgd0pzOKFuxkR1A;
typedef struct tyTuple__R9cYIordoMujN7rycr4Y7kw tyTuple__R9cYIordoMujN7rycr4Y7kw;
typedef struct tyObject_TIdPair__jFcUgE4X1tLOqan9b4YIIeg tyObject_TIdPair__jFcUgE4X1tLOqan9b4YIIeg;
typedef struct tyTuple__ZUrTP7BFWWFkSv3xO9crp9aQ tyTuple__ZUrTP7BFWWFkSv3xO9crp9aQ;
typedef struct tyObject_LazyType__dsEGDq9cOhnzsRvTUTwwwuA tyObject_LazyType__dsEGDq9cOhnzsRvTUTwwwuA;
typedef struct tyObject_LazyInstantiation__n72c7MnOoHWBy9c9akgwGqEA tyObject_LazyInstantiation__n72c7MnOoHWBy9c9akgwGqEA;
typedef struct tySequence__YxH9cgSorHRI8ZPzHf47NNQ tySequence__YxH9cgSorHRI8ZPzHf47NNQ;
typedef struct tySequence__YxH9cgSorHRI8ZPzHf47NNQ_Content tySequence__YxH9cgSorHRI8ZPzHf47NNQ_Content;
typedef struct tyTuple__lGHLhAAUpxgfrnQkIzNrMw tyTuple__lGHLhAAUpxgfrnQkIzNrMw;
typedef struct tyObject_TinyLineInfo__qW2GTIPjeOQ42q9c2MPWLLA tyObject_TinyLineInfo__qW2GTIPjeOQ42q9c2MPWLLA;
typedef struct tyTuple__V6P73hvHy70PBBwharKjig tyTuple__V6P73hvHy70PBBwharKjig;
typedef NU8 tySet_tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw[38];
struct tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA {
	NU16 line;
	NI16 col;
	NI32 fileIndex;
};
typedef NU32 tySet_tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw;
typedef NU8 tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw;
struct NimStrPayload {
	NI cap;
	NIM_CHAR data[SEQ_DECL_SIZE];
};
struct NimStringV2 {
	NI len;
	NimStrPayload* p;
};
struct tySequence__9ahcSjIErJohSBBFLwuF56Q {
  NI len; tySequence__9ahcSjIErJohSBBFLwuF56Q_Content* p;
};
struct tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typField;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info;
	tySet_tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw flags;
	tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw kind;
union{
	struct {
	NI64 intVal;
} _kind_1;
	struct {
	NF floatVal;
} _kind_2;
	struct {
	NimStringV2 strVal;
} _kind_3;
	struct {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym;
} _kind_4;
	struct {
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* ident;
} _kind_5;
	struct {
	tySequence__9ahcSjIErJohSBBFLwuF56Q sons;
} _kind_6;
};
};
typedef NU8 tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw;
typedef NU16 tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw;
typedef NU8 tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA;
struct tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA {
	NI id;
	NimStringV2 s;
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* next;
	NI h;
};
struct TNimTypeV2 {
	void* destructor;
	NI size;
	NI16 align;
	NI16 depth;
	NU32* display;
	void* traceImpl;
	void* typeInfoV1;
	NI flags;
	void* vTable[SEQ_DECL_SIZE];
};
struct RootObj {
	TNimTypeV2* m_type;
};
struct tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ {
	RootObj Sup;
	tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen;
};
struct tySequence__AE2UIxl7EbPzzBnmYsjIcw {
  NI len; tySequence__AE2UIxl7EbPzzBnmYsjIcw_Content* p;
};
typedef tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* tyArray__uJvLVbod8mnHGzJkQj89bWg[38];
struct tySequence__ZCZaCk14bTmSb6LMW9aWPVA {
  NI len; tySequence__ZCZaCk14bTmSb6LMW9aWPVA_Content* p;
};
struct tySequence__tsHRsYLyvTCPLlGRExqi7Q {
  NI len; tySequence__tsHRsYLyvTCPLlGRExqi7Q_Content* p;
};
struct tySequence__lAikaRQvUF0uwNAz0U4FFA {
  NI len; tySequence__lAikaRQvUF0uwNAz0U4FFA_Content* p;
};
typedef N_NIMCALL_PTR(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, tyProc__Yik7hgYZHhPeLJ5RsXTPqg) (tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* expectedType_p2);
typedef NU32 tySet_tyEnum_TExprFlag__LJ8tOeZrTQZuHS9cNbj1XCg;
typedef N_NIMCALL_PTR(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, tyProc__JIyBW5s9ba7hfYBnWxDVvgg) (tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tySet_tyEnum_TExprFlag__LJ8tOeZrTQZuHS9cNbj1XCg flags_p2, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* expectedType_p3);
typedef N_NIMCALL_PTR(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, tyProc__iXlRd9cBAN0CQpA5dkyhRvw) (tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tySet_tyEnum_TExprFlag__LJ8tOeZrTQZuHS9cNbj1XCg flags_p2);
typedef N_NIMCALL_PTR(NIM_BOOL, tyProc__7FLV9alRQFu6LOhr9bksExQQ) (tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p1);
typedef struct {
N_NIMCALL_PTR(NIM_BOOL, ClP_0) (tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, void* ClE_0);
void* ClE_0;
} tyProc__0qHBYUhlP28E2DV7mVNNAg;
typedef N_NIMCALL_PTR(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, tyProc__1nD4dBuhjTAOzMZJo9bmgog) (tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
typedef NU32 tySet_tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q;
typedef N_NIMCALL_PTR(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, tyProc__209aOewTLBT6nbWmyvOQFiw) (tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* nOrig_p2, tySet_tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q filter_p3, tySet_tyEnum_TExprFlag__LJ8tOeZrTQZuHS9cNbj1XCg flags_p4, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* expectedType_p5);
typedef N_NIMCALL_PTR(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, tyProc__D9aXgBooMpgLrPTmha6q31w) (tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* prev_p2);
typedef struct {
N_NIMCALL_PTR(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, ClP_0) (tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_LayeredIdTableObj__PbmRWgwPdgBZOtiSK65Q7A* pt_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p2, void* ClE_0);
void* ClE_0;
} tyProc__GbPSPD9bjvt0RIJnnVTczJA;
typedef struct {
N_NIMCALL_PTR(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, ClP_0) (tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* fn_p1, tyObject_LayeredIdTableObj__PbmRWgwPdgBZOtiSK65Q7A* pt_p2, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p3, void* ClE_0);
void* ClE_0;
} tyProc__iDJMP540ifFac3zJ49bj2cA;
typedef struct {
N_NIMCALL_PTR(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, ClP_0) (tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_LayeredIdTableObj__PbmRWgwPdgBZOtiSK65Q7A* pt_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* prc_p2, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p3, void* ClE_0);
void* ClE_0;
} tyProc__gq9a76bauTeymgreaiTI9cmg;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** n_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* expectedType_p2, void* ClE_0);
void* ClE_0;
} tyProc__Gji0NjiFFDU49aJiF3QZF8A;
struct tySequence__ZeWVlH6DqG79b1pTDhrrUYA {
  NI len; tySequence__ZeWVlH6DqG79b1pTDhrrUYA_Content* p;
};
typedef NI tyArray__k7D0lwfLmYccbQxUd49bbcQ[34];
struct tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA {
	NI elems;
	NI counter;
	NI max;
	tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA* head;
	tySequence__ZeWVlH6DqG79b1pTDhrrUYA data;
	tyArray__k7D0lwfLmYccbQxUd49bbcQ a;
};
struct tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg {
	NI counter;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA data;
};
struct tySequence__4zAALtm0xUbRlYWQ2V8K7A {
  NI len; tySequence__4zAALtm0xUbRlYWQ2V8K7A_Content* p;
};
typedef NU8 tyEnum_TTypeAttachedOp__RefHoBI5deIfxIZqo3dS5Q;
typedef N_NIMCALL_PTR(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, tyProc__UAj9bGJLVN9cwAsTcRZFyWmg) (tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* dc_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p2, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p3, tyEnum_TTypeAttachedOp__RefHoBI5deIfxIZqo3dS5Q op_p4, NI col_p5);
typedef NU32 tySet_tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ;
struct tySequence__9bffTLF0HkxjFCzZL8og4GA {
  NI len; tySequence__9bffTLF0HkxjFCzZL8og4GA_Content* p;
};
struct tySequence__Bis5AbpONWcIRrPyPJS8Yw {
  NI len; tySequence__Bis5AbpONWcIRrPyPJS8Yw_Content* p;
};
struct tyObject_HashSet__cx4zJRA9aTCfmpbY2J9bKwnQ {
	tySequence__Bis5AbpONWcIRrPyPJS8Yw data;
	NI counter;
};
struct tySequence__E8pi9b5QNahsURYzXMjh3qw {
  NI len; tySequence__E8pi9b5QNahsURYzXMjh3qw_Content* p;
};
struct tyObject_Table__nBRoNCTSfpfbfAeK9bNW1qw {
	tySequence__E8pi9b5QNahsURYzXMjh3qw data;
	NI counter;
};
struct tySequence__3B6hFqG0Do0FxDvnNucL7w {
  NI len; tySequence__3B6hFqG0Do0FxDvnNucL7w_Content* p;
};
struct tyObject_Table__g77QNejuRRKraNk8K2YkoA {
	tySequence__3B6hFqG0Do0FxDvnNucL7w data;
	NI counter;
};
struct tySequence__QqvaCqCpEE1QmQZbcZLi5A {
  NI len; tySequence__QqvaCqCpEE1QmQZbcZLi5A_Content* p;
};
struct tyObject_Table__toCaB3NxiVHPRVLgcez0Xg {
	tySequence__QqvaCqCpEE1QmQZbcZLi5A data;
	NI counter;
};
typedef N_NIMCALL_PTR(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, tyProc__bvRec9bo79ajqrJt3Bkg9c33w) (tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw k_p2);
struct tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw {
	tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ Sup;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* enforceVoidContext;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* voidType;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module;
	tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww* currentScope;
	tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww* moduleScope;
	tySequence__AE2UIxl7EbPzzBnmYsjIcw imports;
	tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww* topLevelScope;
	tyObject_TProcCon__ftBtv4UEhPouLts4uXXNLQ* p;
	tyArray__uJvLVbod8mnHGzJkQj89bWg intTypeCache;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* nilTypeCache;
	tyObject_TMatchedConcept__tvh59a8SIGC9ccJV9atmyb8kg* matchedConcept;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA friendModules;
	NI instCounter;
	NI* templInstCounter;
	NI inGenericContext;
	NI inStaticContext;
	NI inUnrolledContext;
	NI compilesContextId;
	NI compilesContextIdGenerator;
	NI inGenericInst;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA converters;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA patterns;
	tySequence__tsHRsYLyvTCPLlGRExqi7Q optionStack;
	tySequence__lAikaRQvUF0uwNAz0U4FFA libs;
	tyProc__Yik7hgYZHhPeLJ5RsXTPqg semConstExpr;
	tyProc__JIyBW5s9ba7hfYBnWxDVvgg semExpr;
	tyProc__JIyBW5s9ba7hfYBnWxDVvgg semExprWithType;
	tyProc__iXlRd9cBAN0CQpA5dkyhRvw semTryExpr;
	tyProc__Yik7hgYZHhPeLJ5RsXTPqg semTryConstExpr;
	tyProc__7FLV9alRQFu6LOhr9bksExQQ computeRequiresInit;
	tyProc__0qHBYUhlP28E2DV7mVNNAg hasUnresolvedArgs;
	tyProc__iXlRd9cBAN0CQpA5dkyhRvw semOperand;
	tyProc__1nD4dBuhjTAOzMZJo9bmgog semConstBoolExpr;
	tyProc__209aOewTLBT6nbWmyvOQFiw semOverloadedCall;
	tyProc__D9aXgBooMpgLrPTmha6q31w semTypeNode;
	tyProc__GbPSPD9bjvt0RIJnnVTczJA semInferredLambda;
	tyProc__iDJMP540ifFac3zJ49bj2cA semGenerateInstance;
	tyProc__gq9a76bauTeymgreaiTI9cmg instantiateOnlyProcType;
	tyProc__Gji0NjiFFDU49aJiF3QZF8A fitDefaultNode;
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA includedFiles;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg pureEnumFields;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg userPragmas;
	tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew* evalContext;
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA unknownIdents;
	tySequence__4zAALtm0xUbRlYWQ2V8K7A generics;
	NI topStmts;
	NI lastGenericIdx;
	NI inParallelStmt;
	tyProc__UAj9bGJLVN9cwAsTcRZFyWmg instTypeBoundOp;
	tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* cache;
	tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg signatures;
	NimStringV2 recursiveDep;
	NIM_BOOL suggestionsMade;
	NIM_BOOL isAmbiguous;
	tySet_tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ features;
	NI inTypeContext;
	NI inConceptDecl;
	tySequence__9bffTLF0HkxjFCzZL8og4GA unusedImports;
	tyObject_HashSet__cx4zJRA9aTCfmpbY2J9bKwnQ exportIndirections;
	tyObject_Table__nBRoNCTSfpfbfAeK9bNW1qw importModuleMap;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA lastTLineInfo;
	tyObject_Table__g77QNejuRRKraNk8K2YkoA sideEffects;
	NI inUncheckedAssignSection;
	tyObject_Table__toCaB3NxiVHPRVLgcez0Xg importModuleLookup;
	tySequence__9ahcSjIErJohSBBFLwuF56Q skipTypes;
	NI inTypeofContext;
	tyProc__bvRec9bo79ajqrJt3Bkg9c33w semAsgnOpr;
};
struct tySequence__TfHJycarvNts8E4mVG4Mfg {
  NI len; tySequence__TfHJycarvNts8E4mVG4Mfg_Content* p;
};
struct tySequence__5reviU45axUMPQgL9aoENrg {
  NI len; tySequence__5reviU45axUMPQgL9aoENrg_Content* p;
};
struct tyObject_PackedModuleGraph__vzv9a6xTiz616FotDgUeo9bg {
	tySequence__5reviU45axUMPQgL9aoENrg pm;
};
struct tySequence__dtr79aXjHrgHuH79ac55I2aw {
  NI len; tySequence__dtr79aXjHrgHuH79ac55I2aw_Content* p;
};
struct tySequence__8y0Gi4GwtXi2wk2mK1IOzw {
  NI len; tySequence__8y0Gi4GwtXi2wk2mK1IOzw_Content* p;
};
struct tyObject_Table__EBJpp1hXwvFl9cyekUv4qHg {
	tySequence__8y0Gi4GwtXi2wk2mK1IOzw data;
	NI counter;
};
struct tySequence__C2ivDnhTZ6IxAdui1rfuqw {
  NI len; tySequence__C2ivDnhTZ6IxAdui1rfuqw_Content* p;
};
struct tyObject_Table__nn0jq9adRZXGGj9assM9c9bR0w {
	tySequence__C2ivDnhTZ6IxAdui1rfuqw data;
	NI counter;
};
struct tySequence__3vEEVfBECLN6NIRA3FIp5g {
  NI len; tySequence__3vEEVfBECLN6NIRA3FIp5g_Content* p;
};
struct tyObject_Table__ChMwcRY3QzpOEBWbGAfvcA {
	tySequence__3vEEVfBECLN6NIRA3FIp5g data;
	NI counter;
};
typedef tyObject_Table__ChMwcRY3QzpOEBWbGAfvcA tyArray__HTPiakF26bUQGH9bgtmrtkA[7];
struct tySequence__9aSa87aKMiolq9a7z3kC0jTw {
  NI len; tySequence__9aSa87aKMiolq9a7z3kC0jTw_Content* p;
};
struct tyObject_Table__tEqt8LkShErhjQ9acvGyE7g {
	tySequence__9aSa87aKMiolq9a7z3kC0jTw data;
	NI counter;
};
struct tySequence__N589c2UsUgqqOITU2JfIuAQ {
  NI len; tySequence__N589c2UsUgqqOITU2JfIuAQ_Content* p;
};
struct tyObject_Table__QS2Z9cQjmvkp1aaFGq4ippw {
	tySequence__N589c2UsUgqqOITU2JfIuAQ data;
	NI counter;
};
struct tySequence__GYDW6wGgERshoSd16jJ3eQ {
  NI len; tySequence__GYDW6wGgERshoSd16jJ3eQ_Content* p;
};
struct tyObject_Table__bnfVX2VJ9aUicVujDM0GIhw {
	tySequence__GYDW6wGgERshoSd16jJ3eQ data;
	NI counter;
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw {
  NI len; tySequence__7lEisrXlQEzwtUKW5pzRCw_Content* p;
};
struct tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A {
	tySequence__7lEisrXlQEzwtUKW5pzRCw data;
	NI counter;
};
typedef NU8 tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw;
typedef NU8 tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg;
typedef NU8 tyEnum_TSystemCC__A5wZwpTXF1SiKGvwgH1wrA;
typedef NU32 tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ;
typedef NU64 tySet_tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A;
struct tyObject_PackedConfig__Hpn673wkKPDorr1HY9bOaDQ {
	tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw backend;
	tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg selectedGC;
	tyEnum_TSystemCC__A5wZwpTXF1SiKGvwgH1wrA cCompiler;
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ options;
	tySet_tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A globalOptions;
};
struct tySequence__fdmz6VkIf1ewwrssKYqRFg {
  NI len; tySequence__fdmz6VkIf1ewwrssKYqRFg_Content* p;
};
struct tyObject_Table__79b4rr6WWQqgRr9b4NH4UF9cw {
	tySequence__fdmz6VkIf1ewwrssKYqRFg data;
	NI counter;
};
struct tySequence__kxu4GK0onha2t9bo86mdVAg {
  NI len; tySequence__kxu4GK0onha2t9bo86mdVAg_Content* p;
};
struct tyObject_Table__AC9bec2JdoOuC3xQePGWgmA {
	tySequence__kxu4GK0onha2t9bo86mdVAg data;
	NI counter;
};
struct tySequence__48JTohSgTy339bRxHzUD8KA {
  NI len; tySequence__48JTohSgTy339bRxHzUD8KA_Content* p;
};
typedef struct {
N_NIMCALL_PTR(NIM_BOOL, ClP_0) (void* ClE_0);
void* ClE_0;
} tyProc__In3g79a0qTcRmbTbJp9ba9ctg;
struct tySequence__fz0REU1l0nYmKHXgMLRrIg {
  NI len; tySequence__fz0REU1l0nYmKHXgMLRrIg_Content* p;
};
struct tyObject_Table__bHTcQUCehDW9clHfFZXI7lQ {
	tySequence__fz0REU1l0nYmKHXgMLRrIg data;
	NI counter;
};
struct tySequence__Ip9aV1IKO2gVdheNOM31DCQ {
  NI len; tySequence__Ip9aV1IKO2gVdheNOM31DCQ_Content* p;
};
struct tyObject_Table__w2vCG1OPnHmNolvQVT168g {
	tySequence__Ip9aV1IKO2gVdheNOM31DCQ data;
	NI counter;
};
struct tySequence__kHjIdgrpmuSn9cUIIKpSiDg {
  NI len; tySequence__kHjIdgrpmuSn9cUIIKpSiDg_Content* p;
};
struct tySequence__Wd0Vle6gxRCPPoSlNEvfTA {
  NI len; tySequence__Wd0Vle6gxRCPPoSlNEvfTA_Content* p;
};
struct tyObject_CountTable__qvMelb9coODdwoghoAPc9c9aA {
	tySequence__Wd0Vle6gxRCPPoSlNEvfTA data;
	NI counter;
	NIM_BOOL isSorted;
};
struct tySequence__T7nNEWoEbKBa0G5Htr45Xw {
  NI len; tySequence__T7nNEWoEbKBa0G5Htr45Xw_Content* p;
};
struct tyObject_Table__fZyCWkMwhdvr3pauCNDaag {
	tySequence__T7nNEWoEbKBa0G5Htr45Xw data;
	NI counter;
};
struct tySequence__q9cHvMDDxYU1hSCdG4YwIhA {
  NI len; tySequence__q9cHvMDDxYU1hSCdG4YwIhA_Content* p;
};
struct tyObject_Table__5vmBY49areSIlgIs4A1LLKQ {
	tySequence__q9cHvMDDxYU1hSCdG4YwIhA data;
	NI counter;
};
struct tySequence__olFOFaYzOJN9aV5BWqK4b9bA {
  NI len; tySequence__olFOFaYzOJN9aV5BWqK4b9bA_Content* p;
};
typedef tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* tyArray__EOkbZZXacNOZHC8p7xc7hw[65];
struct tySequence__vJcM7B74R2U5db9cxyXT9coA {
  NI len; tySequence__vJcM7B74R2U5db9cxyXT9coA_Content* p;
};
struct tyObject_Table__9bmd0cvHWe1s4FTDn5BPmfw {
	tySequence__vJcM7B74R2U5db9cxyXT9coA data;
	NI counter;
};
struct tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg {
  NI len; tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg_Content* p;
};
struct tyObject_Table__GhjCMuklnRqwdX9bZo9bCoNg {
	tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg data;
	NI counter;
};
typedef N_NIMCALL_PTR(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, tyProc__QieBhPPkGvcmpFg89a4ftcA) (tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* m_p1, NI32 fileIdx_p2);
typedef N_NIMCALL_PTR(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, tyProc__F2ahyGAjs3aNLJYEXzu07g) (tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* m_p1, NI32 fileIdx_p2);
struct tySequence__R9c39btP6BwOBBPnbaNUtMQg {
  NI len; tySequence__R9c39btP6BwOBBPnbaNUtMQg_Content* p;
};
struct tyObject_Table__pI3mJh4Ap2XujSCfcSeUvQ {
	tySequence__R9c39btP6BwOBBPnbaNUtMQg data;
	NI counter;
};
struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA {
  NI len; tySequence__squ9b9bUH4OLHf6cEMrt6hVA_Content* p;
};
struct tyObject_Table__MsPmCuYz1KcEw6lr7P9cGkw {
	tySequence__squ9b9bUH4OLHf6cEMrt6hVA data;
	NI counter;
};
struct tySequence__3nALyQgqjnfK2Qjc6ny2Uw {
  NI len; tySequence__3nALyQgqjnfK2Qjc6ny2Uw_Content* p;
};
struct tyObject_Table__1HJsK7ponJ4Vb1lJgVFVTQ {
	tySequence__3nALyQgqjnfK2Qjc6ny2Uw data;
	NI counter;
};
struct tySequence__WbW5Q8QVks0bQpUJSGmuVg {
  NI len; tySequence__WbW5Q8QVks0bQpUJSGmuVg_Content* p;
};
typedef NU8 tyEnum_PipelinePass__kO50VlNfBJZtrNuD4VL9aTg;
typedef N_NIMCALL_PTR(void, tyProc__c9a5q9aZQWYYOu1vHoRoq9bVQ) (tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p2);
typedef N_NIMCALL_PTR(void, tyProc__kj3TYePLaHBuXxhRznQQNQ) (tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* owner_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* body_p2);
typedef N_NIMCALL_PTR(NIM_BOOL, tyProc__D3Q9bYoPIpHZVLfEIxpBssA) (tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* formal_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* actual_p2);
struct tyObject_Operators__yrAfvKhiysDamJlcGNgVfQ {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opNot;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opContains;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opLe;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opLt;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opAnd;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opOr;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opIsNil;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opEq;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opAdd;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opSub;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opMul;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opDiv;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opLen;
};
struct tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw {
	tySequence__TfHJycarvNts8E4mVG4Mfg ifaces;
	tyObject_PackedModuleGraph__vzv9a6xTiz616FotDgUeo9bg packed_0;
	tySequence__dtr79aXjHrgHuH79ac55I2aw encoders;
	tyObject_Table__EBJpp1hXwvFl9cyekUv4qHg typeInstCache;
	tyObject_Table__nn0jq9adRZXGGj9assM9c9bR0w procInstCache;
	tyArray__HTPiakF26bUQGH9bgtmrtkA attachedOps;
	tyObject_Table__tEqt8LkShErhjQ9acvGyE7g methodsPerGenericType;
	tyObject_Table__QS2Z9cQjmvkp1aaFGq4ippw memberProcsPerType;
	tyObject_Table__bnfVX2VJ9aUicVujDM0GIhw initializersPerType;
	tyObject_Table__ChMwcRY3QzpOEBWbGAfvcA enumToStringProcs;
	tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A emittedTypeInfo;
	tyObject_PackedConfig__Hpn673wkKPDorr1HY9bOaDQ startupPackedConfig;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg packageSyms;
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA deps;
	tyObject_Table__79b4rr6WWQqgRr9b4NH4UF9cw importDeps;
	NIM_BOOL suggestMode;
	NIM_BOOL invalidTransitiveClosure;
	NIM_BOOL interactive;
	NIM_BOOL withinSystem;
	tyObject_Table__AC9bec2JdoOuC3xQePGWgmA inclToMod;
	tySequence__48JTohSgTy339bRxHzUD8KA importStack;
	RootObj* backend;
	tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* config;
	tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* cache;
	RootObj* vm;
	RootObj* repl;
	tyProc__In3g79a0qTcRmbTbJp9ba9ctg doStopCompile;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* usageSym;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA owners;
	tyObject_Table__bHTcQUCehDW9clHfFZXI7lQ suggestSymbols;
	tyObject_Table__w2vCG1OPnHmNolvQVT168g suggestErrors;
	tySequence__kHjIdgrpmuSn9cUIIKpSiDg methods;
	tyObject_CountTable__qvMelb9coODdwoghoAPc9c9aA bucketTable;
	tyObject_Table__fZyCWkMwhdvr3pauCNDaag objectTree;
	tyObject_Table__5vmBY49areSIlgIs4A1LLKQ methodsPerType;
	tySequence__olFOFaYzOJN9aV5BWqK4b9bA dispatchers;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* systemModule;
	tyArray__EOkbZZXacNOZHC8p7xc7hw sysTypes;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg compilerprocs;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg exposed;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg packageTypes;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* emptyNode;
	tyObject_Table__9bmd0cvHWe1s4FTDn5BPmfw canonTypes;
	tyObject_Table__GhjCMuklnRqwdX9bZo9bCoNg symBodyHashes;
	tyProc__QieBhPPkGvcmpFg89a4ftcA importModuleCallback;
	tyProc__F2ahyGAjs3aNLJYEXzu07g includeFileCallback;
	tyObject_Table__pI3mJh4Ap2XujSCfcSeUvQ cacheSeqs;
	tyObject_Table__MsPmCuYz1KcEw6lr7P9cGkw cacheCounters;
	tyObject_Table__1HJsK7ponJ4Vb1lJgVFVTQ cacheTables;
	tySequence__WbW5Q8QVks0bQpUJSGmuVg passes;
	tyEnum_PipelinePass__kO50VlNfBJZtrNuD4VL9aTg pipelinePass;
	tyProc__c9a5q9aZQWYYOu1vHoRoq9bVQ onDefinition;
	tyProc__c9a5q9aZQWYYOu1vHoRoq9bVQ onDefinitionResolveForward;
	tyProc__c9a5q9aZQWYYOu1vHoRoq9bVQ onUsage;
	tySequence__9ahcSjIErJohSBBFLwuF56Q globalDestructors;
	tyProc__kj3TYePLaHBuXxhRznQQNQ strongSemCheck;
	tyProc__D3Q9bYoPIpHZVLfEIxpBssA compatibleProps;
	tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen;
	tyObject_Operators__yrAfvKhiysDamJlcGNgVfQ operators;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* cachedFiles;
	tySequence__9ahcSjIErJohSBBFLwuF56Q procGlobals;
};
typedef NU8 tyEnum_TSystemCPU__3f9cinURS2hpZEHtBX69bm9cw;
typedef NU8 tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw;
struct tyObject_Target__GzbDkV2u8Pgzlf9azvC43FA {
	tyEnum_TSystemCPU__3f9cinURS2hpZEHtBX69bm9cw targetCPU;
	tyEnum_TSystemCPU__3f9cinURS2hpZEHtBX69bm9cw hostCPU;
	tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw targetOS;
	tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw hostOS;
	NI intSize;
	NI floatSize;
	NI ptrSize;
	NimStringV2 tnl;
};
typedef NU8 tySet_tyEnum_TErrorOutput__wGgqZXVnY1wkKEe8EL9cL9aw;
struct tySequence__E0kio2ZnplNTuln9bsnljSA {
  NI len; tySequence__E0kio2ZnplNTuln9bsnljSA_Content* p;
};
struct tySequence__hTEiKNj3evQAjIXUI21elA {
  NI len; tySequence__hTEiKNj3evQAjIXUI21elA_Content* p;
};
struct tyObject_MsgConfig__E1VAUnnaNIOngCdEgTI2Dw {
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA trackPos;
	NIM_BOOL trackPosAttached;
	tySet_tyEnum_TErrorOutput__wGgqZXVnY1wkKEe8EL9cL9aw errorOutputs;
	tySequence__E0kio2ZnplNTuln9bsnljSA msgContext;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA lastError;
	tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A filenameToIndexTbl;
	tySequence__hTEiKNj3evQAjIXUI21elA fileInfos;
	NI32 systemFileIdx;
};
typedef NU8 tyEnum_FilenameOption__o3jmnnVs6HdBg5KcNAzYiQ;
typedef NU8 tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ;
typedef NU8 tyEnum_ExceptionSystem__dJ6sXW7k8NDYNNBUjVZmnw;
typedef NU8 tyEnum_SymbolFilesOption__2eyIIreuRXhYT9buPPZbBYA;
struct tySequence__4eRCaZmrYLLw2k30GPTiMw {
  NI len; tySequence__4eRCaZmrYLLw2k30GPTiMw_Content* p;
};
struct tyObject_HashSet__8IGL0eIK5PYDsNGVA78Wmw {
	tySequence__4eRCaZmrYLLw2k30GPTiMw data;
	NI counter;
};
typedef NU8 tySet_tyEnum_LegacyFeature__yvNVqOQTgcxHpvo1MvfBfA;
typedef NU8 tyEnum_IdeCmd__mZiSMTDWSAKKDbZfXDQwng;
typedef NU8 tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw[13];
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ {
  NI len; tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content* p;
};
typedef NU8 tySet_tyEnum_StdOrrKind__so1PI9cHP1cN622ePtqa0yw;
struct tySequence__xOJ2kx2lq9bBfIm3IXnde3Q {
  NI len; tySequence__xOJ2kx2lq9bBfIm3IXnde3Q_Content* p;
};
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_SuggestcolonObjectType___UyASNXAqAMRY5zJmcRD9ccA* result_p0, void* ClE_0);
void* ClE_0;
} tyProc__QQyR5yGA47tr5TwLxcC4Gw;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (NimStringV2 output_p0, void* ClE_0);
void* ClE_0;
} tyProc__k2HFjxisIgDALbEUFojxaQ;
typedef NU8 tyEnum_Severity__mHEDvws7FmOtnFhcQsM8UA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* config_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, NimStringV2 msg_p2, tyEnum_Severity__mHEDvws7FmOtnFhcQsM8UA severity_p3, void* ClE_0);
void* ClE_0;
} tyProc__DA9aR62IikoxFqfC5rIT9cuw;
struct tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg {
	tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw backend;
	tyObject_Target__GzbDkV2u8Pgzlf9azvC43FA target;
	NI linesCompiled;
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ options;
	tySet_tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A globalOptions;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* macrosToExpand;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* arcToExpand;
	tyObject_MsgConfig__E1VAUnnaNIOngCdEgTI2Dw m;
	tyEnum_FilenameOption__o3jmnnVs6HdBg5KcNAzYiQ filenameOption;
	NimStringV2 unitSep;
	NI evalTemplateCounter;
	NI evalMacroCounter;
	NI8 exitcode;
	tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ cmd;
	NimStringV2 cmdInput;
	NIM_BOOL projectIsCmd;
	NIM_BOOL implicitCmd;
	tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg selectedGC;
	tyEnum_ExceptionSystem__dJ6sXW7k8NDYNNBUjVZmnw exc;
	NIM_BOOL hintProcessingDots;
	NI verbosity;
	NI numberOfProcessors;
	NF lastCmdTime;
	tyEnum_SymbolFilesOption__2eyIIreuRXhYT9buPPZbBYA symbolFiles;
	NI spellSuggestMax;
	tyObject_HashSet__8IGL0eIK5PYDsNGVA78Wmw cppDefines;
	NimStringV2 headerFile;
	NimStringV2 nimbasePattern;
	tySet_tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ features;
	tySet_tyEnum_LegacyFeature__yvNVqOQTgcxHpvo1MvfBfA legacyFeatures;
	NimStringV2 arguments;
	tyEnum_IdeCmd__mZiSMTDWSAKKDbZfXDQwng ideCmd;
	tyEnum_TSystemCC__A5wZwpTXF1SiKGvwgH1wrA cCompiler;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw modifiedyNotes;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw cmdlineNotes;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw foreignPackageNotes;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw notes;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw warningAsErrors;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw mainPackageNotes;
	NI mainPackageId;
	NI errorCounter;
	NI hintCounter;
	NI warnCounter;
	NI errorMax;
	NI maxLoopIterationsVM;
	NI maxCallDepthVM;
	NIM_BOOL isVmTrace;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* configVars;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* symbols;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* packageCache;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ nimblePaths;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ searchPaths;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ lazyPaths;
	NimStringV2 outFile;
	NimStringV2 outDir;
	NimStringV2 jsonBuildFile;
	NimStringV2 prefixDir;
	NimStringV2 libpath;
	NimStringV2 nimcacheDir;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* dllOverrides;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* moduleOverrides;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* cfileSpecificOptions;
	NimStringV2 projectName;
	NimStringV2 projectPath;
	NimStringV2 projectFull;
	NIM_BOOL projectIsStdin;
	NimStringV2 stdinFile;
	tySet_tyEnum_StdOrrKind__so1PI9cHP1cN622ePtqa0yw lastMsgWasDot;
	NI32 projectMainIdx;
	NI32 projectMainIdx2;
	NimStringV2 command;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ commandArgs;
	NimStringV2 commandLine;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ extraCmds;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ implicitImports;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ implicitIncludes;
	NimStringV2 docSeeSrcUrl;
	NimStringV2 docRoot;
	NimStringV2 docCmd;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ configFiles;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ cIncludes;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ cLibs;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ cLinkedLibs;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ externalToLink;
	NimStringV2 linkOptionsCmd;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ compileOptionsCmd;
	NimStringV2 linkOptions;
	NimStringV2 compileOptions;
	NimStringV2 cCompilerPath;
	tySequence__xOJ2kx2lq9bBfIm3IXnde3Q toCompile;
	tyProc__QQyR5yGA47tr5TwLxcC4Gw suggestionResultHook;
	NI suggestVersion;
	NI suggestMaxResults;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA lastLineInfo;
	tyProc__k2HFjxisIgDALbEUFojxaQ writelnHook;
	tyProc__DA9aR62IikoxFqfC5rIT9cuw structuredErrorHook;
	NimStringV2 cppCustomNamespace;
	NimStringV2 nimMainPrefix;
	tyObject_ProfileDatacolonObjectType___R9cEb9cNTzPRldVmD9bCDO0xQ* vmProfileData;
	NIM_BOOL expandProgress;
	NI expandLevels;
	NimStringV2 expandNodeResult;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA expandPosition;
	NimStringV2 currentConfigDir;
	NI clientProcessId;
};
typedef NU8 tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w;
typedef NU16 tySet_tyEnum_TRenderFlag__Il2q467fyuki59ci9aspexFg;
struct tyTuple__kN8up2W6YKc5YA9avn5mV5w {
	NimStringV2 Field0;
	NI Field1;
	NI Field2;
};
typedef N_CLOSURE_PTR(NIM_BOOL, TM__tPA3StZ6VsKyoznyrIfFxg_12) (tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
struct tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA {
	NI32 module;
	NI32 item;
};
typedef NU8 tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg;
typedef NU8 tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ;
typedef NU64 tySet_tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A;
struct tySequence__d8ZV4IMgHt9biik9cS9a0hrmg {
  NI len; tySequence__d8ZV4IMgHt9biik9cS9a0hrmg_Content* p;
};
typedef NU8 tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ;
typedef NU8 tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg;
typedef NU16 tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg;
struct tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw {
	tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ k;
	tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg storage;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg flags;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* lode;
	NimStringV2 snippet;
};
struct tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg {
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA itemId;
	tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg kind;
	tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ callConv;
	tySet_tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A flags;
	tySequence__d8ZV4IMgHt9biik9cS9a0hrmg sons;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* ownerField;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym;
	NI64 size;
	NI16 align;
	NI16 paddingAtEnd;
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw loc;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typeInst;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA uniqueId;
};
typedef NU8 tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg[9];
typedef tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* tyArray__TAsXwXSUBvAawE1kIQ5ziQ[1];
typedef tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* tyArray__al2p7ldDMvbBVYNFCuu4Rw[2];
typedef NU8 tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q;
typedef NU16 tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg;
typedef NU64 tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg;
struct tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg {
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA itemId;
	tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q kind;
union{
	struct {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* gcUnsafetyReason;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* transformedBody;
} _kind_1;
	struct {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* guard;
	NI bitsize;
	NI alignment;
} _kind_2;
};
	tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg magic;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ;
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* name;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* ownerField;
	tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg flags;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* ast;
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ options;
	NI position;
	NI32 offset;
	NI32 disamb;
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw loc;
	tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig* annex;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* constraint;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* instantiatedFrom;
};
typedef NU8 tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg;
typedef NU8 tyEnum_TNodeKind__fgQOep3rrztw9aeZI9aS2Ltg;
struct tyObject_HSlice__OAVyDXS0QPw7LdXClfU2hA {
	NI a;
	NI b;
};
struct tySequence__S89cE01OvNjsN9c71FKsSrqQ {
  NI len; tySequence__S89cE01OvNjsN9c71FKsSrqQ_Content* p;
};
struct Exception {
	RootObj Sup;
	Exception* parent;
	NCSTRING name;
	NimStringV2 message;
	tySequence__S89cE01OvNjsN9c71FKsSrqQ trace;
	Exception* up;
};
typedef NimStringV2 tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ[2];
typedef NU8 tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg;
typedef NU8 tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A;
typedef NU8 tySet_tyChar__nmiMWKVIe46vacnhAFrQvw[32];
struct tyObject_Env_pragmasdotnim_processEffectsOf___441zjIQZOyCLH68Plk1FJQ {
	RootObj Sup;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* owner0;
};
struct tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A {
	NI rc;
	NI rootIdx;
};
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, void* ClE_0);
void* ClE_0;
} tyProc__9b9a7FRnQW3XNIvbw12GxI7w;
typedef N_CLOSURE_PTR(void, TM__tPA3StZ6VsKyoznyrIfFxg_92) (tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
typedef N_CLOSURE_PTR(void, TM__tPA3StZ6VsKyoznyrIfFxg_93) (tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
typedef NU8 tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ;
typedef NU8 tyEnum_TLibKind__BkKL8ReLoyYDI7of9aQPV0A;
struct tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig {
	tyEnum_TLibKind__BkKL8ReLoyYDI7of9aQPV0A kind;
	NIM_BOOL generated;
	NIM_BOOL isOverridden;
	NimStringV2 name;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* path;
};
typedef NU8 tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A;
struct tyObject_TOptionEntry__KeABxBvAlGa1KroFfkcqAg {
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ options;
	tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ defaultCC;
	tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig* dynlib;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw notes;
	tySet_tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ features;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* otherPragmas;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw warningAsErrors;
};
struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ {
  NI len; tySequence__9cnx3zXnWzeclW8Ko4oUgAQ_Content* p;
};
struct tyObject_Table__uaQEKxLZNO5fpFluyxnhTg {
	tySequence__9cnx3zXnWzeclW8Ko4oUgAQ data;
	NI counter;
};
struct tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ {
	NI32 thisModule;
	NI32 lastFile;
	NU32 lastLit;
	tyObject_Table__uaQEKxLZNO5fpFluyxnhTg filenames;
	tySequence__d8ZV4IMgHt9biik9cS9a0hrmg pendingTypes;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA pendingSyms;
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA typeMarker;
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA symMarker;
	tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* config;
};
typedef NU8 tyEnum_ModuleStatus__uT4B39a2dNaG9a9aunVdyhQtQ;
struct tySequence__PXIzfWocnrafGz5p3CP5LA {
  NI len; tySequence__PXIzfWocnrafGz5p3CP5LA_Content* p;
};
struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA {
  NI len; tySequence__9bAGqSvkAaFL9bWjsEPslrFA_Content* p;
};
struct tySequence__OxRbUT0qZaZN5UjnqQjGPA {
  NI len; tySequence__OxRbUT0qZaZN5UjnqQjGPA_Content* p;
};
struct tySequence__ezS5mGPcRfBURJyMgqYVzA {
  NI len; tySequence__ezS5mGPcRfBURJyMgqYVzA_Content* p;
};
struct tySequence__wW7xkohjuUKO9aMaB0nt9cqA {
  NI len; tySequence__wW7xkohjuUKO9aMaB0nt9cqA_Content* p;
};
struct tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w {
	tySequence__OxRbUT0qZaZN5UjnqQjGPA nodes;
	tySequence__ezS5mGPcRfBURJyMgqYVzA withFlags;
	tySequence__wW7xkohjuUKO9aMaB0nt9cqA withTypes;
};
struct tySequence__b89aLriiJnVTD186H6zNIgg {
  NI len; tySequence__b89aLriiJnVTD186H6zNIgg_Content* p;
};
struct tySequence__hIPTk9aFdaMMVAOzEbnPyqg {
  NI len; tySequence__hIPTk9aFdaMMVAOzEbnPyqg_Content* p;
};
struct tySequence__YYy1721YAuPF0ajBYHd8Wg {
  NI len; tySequence__YYy1721YAuPF0ajBYHd8Wg_Content* p;
};
struct tySequence__UODJbvzmu39c3Ho9cqhSk9agQ {
  NI len; tySequence__UODJbvzmu39c3Ho9cqhSk9agQ_Content* p;
};
struct tySequence__F1qNdU7m0Czu7Y2q0eksXw {
  NI len; tySequence__F1qNdU7m0Czu7Y2q0eksXw_Content* p;
};
struct tySequence__r3Kz9breImOXyFFoJ29aBM8Q {
  NI len; tySequence__r3Kz9breImOXyFFoJ29aBM8Q_Content* p;
};
struct tySequence__qBes3XzcQQ9cyia9bRwnmbJw {
  NI len; tySequence__qBes3XzcQQ9cyia9bRwnmbJw_Content* p;
};
typedef NU8 tySet_tyEnum_ModuleBackendFlag__5FvIlwIIbpcHU0ZRU9a5hrQ;
struct tySequence__Vl1abU3gfp0RqCb1KKfmDA {
  NI len; tySequence__Vl1abU3gfp0RqCb1KKfmDA_Content* p;
};
struct tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw {
	tySequence__Vl1abU3gfp0RqCb1KKfmDA data;
	NI counter;
	NI first;
	NI last;
};
struct tySequence__qyyNkmlc4fzOzelC8spUkQ {
  NI len; tySequence__qyyNkmlc4fzOzelC8spUkQ_Content* p;
};
struct tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw {
	tySequence__qyyNkmlc4fzOzelC8spUkQ data;
	NI counter;
	NI first;
	NI last;
};
struct tyObject_BiTable__KR9c7QZguPO3OKZOIcphgcA {
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ vals;
	tySequence__9bAGqSvkAaFL9bWjsEPslrFA keys;
};
struct tySequence__IHUFRsFxZNv7YydiUO2esQ {
  NI len; tySequence__IHUFRsFxZNv7YydiUO2esQ_Content* p;
};
struct tyObject_BiTable__9aUXwPoJbNPqj9a249c0iSmlg {
	tySequence__IHUFRsFxZNv7YydiUO2esQ vals;
	tySequence__9bAGqSvkAaFL9bWjsEPslrFA keys;
};
struct tySequence__orxtl6CusdjXleqrxi67gw {
  NI len; tySequence__orxtl6CusdjXleqrxi67gw_Content* p;
};
struct tyObject_LineInfoManager__TTy646Kfh1cVyXU9aSMasUQ {
	tySequence__orxtl6CusdjXleqrxi67gw aside;
};
struct tyObject_PackedModule__sRHd9aQ2ZMII76xRsfAbE9aQ {
	NimStringV2 definedSymbols;
	tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg moduleFlags;
	tySequence__PXIzfWocnrafGz5p3CP5LA includes;
	tySequence__9bAGqSvkAaFL9bWjsEPslrFA imports;
	tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w toReplay;
	tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w topLevel;
	tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w bodies;
	tySequence__b89aLriiJnVTD186H6zNIgg exports;
	tySequence__b89aLriiJnVTD186H6zNIgg hidden;
	tySequence__hIPTk9aFdaMMVAOzEbnPyqg reexports;
	tySequence__b89aLriiJnVTD186H6zNIgg compilerProcs;
	tySequence__48JTohSgTy339bRxHzUD8KA converters;
	tySequence__48JTohSgTy339bRxHzUD8KA methods;
	tySequence__48JTohSgTy339bRxHzUD8KA trmacros;
	tySequence__48JTohSgTy339bRxHzUD8KA pureEnums;
	tySequence__YYy1721YAuPF0ajBYHd8Wg typeInstCache;
	tySequence__UODJbvzmu39c3Ho9cqhSk9agQ procInstCache;
	tySequence__F1qNdU7m0Czu7Y2q0eksXw attachedOps;
	tySequence__r3Kz9breImOXyFFoJ29aBM8Q methodsPerGenericType;
	tySequence__YYy1721YAuPF0ajBYHd8Wg enumToStringProcs;
	tySequence__YYy1721YAuPF0ajBYHd8Wg methodsPerType;
	tySequence__qBes3XzcQQ9cyia9bRwnmbJw dispatchers;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ emittedTypeInfo;
	tySet_tyEnum_ModuleBackendFlag__5FvIlwIIbpcHU0ZRU9a5hrQ backendFlags;
	tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw syms;
	tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw types;
	tyObject_BiTable__KR9c7QZguPO3OKZOIcphgcA strings;
	tyObject_BiTable__9aUXwPoJbNPqj9a249c0iSmlg numbers;
	tyObject_LineInfoManager__TTy646Kfh1cVyXU9aSMasUQ man;
	tyObject_PackedConfig__Hpn673wkKPDorr1HY9bOaDQ cfg;
};
struct tySequence__K0j67V58u5FW0dCC534FQw {
  NI len; tySequence__K0j67V58u5FW0dCC534FQw_Content* p;
};
struct tyObject_OrderedTable__h8mIUVGY8LJXF9cakgvB9bqQ {
	tySequence__K0j67V58u5FW0dCC534FQw data;
	NI counter;
	NI first;
	NI last;
};
struct tySequence__UE4b6iUkm1b3zTPamTTkDw {
  NI len; tySequence__UE4b6iUkm1b3zTPamTTkDw_Content* p;
};
struct tyObject_OrderedTable__DED9c7j9bI3Lh5w4GQakK8yQ {
	tySequence__UE4b6iUkm1b3zTPamTTkDw data;
	NI counter;
	NI first;
	NI last;
};
struct tySequence__FmsTQiIcS9arxHxs3QY48vA {
  NI len; tySequence__FmsTQiIcS9arxHxs3QY48vA_Content* p;
};
struct tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg {
	tySequence__FmsTQiIcS9arxHxs3QY48vA data;
	NI counter;
};
struct tyObject_LoadedModule__7NEKRkz5hkiOxQy5guqIHA {
	tyEnum_ModuleStatus__uT4B39a2dNaG9a9aunVdyhQtQ status;
	NIM_BOOL symsInit;
	NIM_BOOL typesInit;
	NIM_BOOL loadedButAliveSetChanged;
	tyObject_PackedModule__sRHd9aQ2ZMII76xRsfAbE9aQ fromDisk;
	tyObject_OrderedTable__h8mIUVGY8LJXF9cakgvB9bqQ syms;
	tyObject_OrderedTable__DED9c7j9bI3Lh5w4GQakK8yQ types;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module;
	tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg iface;
	tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg ifaceHidden;
};
struct tyObject_Env_pragmasdotnim_processCompile___dWXVdC0mxyRcA9cJsc1PdqQ {
	RootObj Sup;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n0;
};
typedef NCSTRING tyUncheckedArray__nvS6J9clHMUMHfoZd8Ad2zg[1];
typedef NU8 tySet_tyEnum_CfileFlag__qhMBL5cBz484papsb5WgFQ;
struct tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg {
	NimStringV2 nimname;
	NimStringV2 cname;
	NimStringV2 obj;
	tySet_tyEnum_CfileFlag__qhMBL5cBz484papsb5WgFQ flags;
	NimStringV2 customArgs;
};
struct tyTuple__7q7q3E6Oj24ZNVJb9aonhAg {
	NimStringV2 Field0;
	NimStringV2 Field1;
	NimStringV2 Field2;
};
typedef NimStringV2 tyArray__Seu7uK9aaOSN0BK3EAjjSHw[4];
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* it_p1, NimStringV2 src_p2, NimStringV2 dest_p3, NimStringV2 customArgs_p4, void* ClE_0);
void* ClE_0;
} tyProc__RR9bG3onntZdMX59cPU9cJE5g;
typedef N_CLOSURE_PTR(void, TM__tPA3StZ6VsKyoznyrIfFxg_161) (tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* it_p1, NimStringV2 src_p2, NimStringV2 dest_p3, NimStringV2 customArgs_p4);
typedef N_CLOSURE_PTR(void, TM__tPA3StZ6VsKyoznyrIfFxg_167) (tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* it_p1, NimStringV2 src_p2, NimStringV2 dest_p3, NimStringV2 customArgs_p4);
typedef NU16 tySet_tyEnum_TInfoCCProp__iDs813gw4el4q2vkEYZ9cBw;
struct tyTuple__Sb9czl1rSUt9cR4FEpnHeteg {
	NimStringV2 Field0;
	NimStringV2 Field1;
	NimStringV2 Field2;
	NimStringV2 Field3;
	NimStringV2 Field4;
	NimStringV2 Field5;
	NimStringV2 Field6;
	NimStringV2 Field7;
	NimStringV2 Field8;
	NimStringV2 Field9;
	NimStringV2 Field10;
	NimStringV2 Field11;
	NimStringV2 Field12;
	NimStringV2 Field13;
	NimStringV2 Field14;
	NimStringV2 Field15;
	NimStringV2 Field16;
	NimStringV2 Field17;
	NimStringV2 Field18;
	NimStringV2 Field19;
	NimStringV2 Field20;
	tySet_tyEnum_TInfoCCProp__iDs813gw4el4q2vkEYZ9cBw Field21;
};
typedef tyTuple__Sb9czl1rSUt9cR4FEpnHeteg tyArray__LheWFUTR89bV9bcpnmBZNQig[13];
struct tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww {
	NI depthLevel;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg symbols;
	tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww* parent;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA allowPrivateAccess;
	NI optionStackLen;
};
typedef NU8 tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ;
struct tyObject_HSlice__JgojxK65oMA6E0HRsL2Wig {
	NI a;
	NI b;
};
struct tySequence__ZUeR9b415wicThQ9cBWO9aYMw {
  NI len; tySequence__ZUeR9b415wicThQ9cBWO9aYMw_Content* p;
};
struct tyObject_TIdTable__xRBvhNSbEADzUTJAdtlGtA {
	NI counter;
	tySequence__ZUeR9b415wicThQ9cBWO9aYMw data;
};
struct tySequence__yo9alHJGzX03OXpfmEsBjBQ {
  NI len; tySequence__yo9alHJGzX03OXpfmEsBjBQ_Content* p;
};
struct tyObject_TProcCon__ftBtv4UEhPouLts4uXXNLQ {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* owner;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* resultSym;
	NI nestedLoopCounter;
	NI nestedBlockCounter;
	NIM_BOOL breakInLoop;
	tyObject_TProcCon__ftBtv4UEhPouLts4uXXNLQ* next;
	NIM_BOOL mappingExists;
	tyObject_TIdTable__xRBvhNSbEADzUTJAdtlGtA mapping;
	tySequence__yo9alHJGzX03OXpfmEsBjBQ caseContext;
	tySequence__9ahcSjIErJohSBBFLwuF56Q localBindStmts;
};
typedef NU8 tySet_tyEnum_TLookupFlag__l9bvZMRwOrEZawdhQi29c5PQ;
struct tySequence__9ahcSjIErJohSBBFLwuF56Q_Content { NI cap; tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* data[SEQ_DECL_SIZE]; };
typedef NU8 tyEnum_ImportMode__rHuf2PYQqUqEBlVu227wVQ;
struct tyObject_ImportedModule__NhRLdOPUbh9bmcDLjImMKWw {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* m;
	tyEnum_ImportMode__rHuf2PYQqUqEBlVu227wVQ mode;
union{
	struct {
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA imported;
} _mode_2;
	struct {
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA exceptSet;
} _mode_3;
};
};
struct tySequence__AE2UIxl7EbPzzBnmYsjIcw_Content { NI cap; tyObject_ImportedModule__NhRLdOPUbh9bmcDLjImMKWw data[SEQ_DECL_SIZE]; };
struct tySequence__ZCZaCk14bTmSb6LMW9aWPVA_Content { NI cap; tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* data[SEQ_DECL_SIZE]; };
struct tySequence__tsHRsYLyvTCPLlGRExqi7Q_Content { NI cap; tyObject_TOptionEntry__KeABxBvAlGa1KroFfkcqAg* data[SEQ_DECL_SIZE]; };
struct tySequence__lAikaRQvUF0uwNAz0U4FFA_Content { NI cap; tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig* data[SEQ_DECL_SIZE]; };
struct tySequence__7OXYQ6bHRkhJpRaiS7kiwQ {
  NI len; tySequence__7OXYQ6bHRkhJpRaiS7kiwQ_Content* p;
};
struct tyObject_TIdTable__XZ9cFaLoittQMULJSfBpHrA {
	NI counter;
	tySequence__7OXYQ6bHRkhJpRaiS7kiwQ data;
};
struct tyObject_LayeredIdTableObj__PbmRWgwPdgBZOtiSK65Q7A {
	tyObject_TIdTable__XZ9cFaLoittQMULJSfBpHrA topLayer;
	tyObject_LayeredIdTableObj__PbmRWgwPdgBZOtiSK65Q7A* nextLayer;
	NI previousLen;
};
struct tySequence__ZeWVlH6DqG79b1pTDhrrUYA_Content { NI cap; tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA* data[SEQ_DECL_SIZE]; };
struct tyObject_TInstantiationPair__bS87nlCVAcAYxO9aJequmYw {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* genericSym;
	tyObject_TInstantiation__jr8MibvPn2sQBnO7XCoZRQ* inst;
};
struct tySequence__4zAALtm0xUbRlYWQ2V8K7A_Content { NI cap; tyObject_TInstantiationPair__bS87nlCVAcAYxO9aJequmYw data[SEQ_DECL_SIZE]; };
struct tyTuple__09aD69az7aYn14Gt61AHvLIA {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* Field0;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA Field1;
};
struct tySequence__9bffTLF0HkxjFCzZL8og4GA_Content { NI cap; tyTuple__09aD69az7aYn14Gt61AHvLIA data[SEQ_DECL_SIZE]; };
struct tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ {
	NI Field0;
	NI Field1;
};
struct tyTuple__NAaJgGVgNmlGoqmiWxdOHQ {
	NI Field0;
	tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ Field1;
};
struct tySequence__Bis5AbpONWcIRrPyPJS8Yw_Content { NI cap; tyTuple__NAaJgGVgNmlGoqmiWxdOHQ data[SEQ_DECL_SIZE]; };
struct tyTuple__47w2DboNEPf69aPgubZdd7Q {
	NI Field0;
	NI Field1;
	NI Field2;
};
struct tySequence__E8pi9b5QNahsURYzXMjh3qw_Content { NI cap; tyTuple__47w2DboNEPf69aPgubZdd7Q data[SEQ_DECL_SIZE]; };
struct tySequence__KYLoGmc5aaHsSDjEH1FTxQ {
  NI len; tySequence__KYLoGmc5aaHsSDjEH1FTxQ_Content* p;
};
struct tyTuple__CH9a39cWKma9c9c9cYqCyX1wBsw {
	NI Field0;
	NI Field1;
	tySequence__KYLoGmc5aaHsSDjEH1FTxQ Field2;
};
struct tySequence__3B6hFqG0Do0FxDvnNucL7w_Content { NI cap; tyTuple__CH9a39cWKma9c9c9cYqCyX1wBsw data[SEQ_DECL_SIZE]; };
struct tySequence__qwqHTkRvwhrRyENtudHQ7g {
  NI len; tySequence__qwqHTkRvwhrRyENtudHQ7g_Content* p;
};
struct tyTuple__EbsafWGli8bW2GRJQ9apsjA {
	NI Field0;
	NI Field1;
	tySequence__qwqHTkRvwhrRyENtudHQ7g Field2;
};
struct tySequence__QqvaCqCpEE1QmQZbcZLi5A_Content { NI cap; tyTuple__EbsafWGli8bW2GRJQ9apsjA data[SEQ_DECL_SIZE]; };
struct tyObject_Iface__j1FkQxwEAKMJy1o9bap1xow {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module;
	tySequence__olFOFaYzOJN9aV5BWqK4b9bA converters;
	tySequence__olFOFaYzOJN9aV5BWqK4b9bA patterns;
	tySequence__olFOFaYzOJN9aV5BWqK4b9bA pureEnums;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg interf;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg interfHidden;
	NimStringV2 uniqueName;
};
struct tySequence__TfHJycarvNts8E4mVG4Mfg_Content { NI cap; tyObject_Iface__j1FkQxwEAKMJy1o9bap1xow data[SEQ_DECL_SIZE]; };
struct tySequence__5reviU45axUMPQgL9aoENrg_Content { NI cap; tyObject_LoadedModule__7NEKRkz5hkiOxQy5guqIHA data[SEQ_DECL_SIZE]; };
struct tySequence__dtr79aXjHrgHuH79ac55I2aw_Content { NI cap; tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ data[SEQ_DECL_SIZE]; };
struct tySequence__vb3AGHvMJTxdOSSwMmBmTQ {
  NI len; tySequence__vb3AGHvMJTxdOSSwMmBmTQ_Content* p;
};
struct tyTuple__7TXOq9czx9cn1FWKG5gXNK8Q {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tySequence__vb3AGHvMJTxdOSSwMmBmTQ Field2;
};
struct tySequence__8y0Gi4GwtXi2wk2mK1IOzw_Content { NI cap; tyTuple__7TXOq9czx9cn1FWKG5gXNK8Q data[SEQ_DECL_SIZE]; };
struct tySequence__apM9bRAO19cVjhWlxqd1PGeA {
  NI len; tySequence__apM9bRAO19cVjhWlxqd1PGeA_Content* p;
};
struct tyTuple__F1mMODXmKFMNQ5rLCtcv0Q {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tySequence__apM9bRAO19cVjhWlxqd1PGeA Field2;
};
struct tySequence__C2ivDnhTZ6IxAdui1rfuqw_Content { NI cap; tyTuple__F1mMODXmKFMNQ5rLCtcv0Q data[SEQ_DECL_SIZE]; };
struct tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig {
	NU32 module;
	NI32 item;
};
struct tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ {
	NI module;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig packed_0;
};
struct tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA {
	tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ id;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym;
};
struct tyTuple__vHfXSpEC1R9b9cKgfFB9a58gw {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA Field2;
};
struct tySequence__3vEEVfBECLN6NIRA3FIp5g_Content { NI cap; tyTuple__vHfXSpEC1R9b9cKgfFB9a58gw data[SEQ_DECL_SIZE]; };
struct tySequence__9bW2eTK9b7vXE70Sx5VPH1mw {
  NI len; tySequence__9bW2eTK9b7vXE70Sx5VPH1mw_Content* p;
};
struct tyTuple__4iq9bD09amB7Ah0r9cBB0nSPQ {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tySequence__9bW2eTK9b7vXE70Sx5VPH1mw Field2;
};
struct tySequence__9aSa87aKMiolq9a7z3kC0jTw_Content { NI cap; tyTuple__4iq9bD09amB7Ah0r9cBB0nSPQ data[SEQ_DECL_SIZE]; };
struct tyTuple__bnJwOH0eJlAwCAMbr1inhw {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA Field2;
};
struct tySequence__N589c2UsUgqqOITU2JfIuAQ_Content { NI cap; tyTuple__bnJwOH0eJlAwCAMbr1inhw data[SEQ_DECL_SIZE]; };
struct tyTuple__YG7h1OUHzgfgTeH9cl0U0dw {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* Field2;
};
struct tySequence__GYDW6wGgERshoSd16jJ3eQ_Content { NI cap; tyTuple__YG7h1OUHzgfgTeH9cl0U0dw data[SEQ_DECL_SIZE]; };
struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw {
	NI Field0;
	NimStringV2 Field1;
	NI32 Field2;
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw_Content { NI cap; tyTuple__xYhUhS7X82rKTqbT9bRfCnw data[SEQ_DECL_SIZE]; };
struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q {
	NI Field0;
	NI32 Field1;
	tySequence__48JTohSgTy339bRxHzUD8KA Field2;
};
struct tySequence__fdmz6VkIf1ewwrssKYqRFg_Content { NI cap; tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q data[SEQ_DECL_SIZE]; };
struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ {
	NI Field0;
	NI32 Field1;
	NI32 Field2;
};
struct tySequence__kxu4GK0onha2t9bo86mdVAg_Content { NI cap; tyTuple__xDU9bZmv1ZbZkJDaATBekIQ data[SEQ_DECL_SIZE]; };
struct tySequence__48JTohSgTy339bRxHzUD8KA_Content { NI cap; NI32 data[SEQ_DECL_SIZE]; };
struct tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg {
  NI len; tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg_Content* p;
};
struct tySequence__yUWoZehF86MIc40opFgacw {
  NI len; tySequence__yUWoZehF86MIc40opFgacw_Content* p;
};
struct tyObject_PackedBoolArray__1pk9boftqWMNDE1oh5HcIhw {
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA s;
	NI len;
};
struct tyObject_SuggestFileSymbolDatabase__o0ahEzaLn5a7TdNqH4OVqQ {
	tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg lineInfo;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA sym;
	tySequence__yUWoZehF86MIc40opFgacw caughtExceptions;
	tyObject_PackedBoolArray__1pk9boftqWMNDE1oh5HcIhw caughtExceptionsSet;
	tyObject_PackedBoolArray__1pk9boftqWMNDE1oh5HcIhw isDecl;
	tyObject_PackedBoolArray__1pk9boftqWMNDE1oh5HcIhw isGenericInstance;
	NI32 fileIndex;
	NIM_BOOL trackCaughtExceptions;
	NIM_BOOL isSorted;
};
struct tyTuple__tG5yYi8DnD7bl00aT9cgctQ {
	NI Field0;
	NI32 Field1;
	tyObject_SuggestFileSymbolDatabase__o0ahEzaLn5a7TdNqH4OVqQ Field2;
};
struct tySequence__fz0REU1l0nYmKHXgMLRrIg_Content { NI cap; tyTuple__tG5yYi8DnD7bl00aT9cgctQ data[SEQ_DECL_SIZE]; };
struct tySequence__nSO1ltijM4vhc0UrrXKEqA {
  NI len; tySequence__nSO1ltijM4vhc0UrrXKEqA_Content* p;
};
struct tyTuple__gnRkA1L4XiR4uByriyHW8Q {
	NI Field0;
	NI32 Field1;
	tySequence__nSO1ltijM4vhc0UrrXKEqA Field2;
};
struct tySequence__Ip9aV1IKO2gVdheNOM31DCQ_Content { NI cap; tyTuple__gnRkA1L4XiR4uByriyHW8Q data[SEQ_DECL_SIZE]; };
struct tyTuple__CvjVmQeIfivirDme2r5MRw {
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA Field0;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* Field1;
};
struct tySequence__kHjIdgrpmuSn9cUIIKpSiDg_Content { NI cap; tyTuple__CvjVmQeIfivirDme2r5MRw data[SEQ_DECL_SIZE]; };
struct tyTuple__2QDyOgS51ZMPO0W1pWCY6g {
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field0;
	NI Field1;
};
struct tySequence__Wd0Vle6gxRCPPoSlNEvfTA_Content { NI cap; tyTuple__2QDyOgS51ZMPO0W1pWCY6g data[SEQ_DECL_SIZE]; };
struct tySequence__juxPMVNF1FoR2ltzeQu8NQ {
  NI len; tySequence__juxPMVNF1FoR2ltzeQu8NQ_Content* p;
};
struct tyTuple__UbCNQED4XJUgxOgPHJUcAQ {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tySequence__juxPMVNF1FoR2ltzeQu8NQ Field2;
};
struct tySequence__T7nNEWoEbKBa0G5Htr45Xw_Content { NI cap; tyTuple__UbCNQED4XJUgxOgPHJUcAQ data[SEQ_DECL_SIZE]; };
struct tyTuple__zExIg9bDTcVf2FHROUpzoow {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tySequence__olFOFaYzOJN9aV5BWqK4b9bA Field2;
};
struct tySequence__q9cHvMDDxYU1hSCdG4YwIhA_Content { NI cap; tyTuple__zExIg9bDTcVf2FHROUpzoow data[SEQ_DECL_SIZE]; };
struct tySequence__olFOFaYzOJN9aV5BWqK4b9bA_Content { NI cap; tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA data[SEQ_DECL_SIZE]; };
typedef NU8 tyArray__dnD8kjh6rJ1Yy5jHvid0Ow[16];
struct tyTuple__XrHNJHOzS3O7uwF9bvCySiA {
	NI Field0;
	tyArray__dnD8kjh6rJ1Yy5jHvid0Ow Field1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* Field2;
};
struct tySequence__vJcM7B74R2U5db9cxyXT9coA_Content { NI cap; tyTuple__XrHNJHOzS3O7uwF9bvCySiA data[SEQ_DECL_SIZE]; };
struct tyTuple__EdLY4EJQ37VFgbAn5g5rXQ {
	NI Field0;
	NI Field1;
	tyArray__dnD8kjh6rJ1Yy5jHvid0Ow Field2;
};
struct tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg_Content { NI cap; tyTuple__EdLY4EJQ37VFgbAn5g5rXQ data[SEQ_DECL_SIZE]; };
struct tyTuple__OtlgAx3kBps9cOSMNDZSzBA {
	NI Field0;
	NimStringV2 Field1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* Field2;
};
struct tySequence__R9c39btP6BwOBBPnbaNUtMQg_Content { NI cap; tyTuple__OtlgAx3kBps9cOSMNDZSzBA data[SEQ_DECL_SIZE]; };
struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg {
	NI Field0;
	NimStringV2 Field1;
	NI64 Field2;
};
struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA_Content { NI cap; tyTuple__F3gkSrMB1qp2Tvf9bixVXwg data[SEQ_DECL_SIZE]; };
struct tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw {
	tyObject_NodecolonObjectType___U4ON6JZL9cIHezBQjmQzJ8Q* root;
	NI entries;
};
struct tyTuple__RFOJ4fF7D9bpvmh9birH1JhQ {
	NI Field0;
	NimStringV2 Field1;
	tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw Field2;
};
struct tySequence__3nALyQgqjnfK2Qjc6ny2Uw_Content { NI cap; tyTuple__RFOJ4fF7D9bpvmh9birH1JhQ data[SEQ_DECL_SIZE]; };
typedef N_NIMCALL_PTR(tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ*, tyProc__TVHQTM3bKm4Mi6Ul6zgzuQ) (tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module_p1, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p2);
typedef N_NIMCALL_PTR(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, tyProc__74nHWc2UIRu3iSR9akqDDBg) (tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* topLevelStmt_p1);
typedef N_NIMCALL_PTR(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, tyProc__S9bLWKf8jgjzoiotAmEyFSw) (tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ* p_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p2);
struct tyTuple__O3g9a8zTXSX36ljWponcAoA {
	tyProc__TVHQTM3bKm4Mi6Ul6zgzuQ Field0;
	tyProc__74nHWc2UIRu3iSR9akqDDBg Field1;
	tyProc__S9bLWKf8jgjzoiotAmEyFSw Field2;
	NIM_BOOL Field3;
};
struct tySequence__WbW5Q8QVks0bQpUJSGmuVg_Content { NI cap; tyTuple__O3g9a8zTXSX36ljWponcAoA data[SEQ_DECL_SIZE]; };
struct tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ {
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA Field0;
	NimStringV2 Field1;
};
struct tySequence__E0kio2ZnplNTuln9bsnljSA_Content { NI cap; tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ data[SEQ_DECL_SIZE]; };
struct tyObject_TFileInfo__xPdjmgevOVG8T0Aq8BK7jw {
	NimStringV2 fullPath;
	NimStringV2 projPath;
	NimStringV2 shortName;
	NimStringV2 quotedName;
	NimStringV2 quotedFullName;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ lines;
	NimStringV2 dirtyFile;
	NimStringV2 hash;
	NIM_BOOL dirty;
};
struct tySequence__hTEiKNj3evQAjIXUI21elA_Content { NI cap; tyObject_TFileInfo__xPdjmgevOVG8T0Aq8BK7jw data[SEQ_DECL_SIZE]; };
struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw {
	NI Field0;
	NimStringV2 Field1;
};
struct tySequence__4eRCaZmrYLLw2k30GPTiMw_Content { NI cap; tyTuple__QeWl6B6ffS4pU6WWrtcrDw data[SEQ_DECL_SIZE]; };
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content { NI cap; NimStringV2 data[SEQ_DECL_SIZE]; };
struct tySequence__xOJ2kx2lq9bBfIm3IXnde3Q_Content { NI cap; tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg data[SEQ_DECL_SIZE]; };
struct tySequence__d8ZV4IMgHt9biik9cS9a0hrmg_Content { NI cap; tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* data[SEQ_DECL_SIZE]; };
struct tyObject_StackTraceEntry__RcJz5RXFIYjIseutvVFICA {
	NCSTRING procname;
	NI line;
	NCSTRING filename;
};
struct tySequence__S89cE01OvNjsN9c71FKsSrqQ_Content { NI cap; tyObject_StackTraceEntry__RcJz5RXFIYjIseutvVFICA data[SEQ_DECL_SIZE]; };
struct tyTuple__UvldbCB6B9ayi9bGYW7vJNLA {
	NI Field0;
	NI32 Field1;
	NU32 Field2;
};
struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ_Content { NI cap; tyTuple__UvldbCB6B9ayi9bGYW7vJNLA data[SEQ_DECL_SIZE]; };
struct tyTuple__0q9cmhneJEKnQERTpXXdz6Q {
	NU32 Field0;
	NimStringV2 Field1;
};
struct tySequence__PXIzfWocnrafGz5p3CP5LA_Content { NI cap; tyTuple__0q9cmhneJEKnQERTpXXdz6Q data[SEQ_DECL_SIZE]; };
struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA_Content { NI cap; NU32 data[SEQ_DECL_SIZE]; };
struct tyObject_PackedNode__YxKk4C732K04CNgtMhmc0w {
	NU32 x;
	NU32 info;
};
struct tySequence__OxRbUT0qZaZN5UjnqQjGPA_Content { NI cap; tyObject_PackedNode__YxKk4C732K04CNgtMhmc0w data[SEQ_DECL_SIZE]; };
struct tyTuple__48iPM3yLBKU5nyEuYwJvuQ {
	NI32 Field0;
	tySet_tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw Field1;
};
struct tySequence__ezS5mGPcRfBURJyMgqYVzA_Content { NI cap; tyTuple__48iPM3yLBKU5nyEuYwJvuQ data[SEQ_DECL_SIZE]; };
struct tyTuple__R3ddFrA0G9buJY57Qhf9cTpg {
	NI32 Field0;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field1;
};
struct tySequence__wW7xkohjuUKO9aMaB0nt9cqA_Content { NI cap; tyTuple__R3ddFrA0G9buJY57Qhf9cTpg data[SEQ_DECL_SIZE]; };
struct tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ {
	NU32 Field0;
	NI32 Field1;
};
struct tySequence__b89aLriiJnVTD186H6zNIgg_Content { NI cap; tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ data[SEQ_DECL_SIZE]; };
struct tyTuple__7rmdAMLZ8fDd79brQn2ixZA {
	NU32 Field0;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field1;
};
struct tySequence__hIPTk9aFdaMMVAOzEbnPyqg_Content { NI cap; tyTuple__7rmdAMLZ8fDd79brQn2ixZA data[SEQ_DECL_SIZE]; };
struct tyTuple__qPXRCRNQuZLLKto7CIIEzw {
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field0;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field1;
};
struct tySequence__YYy1721YAuPF0ajBYHd8Wg_Content { NI cap; tyTuple__qPXRCRNQuZLLKto7CIIEzw data[SEQ_DECL_SIZE]; };
struct tyObject_PackedInstantiation__C3FSePJFY8gUIMObsjT2dg {
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig key;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig sym;
	tySequence__qBes3XzcQQ9cyia9bRwnmbJw concreteTypes;
};
struct tySequence__UODJbvzmu39c3Ho9cqhSk9agQ_Content { NI cap; tyObject_PackedInstantiation__C3FSePJFY8gUIMObsjT2dg data[SEQ_DECL_SIZE]; };
struct tyTuple__6kG8KAxm9aXPdLdlxcxqJJw {
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field0;
	tyEnum_TTypeAttachedOp__RefHoBI5deIfxIZqo3dS5Q Field1;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field2;
};
struct tySequence__F1qNdU7m0Czu7Y2q0eksXw_Content { NI cap; tyTuple__6kG8KAxm9aXPdLdlxcxqJJw data[SEQ_DECL_SIZE]; };
struct tyTuple__TRK7rrwoha9bbDAdPWsqJMw {
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field0;
	NI Field1;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field2;
};
struct tySequence__r3Kz9breImOXyFFoJ29aBM8Q_Content { NI cap; tyTuple__TRK7rrwoha9bbDAdPWsqJMw data[SEQ_DECL_SIZE]; };
struct tySequence__qBes3XzcQQ9cyia9bRwnmbJw_Content { NI cap; tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig data[SEQ_DECL_SIZE]; };
struct tyObject_PackedLib__EpwVLk0Fuc5Q9agKLMWedbg {
	tyEnum_TLibKind__BkKL8ReLoyYDI7of9aQPV0A kind;
	NIM_BOOL generated;
	NIM_BOOL isOverridden;
	NU32 name;
	NI32 path;
};
struct tyObject_PackedSym__KKnx6w8Cc9aaVsaPOpaqxbw {
	NI32 id;
	tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q kind;
	NU32 name;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig typ;
	tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg flags;
	tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg magic;
	NU32 info;
	NI32 ast;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig owner;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig guard;
	NI bitsize;
	NI alignment;
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ options;
	NI position;
	NI32 offset;
	NI32 disamb;
	NU32 externalName;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg locFlags;
	tyObject_PackedLib__EpwVLk0Fuc5Q9agKLMWedbg annex;
	NI32 constraint;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig instantiatedFrom;
};
struct tyTuple__V1VWX9bHapuzCjpMfFfys5Q {
	NI Field0;
	NI Field1;
	NI32 Field2;
	tyObject_PackedSym__KKnx6w8Cc9aaVsaPOpaqxbw Field3;
};
struct tySequence__Vl1abU3gfp0RqCb1KKfmDA_Content { NI cap; tyTuple__V1VWX9bHapuzCjpMfFfys5Q data[SEQ_DECL_SIZE]; };
struct tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ {
	NI32 id;
	tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg kind;
	tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ callConv;
	tySet_tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A flags;
	tySequence__qBes3XzcQQ9cyia9bRwnmbJw types;
	NI32 n;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig sym;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig owner;
	NI64 size;
	NI16 align;
	NI16 paddingAtEnd;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig typeInst;
	NI32 nonUniqueId;
};
struct tyTuple__anemVmHCFglLFt6LiEhFvg {
	NI Field0;
	NI Field1;
	NI32 Field2;
	tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ Field3;
};
struct tySequence__qyyNkmlc4fzOzelC8spUkQ_Content { NI cap; tyTuple__anemVmHCFglLFt6LiEhFvg data[SEQ_DECL_SIZE]; };
struct tySequence__IHUFRsFxZNv7YydiUO2esQ_Content { NI cap; NI64 data[SEQ_DECL_SIZE]; };
struct tyTuple__MaWaKZwaGUqCXKsSK12rVg {
	NU32 Field0;
	NI32 Field1;
	NI32 Field2;
};
struct tySequence__orxtl6CusdjXleqrxi67gw_Content { NI cap; tyTuple__MaWaKZwaGUqCXKsSK12rVg data[SEQ_DECL_SIZE]; };
struct tyTuple__nL9cBxaIV4ZA9b9ceY79coA5eA {
	NI Field0;
	NI Field1;
	NI32 Field2;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* Field3;
};
struct tySequence__K0j67V58u5FW0dCC534FQw_Content { NI cap; tyTuple__nL9cBxaIV4ZA9b9ceY79coA5eA data[SEQ_DECL_SIZE]; };
struct tyTuple__1xWeGeoNoZxaLhTUDDWYyA {
	NI Field0;
	NI Field1;
	NI32 Field2;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* Field3;
};
struct tySequence__UE4b6iUkm1b3zTPamTTkDw_Content { NI cap; tyTuple__1xWeGeoNoZxaLhTUDDWYyA data[SEQ_DECL_SIZE]; };
struct tyTuple__MZVSn3SE3XUBJOaMu7ofRQ {
	NI Field0;
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* Field1;
	tySequence__qBes3XzcQQ9cyia9bRwnmbJw Field2;
};
struct tySequence__FmsTQiIcS9arxHxs3QY48vA_Content { NI cap; tyTuple__MZVSn3SE3XUBJOaMu7ofRQ data[SEQ_DECL_SIZE]; };
struct tyObject_TIdPair__03S6SAVUgd0pzOKFuxkR1A {
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* val;
};
struct tySequence__ZUeR9b415wicThQ9cBWO9aYMw_Content { NI cap; tyObject_TIdPair__03S6SAVUgd0pzOKFuxkR1A data[SEQ_DECL_SIZE]; };
struct tyTuple__R9cYIordoMujN7rycr4Y7kw {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* Field0;
	NI Field1;
};
struct tySequence__yo9alHJGzX03OXpfmEsBjBQ_Content { NI cap; tyTuple__R9cYIordoMujN7rycr4Y7kw data[SEQ_DECL_SIZE]; };
struct tyObject_TIdPair__jFcUgE4X1tLOqan9b4YIIeg {
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* val;
};
struct tySequence__7OXYQ6bHRkhJpRaiS7kiwQ_Content { NI cap; tyObject_TIdPair__jFcUgE4X1tLOqan9b4YIIeg data[SEQ_DECL_SIZE]; };
struct tyTuple__ZUrTP7BFWWFkSv3xO9crp9aQ {
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA Field0;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* Field1;
};
struct tySequence__KYLoGmc5aaHsSDjEH1FTxQ_Content { NI cap; tyTuple__ZUrTP7BFWWFkSv3xO9crp9aQ data[SEQ_DECL_SIZE]; };
struct tySequence__qwqHTkRvwhrRyENtudHQ7g_Content { NI cap; NI data[SEQ_DECL_SIZE]; };
struct tyObject_LazyType__dsEGDq9cOhnzsRvTUTwwwuA {
	tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ id;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ;
};
struct tySequence__vb3AGHvMJTxdOSSwMmBmTQ_Content { NI cap; tyObject_LazyType__dsEGDq9cOhnzsRvTUTwwwuA data[SEQ_DECL_SIZE]; };
struct tySequence__YxH9cgSorHRI8ZPzHf47NNQ {
  NI len; tySequence__YxH9cgSorHRI8ZPzHf47NNQ_Content* p;
};
struct tyObject_LazyInstantiation__n72c7MnOoHWBy9c9akgwGqEA {
	NI module;
	tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ sym;
	tySequence__YxH9cgSorHRI8ZPzHf47NNQ concreteTypes;
	tyObject_TInstantiation__jr8MibvPn2sQBnO7XCoZRQ* inst;
};
struct tySequence__apM9bRAO19cVjhWlxqd1PGeA_Content { NI cap; tyObject_LazyInstantiation__n72c7MnOoHWBy9c9akgwGqEA data[SEQ_DECL_SIZE]; };
struct tyTuple__lGHLhAAUpxgfrnQkIzNrMw {
	NI Field0;
	tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA Field1;
};
struct tySequence__9bW2eTK9b7vXE70Sx5VPH1mw_Content { NI cap; tyTuple__lGHLhAAUpxgfrnQkIzNrMw data[SEQ_DECL_SIZE]; };
struct tyObject_TinyLineInfo__qW2GTIPjeOQ42q9c2MPWLLA {
	NU16 line;
	NI16 col;
};
struct tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg_Content { NI cap; tyObject_TinyLineInfo__qW2GTIPjeOQ42q9c2MPWLLA data[SEQ_DECL_SIZE]; };
struct tySequence__yUWoZehF86MIc40opFgacw_Content { NI cap; tySequence__d8ZV4IMgHt9biik9cS9a0hrmg data[SEQ_DECL_SIZE]; };
struct tySequence__nSO1ltijM4vhc0UrrXKEqA_Content { NI cap; tyObject_SuggestcolonObjectType___UyASNXAqAMRY5zJmcRD9ccA* data[SEQ_DECL_SIZE]; };
struct tyTuple__V6P73hvHy70PBBwharKjig {
	NI Field0;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* Field1;
};
struct tySequence__juxPMVNF1FoR2ltzeQu8NQ_Content { NI cap; tyTuple__V6P73hvHy70PBBwharKjig data[SEQ_DECL_SIZE]; };
struct tySequence__YxH9cgSorHRI8ZPzHf47NNQ_Content { NI cap; tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ data[SEQ_DECL_SIZE]; };
N_LIB_PRIVATE N_NIMCALL(void, pragmaRec__pragmas_u2509)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p2, tySet_tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw validPragmas_p3, NIM_BOOL isStatement_p4);
static N_INLINE(NI, len__ast_u3190)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, singlePragma__pragmas_u1506)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p2, NI* i_p3, tySet_tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw validPragmas_p4, NIM_BOOL comesFromPush_p5, NIM_BOOL isStatement_p6);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___ast_u3255)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** dest_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* src_p1);
N_LIB_PRIVATE N_NIMCALL(void, processNote__pragmas_u654)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw, whichKeyword__idents_u360)(tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* id_p0);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA, findStr__commands_u346)(NimStringV2 s_p2, tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA default_p3);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u3252)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, invalidPragma__pragmas_u142)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
N_LIB_PRIVATE N_NOINLINE(void, liMessage__msgs_u1227)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA msg_p2, NimStringV2 arg_p3, tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w eh_p4, tyTuple__kN8up2W6YKc5YA9avn5mV5w* info2_p5, NIM_BOOL isRaw_p6, NIM_BOOL ignoreError_p7);
static N_INLINE(void, appendString)(NimStringV2* dest_p0, NimStringV2 src_p1);
static N_INLINE(void, copyMem__system_u1742)(void* dest_p0, void* source_p1, NI size_p2);
static N_INLINE(void, nimCopyMem)(void* dest_p0, void* source_p1, NI size_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, renderTree__renderer_u59)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0, tySet_tyEnum_TRenderFlag__Il2q467fyuki59ci9aspexFg renderFlags_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, rawNewString)(NI space_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___system_u2691)(NimStringV2 dest_p0);
static N_INLINE(NIM_BOOL*, nimErrorFlag)(void);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA, findStr__commands_u377)(NimStringV2 s_p2, tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA default_p3);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u4574)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___idents_u155)(tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw, whichPragma__trees_u218)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0);
N_LIB_PRIVATE N_NIMCALL(void, pragmaRaisesOrTags__pragmas_u1305)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
N_LIB_PRIVATE N_NIMCALL(void, processExc__pragmas_u1308)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* x_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___ast_u3387)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg** dest_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* src_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, makeTypeFromExpr__semdata_u4430)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u3378)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, skipTypes__ast_u5379)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p0, tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg kinds_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___ast_u3375)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg** dest_p0);
static N_INLINE(NI, safeLen__ast_u3197)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___ast_u3261)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** dest_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* src_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, semCustomPragma__pragmas_u1430)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_p2);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, newTree__ast_u4170)(tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw kind_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** children_p1, NI children_p1Len_0);
static N_INLINE(void, nimZeroMem)(void* p_p0, NI size_p1);
static N_INLINE(void, nimSetMem__system_u2172)(void* a_p0, int v_p1, NI size_p2);
N_LIB_PRIVATE N_NIMCALL(void, illegalCustomPragma__pragmas_u145)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p2);
N_LIB_PRIVATE N_NIMCALL(void, prepareAdd)(NimStringV2* s_p0, NI addLen_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___ast_u309)(tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q e_p0);
N_LIB_PRIVATE N_NIMCALL(void, transitionSonsKind__ast_u6769)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0, tyEnum_TNodeKind__fgQOep3rrztw9aeZI9aS2Ltg kind_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA*, considerQuotedIdent__lookups_u31)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* origin_p2);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, strTableGet__astalgo_u2726)(tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg t_p0, tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* name_p1);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, belongsToProjectPackageMaybeNil__packages_u85)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, getModule__modulegraphs_u14809)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, NI32 fileIdx_p1);
N_LIB_PRIVATE N_NIMCALL(void, styleCheckUseImpl__linter_u198)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p2);
N_LIB_PRIVATE N_NIMCALL(void, pragma__pragmas_u120)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p2, tySet_tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw validPragmas_p3, NIM_BOOL isStatement_p4, NIM_BOOL comesFromPush_p5);
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___pragmas_u1583)(tySequence__9ahcSjIErJohSBBFLwuF56Q* s_p0, tyObject_HSlice__OAVyDXS0QPw7LdXClfU2hA x_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** b_p2, NI b_p2Len_0);
static N_INLINE(tyObject_HSlice__OAVyDXS0QPw7LdXClfU2hA, dotdot___stdZstrbasics_u49)(NI a_p0, NI b_p1);
N_LIB_PRIVATE N_NIMCALL(void, checkPragmaUseImpl__linter_u241)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw w_p2, NimStringV2 pragmaName_p3);
N_LIB_PRIVATE N_NIMCALL(void, makeExternExport__pragmas_u215)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1, NimStringV2 extname_p2, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p3);
N_LIB_PRIVATE N_NIMCALL(void, setExternName__pragmas_u193)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1, NimStringV2 extname_p2, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p3);
static N_INLINE(NIM_BOOL, eqStrings)(NimStringV2 a_p0, NimStringV2 b_p1);
static N_INLINE(NIM_BOOL, equalMem__system_u1750)(void* a_p0, void* b_p1, NI size_p2);
static N_INLINE(int, nimCmpMem)(void* a_p0, void* b_p1, NI size_p2);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___system_u2694)(NimStringV2* dest_p0, NimStringV2 src_p1);
static N_INLINE(NIM_BOOL, contains__stdZprivateZospaths2_u383)(NIM_CHAR* a_p0, NI a_p0Len_0, NIM_CHAR item_p1);
static N_INLINE(NI, find__stdZprivateZospaths2_u388)(NIM_CHAR* a_p0, NI a_p0Len_0, NIM_CHAR item_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___system_u2700)(NimStringV2* dest_p0, NimStringV2 src_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nsuFormatSingleElem)(NimStringV2 formatstr_p0, NimStringV2 a_p1);
static N_INLINE(NIM_BOOL, isObjDisplayCheck)(TNimTypeV2* source_p0, NI16 targetDepth_p1, NU32 token_p2);
static N_INLINE(Exception*, nimBorrowCurrentException)(void);
static N_INLINE(void, popCurrentException)(void);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___system_u3661)(Exception** dest_p0, Exception* src_p1, NIM_BOOL cyclic_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getOptionalStr__pragmas_u322)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, NimStringV2 defaultStr_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, expectStrLit__pragmas_u308)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, getStrLitNode__pragmas_u298)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
N_LIB_PRIVATE N_NOINLINE(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, newEmptyStrNode__pragmas_u293)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, NimStringV2 strVal_p2);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, newNodeIT__ast_u4112)(tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw kind_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p2);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, getSysType__magicsys_u55)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg kind_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___options_u144)(tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw e_p0);
N_LIB_PRIVATE N_NIMCALL(void, cppDefine__options_u2159)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* c_p0, NimStringV2 define_p1);
N_LIB_PRIVATE N_NIMCALL(void, recordPragma__pragmas_u127)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, NimStringV2* args_p2, NI args_p2Len_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, newNodeI__ast_u4091)(tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw kind_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1);
N_LIB_PRIVATE N_NIMCALL(void, add__ast_u3215)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* father_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* son_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, newStrNode__ast_u5426)(NimStringV2 strVal_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1);
N_LIB_PRIVATE N_NIMCALL(void, addPragmaComputation__semdata_u4254)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
N_LIB_PRIVATE N_NIMCALL(void, makeExternImport__pragmas_u202)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1, NimStringV2 extname_p2, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p3);
N_LIB_PRIVATE N_NIMCALL(void, processImportCompilerProc__pragmas_u224)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1, NimStringV2 extname_p2, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p3);
N_LIB_PRIVATE N_NIMCALL(void, processImportCpp__pragmas_u241)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1, NimStringV2 extname_p2, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p3);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, getModule__astalgo_u156)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, contains__pureZstrutils_u1837)(NimStringV2 s_p0, tySet_tyChar__nmiMWKVIe46vacnhAFrQvw chars_p1);
N_LIB_PRIVATE N_NIMCALL(void, processImportObjC__pragmas_u271)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1, NimStringV2 extname_p2, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p3);
N_LIB_PRIVATE N_NIMCALL(NI, expectIntLit__pragmas_u312)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
N_LIB_PRIVATE N_NIMCALL(void, setImportedTypeSize__types_u3415)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p1, NI size_p2);
N_LIB_PRIVATE N_NIMCALL(NI16, floatInt64Align__options_u4319)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isPowerOfTwo__pureZmath_u253)(NI x_p0);
N_LIB_PRIVATE N_NIMCALL(void, noVal__pragmas_u1152)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
N_LIB_PRIVATE N_NIMCALL(void, processEffectsOf__pragmas_u1467)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* owner_p2);
N_LIB_PRIVATE N_NIMCALL(void*, nimNewObj)(NI size_p0, NI alignment_p1);
N_LIB_PRIVATE N_NIMCALL(void, rttiDestroy__pragmas_u2696)(void* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___pragmas_u2625)(tyObject_Env_pragmasdotnim_processEffectsOf___441zjIQZOyCLH68Plk1FJQ* dest_p0);
static N_INLINE(NIM_BOOL, nimDecRefIsLastDyn)(void* p_p0);
static N_INLINE(NI, minuspercent___system_u805)(NI x_p0, NI y_p1);
N_LIB_PRIVATE N_NIMCALL(void, unregisterCycle__system_u3127)(tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* s_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u3469)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, nimRawDispose)(void* p_p0, NI alignment_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___ast_u4577)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg** dest_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* src_p1);
N_LIB_PRIVATE N_CLOSURE(void, processParam__pragmas_u1471)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, void* ClE_0);
static N_INLINE(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, owner__ast_u6254)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___pragmas_u2656)(tyObject_Env_pragmasdotnim_processEffectsOf___441zjIQZOyCLH68Plk1FJQ* dest_p0);
static N_INLINE(NIM_BOOL, nimDecRefIsLastCyclicStatic)(void* p_p0, TNimTypeV2* desc_p1);
N_LIB_PRIVATE N_NOINLINE(void, rememberCycle__system_u3497)(NIM_BOOL isDestroyAction_p0, tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* s_p1, TNimTypeV2* desc_p2);
static N_INLINE(void, warningDeprecated__msgs_u1572)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, NimStringV2 msg_p2);
N_LIB_PRIVATE N_NIMCALL(void, pragmaNoForward__pragmas_u441)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg flag_p2);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isTurnedOn__pragmas_u411)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
N_LIB_PRIVATE N_NIMCALL(void, processMagic__pragmas_u353)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, substr__system_u8664)(NimStringV2 s_p0, NI first_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___ast_u606)(tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg e_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig*, getLib__pragmas_u511)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyEnum_TLibKind__BkKL8ReLoyYDI7of9aQPV0A kind_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* path_p2);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, exprStructuralEquivalent__trees_u63)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* b_p1, NIM_BOOL strictSymEquality_p2);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___ast_u6219)(tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig** dest_p0, tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig* src_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig*, newLib__semdata_u4362)(tyEnum_TLibKind__BkKL8ReLoyYDI7of9aQPV0A kind_p0);
N_LIB_PRIVATE N_NIMCALL(void, add__pragmas_u541)(tySequence__lAikaRQvUF0uwNAz0U4FFA* x_p0, tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig* y_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig*, eqdup___ast_u6222)(tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig* src_p0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isDynlibOverride__options_u4266)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 lib_p1);
N_LIB_PRIVATE N_NIMCALL(void, addToLib__semdata_u4365)(tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig* lib_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u6216)(tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig* dest_p0);
static N_INLINE(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, returnType__ast_u5354)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* n_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___ast_u3381)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg** dest_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* src_p1);
N_LIB_PRIVATE N_NIMCALL(void, processDynLib__pragmas_u612)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_p2);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, expectDynlibNode__pragmas_u584)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___ast_u6225)(tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig** dest_p0, tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig* src_p1);
static N_INLINE(tyObject_TOptionEntry__KeABxBvAlGa1KroFfkcqAg**, X5BX5D___semdata_u454)(tyObject_TOptionEntry__KeABxBvAlGa1KroFfkcqAg** s_p0, NI s_p0Len_0, NI i_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___ast_u6213)(tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig** dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, markCompilerProc__pragmas_u1366)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1);
N_LIB_PRIVATE N_NIMCALL(void, registerCompilerProc__magicsys_u159)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1);
N_LIB_PRIVATE N_NIMCALL(void, addCompilerProc__icZic_u3303)(tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ* c_p0, tyObject_PackedModule__sRHd9aQ2ZMII76xRsfAbE9aQ* m_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p2);
N_LIB_PRIVATE N_NIMCALL(void, deprecatedStmt__pragmas_u1385)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* outerPragma_p1);
N_LIB_PRIVATE N_NIMCALL(void, typeBorrow__pragmas_u1349)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p2);
static N_INLINE(NIM_BOOL, isRoutine__ast_u7152)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p0);
N_LIB_PRIVATE N_NIMCALL(void, processDefine__pragmas_u1009)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_p2);
N_LIB_PRIVATE N_NIMCALL(void, processDefineConst__pragmas_u1000)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_p2, tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg kind_p3);
N_LIB_PRIVATE N_NIMCALL(void, defineSymbol__condsyms_u4)(tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* symbols_p0, NimStringV2 symbol_p1, NimStringV2 value_p2);
N_LIB_PRIVATE N_NIMCALL(void, processUndef__pragmas_u1029)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
N_LIB_PRIVATE N_NIMCALL(void, undefSymbol__condsyms_u8)(tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* symbols_p0, NimStringV2 symbol_p1);
N_LIB_PRIVATE N_NIMCALL(void, processCompile__pragmas_u1049)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
N_LIB_PRIVATE N_NIMCALL(void, rttiDestroy__pragmas_u2843)(void* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___pragmas_u2760)(tyObject_Env_pragmasdotnim_processCompile___dWXVdC0mxyRcA9cJsc1PdqQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u3270)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getStrLit__pragmas_u1059)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, NI i_p2);
static N_INLINE(NimStringV2, slash___stdZprivateZospaths2_u91)(NimStringV2 head_p0, NimStringV2 tail_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nosjoinPath)(NimStringV2 head_p0, NimStringV2 tail_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nosparentDir)(NimStringV2 path_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, toFullPath__msgs_u624)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NI32 fileIdx_p1);
static N_INLINE(NCSTRING, nimToCStringConv)(NimStringV2 s_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, cstrToNimstr)(NCSTRING str_p0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, nosfileExists)(NimStringV2 filename_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, completeCfilePath__extccomp_u929)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 cfile_p1, NIM_BOOL createSubDir_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nosextractFilename)(NimStringV2 path_p0);
N_LIB_PRIVATE N_CLOSURE(void, docompile__pragmas_u1052)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* it_p1, NimStringV2 src_p2, NimStringV2 dest_p3, NimStringV2 customArgs_p4, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, eqdup___system_u2697)(NimStringV2 src_p0);
N_LIB_PRIVATE N_NIMCALL(void, splitFile__pathutils_u39)(NimStringV2 x_p0, tyTuple__7q7q3E6Oj24ZNVJb9aonhAg* Result);
N_LIB_PRIVATE N_NIMCALL(void, addExternalFileToCompile__extccomp_u1334)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg* c_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___pathutils_u73)(tyTuple__7q7q3E6Oj24ZNVJb9aonhAg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___options_u1619)(tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, nosisAbsolute)(NimStringV2 path_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___system_u2688)(NimStringV2* dest_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, findFile__options_u4081)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 f_p1, NIM_BOOL suppressStdlib_p2);
static N_INLINE(NIM_BOOL, isEmpty__options_u4086)(NimStringV2 x_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, mangleModuleName__modulepaths_u40)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 path_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, toObjFile__extccomp_u934)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 filename_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___pragmas_u2791)(tyObject_Env_pragmasdotnim_processCompile___dWXVdC0mxyRcA9cJsc1PdqQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, processLink__pragmas_u1092)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, relativeFile__pragmas_u1040)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, NimStringV2 ext_p2);
N_LIB_PRIVATE N_NIMCALL(void, nossplitFile)(NimStringV2 path_p0, tyTuple__7q7q3E6Oj24ZNVJb9aonhAg* Result);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nosaddFileExt)(NimStringV2 filename_p0, NimStringV2 ext_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___pureZos_u200)(tyTuple__7q7q3E6Oj24ZNVJb9aonhAg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, addExternalFileToLink__extccomp_u977)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 filename_p1);
N_LIB_PRIVATE N_NIMCALL(void, addLinkOption__extccomp_u906)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 option_p1);
N_LIB_PRIVATE N_NIMCALL(void, addCompileOption__extccomp_u909)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 option_p1);
N_LIB_PRIVATE N_NIMCALL(void, appendToModule__ast_u4652)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* m_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
N_LIB_PRIVATE N_NIMCALL(void, addLocalCompileOption__extccomp_u961)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 option_p1, NimStringV2 nimfile_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, toFullPathConsiderDirty__msgs_u657)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NI32 fileIdx_p1);
N_LIB_PRIVATE N_NIMCALL(void, processPush__pragmas_u969)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, NI start_p2);
N_LIB_PRIVATE N_NIMCALL(tyObject_TOptionEntry__KeABxBvAlGa1KroFfkcqAg*, pushOptionEntry__semdata_u2309)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, tryProcessOption__pragmas_u886)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ* resOptions_p2);
N_LIB_PRIVATE N_NIMCALL(void, processExperimental__pragmas_u842)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
N_LIB_PRIVATE N_NIMCALL(tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ, parseEnum__commands_u900)(NimStringV2 s_p0);
static N_INLINE(NIM_BOOL, isTopLevel__semdata_u4679)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0);
static N_INLINE(tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ, pragmaToOptions__pragmas_u839)(tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw w_p0);
N_LIB_PRIVATE N_NIMCALL(void, onOff__pragmas_u426)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ op_p2, tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ* resOptions_p3);
N_LIB_PRIVATE N_NIMCALL(void, processCallConv__pragmas_u495)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ, wordToCallConv__pragmas_u398)(tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw sw_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nsuNormalize)(NimStringV2 s_p0);
N_LIB_PRIVATE N_NIMCALL(void, checkPushedPragma__pragmas_u945)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___semdata_u611)(tyObject_TOptionEntry__KeABxBvAlGa1KroFfkcqAg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, processPop__pragmas_u994)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
N_LIB_PRIVATE N_NIMCALL(void, popOptionEntry__semdata_u2337)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0);
N_LIB_PRIVATE N_NIMCALL(void, processPragma__pragmas_u1199)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, NI i_p2);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u3696)(tySequence__9ahcSjIErJohSBBFLwuF56Q dest_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, newSym__ast_u4205)(tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q symKind_p0, tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* name_p1, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p2, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* owner_p3, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p4, tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ options_p5);
N_LIB_PRIVATE N_NIMCALL(void, nep1CheckDefImpl__linter_u146)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p2, tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q k_p3);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, newTreeI__ast_u4180)(tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw kind_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** children_p2, NI children_p2Len_0);
N_LIB_PRIVATE N_NIMCALL(tySequence__9ahcSjIErJohSBBFLwuF56Q, X5BX5D___pragmas_u1282)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** s_p0, NI s_p0Len_0, tyObject_HSlice__JgojxK65oMA6E0HRsL2Wig x_p1);
static N_INLINE(tyObject_HSlice__JgojxK65oMA6E0HRsL2Wig, dotdot___stdZenumutils_u106)(NI a_p0, NI b_p1);
N_LIB_PRIVATE N_NIMCALL(void, strTableAdd__astalgo_u2666)(tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg* t_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* n_p1);
N_LIB_PRIVATE N_NIMCALL(void, processCodegenDecl__pragmas_u345)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_p2);
N_LIB_PRIVATE N_NIMCALL(void, processOption__pragmas_u941)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ* resOptions_p2);
N_LIB_PRIVATE N_NIMCALL(void, pragmaEmit__pragmas_u1130)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, newNodeI__ast_u4095)(tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw kind_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, NI children_p2);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, semAsmOrEmit__pragmas_u1096)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* con_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, NIM_CHAR marker_p2);
N_LIB_PRIVATE N_NIMCALL(NI, nsuFindChar)(NimStringV2 s_p0, NIM_CHAR sub_p1, NI start_p2, NI last_p3);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, substr__system_u8651)(NimStringV2 s_p0, NI first_p1, NI last_p2);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, newStrNode__ast_u5422)(tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw kind_p0, NimStringV2 strVal_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, searchInScopes__lookups_u2425)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* s_p1, NIM_BOOL* ambiguous_p2);
N_LIB_PRIVATE N_NIMCALL(tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA*, getIdent__idents_u206)(tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* ic_p0, NimStringV2 identifier_p1);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isDefined__options_u959)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 symbol_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, newSymNode__ast_u5168)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nimCharToStr)(NIM_CHAR x_p0);
N_LIB_PRIVATE N_NIMCALL(void, illFormedAstLocal__semdata_u4668)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p1);
N_LIB_PRIVATE N_NIMCALL(void, pragmaUnroll__pragmas_u1159)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
static N_INLINE(NIM_BOOL, ltpercent___system_u1092)(NI x_p0, NI y_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, newIntNode__ast_u5200)(tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw kind_p0, NI64 intVal_p1);
N_LIB_PRIVATE N_NIMCALL(void, pragmaLine__pragmas_u1167)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
N_LIB_PRIVATE N_NIMCALL(NI32, fileInfoIdx__msgs_u404)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 filename_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA, getInfoContext__msgs_u602)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NI index_p1);
N_LIB_PRIVATE N_NIMCALL(void, pragmaLockStmt__pragmas_u1330)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* it_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___ast_u4583)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg** dest_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* src_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, pragmaGuard__pragmas_u1401)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* it_p1, tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q kind_p2);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, qualifiedLookUp__lookups_u5229)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tySet_tyEnum_TLookupFlag__l9bvZMRwOrEZawdhQi29c5PQ flags_p2);
N_LIB_PRIVATE N_NIMCALL(void, registerNimScriptSymbol__magicsys_u162)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1);
N_LIB_PRIVATE N_NIMCALL(void, pragmaProposition__pragmas_u157)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
N_LIB_PRIVATE N_NIMCALL(void, pragmaEnsures__pragmas_u166)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww*, openScope__lookups_u65)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, getCurrOwner__semdata_u425)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0);
static N_INLINE(void, addDecl__lookups_u3789)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_p1);
static N_INLINE(void, addDeclAt__lookups_u3781)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww* scope_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_p2);
N_LIB_PRIVATE N_NIMCALL(void, addDeclAt__lookups_u3253)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww* scope_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_p2, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p3);
N_LIB_PRIVATE N_NIMCALL(void, closeScope__lookups_u102)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___lookups_u74)(tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, processVirtual__pragmas_u331)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p2, tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg flag_p3);
N_LIB_PRIVATE N_NIMCALL(void, implicitPragmas__pragmas_u2378)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_p1, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p2, tySet_tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw validPragmas_p3);
N_LIB_PRIVATE N_NIMCALL(void, pushInfoContext__msgs_u569)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, NimStringV2 detail_p2);
N_LIB_PRIVATE N_NIMCALL(void, internalErrorImpl__msgs_u1598)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, NimStringV2 errMsg_p2, tyTuple__kN8up2W6YKc5YA9avn5mV5w* info2_p3);
N_LIB_PRIVATE N_NIMCALL(void, popInfoContext__msgs_u593)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0);
N_LIB_PRIVATE N_NIMCALL(void, mergeValidPragmas__pragmas_u2363)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* pragmas_p1, tySet_tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw validPragmas_p2);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, copyTree__ast_u6891)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* src_p0);
N_LIB_PRIVATE N_NIMCALL(void, overwriteLineInfo__pragmas_u2346)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___ast_u3249)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** dest_p0);
static N_INLINE(NIM_BOOL, contains__stdZenumutils_u51)(NimStringV2* a_p0, NI a_p0Len_0, NimStringV2 item_p1);
static N_INLINE(NI, find__stdZenumutils_u56)(NimStringV2* a_p0, NI a_p0Len_0, NimStringV2 item_p1);
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__tPA3StZ6VsKyoznyrIfFxg_2 = { 16 | NIM_STRLIT_FLAG, "invalid pragma: " };
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_3 = {16, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_2};
static const struct {
  NI cap; NIM_CHAR data[62+1];
} TM__tPA3StZ6VsKyoznyrIfFxg_5 = { 62 | NIM_STRLIT_FLAG, "/home/runner/work/nightlies/nightlies/nim/compiler/pragmas.nim" };
static const struct {
  NI cap; NIM_CHAR data[32+1];
} TM__tPA3StZ6VsKyoznyrIfFxg_6 = { 32 | NIM_STRLIT_FLAG, "a \'cast\' pragma cannot be pushed" };
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_7 = {32, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_6};
static const struct {
  NI cap; NIM_CHAR data[49+1];
} TM__tPA3StZ6VsKyoznyrIfFxg_9 = { 49 | NIM_STRLIT_FLAG, "\'cast\' pragma only allowed in a statement context" };
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_10 = {49, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_9};
static NIM_CONST tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg TM__tPA3StZ6VsKyoznyrIfFxg_13 = {
0x10, 0x09, 0xe0, 0x00, 0x00, 0xe0, 0x80, 0x00,
0x00}
;
static const struct {
  NI cap; NIM_CHAR data[33+1];
} TM__tPA3StZ6VsKyoznyrIfFxg_14 = { 33 | NIM_STRLIT_FLAG, "invalid type for raises/tags list" };
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_15 = {33, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_14};
static const struct {
  NI cap; NIM_CHAR data[34+1];
} TM__tPA3StZ6VsKyoznyrIfFxg_17 = { 34 | NIM_STRLIT_FLAG, "cannot attach a custom pragma to \'" };
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_18 = {34, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_17};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__tPA3StZ6VsKyoznyrIfFxg_19 = { 1 | NIM_STRLIT_FLAG, "\'" };
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_20 = {1, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_19};
static const struct {
  NI cap; NIM_CHAR data[39+1];
} TM__tPA3StZ6VsKyoznyrIfFxg_21 = { 39 | NIM_STRLIT_FLAG, "; custom pragmas are not supported for " };
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_22 = {39, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_21};
static const struct {
  NI cap; NIM_CHAR data[20+1];
} TM__tPA3StZ6VsKyoznyrIfFxg_23 = { 20 | NIM_STRLIT_FLAG, "`for` loop variables" };
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_24 = {20, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_23};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__tPA3StZ6VsKyoznyrIfFxg_25 = { 11 | NIM_STRLIT_FLAG, "enum fields" };
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_26 = {11, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_25};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__tPA3StZ6VsKyoznyrIfFxg_27 = { 7 | NIM_STRLIT_FLAG, "modules" };
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_28 = {7, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_27};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__tPA3StZ6VsKyoznyrIfFxg_29 = { 12 | NIM_STRLIT_FLAG, "symbol kind " };
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_30 = {12, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_29};
static const struct {
  NI cap; NIM_CHAR data[22+1];
} TM__tPA3StZ6VsKyoznyrIfFxg_32 = { 22 | NIM_STRLIT_FLAG, "recursive dependency: " };
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_33 = {22, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_32};
static const struct {
  NI cap; NIM_CHAR data[33+1];
} TM__tPA3StZ6VsKyoznyrIfFxg_35 = { 33 | NIM_STRLIT_FLAG, "user pragma cannot have arguments" };
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_36 = {33, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_35};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__tPA3StZ6VsKyoznyrIfFxg_38 = { 2 | NIM_STRLIT_FLAG, "$1" };
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_39 = {2, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_38};
static const struct {
  NI cap; NIM_CHAR data[22+1];
} TM__tPA3StZ6VsKyoznyrIfFxg_40 = { 22 | NIM_STRLIT_FLAG, "invalid extern name: \'" };
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_41 = {22, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_40};
static const struct {
  NI cap; NIM_CHAR data[26+1];
} TM__tPA3StZ6VsKyoznyrIfFxg_42 = { 26 | NIM_STRLIT_FLAG, "\'. (Forgot to escape \'$\'\?)" };
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_43 = {26, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_42};
static const struct {
  NI cap; NIM_CHAR data[23+1];
} TM__tPA3StZ6VsKyoznyrIfFxg_45 = { 23 | NIM_STRLIT_FLAG, "string literal expected" };
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_46 = {23, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_45};
static const struct {
  NI cap; NIM_CHAR data[0+1];
} TM__tPA3StZ6VsKyoznyrIfFxg_48 = { 0 | NIM_STRLIT_FLAG, "" };
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_49 = {0, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_48};
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_50 = {23, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_45};
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_52 = {0, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_48};
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_53 = {2, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_38};
static const struct {
  NI cap; NIM_CHAR data[39+1];
} TM__tPA3StZ6VsKyoznyrIfFxg_54 = { 39 | NIM_STRLIT_FLAG, "exportcpp requires `cpp` backend, got: " };
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_55 = {39, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_54};
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_57 = {2, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_38};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__tPA3StZ6VsKyoznyrIfFxg_58 = { 9 | NIM_STRLIT_FLAG, "cppdefine" };
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_59 = {9, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_58};
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_60 = {2, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_38};
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_61 = {9, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_58};
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_62 = {2, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_38};
static const struct {
  NI cap; NIM_CHAR data[48+1];
} TM__tPA3StZ6VsKyoznyrIfFxg_63 = { 48 | NIM_STRLIT_FLAG, "`importjs` pragma requires the JavaScript target" };
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_64 = {48, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_63};
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_66 = {2, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_38};
static NIM_CONST tySet_tyChar__nmiMWKVIe46vacnhAFrQvw TM__tPA3StZ6VsKyoznyrIfFxg_67 = {
0x00, 0x00, 0x00, 0x00, 0x08, 0x01, 0x00, 0x00,
0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00}
;
static const struct {
  NI cap; NIM_CHAR data[42+1];
} TM__tPA3StZ6VsKyoznyrIfFxg_68 = { 42 | NIM_STRLIT_FLAG, "`importjs` for routines requires a pattern" };
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_69 = {42, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_68};
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_71 = {2, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_38};
static const struct {
  NI cap; NIM_CHAR data[24+1];
} TM__tPA3StZ6VsKyoznyrIfFxg_72 = { 24 | NIM_STRLIT_FLAG, "integer literal expected" };
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_73 = {24, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_72};
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_75 = {24, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_72};
static const struct {
  NI cap; NIM_CHAR data[29+1];
} TM__tPA3StZ6VsKyoznyrIfFxg_77 = { 29 | NIM_STRLIT_FLAG, "size may only be 1, 2, 4 or 8" };
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_78 = {29, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_77};
static const struct {
  NI cap; NIM_CHAR data[21+1];
} TM__tPA3StZ6VsKyoznyrIfFxg_80 = { 21 | NIM_STRLIT_FLAG, "power of two expected" };
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_81 = {21, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_80};
N_LIB_PRIVATE TNimTypeV2 NTIv2__441zjIQZOyCLH68Plk1FJQ_;
static const struct {
  NI cap; NIM_CHAR data[23+1];
} TM__tPA3StZ6VsKyoznyrIfFxg_84 = { 23 | NIM_STRLIT_FLAG, "parameter name expected" };
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_85 = {23, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_84};
static const struct {
  NI cap; NIM_CHAR data[42+1];
} TM__tPA3StZ6VsKyoznyrIfFxg_87 = { 42 | NIM_STRLIT_FLAG, "parameter cannot be declared as .effectsOf" };
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_88 = {42, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_87};
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_90 = {23, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_84};
static const struct {
  NI cap; NIM_CHAR data[59+1];
} TM__tPA3StZ6VsKyoznyrIfFxg_95 = { 59 | NIM_STRLIT_FLAG, "/home/runner/work/nightlies/nightlies/nim/compiler/msgs.nim" };
static const struct {
  NI cap; NIM_CHAR data[48+1];
} TM__tPA3StZ6VsKyoznyrIfFxg_96 = { 48 | NIM_STRLIT_FLAG, "\'{.deadcodeelim: on.}\' is deprecated, now a noop" };
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_97 = {48, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_96};
static const struct {
  NI cap; NIM_CHAR data[22+1];
} TM__tPA3StZ6VsKyoznyrIfFxg_98 = { 22 | NIM_STRLIT_FLAG, "\'on\' or \'off\' expected" };
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_99 = {22, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_98};
static const struct {
  NI cap; NIM_CHAR data[48+1];
} TM__tPA3StZ6VsKyoznyrIfFxg_101 = { 48 | NIM_STRLIT_FLAG, "use {.experimental: \"codeReordering\".} instead; " };
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_102 = {48, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_101};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__tPA3StZ6VsKyoznyrIfFxg_103 = { 13 | NIM_STRLIT_FLAG, "{.noForward.}" };
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_104 = {13, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_103};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__tPA3StZ6VsKyoznyrIfFxg_105 = { 11 | NIM_STRLIT_FLAG, "{.reorder.}" };
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_106 = {11, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_105};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__tPA3StZ6VsKyoznyrIfFxg_107 = { 14 | NIM_STRLIT_FLAG, " is deprecated" };
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_108 = {14, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_107};
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_110 = {23, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_45};
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_113 = {0, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_48};
static const struct {
  NI cap; NIM_CHAR data[38+1];
} TM__tPA3StZ6VsKyoznyrIfFxg_114 = { 38 | NIM_STRLIT_FLAG, ".noreturn with return type not allowed" };
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_115 = {38, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_114};
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_117 = {23, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_45};
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_119 = {0, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_48};
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_120 = {23, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_45};
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_122 = {0, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_48};
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_123 = {9, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_58};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__tPA3StZ6VsKyoznyrIfFxg_124 = { 7 | NIM_STRLIT_FLAG, "FlowVar" };
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_125 = {7, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_124};
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_126 = {2, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_38};
static const struct {
  NI cap; NIM_CHAR data[43+1];
} TM__tPA3StZ6VsKyoznyrIfFxg_127 = { 43 | NIM_STRLIT_FLAG, "annotation to deprecated not supported here" };
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_128 = {43, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_127};
static const struct {
  NI cap; NIM_CHAR data[32+1];
} TM__tPA3StZ6VsKyoznyrIfFxg_130 = { 32 | NIM_STRLIT_FLAG, "list of key:value pairs expected" };
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_131 = {32, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_130};
static const struct {
  NI cap; NIM_CHAR data[66+1];
} TM__tPA3StZ6VsKyoznyrIfFxg_133 = { 66 | NIM_STRLIT_FLAG, "deprecated statement is now a no-op, use regular deprecated pragma" };
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_134 = {66, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_133};
static const struct {
  NI cap; NIM_CHAR data[34+1];
} TM__tPA3StZ6VsKyoznyrIfFxg_136 = { 34 | NIM_STRLIT_FLAG, "a type can only borrow `.` for now" };
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_137 = {34, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_136};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__tPA3StZ6VsKyoznyrIfFxg_139 = { 4 | NIM_STRLIT_FLAG, "hint" };
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_140 = {4, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_139};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__tPA3StZ6VsKyoznyrIfFxg_142 = { 7 | NIM_STRLIT_FLAG, "warning" };
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_143 = {7, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_142};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__tPA3StZ6VsKyoznyrIfFxg_145 = { 5 | NIM_STRLIT_FLAG, "error" };
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_146 = {5, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_145};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__tPA3StZ6VsKyoznyrIfFxg_149 = { 4 | NIM_STRLIT_FLAG, "true" };
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_150 = {4, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_149};
N_LIB_PRIVATE TNimTypeV2 NTIv2__dWXVdC0mxyRcA9cJsc1PdqQ_;
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_152 = {23, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_45};
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_154 = {0, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_48};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__tPA3StZ6VsKyoznyrIfFxg_155 = { 13 | NIM_STRLIT_FLAG, "cannot find: " };
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_156 = {13, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_155};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__tPA3StZ6VsKyoznyrIfFxg_158 = { 7 | NIM_STRLIT_FLAG, "compile" };
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_159 = {7, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_158};
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_160 = {0, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_48};
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_162 = {0, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_48};
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_163 = {0, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_48};
static const struct {
  NI cap; NIM_CHAR data[38+1];
} TM__tPA3StZ6VsKyoznyrIfFxg_164 = { 38 | NIM_STRLIT_FLAG, "\'.compile\' pragma takes up 2 arguments" };
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_165 = {38, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_164};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__tPA3StZ6VsKyoznyrIfFxg_168 = { 4 | NIM_STRLIT_FLAG, "link" };
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_169 = {4, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_168};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__tPA3StZ6VsKyoznyrIfFxg_170 = { 5 | NIM_STRLIT_FLAG, "passl" };
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_171 = {5, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_170};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__tPA3StZ6VsKyoznyrIfFxg_172 = { 5 | NIM_STRLIT_FLAG, "passc" };
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_173 = {5, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_172};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__tPA3StZ6VsKyoznyrIfFxg_174 = { 10 | NIM_STRLIT_FLAG, "localpassl" };
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_175 = {10, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_174};
static const struct {
  NI cap; NIM_CHAR data[28+1];
} TM__tPA3StZ6VsKyoznyrIfFxg_176 = { 28 | NIM_STRLIT_FLAG, "\'push\' cannot have arguments" };
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_177 = {28, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_176};
static const struct {
  NI cap; NIM_CHAR data[58+1];
} TM__tPA3StZ6VsKyoznyrIfFxg_179 = { 58 | NIM_STRLIT_FLAG, "Code reordering experimental pragma only valid at toplevel" };
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_180 = {58, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_179};
static const struct {
  NI cap; NIM_CHAR data[28+1];
} TM__tPA3StZ6VsKyoznyrIfFxg_182 = { 28 | NIM_STRLIT_FLAG, "unknown experimental feature" };
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_183 = {28, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_182};
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_185 = {23, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_45};
static const struct {
  NI cap; NIM_CHAR data[27+1];
} TM__tPA3StZ6VsKyoznyrIfFxg_187 = { 27 | NIM_STRLIT_FLAG, "calling convention expected" };
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_188 = {27, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_187};
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_190 = {27, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_187};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__tPA3StZ6VsKyoznyrIfFxg_192 = { 5 | NIM_STRLIT_FLAG, "speed" };
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_193 = {5, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_192};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__tPA3StZ6VsKyoznyrIfFxg_194 = { 4 | NIM_STRLIT_FLAG, "size" };
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_195 = {4, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_194};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__tPA3StZ6VsKyoznyrIfFxg_196 = { 4 | NIM_STRLIT_FLAG, "none" };
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_197 = {4, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_196};
static const struct {
  NI cap; NIM_CHAR data[34+1];
} TM__tPA3StZ6VsKyoznyrIfFxg_198 = { 34 | NIM_STRLIT_FLAG, "\'none\', \'speed\' or \'size\' expected" };
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_199 = {34, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_198};
static const struct {
  NI cap; NIM_CHAR data[33+1];
} TM__tPA3StZ6VsKyoznyrIfFxg_201 = { 33 | NIM_STRLIT_FLAG, "an \'emit\' pragma cannot be pushed" };
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_202 = {33, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_201};
static const struct {
  NI cap; NIM_CHAR data[40+1];
} TM__tPA3StZ6VsKyoznyrIfFxg_204 = { 40 | NIM_STRLIT_FLAG, "{.pop.} without a corresponding {.push.}" };
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_205 = {40, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_204};
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__tPA3StZ6VsKyoznyrIfFxg_207 = { 15 | NIM_STRLIT_FLAG, "option expected" };
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_208 = {15, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_207};
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_210 = {23, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_45};
static const struct {
  NI cap; NIM_CHAR data[21+1];
} TM__tPA3StZ6VsKyoznyrIfFxg_212 = { 21 | NIM_STRLIT_FLAG, "empty \'asm\' statement" };
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_213 = {21, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_212};
static const struct {
  NI cap; NIM_CHAR data[22+1];
} TM__tPA3StZ6VsKyoznyrIfFxg_215 = { 22 | NIM_STRLIT_FLAG, "nimPreviewAsmSemSymbol" };
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_216 = {22, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_215};
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_217 = {23, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_45};
static const struct {
  NI cap; NIM_CHAR data[46+1];
} TM__tPA3StZ6VsKyoznyrIfFxg_219 = { 46 | NIM_STRLIT_FLAG, "`{.union.}` is not implemented for js backend." };
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_220 = {46, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_219};
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_222 = {23, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_45};
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_224 = {24, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_72};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__tPA3StZ6VsKyoznyrIfFxg_226 = { 14 | NIM_STRLIT_FLAG, "tuple expected" };
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_227 = {14, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_226};
static const struct {
  NI cap; NIM_CHAR data[40+1];
} TM__tPA3StZ6VsKyoznyrIfFxg_229 = { 40 | NIM_STRLIT_FLAG, "locks pragma takes a list of expressions" };
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_230 = {40, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_229};
static const struct {
  NI cap; NIM_CHAR data[40+1];
} TM__tPA3StZ6VsKyoznyrIfFxg_232 = { 40 | NIM_STRLIT_FLAG, "\'Lock levels\' are deprecated, now a noop" };
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_233 = {40, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_232};
static const struct {
  NI cap; NIM_CHAR data[28+1];
} TM__tPA3StZ6VsKyoznyrIfFxg_234 = { 28 | NIM_STRLIT_FLAG, "bitsize needs to be positive" };
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_235 = {28, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_234};
static const struct {
  NI cap; NIM_CHAR data[81+1];
} TM__tPA3StZ6VsKyoznyrIfFxg_237 = { 81 | NIM_STRLIT_FLAG, "\'experimental\' pragma only valid as toplevel statement or in a \'push\' environment" };
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_238 = {81, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_237};
static const struct {
  NI cap; NIM_CHAR data[50+1];
} TM__tPA3StZ6VsKyoznyrIfFxg_240 = { 50 | NIM_STRLIT_FLAG, "\"doctype\" pragma only valid as top-level statement" };
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_241 = {50, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_240};
static const struct {
  NI cap; NIM_CHAR data[20+1];
} TM__tPA3StZ6VsKyoznyrIfFxg_243 = { 20 | NIM_STRLIT_FLAG, "proposition expected" };
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_244 = {20, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_243};
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_246 = {20, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_243};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__tPA3StZ6VsKyoznyrIfFxg_248 = { 6 | NIM_STRLIT_FLAG, "result" };
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_249 = {6, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_248};
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_250 = {2, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_38};
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_251 = {0, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_48};
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__tPA3StZ6VsKyoznyrIfFxg_252 = { 15 | NIM_STRLIT_FLAG, "implicitPragmas" };
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_253 = {15, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_252};
static const struct {
  NI cap; NIM_CHAR data[25+1];
} TM__tPA3StZ6VsKyoznyrIfFxg_255 = { 25 | NIM_STRLIT_FLAG, ".dynlib requires .exportc" };
static const NimStringV2 TM__tPA3StZ6VsKyoznyrIfFxg_256 = {25, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_255};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__tPA3StZ6VsKyoznyrIfFxg_259 = { 3 | NIM_STRLIT_FLAG, "gcc" };
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__tPA3StZ6VsKyoznyrIfFxg_260 = { 3 | NIM_STRLIT_FLAG, "vcc" };
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_4 = {{62, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_5},
((NI)123),
((NI)12)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_8 = {{62, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_5},
((NI)872),
((NI)16)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_11 = {{62, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_5},
((NI)874),
((NI)16)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_16 = {{62, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_5},
((NI)732),
((NI)18)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_31 = {{62, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_5},
((NI)134),
((NI)12)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_34 = {{62, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_5},
((NI)891),
((NI)17)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_37 = {{62, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_5},
((NI)894),
((NI)16)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_44 = {{62, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_5},
((NI)166),
((NI)16)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_47 = {{62, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_5},
((NI)210),
((NI)14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_51 = {{62, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_5},
((NI)218),
((NI)16)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_56 = {{62, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_5},
((NI)908),
((NI)22)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_65 = {{62, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_5},
((NI)938),
((NI)20)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_70 = {{62, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_5},
((NI)943),
((NI)20)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_74 = {{62, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_5},
((NI)228),
((NI)14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_76 = {{62, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_5},
((NI)233),
((NI)20)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_79 = {{62, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_5},
((NI)962),
((NI)22)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_82 = {{62, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_5},
((NI)968),
((NI)20)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_86 = {{62, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_5},
((NI)852),
((NI)14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_89 = {{62, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_5},
((NI)847),
((NI)18)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_91 = {{62, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_5},
((NI)849),
((NI)16)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_94 = {{59, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_95},
((NI)629),
((NI)9)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_100 = {{62, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_5},
((NI)277),
((NI)12)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_109 = {{62, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_5},
((NI)292),
((NI)9)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_111 = {{62, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_5},
((NI)255),
((NI)14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_112 = {{62, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_5},
((NI)264),
((NI)30)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_116 = {{62, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_5},
((NI)1040),
((NI)20)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_118 = {{62, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_5},
((NI)337),
((NI)14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_121 = {{62, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_5},
((NI)347),
((NI)16)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_129 = {{62, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_5},
((NI)1069),
((NI)22)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_132 = {{62, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_5},
((NI)780),
((NI)14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_135 = {{62, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_5},
((NI)781),
((NI)9)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_138 = {{62, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_5},
((NI)759),
((NI)16)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_141 = {{62, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_5},
((NI)1132),
((NI)15)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_144 = {{62, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_5},
((NI)1136),
((NI)15)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_147 = {{62, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_5},
((NI)1149),
((NI)20)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_148 = {{62, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_5},
((NI)1150),
((NI)22)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_153 = {{62, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_5},
((NI)577),
((NI)16)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_157 = {{62, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_5},
((NI)563),
((NI)16)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_166 = {{62, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_5},
((NI)596),
((NI)18)}
;
extern NIM_CONST tyArray__LheWFUTR89bV9bcpnmBZNQig CC__extccomp_u624;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_178 = {{62, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_5},
((NI)497),
((NI)14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_181 = {{62, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_5},
((NI)436),
((NI)24)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_184 = {{62, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_5},
((NI)440),
((NI)18)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_186 = {{62, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_5},
((NI)442),
((NI)16)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_189 = {{62, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_5},
((NI)320),
((NI)20)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_191 = {{62, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_5},
((NI)322),
((NI)14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_200 = {{62, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_5},
((NI)475),
((NI)26)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_203 = {{62, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_5},
((NI)493),
((NI)18)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_206 = {{62, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_5},
((NI)516),
((NI)14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_209 = {{62, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_5},
((NI)481),
((NI)14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_211 = {{62, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_5},
((NI)658),
((NI)14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_214 = {{62, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_5},
((NI)622),
((NI)16)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_218 = {{62, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_5},
((NI)672),
((NI)18)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_221 = {{62, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_5},
((NI)1234),
((NI)20)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_223 = {{62, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_5},
((NI)698),
((NI)18)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_225 = {{62, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_5},
((NI)700),
((NI)18)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_228 = {{62, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_5},
((NI)705),
((NI)16)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_231 = {{62, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_5},
((NI)750),
((NI)16)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_236 = {{62, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_5},
((NI)1283),
((NI)22)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_239 = {{62, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_5},
((NI)1299),
((NI)20)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_242 = {{62, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_5},
((NI)1303),
((NI)20)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_245 = {{62, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_5},
((NI)138),
((NI)14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_247 = {{62, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_5},
((NI)144),
((NI)14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_254 = {{62, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_5},
((NI)1378),
((NI)25)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_257 = {{62, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_5},
((NI)1385),
((NI)16)}
;
static NIM_CONST tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ TM__tPA3StZ6VsKyoznyrIfFxg_258 = {{3, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_259},
{3, (NimStrPayload*)&TM__tPA3StZ6VsKyoznyrIfFxg_260}}
;
extern NIM_BOOL nimInErrorMode__system_u4143;
extern Exception* currException__system_u3628;
static NIM_CONST NU32 TM__tPA3StZ6VsKyoznyrIfFxg_83[2] = {3701606400, 2373159936};
N_LIB_PRIVATE TNimTypeV2 NTIv2__441zjIQZOyCLH68Plk1FJQ_ = {.destructor = (void*)rttiDestroy__pragmas_u2696, .size = sizeof(tyObject_Env_pragmasdotnim_processEffectsOf___441zjIQZOyCLH68Plk1FJQ), .align = (NI16) NIM_ALIGNOF(tyObject_Env_pragmasdotnim_processEffectsOf___441zjIQZOyCLH68Plk1FJQ), .depth = 1, .display = TM__tPA3StZ6VsKyoznyrIfFxg_83, .traceImpl = (void*)NIM_NIL, .flags = 0};
static NIM_CONST NU32 TM__tPA3StZ6VsKyoznyrIfFxg_151[2] = {3701606400, 1708487680};
N_LIB_PRIVATE TNimTypeV2 NTIv2__dWXVdC0mxyRcA9cJsc1PdqQ_ = {.destructor = (void*)rttiDestroy__pragmas_u2843, .size = sizeof(tyObject_Env_pragmasdotnim_processCompile___dWXVdC0mxyRcA9cJsc1PdqQ), .align = (NI16) NIM_ALIGNOF(tyObject_Env_pragmasdotnim_processCompile___dWXVdC0mxyRcA9cJsc1PdqQ), .depth = 1, .display = TM__tPA3StZ6VsKyoznyrIfFxg_151, .traceImpl = (void*)NIM_NIL, .flags = 0};
static N_INLINE(NI, len__ast_u3190)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0) {
	NI result;
	NI T1_;
	T1_ = (*n_p0)._kind_6.sons.len;
	result = T1_;
	return result;
}
static N_INLINE(void, nimCopyMem)(void* dest_p0, void* source_p1, NI size_p2) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest_p0, source_p1, ((size_t) (size_p2)));
}
static N_INLINE(void, copyMem__system_u1742)(void* dest_p0, void* source_p1, NI size_p2) {
	nimCopyMem(dest_p0, source_p1, size_p2);
}
static N_INLINE(void, appendString)(NimStringV2* dest_p0, NimStringV2 src_p1) {
	{
		if (!(((NI)0) < src_p1.len)) goto LA3_;
		copyMem__system_u1742(((void*) ((&(*(*dest_p0).p).data[(*dest_p0).len]))), ((void*) ((&(*src_p1.p).data[((NI)0)]))), (src_p1.len));
		(*dest_p0).len += src_p1.len;
		(*(*dest_p0).p).data[(*dest_p0).len] = 0;
	}
LA3_: ;
}
static N_INLINE(NIM_BOOL*, nimErrorFlag)(void) {
	NIM_BOOL* result;
	result = (&nimInErrorMode__system_u4143);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, invalidPragma__pragmas_u142)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
	NimStringV2 colontmpD_;
	NimStringV2 colontmpD__2;
	NimStringV2 T2_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	T2_.len = 0; T2_.p = NIM_NIL;
	colontmpD_ = renderTree__renderer_u59(n_p1, 4);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T2_ = rawNewString(colontmpD_.len + 16);
appendString((&T2_), TM__tPA3StZ6VsKyoznyrIfFxg_3);
appendString((&T2_), colontmpD_);
	colontmpD__2 = T2_;
	liMessage__msgs_u1227((*(*c_p0).graph).config, (*n_p1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), colontmpD__2, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__tPA3StZ6VsKyoznyrIfFxg_4), NIM_FALSE, NIM_FALSE);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(colontmpD_);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, processNote__pragmas_u654)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NIM_BOOL T3_;
		NIM_BOOL T4_;
		NIM_BOOL T5_;
		NIM_BOOL T6_;
		NIM_BOOL T7_;
		NI T9_;
		NI T12_;
		tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw nk_1;
		tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw T17_;
		T3_ = (NIM_BOOL)0;
		T4_ = (NIM_BOOL)0;
		T5_ = (NIM_BOOL)0;
		T6_ = (NIM_BOOL)0;
		T7_ = (NIM_BOOL)0;
		T7_ = ((*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)34) || (*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)27) || (*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)28));
		if (!(T7_)) goto LA8_;
		T9_ = (NI)0;
		T9_ = len__ast_u3190(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T7_ = (T9_ == ((NI)2));
LA8_: ;
		T6_ = T7_;
		if (!(T6_)) goto LA10_;
		T6_ = ((*(*n_p1)._kind_6.sons.p->data[((NI)0)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)42));
LA10_: ;
		T5_ = T6_;
		if (!(T5_)) goto LA11_;
		T12_ = (NI)0;
		T12_ = len__ast_u3190((*n_p1)._kind_6.sons.p->data[((NI)0)]);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T5_ = (T12_ == ((NI)2));
LA11_: ;
		T4_ = T5_;
		if (!(T4_)) goto LA13_;
		T4_ = ((*(*(*n_p1)._kind_6.sons.p->data[((NI)0)])._kind_6.sons.p->data[((NI)1)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)2));
LA13_: ;
		T3_ = T4_;
		if (!(T3_)) goto LA14_;
		T3_ = ((*(*(*n_p1)._kind_6.sons.p->data[((NI)0)])._kind_6.sons.p->data[((NI)0)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)2));
LA14_: ;
		if (!T3_) goto LA15_;
		nk_1 = ((tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw)20);
		T17_ = (tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)0;
		T17_ = whichKeyword__idents_u360((*(*(*n_p1)._kind_6.sons.p->data[((NI)0)])._kind_6.sons.p->data[((NI)0)])._kind_5.ident);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		switch (T17_) {
		case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)125):
		{
			tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA xX60gensym135__1;
			xX60gensym135__1 = findStr__commands_u346((*(*(*(*n_p1)._kind_6.sons.p->data[((NI)0)])._kind_6.sons.p->data[((NI)1)])._kind_5.ident).s, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)0));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			{
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* xX60gensym135__2;
				if (!!((xX60gensym135__1 == ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)0)))) goto LA21_;
				xX60gensym135__2 = NIM_NIL;
				nk_1 = (xX60gensym135__1);
				xX60gensym135__2 = (*c_p0).semConstBoolExpr(c_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)]);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				eqcopy___ast_u3255(&(*n_p1)._kind_6.sons.p->data[((NI)1)], xX60gensym135__2);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				{
					NIM_BOOL T25_;
					T25_ = (NIM_BOOL)0;
					T25_ = ((*xX60gensym135__2).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)6));
					if (!(T25_)) goto LA26_;
					T25_ = !(((*xX60gensym135__2)._kind_1.intVal == IL64(0)));
LA26_: ;
					if (!T25_) goto LA27_;
					(*(*(*c_p0).graph).config).notes[(NU)((nk_1 - 20))>>3] |=(1U<<((nk_1 - 20)&7U));
				}
				goto LA23_;
LA27_: ;
				{
					(*(*(*c_p0).graph).config).notes[(NU)((nk_1 - 20))>>3] &= ~(1U<<((nk_1 - 20)&7U));
				}
LA23_: ;
				eqdestroy___ast_u3252(xX60gensym135__2);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			}
			goto LA19_;
LA21_: ;
			{
				invalidPragma__pragmas_u142(c_p0, n_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			}
LA19_: ;
		}
		break;
		case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)124):
		{
			tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA xX60gensym144__1;
			xX60gensym144__1 = findStr__commands_u377((*(*(*(*n_p1)._kind_6.sons.p->data[((NI)0)])._kind_6.sons.p->data[((NI)1)])._kind_5.ident).s, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)0));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			{
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* xX60gensym144__2;
				if (!!((xX60gensym144__1 == ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)0)))) goto LA34_;
				xX60gensym144__2 = NIM_NIL;
				nk_1 = (xX60gensym144__1);
				xX60gensym144__2 = (*c_p0).semConstBoolExpr(c_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)]);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				eqcopy___ast_u3255(&(*n_p1)._kind_6.sons.p->data[((NI)1)], xX60gensym144__2);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				{
					NIM_BOOL T38_;
					T38_ = (NIM_BOOL)0;
					T38_ = ((*xX60gensym144__2).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)6));
					if (!(T38_)) goto LA39_;
					T38_ = !(((*xX60gensym144__2)._kind_1.intVal == IL64(0)));
LA39_: ;
					if (!T38_) goto LA40_;
					(*(*(*c_p0).graph).config).notes[(NU)((nk_1 - 20))>>3] |=(1U<<((nk_1 - 20)&7U));
				}
				goto LA36_;
LA40_: ;
				{
					(*(*(*c_p0).graph).config).notes[(NU)((nk_1 - 20))>>3] &= ~(1U<<((nk_1 - 20)&7U));
				}
LA36_: ;
				eqdestroy___ast_u3252(xX60gensym144__2);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			}
			goto LA32_;
LA34_: ;
			{
				invalidPragma__pragmas_u142(c_p0, n_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			}
LA32_: ;
		}
		break;
		case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)126):
		{
			tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA xX60gensym153__1;
			xX60gensym153__1 = findStr__commands_u377((*(*(*(*n_p1)._kind_6.sons.p->data[((NI)0)])._kind_6.sons.p->data[((NI)1)])._kind_5.ident).s, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)0));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			{
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* xX60gensym153__2;
				if (!!((xX60gensym153__1 == ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)0)))) goto LA47_;
				xX60gensym153__2 = NIM_NIL;
				nk_1 = (xX60gensym153__1);
				xX60gensym153__2 = (*c_p0).semConstBoolExpr(c_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)]);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				eqcopy___ast_u3255(&(*n_p1)._kind_6.sons.p->data[((NI)1)], xX60gensym153__2);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				{
					NIM_BOOL T51_;
					T51_ = (NIM_BOOL)0;
					T51_ = ((*xX60gensym153__2).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)6));
					if (!(T51_)) goto LA52_;
					T51_ = !(((*xX60gensym153__2)._kind_1.intVal == IL64(0)));
LA52_: ;
					if (!T51_) goto LA53_;
					(*(*(*c_p0).graph).config).warningAsErrors[(NU)((nk_1 - 20))>>3] |=(1U<<((nk_1 - 20)&7U));
				}
				goto LA49_;
LA53_: ;
				{
					(*(*(*c_p0).graph).config).warningAsErrors[(NU)((nk_1 - 20))>>3] &= ~(1U<<((nk_1 - 20)&7U));
				}
LA49_: ;
				eqdestroy___ast_u3252(xX60gensym153__2);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			}
			goto LA45_;
LA47_: ;
			{
				invalidPragma__pragmas_u142(c_p0, n_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			}
LA45_: ;
		}
		break;
		case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)127):
		{
			tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA xX60gensym162__1;
			xX60gensym162__1 = findStr__commands_u346((*(*(*(*n_p1)._kind_6.sons.p->data[((NI)0)])._kind_6.sons.p->data[((NI)1)])._kind_5.ident).s, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)0));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			{
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* xX60gensym162__2;
				if (!!((xX60gensym162__1 == ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)0)))) goto LA60_;
				xX60gensym162__2 = NIM_NIL;
				nk_1 = (xX60gensym162__1);
				xX60gensym162__2 = (*c_p0).semConstBoolExpr(c_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)]);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				eqcopy___ast_u3255(&(*n_p1)._kind_6.sons.p->data[((NI)1)], xX60gensym162__2);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				{
					NIM_BOOL T64_;
					T64_ = (NIM_BOOL)0;
					T64_ = ((*xX60gensym162__2).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)6));
					if (!(T64_)) goto LA65_;
					T64_ = !(((*xX60gensym162__2)._kind_1.intVal == IL64(0)));
LA65_: ;
					if (!T64_) goto LA66_;
					(*(*(*c_p0).graph).config).warningAsErrors[(NU)((nk_1 - 20))>>3] |=(1U<<((nk_1 - 20)&7U));
				}
				goto LA62_;
LA66_: ;
				{
					(*(*(*c_p0).graph).config).warningAsErrors[(NU)((nk_1 - 20))>>3] &= ~(1U<<((nk_1 - 20)&7U));
				}
LA62_: ;
				eqdestroy___ast_u3252(xX60gensym162__2);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			}
			goto LA58_;
LA60_: ;
			{
				invalidPragma__pragmas_u142(c_p0, n_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			}
LA58_: ;
		}
		break;
		default:
		{
			invalidPragma__pragmas_u142(c_p0, n_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		break;
		}
	}
	goto LA1_;
LA15_: ;
	{
		invalidPragma__pragmas_u142(c_p0, n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, processExc__pragmas_u1308)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* x_p1) {
NIM_BOOL oldNimErrFin8_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NIM_BOOL T3_;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* T6_;
		T3_ = (NIM_BOOL)0;
		T3_ = (*c_p0).hasUnresolvedArgs.ClE_0? (*c_p0).hasUnresolvedArgs.ClP_0(c_p0, x_p1, (*c_p0).hasUnresolvedArgs.ClE_0):((TM__tPA3StZ6VsKyoznyrIfFxg_12)((*c_p0).hasUnresolvedArgs.ClP_0))(c_p0, x_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!T3_) goto LA4_;
		T6_ = NIM_NIL;
		T6_ = makeTypeFromExpr__semdata_u4430(c_p0, x_p1);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3378(T6_); goto BeforeRet_;}
		eqsink___ast_u3387(&(*x_p1).typField, T6_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA4_: ;
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_1;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
		t_1 = NIM_NIL;
		colontmpD_ = NIM_NIL;
		colontmpD_ = (*c_p0).semTypeNode(c_p0, x_p1, ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL));
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		t_1 = skipTypes__ast_u5379(colontmpD_, TM__tPA3StZ6VsKyoznyrIfFxg_13);
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		{
			if (!!(((*t_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)17) || (*t_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)57)))) goto LA11_;
			liMessage__msgs_u1227((*(*c_p0).graph).config, (*x_p1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), TM__tPA3StZ6VsKyoznyrIfFxg_15, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__tPA3StZ6VsKyoznyrIfFxg_16), NIM_FALSE, NIM_FALSE);
			if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		}
LA11_: ;
		eqsink___ast_u3387(&(*x_p1).typField, t_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		eqwasMoved___ast_u3375(&t_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		{
			LA8_:;
		}
		{
			oldNimErrFin8_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3378(colontmpD_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			eqdestroy___ast_u3378(t_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin8_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
}
static N_INLINE(NI, safeLen__ast_u3197)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0) {
	NI result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	{
		if (!((*n_p0).kind >= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)0) && (*n_p0).kind <= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)23))) goto LA3_;
		result = ((NI)0);
	}
	goto LA1_;
LA3_: ;
	{
		result = len__ast_u3190(n_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, pragmaRaisesOrTags__pragmas_u1305)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
NIM_BOOL oldNimErrFin15_;
NIM_BOOL oldNimErrFin8_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NIM_BOOL T3_;
		NI T5_;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* it_1;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)34) || (*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)27) || (*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)28));
		if (!(T3_)) goto LA4_;
		T5_ = (NI)0;
		T5_ = len__ast_u3190(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T3_ = (T5_ == ((NI)2));
LA4_: ;
		if (!T3_) goto LA6_;
		it_1 = NIM_NIL;
		eqcopy___ast_u3255(&it_1, (*n_p1)._kind_6.sons.p->data[((NI)1)]);
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		{
			if (!!(((*it_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)39) || (*it_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)41)))) goto LA11_;
			processExc__pragmas_u1308(c_p0, it_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		}
		goto LA9_;
LA11_: ;
		{
			{
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_1;
				e_1 = NIM_NIL;
				{
					NI i_1;
					NI colontmp_;
					NI i_2;
					i_1 = (NI)0;
					colontmp_ = (NI)0;
					colontmp_ = safeLen__ast_u3197(it_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
					i_2 = ((NI)0);
					{
						while (1) {
							if (!(i_2 < colontmp_)) goto LA18;
							i_1 = i_2;
							eqcopy___ast_u3255(&e_1, (*it_1)._kind_6.sons.p->data[i_1]);
							if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
							processExc__pragmas_u1308(c_p0, e_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
							i_2 += ((NI)1);
						} LA18: ;
					}
				}
				{
					LA15_:;
				}
				{
					oldNimErrFin15_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3252(e_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
					*nimErr_ = oldNimErrFin15_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
			}
		}
LA9_: ;
		{
			LA8_:;
		}
		{
			oldNimErrFin8_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3252(it_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin8_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA6_: ;
	{
		invalidPragma__pragmas_u142(c_p0, n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
}
static N_INLINE(void, nimSetMem__system_u2172)(void* a_p0, int v_p1, NI size_p2) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a_p0, v_p1, ((size_t) (size_p2)));
}
static N_INLINE(void, nimZeroMem)(void* p_p0, NI size_p1) {
	nimSetMem__system_u2172(p_p0, ((int)0), size_p1);
}
N_LIB_PRIVATE N_NIMCALL(void, illegalCustomPragma__pragmas_u145)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p2) {
	NimStringV2 msg_1;
	NimStringV2 T2_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	msg_1.len = 0; msg_1.p = NIM_NIL;
	T2_.len = 0; T2_.p = NIM_NIL;
	T2_ = rawNewString((*(*s_p2).name).s.len + 35);
appendString((&T2_), TM__tPA3StZ6VsKyoznyrIfFxg_18);
appendString((&T2_), (*(*s_p2).name).s);
appendString((&T2_), TM__tPA3StZ6VsKyoznyrIfFxg_20);
	msg_1 = T2_;
	{
		if (!!((s_p2 == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)))) goto LA5_;
		prepareAdd((&msg_1), 39);
appendString((&msg_1), TM__tPA3StZ6VsKyoznyrIfFxg_22);
		switch ((*s_p2).kind) {
		case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)21):
		{
			prepareAdd((&msg_1), 20);
appendString((&msg_1), TM__tPA3StZ6VsKyoznyrIfFxg_24);
		}
		break;
		case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)20):
		{
			prepareAdd((&msg_1), 11);
appendString((&msg_1), TM__tPA3StZ6VsKyoznyrIfFxg_26);
		}
		break;
		case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)6):
		{
			prepareAdd((&msg_1), 7);
appendString((&msg_1), TM__tPA3StZ6VsKyoznyrIfFxg_28);
		}
		break;
		default:
		{
			NimStringV2 colontmpD_;
			NimStringV2 colontmpD__2;
			NimStringV2 T11_;
			colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
			colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
			T11_.len = 0; T11_.p = NIM_NIL;
			colontmpD_ = dollar___ast_u309((*s_p2).kind);
			T11_ = rawNewString(colontmpD_.len + 12);
appendString((&T11_), TM__tPA3StZ6VsKyoznyrIfFxg_30);
appendString((&T11_), colontmpD_);
			colontmpD__2 = T11_;
			prepareAdd((&msg_1), colontmpD__2.len + 0);
appendString((&msg_1), colontmpD__2);
			eqdestroy___system_u2691(colontmpD__2);
			eqdestroy___system_u2691(colontmpD_);
		}
		break;
		}
	}
LA5_: ;
	liMessage__msgs_u1227((*(*c_p0).graph).config, (*n_p1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), msg_1, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__tPA3StZ6VsKyoznyrIfFxg_31), NIM_FALSE, NIM_FALSE);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(msg_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, semCustomPragma__pragmas_u1430)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_p2) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* callNode_1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* r_1;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	callNode_1 = NIM_NIL;
	r_1 = NIM_NIL;
	switch ((*n_p1).kind) {
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)2) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)53):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)56) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)57):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)165):
	{
		tyArray__TAsXwXSUBvAawE1kIQ5ziQ T3_;
		nimZeroMem((void*)T3_, sizeof(tyArray__TAsXwXSUBvAawE1kIQ5ziQ));
		T3_[0] = n_p1;
		callNode_1 = newTree__ast_u4170(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)27), T3_, 1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)34):
	{
		tyArray__al2p7ldDMvbBVYNFCuu4Rw T5_;
		nimZeroMem((void*)T5_, sizeof(tyArray__al2p7ldDMvbBVYNFCuu4Rw));
		T5_[0] = (*n_p1)._kind_6.sons.p->data[((NI)0)];
		T5_[1] = (*n_p1)._kind_6.sons.p->data[((NI)1)];
		callNode_1 = newTree__ast_u4170(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)27), T5_, 2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)27) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)28):
	{
		eqcopy___ast_u3255(&callNode_1, n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	default:
	{
		invalidPragma__pragmas_u142(c_p0, n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		eqcopy___ast_u3255(&result, n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		eqdestroy___ast_u3252(r_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3252(callNode_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		goto BeforeRet_;
	}
	break;
	}
	r_1 = (*c_p0).semOverloadedCall(c_p0, callNode_1, n_p1, 262144, 524288, ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NIM_BOOL T10_;
		T10_ = (NIM_BOOL)0;
		T10_ = (r_1 == 0);
		if (T10_) goto LA11_;
		T10_ = !((((*(*(*r_1)._kind_6.sons.p->data[((NI)0)])._kind_4.sym).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)57)))&63U)))!=0));
LA11_: ;
		if (!T10_) goto LA12_;
		invalidPragma__pragmas_u142(c_p0, n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		eqcopy___ast_u3255(&result, n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		eqdestroy___ast_u3252(r_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3252(callNode_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		goto BeforeRet_;
	}
LA12_: ;
	{
		NIM_BOOL T16_;
		T16_ = (NIM_BOOL)0;
		T16_ = !((sym_p2 == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)));
		if (!(T16_)) goto LA17_;
		T16_ = ((*sym_p2).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)20) || (*sym_p2).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)21) || (*sym_p2).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)6));
LA17_: ;
		if (!T16_) goto LA18_;
		illegalCustomPragma__pragmas_u145(c_p0, n_p1, sym_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		eqcopy___ast_u3255(&result, n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		eqdestroy___ast_u3252(r_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3252(callNode_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		goto BeforeRet_;
	}
LA18_: ;
	eqcopy___ast_u3255(&result, r_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NIM_BOOL T22_;
		NI T24_;
		T22_ = (NIM_BOOL)0;
		T22_ = ((*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)2));
		if (!(T22_)) goto LA23_;
		T24_ = (NI)0;
		T24_ = len__ast_u3190(r_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T22_ = (T24_ == ((NI)1));
LA23_: ;
		if (!T22_) goto LA25_;
		eqcopy___ast_u3255(&result, (*result)._kind_6.sons.p->data[((NI)0)]);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA20_;
LA25_: ;
	{
		NIM_BOOL T28_;
		NI T30_;
		T28_ = (NIM_BOOL)0;
		T28_ = ((*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)34));
		if (!(T28_)) goto LA29_;
		T30_ = (NI)0;
		T30_ = len__ast_u3190(r_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T28_ = (T30_ == ((NI)2));
LA29_: ;
		if (!T28_) goto LA31_;
		transitionSonsKind__ast_u6769(result, ((*n_p1).kind));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA20_;
LA31_: ;
LA20_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3252(r_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3252(callNode_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(tyObject_HSlice__OAVyDXS0QPw7LdXClfU2hA, dotdot___stdZstrbasics_u49)(NI a_p0, NI b_p1) {
	tyObject_HSlice__OAVyDXS0QPw7LdXClfU2hA result;
	result.a = a_p0;
	result.b = b_p1;
	return result;
}
static N_INLINE(int, nimCmpMem)(void* a_p0, void* b_p1, NI size_p2) {
	int result;
	result = memcmp(a_p0, b_p1, ((size_t) (size_p2)));
	return result;
}
static N_INLINE(NIM_BOOL, equalMem__system_u1750)(void* a_p0, void* b_p1, NI size_p2) {
	NIM_BOOL result;
	int T1_;
	T1_ = (int)0;
	T1_ = nimCmpMem(a_p0, b_p1, size_p2);
	result = (T1_ == ((NI32)0));
	return result;
}
static N_INLINE(NIM_BOOL, eqStrings)(NimStringV2 a_p0, NimStringV2 b_p1) {
	NIM_BOOL result;
	NI alen_1;
	NI blen_1;
{	result = NIM_FALSE;
	alen_1 = a_p0.len;
	blen_1 = b_p1.len;
	{
		if (!(alen_1 == blen_1)) goto LA3_;
		{
			if (!(alen_1 == ((NI)0))) goto LA7_;
			result = NIM_TRUE;
			goto BeforeRet_;
		}
LA7_: ;
		result = equalMem__system_u1750(((void*) ((&a_p0.p->data[((NI)0)]))), ((void*) ((&b_p1.p->data[((NI)0)]))), (alen_1));
		goto BeforeRet_;
	}
LA3_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI, find__stdZprivateZospaths2_u388)(NIM_CHAR* a_p0, NI a_p0Len_0, NIM_CHAR item_p1) {
	NI result;
{	result = ((NI)0);
	{
		NIM_CHAR i_1;
		NI i_2;
		i_1 = (NIM_CHAR)0;
		i_2 = ((NI)0);
		{
			while (1) {
				if (!(i_2 < a_p0Len_0)) goto LA3;
				i_1 = a_p0[i_2];
				{
					if (!((NU8)(i_1) == (NU8)(item_p1))) goto LA6_;
					goto BeforeRet_;
				}
LA6_: ;
				result += ((NI)1);
				i_2 += ((NI)1);
			} LA3: ;
		}
	}
	result = ((NI)-1);
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, contains__stdZprivateZospaths2_u383)(NIM_CHAR* a_p0, NI a_p0Len_0, NIM_CHAR item_p1) {
	NIM_BOOL result;
	NI T1_;
{	T1_ = (NI)0;
	T1_ = find__stdZprivateZospaths2_u388(a_p0, a_p0Len_0, item_p1);
	result = (((NI)0) <= T1_);
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, isObjDisplayCheck)(TNimTypeV2* source_p0, NI16 targetDepth_p1, NU32 token_p2) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	T1_ = (NIM_BOOL)0;
	T1_ = (targetDepth_p1 <= (*source_p0).depth);
	if (!(T1_)) goto LA2_;
	T1_ = ((*source_p0).display[targetDepth_p1] == token_p2);
LA2_: ;
	result = T1_;
	return result;
}
static N_INLINE(Exception*, nimBorrowCurrentException)(void) {
	Exception* result;
	result = currException__system_u3628;
	return result;
}
static N_INLINE(void, popCurrentException)(void) {
	eqcopy___system_u3661(&currException__system_u3628, (*currException__system_u3628).up, NIM_FALSE);
}
N_LIB_PRIVATE N_NIMCALL(void, setExternName__pragmas_u193)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1, NimStringV2 extname_p2, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p3) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!eqStrings(extname_p2, TM__tPA3StZ6VsKyoznyrIfFxg_39)) goto LA3_;
		eqcopy___system_u2694((&(*s_p1).loc.snippet), (*(*s_p1).name).s);
	}
	goto LA1_;
LA3_: ;
	{
		NIM_BOOL T6_;
		T6_ = (NIM_BOOL)0;
		T6_ = contains__stdZprivateZospaths2_u383(((extname_p2).p) ? (extname_p2.p->data) : NIM_NIL, extname_p2.len, 36);
		if (!!(T6_)) goto LA7_;
		eqcopy___system_u2694((&(*s_p1).loc.snippet), extname_p2);
	}
	goto LA1_;
LA7_: ;
	{
		NimStringV2 T11_;
		T11_.len = 0; T11_.p = NIM_NIL;
		T11_ = nsuFormatSingleElem(extname_p2, (*(*s_p1).name).s);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T11_); goto LA10_;}
		eqsink___system_u2700((&(*s_p1).loc.snippet), T11_);
		if (NIM_UNLIKELY(*nimErr_)) {
			LA10_:;
			if (isObjDisplayCheck(nimBorrowCurrentException()->Sup.m_type, 3, 1871340544)) {
				NimStringV2 colontmpD_;
				NimStringV2 T16_;
				*nimErr_ = NIM_FALSE;
				colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
				T16_.len = 0; T16_.p = NIM_NIL;
				T16_ = rawNewString(extname_p2.len + 48);
appendString((&T16_), TM__tPA3StZ6VsKyoznyrIfFxg_41);
appendString((&T16_), extname_p2);
appendString((&T16_), TM__tPA3StZ6VsKyoznyrIfFxg_43);
				colontmpD_ = T16_;
				liMessage__msgs_u1227((*(*c_p0).graph).config, info_p3, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), colontmpD_, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__tPA3StZ6VsKyoznyrIfFxg_44), NIM_FALSE, NIM_FALSE);
				if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
				{
					LA15_:;
				}
				{
					eqdestroy___system_u2691(colontmpD_);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
				popCurrentException();
				LA13_:;
			}
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, makeExternExport__pragmas_u215)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1, NimStringV2 extname_p2, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p3) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	setExternName__pragmas_u193(c_p0, s_p1, extname_p2, info_p3);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*s_p1).flags |= ((NU64)1)<<(((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)7))) & 63);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NOINLINE(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, newEmptyStrNode__pragmas_u293)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, NimStringV2 strVal_p2) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	colontmpD_ = NIM_NIL;
	colontmpD_ = getSysType__magicsys_u55((*c_p0).graph, (*n_p1).info, ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)28));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	result = newNodeIT__ast_u4112(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)20), (*n_p1).info, colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	eqcopy___system_u2694((&(*result)._kind_3.strVal), strVal_p2);
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, getStrLitNode__pragmas_u298)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	{
		NIM_BOOL T3_;
		NI T5_;
		T3_ = (NIM_BOOL)0;
		T3_ = !(((*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)34) || (*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)27) || (*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)28)));
		if (T3_) goto LA4_;
		T5_ = (NI)0;
		T5_ = len__ast_u3190(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T3_ = !((T5_ == ((NI)2)));
LA4_: ;
		if (!T3_) goto LA6_;
		liMessage__msgs_u1227((*(*c_p0).graph).config, (*n_p1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), TM__tPA3StZ6VsKyoznyrIfFxg_46, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__tPA3StZ6VsKyoznyrIfFxg_47), NIM_FALSE, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		result = newEmptyStrNode__pragmas_u293(c_p0, n_p1, TM__tPA3StZ6VsKyoznyrIfFxg_49);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA6_: ;
	{
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T9_;
		T9_ = NIM_NIL;
		T9_ = (*c_p0).semConstExpr(c_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL));
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T9_); goto BeforeRet_;}
		eqsink___ast_u3261(&(*n_p1)._kind_6.sons.p->data[((NI)1)], T9_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		switch ((*(*n_p1)._kind_6.sons.p->data[((NI)1)]).kind) {
		case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)20):
		case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)21):
		case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)22):
		{
			eqcopy___ast_u3255(&result, (*n_p1)._kind_6.sons.p->data[((NI)1)]);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		break;
		default:
		{
			liMessage__msgs_u1227((*(*c_p0).graph).config, (*n_p1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), TM__tPA3StZ6VsKyoznyrIfFxg_50, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__tPA3StZ6VsKyoznyrIfFxg_51), NIM_FALSE, NIM_FALSE);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			result = newEmptyStrNode__pragmas_u293(c_p0, n_p1, TM__tPA3StZ6VsKyoznyrIfFxg_52);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		break;
		}
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, expectStrLit__pragmas_u308)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
	NimStringV2 result;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	colontmpD_ = NIM_NIL;
	colontmpD_ = getStrLitNode__pragmas_u298(c_p0, n_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	eqcopy___system_u2694((&result), (*colontmpD_)._kind_3.strVal);
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3252(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getOptionalStr__pragmas_u322)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, NimStringV2 defaultStr_p2) {
	NimStringV2 result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	{
		if (!((*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)34) || (*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)27) || (*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)28))) goto LA3_;
		result = expectStrLit__pragmas_u308(c_p0, n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA3_: ;
	{
		eqcopy___system_u2694((&result), defaultStr_p2);
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, recordPragma__pragmas_u127)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, NimStringV2* args_p2, NI args_p2Len_0) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* recorded_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	recorded_1 = NIM_NIL;
	recorded_1 = newNodeI__ast_u4091(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)163), (*n_p1).info);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		NI i_1;
		NI colontmp_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = (args_p2Len_0-1);
		res_1 = ((NI)0);
		{
			while (1) {
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD_;
				if (!(res_1 <= colontmp_)) goto LA3;
				colontmpD_ = NIM_NIL;
				i_1 = ((NI) (res_1));
				colontmpD_ = newStrNode__ast_u5426(args_p2[i_1], (*n_p1).info);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				add__ast_u3215(recorded_1, colontmpD_);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				res_1 += ((NI)1);
				eqdestroy___ast_u3252(colontmpD_);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			} LA3: ;
		}
	}
	addPragmaComputation__semdata_u4254(c_p0, recorded_1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqdestroy___ast_u3252(recorded_1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, makeExternImport__pragmas_u202)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1, NimStringV2 extname_p2, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p3) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	setExternName__pragmas_u193(c_p0, s_p1, extname_p2, info_p3);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*s_p1).flags |= ((NU64)1)<<(((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)6))) & 63);
	(*s_p1).flags &= ~(((NU64)1) << (((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)4))) & 63));
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, processImportCompilerProc__pragmas_u224)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1, NimStringV2 extname_p2, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p3) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	setExternName__pragmas_u193(c_p0, s_p1, extname_p2, info_p3);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*s_p1).flags |= ((NU64)1)<<(((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)6))) & 63);
	(*s_p1).flags &= ~(((NU64)1) << (((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)4))) & 63));
	(*s_p1).loc.flags |= ((NU16)1)<<(((((tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg)6))) & 15);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, processImportCpp__pragmas_u241)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1, NimStringV2 extname_p2, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p3) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	setExternName__pragmas_u193(c_p0, s_p1, extname_p2, info_p3);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*s_p1).flags |= ((NU64)1)<<(((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)6))) & 63);
	(*s_p1).flags |= ((NU64)1)<<(((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)32))) & 63);
	(*s_p1).flags &= ~(((NU64)1) << (((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)4))) & 63));
	{
		tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* m_1;
		if (!((*(*(*c_p0).graph).config).backend == ((tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)1))) goto LA3_;
		m_1 = NIM_NIL;
		m_1 = getModule__astalgo_u156(s_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*m_1).flags |= ((NU64)1)<<(((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)32))) & 63);
		eqdestroy___ast_u4574(m_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA3_: ;
	(*(*(*c_p0).graph).config).globalOptions |= ((NU64)1)<<(((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)40))) & 63);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, processImportObjC__pragmas_u271)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1, NimStringV2 extname_p2, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p3) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* m_1;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	m_1 = NIM_NIL;
	setExternName__pragmas_u193(c_p0, s_p1, extname_p2, info_p3);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	(*s_p1).flags |= ((NU64)1)<<(((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)6))) & 63);
	(*s_p1).flags |= ((NU64)1)<<(((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)33))) & 63);
	(*s_p1).flags &= ~(((NU64)1) << (((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)4))) & 63));
	m_1 = getModule__astalgo_u156(s_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	(*m_1).flags |= ((NU64)1)<<(((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)33))) & 63);
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u4574(m_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NI, expectIntLit__pragmas_u312)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
	NI result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = ((NI)0);
	{
		NIM_BOOL T3_;
		NI T5_;
		T3_ = (NIM_BOOL)0;
		T3_ = !(((*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)34) || (*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)27) || (*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)28)));
		if (T3_) goto LA4_;
		T5_ = (NI)0;
		T5_ = len__ast_u3190(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T3_ = !((T5_ == ((NI)2)));
LA4_: ;
		if (!T3_) goto LA6_;
		liMessage__msgs_u1227((*(*c_p0).graph).config, (*n_p1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), TM__tPA3StZ6VsKyoznyrIfFxg_73, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__tPA3StZ6VsKyoznyrIfFxg_74), NIM_FALSE, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA6_: ;
	{
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T9_;
		T9_ = NIM_NIL;
		T9_ = (*c_p0).semConstExpr(c_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL));
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T9_); goto BeforeRet_;}
		eqsink___ast_u3261(&(*n_p1)._kind_6.sons.p->data[((NI)1)], T9_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		switch ((*(*n_p1)._kind_6.sons.p->data[((NI)1)]).kind) {
		case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)6) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)10):
		{
			result = ((NI) ((*(*n_p1)._kind_6.sons.p->data[((NI)1)])._kind_1.intVal));
		}
		break;
		default:
		{
			liMessage__msgs_u1227((*(*c_p0).graph).config, (*n_p1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), TM__tPA3StZ6VsKyoznyrIfFxg_75, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__tPA3StZ6VsKyoznyrIfFxg_76), NIM_FALSE, NIM_FALSE);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		break;
		}
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, noVal__pragmas_u1152)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NIM_BOOL T3_;
		NI T5_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)34) || (*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)27) || (*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)28));
		if (!(T3_)) goto LA4_;
		T5_ = (NI)0;
		T5_ = len__ast_u3190(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T3_ = (((NI)1) < T5_);
LA4_: ;
		if (!T3_) goto LA6_;
		invalidPragma__pragmas_u142(c_p0, n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA6_: ;
	}BeforeRet_: ;
}
static N_INLINE(NI, minuspercent___system_u805)(NI x_p0, NI y_p1) {
	NI result;
	result = ((NI) ((NU)((NU64)(((NU) (x_p0))) - (NU64)(((NU) (y_p1))))));
	return result;
}
static N_INLINE(NIM_BOOL, nimDecRefIsLastDyn)(void* p_p0) {
	NIM_BOOL result;
	result = NIM_FALSE;
	{
		tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* cell_1;
		NI T5_;
		if (!!((p_p0 == NIM_NIL))) goto LA3_;
		T5_ = (NI)0;
		T5_ = minuspercent___system_u805(((NI) (ptrdiff_t) (p_p0)), ((NI)16));
		cell_1 = ((tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A*) (T5_));
		{
			if (!((NI)((*cell_1).rc & ((NI)-16)) == ((NI)0))) goto LA8_;
			result = NIM_TRUE;
		}
		goto LA6_;
LA8_: ;
		{
			(*cell_1).rc = minuspercent___system_u805((*cell_1).rc, ((NI)16));
		}
LA6_: ;
		{
			if (!result) goto LA13_;
			{
				if (!(((NI)0) < (*cell_1).rootIdx)) goto LA17_;
				unregisterCycle__system_u3127(cell_1);
			}
LA17_: ;
		}
LA13_: ;
	}
LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___pragmas_u2625)(tyObject_Env_pragmasdotnim_processEffectsOf___441zjIQZOyCLH68Plk1FJQ* dest_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastDyn((*dest_p0).owner0);
		if (!T3_) goto LA4_;
		eqdestroy___ast_u3469((&(*(*dest_p0).owner0)));
		nimRawDispose((*dest_p0).owner0, ((NI)8));
	}
LA4_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, rttiDestroy__pragmas_u2696)(void* dest_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqdestroy___pragmas_u2625((&(*((tyObject_Env_pragmasdotnim_processEffectsOf___441zjIQZOyCLH68Plk1FJQ*) (dest_p0)))));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, owner__ast_u6254)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p0) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	eqcopy___ast_u4577(&result, (*s_p0).ownerField);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_CLOSURE(void, processParam__pragmas_u1471)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, void* ClE_0) {
	tyObject_Env_pragmasdotnim_processEffectsOf___441zjIQZOyCLH68Plk1FJQ* colonenvP__1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* r_1;
	tySet_tyEnum_TExprFlag__LJ8tOeZrTQZuHS9cNbj1XCg T2_;
NIM_BOOL oldNimErrFin9_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colonenvP__1 = (tyObject_Env_pragmasdotnim_processEffectsOf___441zjIQZOyCLH68Plk1FJQ*) ClE_0;
	r_1 = NIM_NIL;
	T2_ = 0;
	r_1 = (*c_p0).semExpr(c_p0, n_p1, T2_, ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NIM_BOOL T5_;
		tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD_;
		T5_ = (NIM_BOOL)0;
		T5_ = ((*r_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3));
		if (!(T5_)) goto LA6_;
		T5_ = ((*(*r_1)._kind_4.sym).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)3));
LA6_: ;
		if (!T5_) goto LA7_;
		colontmpD_ = NIM_NIL;
		{
			colontmpD_ = owner__ast_u6254((*r_1)._kind_4.sym);
			if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
			if (!(colontmpD_ == (*colonenvP__1).owner0)) goto LA12_;
			(*(*r_1)._kind_4.sym).flags |= ((NU64)1)<<(((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)48))) & 63);
		}
		goto LA10_;
LA12_: ;
		{
			liMessage__msgs_u1227((*(*c_p0).graph).config, (*n_p1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), TM__tPA3StZ6VsKyoznyrIfFxg_88, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__tPA3StZ6VsKyoznyrIfFxg_89), NIM_FALSE, NIM_FALSE);
			if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
		}
LA10_: ;
		{
			LA9_:;
		}
		{
			oldNimErrFin9_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u4574(colontmpD_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin9_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA3_;
LA7_: ;
	{
		liMessage__msgs_u1227((*(*c_p0).graph).config, (*n_p1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), TM__tPA3StZ6VsKyoznyrIfFxg_90, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__tPA3StZ6VsKyoznyrIfFxg_91), NIM_FALSE, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA3_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3252(r_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(NIM_BOOL, nimDecRefIsLastCyclicStatic)(void* p_p0, TNimTypeV2* desc_p1) {
	NIM_BOOL result;
	result = NIM_FALSE;
	{
		tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* cell_1;
		NI T5_;
		if (!!((p_p0 == NIM_NIL))) goto LA3_;
		T5_ = (NI)0;
		T5_ = minuspercent___system_u805(((NI) (ptrdiff_t) (p_p0)), ((NI)16));
		cell_1 = ((tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A*) (T5_));
		{
			if (!((NI)((*cell_1).rc & ((NI)-16)) == ((NI)0))) goto LA8_;
			result = NIM_TRUE;
		}
		goto LA6_;
LA8_: ;
		{
			(*cell_1).rc = minuspercent___system_u805((*cell_1).rc, ((NI)16));
		}
LA6_: ;
		rememberCycle__system_u3497(result, cell_1, desc_p1);
	}
LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___pragmas_u2656)(tyObject_Env_pragmasdotnim_processEffectsOf___441zjIQZOyCLH68Plk1FJQ* dest_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastCyclicStatic(dest_p0, ((TNimTypeV2*) ((&NTIv2__441zjIQZOyCLH68Plk1FJQ_))));
		if (!T3_) goto LA4_;
		eqdestroy___pragmas_u2625((&(*dest_p0)));
		nimRawDispose(dest_p0, ((NI)8));
	}
LA4_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, processEffectsOf__pragmas_u1467)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* owner_p2) {
	tyObject_Env_pragmasdotnim_processEffectsOf___441zjIQZOyCLH68Plk1FJQ* colonenv__1;
	tyObject_Env_pragmasdotnim_processEffectsOf___441zjIQZOyCLH68Plk1FJQ* T2_;
NIM_BOOL oldNimErrFin17_;
NIM_BOOL oldNimErrFin11_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colonenv__1 = NIM_NIL;
	T2_ = NIM_NIL;
	T2_ = (tyObject_Env_pragmasdotnim_processEffectsOf___441zjIQZOyCLH68Plk1FJQ*) nimNewObj(sizeof(tyObject_Env_pragmasdotnim_processEffectsOf___441zjIQZOyCLH68Plk1FJQ), NIM_ALIGNOF(tyObject_Env_pragmasdotnim_processEffectsOf___441zjIQZOyCLH68Plk1FJQ));
	(*T2_).Sup.m_type = (&NTIv2__441zjIQZOyCLH68Plk1FJQ_);
	colonenv__1 = T2_;
	eqcopy___ast_u4577(&(*colonenv__1).owner0, owner_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NIM_BOOL T5_;
		NI T7_;
		T5_ = (NIM_BOOL)0;
		T5_ = !(((*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)34) || (*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)27) || (*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)28)));
		if (T5_) goto LA6_;
		T7_ = (NI)0;
		T7_ = len__ast_u3190(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T5_ = !((T7_ == ((NI)2)));
LA6_: ;
		if (!T5_) goto LA8_;
		liMessage__msgs_u1227((*(*c_p0).graph).config, (*n_p1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), TM__tPA3StZ6VsKyoznyrIfFxg_85, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__tPA3StZ6VsKyoznyrIfFxg_86), NIM_FALSE, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA3_;
LA8_: ;
	{
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* it_1;
		it_1 = NIM_NIL;
		eqcopy___ast_u3255(&it_1, (*n_p1)._kind_6.sons.p->data[((NI)1)]);
		if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
		{
			if (!((*it_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)39) || (*it_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)41))) goto LA14_;
			{
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* x_1;
				x_1 = NIM_NIL;
				{
					NI i_1;
					NI colontmp_;
					NI i_2;
					i_1 = (NI)0;
					colontmp_ = (NI)0;
					colontmp_ = safeLen__ast_u3197(it_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
					i_2 = ((NI)0);
					{
						while (1) {
							tyProc__9b9a7FRnQW3XNIvbw12GxI7w T21_;
							if (!(i_2 < colontmp_)) goto LA20;
							i_1 = i_2;
							eqcopy___ast_u3255(&x_1, (*it_1)._kind_6.sons.p->data[i_1]);
							if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
							nimZeroMem((void*)(&T21_), sizeof(tyProc__9b9a7FRnQW3XNIvbw12GxI7w));
							T21_.ClP_0 = processParam__pragmas_u1471; T21_.ClE_0 = colonenv__1;
							T21_.ClE_0? T21_.ClP_0(c_p0, x_1, T21_.ClE_0):((TM__tPA3StZ6VsKyoznyrIfFxg_92)(T21_.ClP_0))(c_p0, x_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
							i_2 += ((NI)1);
						} LA20: ;
					}
				}
				{
					LA17_:;
				}
				{
					oldNimErrFin17_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3252(x_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
					*nimErr_ = oldNimErrFin17_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
			}
		}
		goto LA12_;
LA14_: ;
		{
			tyProc__9b9a7FRnQW3XNIvbw12GxI7w T25_;
			nimZeroMem((void*)(&T25_), sizeof(tyProc__9b9a7FRnQW3XNIvbw12GxI7w));
			T25_.ClP_0 = processParam__pragmas_u1471; T25_.ClE_0 = colonenv__1;
			T25_.ClE_0? T25_.ClP_0(c_p0, it_1, T25_.ClE_0):((TM__tPA3StZ6VsKyoznyrIfFxg_93)(T25_.ClP_0))(c_p0, it_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
		}
LA12_: ;
		{
			LA11_:;
		}
		{
			oldNimErrFin11_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3252(it_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin11_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA3_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___pragmas_u2656(colonenv__1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(void, warningDeprecated__msgs_u1572)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, NimStringV2 msg_p2) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	liMessage__msgs_u1227(conf_p0, info_p1, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)24), msg_p2, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__tPA3StZ6VsKyoznyrIfFxg_94), NIM_FALSE, NIM_FALSE);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isTurnedOn__pragmas_u411)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
	NIM_BOOL result;
NIM_BOOL oldNimErrFin8_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_FALSE;
	{
		NIM_BOOL T3_;
		NI T5_;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* x_1;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)34) || (*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)27) || (*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)28));
		if (!(T3_)) goto LA4_;
		T5_ = (NI)0;
		T5_ = len__ast_u3190(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T3_ = (T5_ == ((NI)2));
LA4_: ;
		if (!T3_) goto LA6_;
		x_1 = NIM_NIL;
		x_1 = (*c_p0).semConstBoolExpr(c_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)]);
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		eqcopy___ast_u3255(&(*n_p1)._kind_6.sons.p->data[((NI)1)], x_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		{
			if (!((*x_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)6))) goto LA11_;
			result = !(((*x_1)._kind_1.intVal == IL64(0)));
			eqdestroy___ast_u3252(x_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			goto BeforeRet_;
		}
LA11_: ;
		{
			LA8_:;
		}
		{
			oldNimErrFin8_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3252(x_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin8_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA6_: ;
	liMessage__msgs_u1227((*(*c_p0).graph).config, (*n_p1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), TM__tPA3StZ6VsKyoznyrIfFxg_99, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__tPA3StZ6VsKyoznyrIfFxg_100), NIM_FALSE, NIM_FALSE);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, pragmaNoForward__pragmas_u441)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg flag_p2) {
	NimStringV2 colontmpD_;
	NimStringV2 colontmpD__2;
	NimStringV2 colontmpD__3;
	NimStringV2 T8_;
	NimStringV2 T9_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
	{
		NIM_BOOL T4_;
		T4_ = (NIM_BOOL)0;
		T4_ = isTurnedOn__pragmas_u411(c_p0, n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!T4_) goto LA5_;
		(*(*c_p0).module).flags |= ((NU64)1)<<(((flag_p2)) & 63);
		(*c_p0).features |= ((NU32)1)<<(((((tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ)8))) & 31);
	}
	goto LA2_;
LA5_: ;
	{
		(*(*c_p0).module).flags &= ~(((NU64)1) << (((flag_p2)) & 63));
	}
LA2_: ;
	T8_.len = 0; T8_.p = NIM_NIL;
	T9_.len = 0; T9_.p = NIM_NIL;
	{
		if (!(flag_p2 == ((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)10))) goto LA12_;
		colontmpD_ = TM__tPA3StZ6VsKyoznyrIfFxg_104;
		T9_ = colontmpD_;
	}
	goto LA10_;
LA12_: ;
	{
		colontmpD__2 = TM__tPA3StZ6VsKyoznyrIfFxg_106;
		T9_ = colontmpD__2;
	}
LA10_: ;
	T8_ = rawNewString(T9_.len + 62);
appendString((&T8_), TM__tPA3StZ6VsKyoznyrIfFxg_102);
appendString((&T8_), T9_);
appendString((&T8_), TM__tPA3StZ6VsKyoznyrIfFxg_108);
	colontmpD__3 = T8_;
	liMessage__msgs_u1227((*(*c_p0).graph).config, (*n_p1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)24), colontmpD__3, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__tPA3StZ6VsKyoznyrIfFxg_109), NIM_FALSE, NIM_FALSE);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD__3);
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(colontmpD_);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, processMagic__pragmas_u353)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p2) {
	NimStringV2 v_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	v_1.len = 0; v_1.p = NIM_NIL;
	{
		NIM_BOOL T4_;
		NI T6_;
		T4_ = (NIM_BOOL)0;
		T4_ = !(((*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)34) || (*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)27) || (*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)28)));
		if (T4_) goto LA5_;
		T6_ = (NI)0;
		T6_ = len__ast_u3190(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T4_ = !((T6_ == ((NI)2)));
LA5_: ;
		if (!T4_) goto LA7_;
		liMessage__msgs_u1227((*(*c_p0).graph).config, (*n_p1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), TM__tPA3StZ6VsKyoznyrIfFxg_110, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__tPA3StZ6VsKyoznyrIfFxg_111), NIM_FALSE, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		eqdestroy___system_u2691(v_1);
		goto BeforeRet_;
	}
LA7_: ;
	{
		if (!((*(*n_p1)._kind_6.sons.p->data[((NI)1)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)2))) goto LA11_;
		eqcopy___system_u2694((&v_1), (*(*(*n_p1)._kind_6.sons.p->data[((NI)1)])._kind_5.ident).s);
	}
	goto LA9_;
LA11_: ;
	{
		v_1 = expectStrLit__pragmas_u308(c_p0, n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA9_: ;
	{
		tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg m_1;
		m_1 = (tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)0;
		{
			tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg v_2;
			NI res_1;
			v_2 = (tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)0;
			res_1 = ((NI)0);
			{
				while (1) {
					NimStringV2 colontmpD_;
					NimStringV2 colontmpD__2;
					if (!(res_1 <= ((NI)277))) goto LA17;
					colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
					colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
					v_2 = ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg) (res_1));
					m_1 = v_2;
					{
						colontmpD_ = dollar___ast_u606(m_1);
						colontmpD__2 = substr__system_u8664(colontmpD_, ((NI)1));
						if (!eqStrings(colontmpD__2, v_1)) goto LA21_;
						(*s_p2).magic = m_1;
						eqdestroy___system_u2691(colontmpD__2);
						eqdestroy___system_u2691(colontmpD_);
						goto LA14;
					}
LA21_: ;
					res_1 += ((NI)1);
					{
						LA18_:;
					}
					{
						eqdestroy___system_u2691(colontmpD__2);
						eqdestroy___system_u2691(colontmpD_);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				} LA17: ;
			}
		}
	} LA14: ;
	{
		if (!((*s_p2).magic == ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)0))) goto LA27_;
		liMessage__msgs_u1227((*(*c_p0).graph).config, (*n_p1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)28), v_1, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__tPA3StZ6VsKyoznyrIfFxg_112), NIM_FALSE, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA27_: ;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(v_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig*, getLib__pragmas_u511)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyEnum_TLibKind__BkKL8ReLoyYDI7of9aQPV0A kind_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* path_p2) {
	tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig* result;
	tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig* colontmpD_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	{
		tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig** it_1;
		NI i_1;
		NI L_1;
		NI T2_;
		it_1 = (tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig**)0;
		i_1 = ((NI)0);
		T2_ = (*c_p0).libs.len;
		L_1 = T2_;
		{
			while (1) {
				if (!(i_1 < L_1)) goto LA4;
				it_1 = &(*c_p0).libs.p->data[i_1];
				{
					NIM_BOOL T7_;
					T7_ = (NIM_BOOL)0;
					T7_ = ((*(*it_1)).kind == kind_p1);
					if (!(T7_)) goto LA8_;
					T7_ = exprStructuralEquivalent__trees_u63((*(*it_1)).path, path_p2, NIM_FALSE);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
LA8_: ;
					if (!T7_) goto LA9_;
					eqcopy___ast_u6219(&result, (*it_1));
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					goto BeforeRet_;
				}
LA9_: ;
				i_1 += ((NI)1);
			} LA4: ;
		}
	}
	result = newLib__semdata_u4362(kind_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqcopy___ast_u3255(&(*result).path, path_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	colontmpD_ = eqdup___ast_u6222(result);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	add__pragmas_u541((&(*c_p0).libs), colontmpD_);
	{
		NIM_BOOL T15_;
		if (!((*path_p2).kind >= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)20) && (*path_p2).kind <= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)22))) goto LA13_;
		T15_ = (NIM_BOOL)0;
		T15_ = isDynlibOverride__options_u4266((*(*c_p0).graph).config, (*path_p2)._kind_3.strVal);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*result).isOverridden = T15_;
	}
LA13_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, returnType__ast_u5354)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* n_p0) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	eqcopy___ast_u3381(&result, (*n_p0).sons.p->data[((NI)0)]);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, expectDynlibNode__pragmas_u584)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	{
		NIM_BOOL T3_;
		NI T5_;
		T3_ = (NIM_BOOL)0;
		T3_ = !(((*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)34) || (*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)27) || (*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)28)));
		if (T3_) goto LA4_;
		T5_ = (NI)0;
		T5_ = len__ast_u3190(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T3_ = !((T5_ == ((NI)2)));
LA4_: ;
		if (!T3_) goto LA6_;
		liMessage__msgs_u1227((*(*c_p0).graph).config, (*n_p1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), TM__tPA3StZ6VsKyoznyrIfFxg_117, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__tPA3StZ6VsKyoznyrIfFxg_118), NIM_FALSE, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		result = newEmptyStrNode__pragmas_u293(c_p0, n_p1, TM__tPA3StZ6VsKyoznyrIfFxg_119);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA6_: ;
	{
		tySet_tyEnum_TExprFlag__LJ8tOeZrTQZuHS9cNbj1XCg T9_;
		T9_ = 0;
		result = (*c_p0).semExpr(c_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], T9_, ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		{
			NIM_BOOL T12_;
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T16_;
			T12_ = (NIM_BOOL)0;
			T12_ = ((*result).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3));
			if (!(T12_)) goto LA13_;
			T12_ = ((*(*result)._kind_4.sym).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)10));
LA13_: ;
			if (!T12_) goto LA14_;
			T16_ = NIM_NIL;
			T16_ = (*c_p0).semConstExpr(c_p0, result, ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL));
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T16_); goto BeforeRet_;}
			eqsink___ast_u3261(&result, T16_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA14_: ;
		{
			NIM_BOOL T19_;
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T23_;
			T19_ = (NIM_BOOL)0;
			T19_ = ((*result).typField == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL));
			if (T19_) goto LA20_;
			T19_ = !(((*(*result).typField).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)26) || (*(*result).typField).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)28) || (*(*result).typField).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)25)));
LA20_: ;
			if (!T19_) goto LA21_;
			liMessage__msgs_u1227((*(*c_p0).graph).config, (*n_p1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), TM__tPA3StZ6VsKyoznyrIfFxg_120, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__tPA3StZ6VsKyoznyrIfFxg_121), NIM_FALSE, NIM_FALSE);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			T23_ = NIM_NIL;
			T23_ = newEmptyStrNode__pragmas_u293(c_p0, n_p1, TM__tPA3StZ6VsKyoznyrIfFxg_122);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T23_); goto BeforeRet_;}
			eqsink___ast_u3261(&result, T23_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA21_: ;
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(tyObject_TOptionEntry__KeABxBvAlGa1KroFfkcqAg**, X5BX5D___semdata_u454)(tyObject_TOptionEntry__KeABxBvAlGa1KroFfkcqAg** s_p0, NI s_p0Len_0, NI i_p1) {
	tyObject_TOptionEntry__KeABxBvAlGa1KroFfkcqAg** result;
	result = &s_p0[(NI)(s_p0Len_0 - i_p1)];
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, processDynLib__pragmas_u612)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_p2) {
NIM_BOOL oldNimErrFin7_;
NIM_BOOL oldNimErrFin20_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NIM_BOOL T3_;
		tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig* lib_1;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD_;
		T3_ = (NIM_BOOL)0;
		T3_ = (sym_p2 == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL));
		if (T3_) goto LA4_;
		T3_ = ((*sym_p2).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)6));
LA4_: ;
		if (!T3_) goto LA5_;
		lib_1 = NIM_NIL;
		colontmpD_ = NIM_NIL;
		colontmpD_ = expectDynlibNode__pragmas_u584(c_p0, n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		lib_1 = getLib__pragmas_u511(c_p0, ((tyEnum_TLibKind__BkKL8ReLoyYDI7of9aQPV0A)1), colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		{
			tyObject_TOptionEntry__KeABxBvAlGa1KroFfkcqAg** T12_;
			if (!!((*lib_1).isOverridden)) goto LA10_;
			T12_ = (tyObject_TOptionEntry__KeABxBvAlGa1KroFfkcqAg**)0;
			T12_ = X5BX5D___semdata_u454((((*c_p0).optionStack).p) ? ((*c_p0).optionStack.p->data) : NIM_NIL, (*c_p0).optionStack.len, ((NI)1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
			eqsink___ast_u6225(&(*(*T12_)).dynlib, lib_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
			eqwasMoved___ast_u6213(&lib_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		}
LA10_: ;
		{
			LA7_:;
		}
		{
			oldNimErrFin7_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3252(colontmpD_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			eqdestroy___ast_u6216(lib_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin7_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA5_: ;
	{
		{
			tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig* lib_2;
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__2;
			if (!((*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)34) || (*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)27) || (*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)28))) goto LA18_;
			lib_2 = NIM_NIL;
			colontmpD__2 = NIM_NIL;
			colontmpD__2 = expectDynlibNode__pragmas_u584(c_p0, n_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA20_;
			lib_2 = getLib__pragmas_u511(c_p0, ((tyEnum_TLibKind__BkKL8ReLoyYDI7of9aQPV0A)1), colontmpD__2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA20_;
			{
				if (!!((*lib_2).isOverridden)) goto LA23_;
				addToLib__semdata_u4365(lib_2, sym_p2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA20_;
				(*sym_p2).loc.flags |= ((NU16)1)<<(((((tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg)3))) & 15);
			}
LA23_: ;
			{
				LA20_:;
			}
			{
				oldNimErrFin20_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u3252(colontmpD__2);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				eqdestroy___ast_u6216(lib_2);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				*nimErr_ = oldNimErrFin20_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		goto LA16_;
LA18_: ;
		{
			(*sym_p2).loc.flags |= ((NU16)1)<<(((((tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg)4))) & 15);
		}
LA16_: ;
		{
			NIM_BOOL T30_;
			NIM_BOOL T31_;
			T30_ = (NIM_BOOL)0;
			T31_ = (NIM_BOOL)0;
			T31_ = ((*sym_p2).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)12) || (*sym_p2).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)13) || (*sym_p2).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)14) || (*sym_p2).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)15) || (*sym_p2).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)16) || (*sym_p2).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)17) || (*sym_p2).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)18));
			if (!(T31_)) goto LA32_;
			T31_ = !(((*sym_p2).typ == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL)));
LA32_: ;
			T30_ = T31_;
			if (!(T30_)) goto LA33_;
			T30_ = !((((*(*sym_p2).typ).flags &((NU64)1<<((NU)((((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)42)))&63U)))!=0));
LA33_: ;
			if (!T30_) goto LA34_;
			(*(*sym_p2).typ).callConv = ((tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ)2);
		}
LA34_: ;
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, markCompilerProc__pragmas_u1366)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = !(((*s_p1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)7)));
		if (T3_) goto LA4_;
		T3_ = !(eqStrings((*(*s_p1).name).s, TM__tPA3StZ6VsKyoznyrIfFxg_125));
LA4_: ;
		if (!T3_) goto LA5_;
		makeExternExport__pragmas_u215(c_p0, s_p1, TM__tPA3StZ6VsKyoznyrIfFxg_126, (*s_p1).info);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA5_: ;
	(*s_p1).flags |= ((NU64)1)<<(((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)18))) & 63);
	(*s_p1).flags |= ((NU64)1)<<(((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)0))) & 63);
	registerCompilerProc__magicsys_u159((*c_p0).graph, s_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ* T11_;
		if (!!(((*(*(*c_p0).graph).config).symbolFiles == ((tyEnum_SymbolFilesOption__2eyIIreuRXhYT9buPPZbBYA)0)))) goto LA9_;
		T11_ = (tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ*)0;
		T11_ = (&(*(*c_p0).graph).encoders.p->data[(*(*c_p0).module).position]);
		addCompilerProc__icZic_u3303(T11_, (&(*(*c_p0).graph).packed_0.pm.p->data[(*(*c_p0).module).position].fromDisk), s_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA9_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, deprecatedStmt__pragmas_u1385)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* outerPragma_p1) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* pragma_1;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	pragma_1 = NIM_NIL;
	eqcopy___ast_u3255(&pragma_1, (*outerPragma_p1)._kind_6.sons.p->data[((NI)1)]);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T6_;
		if (!((*pragma_1).kind >= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)20) && (*pragma_1).kind <= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)22))) goto LA4_;
		(*(*c_p0).module).flags |= ((NU64)1)<<(((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)22))) & 63);
		T6_ = NIM_NIL;
		T6_ = getStrLitNode__pragmas_u298(c_p0, outerPragma_p1);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T6_); goto LA1_;}
		eqsink___ast_u3261(&(*(*c_p0).module).constraint, T6_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		eqdestroy___ast_u3252(pragma_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		goto BeforeRet_;
	}
LA4_: ;
	{
		if (!!(((*pragma_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)41)))) goto LA9_;
		liMessage__msgs_u1227((*(*c_p0).graph).config, (*pragma_1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), TM__tPA3StZ6VsKyoznyrIfFxg_131, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__tPA3StZ6VsKyoznyrIfFxg_132), NIM_FALSE, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		eqdestroy___ast_u3252(pragma_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		goto BeforeRet_;
	}
LA9_: ;
	liMessage__msgs_u1227((*(*c_p0).graph).config, (*pragma_1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)24), TM__tPA3StZ6VsKyoznyrIfFxg_134, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__tPA3StZ6VsKyoznyrIfFxg_135), NIM_FALSE, NIM_FALSE);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3252(pragma_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, typeBorrow__pragmas_u1349)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p2) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NIM_BOOL T3_;
		NI T5_;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* it_1;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*n_p2).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)34) || (*n_p2).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)27) || (*n_p2).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)28));
		if (!(T3_)) goto LA4_;
		T5_ = (NI)0;
		T5_ = len__ast_u3190(n_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T3_ = (T5_ == ((NI)2));
LA4_: ;
		if (!T3_) goto LA6_;
		it_1 = NIM_NIL;
		it_1 = (*n_p2)._kind_6.sons.p->data[((NI)1)];
		{
			if (!!(((*it_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)53)))) goto LA10_;
			liMessage__msgs_u1227((*(*c_p0).graph).config, (*n_p2).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), TM__tPA3StZ6VsKyoznyrIfFxg_137, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__tPA3StZ6VsKyoznyrIfFxg_138), NIM_FALSE, NIM_FALSE);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA10_: ;
	}
LA6_: ;
	(*(*sym_p1).typ).flags |= ((NU64)1)<<(((((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)32))) & 63);
	}BeforeRet_: ;
}
static N_INLINE(NIM_BOOL, isRoutine__ast_u7152)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p0) {
	NIM_BOOL result;
	result = ((*s_p0).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)12) || (*s_p0).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)13) || (*s_p0).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)18) || (*s_p0).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)17) || (*s_p0).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)15) || (*s_p0).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)14) || (*s_p0).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)16));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, processDefineConst__pragmas_u1000)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_p2, tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg kind_p3) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	(*sym_p2).magic = kind_p3;
	{
		NIM_BOOL T3_;
		NI T5_;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T8_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)34) || (*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)27) || (*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)28));
		if (!(T3_)) goto LA4_;
		T5_ = (NI)0;
		T5_ = len__ast_u3190(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T3_ = (T5_ == ((NI)2));
LA4_: ;
		if (!T3_) goto LA6_;
		T8_ = NIM_NIL;
		T8_ = getStrLitNode__pragmas_u298(c_p0, n_p1);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T8_); goto BeforeRet_;}
		eqsink___ast_u3261(&(*n_p1)._kind_6.sons.p->data[((NI)1)], T8_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA6_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, processDefine__pragmas_u1009)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_p2) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = !((sym_p2 == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)));
		if (!(T3_)) goto LA4_;
		T3_ = ((*sym_p2).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)10));
LA4_: ;
		if (!T3_) goto LA5_;
		processDefineConst__pragmas_u1000(c_p0, n_p1, sym_p2, ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)267));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA5_: ;
	{
		NIM_BOOL T8_;
		NIM_BOOL T9_;
		NI T11_;
		T8_ = (NIM_BOOL)0;
		T9_ = (NIM_BOOL)0;
		T9_ = ((*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)34) || (*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)27) || (*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)28));
		if (!(T9_)) goto LA10_;
		T11_ = (NI)0;
		T11_ = len__ast_u3190(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T9_ = (T11_ == ((NI)2));
LA10_: ;
		T8_ = T9_;
		if (!(T8_)) goto LA12_;
		T8_ = ((*(*n_p1)._kind_6.sons.p->data[((NI)1)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)2));
LA12_: ;
		if (!T8_) goto LA13_;
		defineSymbol__condsyms_u4((*(*(*c_p0).graph).config).symbols, (*(*(*n_p1)._kind_6.sons.p->data[((NI)1)])._kind_5.ident).s, TM__tPA3StZ6VsKyoznyrIfFxg_150);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA13_: ;
	{
		invalidPragma__pragmas_u142(c_p0, n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, processUndef__pragmas_u1029)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NIM_BOOL T3_;
		NIM_BOOL T4_;
		NI T6_;
		T3_ = (NIM_BOOL)0;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)34) || (*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)27) || (*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)28));
		if (!(T4_)) goto LA5_;
		T6_ = (NI)0;
		T6_ = len__ast_u3190(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T4_ = (T6_ == ((NI)2));
LA5_: ;
		T3_ = T4_;
		if (!(T3_)) goto LA7_;
		T3_ = ((*(*n_p1)._kind_6.sons.p->data[((NI)1)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)2));
LA7_: ;
		if (!T3_) goto LA8_;
		undefSymbol__condsyms_u8((*(*(*c_p0).graph).config).symbols, (*(*(*n_p1)._kind_6.sons.p->data[((NI)1)])._kind_5.ident).s);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA8_: ;
	{
		invalidPragma__pragmas_u142(c_p0, n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___pragmas_u2760)(tyObject_Env_pragmasdotnim_processCompile___dWXVdC0mxyRcA9cJsc1PdqQ* dest_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastDyn((*dest_p0).n0);
		if (!T3_) goto LA4_;
		eqdestroy___ast_u3270((&(*(*dest_p0).n0)));
		nimRawDispose((*dest_p0).n0, ((NI)8));
	}
LA4_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, rttiDestroy__pragmas_u2843)(void* dest_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqdestroy___pragmas_u2760((&(*((tyObject_Env_pragmasdotnim_processCompile___dWXVdC0mxyRcA9cJsc1PdqQ*) (dest_p0)))));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getStrLit__pragmas_u1059)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, NI i_p2) {
	NimStringV2 result;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	T1_ = NIM_NIL;
	T1_ = (*c_p0).semConstExpr(c_p0, (*n_p1)._kind_6.sons.p->data[i_p2], ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL));
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T1_); goto BeforeRet_;}
	eqsink___ast_u3261(&(*n_p1)._kind_6.sons.p->data[i_p2], T1_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	switch ((*(*n_p1)._kind_6.sons.p->data[i_p2]).kind) {
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)20):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)21):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)22):
	{
		eqcopy___system_u2694((&result), (*(*n_p1)._kind_6.sons.p->data[i_p2])._kind_3.strVal);
	}
	break;
	default:
	{
		liMessage__msgs_u1227((*(*c_p0).graph).config, (*n_p1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), TM__tPA3StZ6VsKyoznyrIfFxg_152, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__tPA3StZ6VsKyoznyrIfFxg_153), NIM_FALSE, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		result = TM__tPA3StZ6VsKyoznyrIfFxg_154;
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NimStringV2, slash___stdZprivateZospaths2_u91)(NimStringV2 head_p0, NimStringV2 tail_p1) {
	NimStringV2 result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	result = nosjoinPath(head_p0, tail_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NCSTRING, nimToCStringConv)(NimStringV2 s_p0) {
	NCSTRING result;
	{
		if (!(s_p0.len == ((NI)0))) goto LA3_;
		result = "";
	}
	goto LA1_;
LA3_: ;
	{
		result = ((NCSTRING) ((*s_p0.p).data));
	}
LA1_: ;
	return result;
}
N_LIB_PRIVATE N_CLOSURE(void, docompile__pragmas_u1052)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* it_p1, NimStringV2 src_p2, NimStringV2 dest_p3, NimStringV2 customArgs_p4, void* ClE_0) {
	tyObject_Env_pragmasdotnim_processCompile___dWXVdC0mxyRcA9cJsc1PdqQ* colonenvP__1;
	tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg cf_1;
	NimStringV2 colontmpD_;
	tyTuple__7q7q3E6Oj24ZNVJb9aonhAg colontmpD__2;
	NimStringV2 colontmpD__3;
	NimStringV2 colontmpD__4;
	NimStringV2 colontmpD__5;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colonenvP__1 = (tyObject_Env_pragmasdotnim_processCompile___dWXVdC0mxyRcA9cJsc1PdqQ*) ClE_0;
	nimZeroMem((void*)(&cf_1), sizeof(tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg));
	nimZeroMem((void*)(&colontmpD__2), sizeof(tyTuple__7q7q3E6Oj24ZNVJb9aonhAg));
	splitFile__pathutils_u39(src_p2, (&colontmpD__2));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD_ = eqdup___system_u2697(colontmpD__2.Field1);
	cf_1.nimname = colontmpD_;
	colontmpD__3 = eqdup___system_u2697(src_p2);
	cf_1.cname = colontmpD__3;
	colontmpD__4 = eqdup___system_u2697(dest_p3);
	cf_1.obj = colontmpD__4;
	cf_1.flags = 2;
	colontmpD__5 = eqdup___system_u2697(customArgs_p4);
	cf_1.customArgs = colontmpD__5;
	{
		NIM_BOOL T4_;
		NimStringV2 colontmpD__6;
		NimStringV2 T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = nosfileExists(src_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!!(T4_)) goto LA5_;
		colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
		T8_.len = 0; T8_.p = NIM_NIL;
		T8_ = rawNewString(src_p2.len + 13);
appendString((&T8_), TM__tPA3StZ6VsKyoznyrIfFxg_156);
appendString((&T8_), src_p2);
		colontmpD__6 = T8_;
		liMessage__msgs_u1227((*(*c_p0).graph).config, (*(*colonenvP__1).n0).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), colontmpD__6, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__tPA3StZ6VsKyoznyrIfFxg_157), NIM_FALSE, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		{
			LA7_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__6);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA2_;
LA5_: ;
	{
		tyArray__Seu7uK9aaOSN0BK3EAjjSHw T12_;
		addExternalFileToCompile__extccomp_u1334((*(*c_p0).graph).config, (&cf_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T12_[0] = TM__tPA3StZ6VsKyoznyrIfFxg_159;
		T12_[1] = src_p2;
		T12_[2] = dest_p3;
		T12_[3] = customArgs_p4;
		recordPragma__pragmas_u127(c_p0, it_p1, T12_, 4);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA2_: ;
	{
		LA1_:;
	}
	{
		eqdestroy___pathutils_u73((&colontmpD__2));
		eqdestroy___options_u1619((&cf_1));
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(NIM_BOOL, isEmpty__options_u4086)(NimStringV2 x_p0) {
	NIM_BOOL result;
	result = (x_p0.len == ((NI)0));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___pragmas_u2791)(tyObject_Env_pragmasdotnim_processCompile___dWXVdC0mxyRcA9cJsc1PdqQ* dest_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastCyclicStatic(dest_p0, ((TNimTypeV2*) ((&NTIv2__dWXVdC0mxyRcA9cJsc1PdqQ_))));
		if (!T3_) goto LA4_;
		eqdestroy___pragmas_u2760((&(*dest_p0)));
		nimRawDispose(dest_p0, ((NI)8));
	}
LA4_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, processCompile__pragmas_u1049)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
	tyObject_Env_pragmasdotnim_processCompile___dWXVdC0mxyRcA9cJsc1PdqQ* colonenv__1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* it_1;
	tyObject_Env_pragmasdotnim_processCompile___dWXVdC0mxyRcA9cJsc1PdqQ* T2_;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T3_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colonenv__1 = NIM_NIL;
	it_1 = NIM_NIL;
	T2_ = NIM_NIL;
	T2_ = (tyObject_Env_pragmasdotnim_processCompile___dWXVdC0mxyRcA9cJsc1PdqQ*) nimNewObj(sizeof(tyObject_Env_pragmasdotnim_processCompile___dWXVdC0mxyRcA9cJsc1PdqQ), NIM_ALIGNOF(tyObject_Env_pragmasdotnim_processCompile___dWXVdC0mxyRcA9cJsc1PdqQ));
	(*T2_).Sup.m_type = (&NTIv2__dWXVdC0mxyRcA9cJsc1PdqQ_);
	colonenv__1 = T2_;
	eqcopy___ast_u3255(&(*colonenv__1).n0, n_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T3_ = NIM_NIL;
	{
		NIM_BOOL T6_;
		NI T8_;
		T6_ = (NIM_BOOL)0;
		T6_ = ((*(*colonenv__1).n0).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)34) || (*(*colonenv__1).n0).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)27) || (*(*colonenv__1).n0).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)28));
		if (!(T6_)) goto LA7_;
		T8_ = (NI)0;
		T8_ = len__ast_u3190((*colonenv__1).n0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T6_ = (T8_ == ((NI)2));
LA7_: ;
		if (!T6_) goto LA9_;
		eqcopy___ast_u3255(&it_1, (*(*colonenv__1).n0)._kind_6.sons.p->data[((NI)1)]);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA4_;
LA9_: ;
	{
		eqcopy___ast_u3255(&it_1, (*colonenv__1).n0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA4_: ;
	{
		NIM_BOOL T14_;
		NI T16_;
		NimStringV2 s_1;
		NimStringV2 dest_1;
		NimStringV2 found_1;
		NimStringV2 colontmpD_;
		NimStringV2 colontmpD__2;
		T14_ = (NIM_BOOL)0;
		T14_ = ((*it_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)37) || (*it_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)160));
		if (!(T14_)) goto LA15_;
		T16_ = (NI)0;
		T16_ = len__ast_u3190(it_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T14_ = (T16_ == ((NI)2));
LA15_: ;
		if (!T14_) goto LA17_;
		s_1.len = 0; s_1.p = NIM_NIL;
		dest_1.len = 0; dest_1.p = NIM_NIL;
		found_1.len = 0; found_1.p = NIM_NIL;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		s_1 = getStrLit__pragmas_u1059(c_p0, it_1, ((NI)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
		dest_1 = getStrLit__pragmas_u1059(c_p0, it_1, ((NI)1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
		colontmpD_ = toFullPath__msgs_u624((*(*c_p0).graph).config, (*(*colonenv__1).n0).info.fileIndex);
		if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
		colontmpD__2 = nosparentDir(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
		found_1 = slash___stdZprivateZospaths2_u91(colontmpD__2, s_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
		{
			NimStringV2 f_1;
			glob_t fX60gensym5__1;
			NI resX60gensym5__1;
			int T21_;
			f_1.len = 0; f_1.p = NIM_NIL;
			nimZeroMem((void*)(&fX60gensym5__1), sizeof(glob_t));
			resX60gensym5__1 = (NI)0;
			fX60gensym5__1.gl_offs = ((NI)0);
			fX60gensym5__1.gl_pathc = ((NI)0);
			fX60gensym5__1.gl_pathv = ((NCSTRING*) NIM_NIL);
			T21_ = (int)0;
			T21_ = glob(nimToCStringConv(found_1), ((int)0), NIM_NIL, (&fX60gensym5__1));
			resX60gensym5__1 = ((NI) (T21_));
			{
				if (!(resX60gensym5__1 == ((NI)0))) goto LA25_;
				{
					NI iX60gensym5__1;
					NI colontmp_;
					NI res_1;
					iX60gensym5__1 = (NI)0;
					colontmp_ = (NI)0;
					colontmp_ = (NI)(fX60gensym5__1.gl_pathc - ((NI)1));
					res_1 = ((NI)0);
					{
						while (1) {
							NimStringV2 pathX60gensym5__1;
							if (!(res_1 <= colontmp_)) goto LA29;
							pathX60gensym5__1.len = 0; pathX60gensym5__1.p = NIM_NIL;
							iX60gensym5__1 = ((NI) (res_1));
							pathX60gensym5__1 = cstrToNimstr(fX60gensym5__1.gl_pathv[iX60gensym5__1]);
							{
								NIM_BOOL T33_;
								NimStringV2 obj_1;
								NimStringV2 colontmpD__3;
								NimStringV2 colontmpD__4;
								tyProc__RR9bG3onntZdMX59cPU9cJE5g T37_;
								T33_ = (NIM_BOOL)0;
								T33_ = nosfileExists(pathX60gensym5__1);
								if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
								if (!T33_) goto LA34_;
								obj_1.len = 0; obj_1.p = NIM_NIL;
								colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
								colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
								f_1 = pathX60gensym5__1;
								colontmpD__3 = nosextractFilename(f_1);
								if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
								colontmpD__4 = nsuFormatSingleElem(dest_1, colontmpD__3);
								if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
								obj_1 = completeCfilePath__extccomp_u929((*(*c_p0).graph).config, colontmpD__4, NIM_TRUE);
								if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
								nimZeroMem((void*)(&T37_), sizeof(tyProc__RR9bG3onntZdMX59cPU9cJE5g));
								T37_.ClP_0 = docompile__pragmas_u1052; T37_.ClE_0 = colonenv__1;
								T37_.ClE_0? T37_.ClP_0(c_p0, it_1, f_1, obj_1, TM__tPA3StZ6VsKyoznyrIfFxg_160, T37_.ClE_0):((TM__tPA3StZ6VsKyoznyrIfFxg_161)(T37_.ClP_0))(c_p0, it_1, f_1, obj_1, TM__tPA3StZ6VsKyoznyrIfFxg_160);
								if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
								{
									LA36_:;
								}
								{
									eqdestroy___system_u2691(colontmpD__4);
									eqdestroy___system_u2691(colontmpD__3);
									eqdestroy___system_u2691(obj_1);
								}
								if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
							}
LA34_: ;
							res_1 += ((NI)1);
							{
								LA30_:;
							}
							{
								eqdestroy___system_u2691(pathX60gensym5__1);
							}
							if (NIM_UNLIKELY(*nimErr_)) goto LA22_;
						} LA29: ;
					}
				}
			}
LA25_: ;
			{
				LA22_:;
			}
			{
				globfree((&fX60gensym5__1));
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
		}
		{
			LA19_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__2);
			eqdestroy___system_u2691(colontmpD_);
			eqdestroy___system_u2691(found_1);
			eqdestroy___system_u2691(dest_1);
			eqdestroy___system_u2691(s_1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA12_;
LA17_: ;
	{
		NimStringV2 s_2;
		NimStringV2 customArgs_1;
		NimStringV2 found_2;
		NimStringV2 colontmpD__5;
		NimStringV2 colontmpD__6;
		NimStringV2 mangled_1;
		NimStringV2 colontmpD__7;
		NimStringV2 obj_2;
		tyProc__RR9bG3onntZdMX59cPU9cJE5g T79_;
		s_2.len = 0; s_2.p = NIM_NIL;
		customArgs_1.len = 0; customArgs_1.p = NIM_NIL;
		found_2.len = 0; found_2.p = NIM_NIL;
		colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
		colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
		mangled_1.len = 0; mangled_1.p = NIM_NIL;
		colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
		obj_2.len = 0; obj_2.p = NIM_NIL;
		s_2 = TM__tPA3StZ6VsKyoznyrIfFxg_162;
		customArgs_1 = TM__tPA3StZ6VsKyoznyrIfFxg_163;
		{
			NimStringV2 T52_;
			if (!((*(*colonenv__1).n0).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)27) || (*(*colonenv__1).n0).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)29) || (*(*colonenv__1).n0).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)30) || (*(*colonenv__1).n0).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)31) || (*(*colonenv__1).n0).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)26) || (*(*colonenv__1).n0).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)28) || (*(*colonenv__1).n0).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)32))) goto LA50_;
			T52_.len = 0; T52_.p = NIM_NIL;
			T52_ = getStrLit__pragmas_u1059(c_p0, (*colonenv__1).n0, ((NI)1));
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T52_); goto LA47_;}
			eqsink___system_u2700((&s_2), T52_);
			{
				NI T55_;
				NimStringV2 T58_;
				T55_ = (NI)0;
				T55_ = len__ast_u3190((*colonenv__1).n0);
				if (NIM_UNLIKELY(*nimErr_)) goto LA47_;
				if (!(T55_ == ((NI)3))) goto LA56_;
				T58_.len = 0; T58_.p = NIM_NIL;
				T58_ = getStrLit__pragmas_u1059(c_p0, (*colonenv__1).n0, ((NI)2));
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T58_); goto LA47_;}
				eqsink___system_u2700((&customArgs_1), T58_);
			}
			goto LA53_;
LA56_: ;
			{
				liMessage__msgs_u1227((*(*c_p0).graph).config, (*(*colonenv__1).n0).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), TM__tPA3StZ6VsKyoznyrIfFxg_165, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__tPA3StZ6VsKyoznyrIfFxg_166), NIM_FALSE, NIM_FALSE);
				if (NIM_UNLIKELY(*nimErr_)) goto LA47_;
			}
LA53_: ;
		}
		goto LA48_;
LA50_: ;
		{
			NimStringV2 T61_;
			T61_.len = 0; T61_.p = NIM_NIL;
			T61_ = expectStrLit__pragmas_u308(c_p0, (*colonenv__1).n0);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T61_); goto LA47_;}
			eqsink___system_u2700((&s_2), T61_);
		}
LA48_: ;
		colontmpD__5 = toFullPath__msgs_u624((*(*c_p0).graph).config, (*(*colonenv__1).n0).info.fileIndex);
		if (NIM_UNLIKELY(*nimErr_)) goto LA47_;
		colontmpD__6 = nosparentDir(colontmpD__5);
		if (NIM_UNLIKELY(*nimErr_)) goto LA47_;
		found_2 = slash___stdZprivateZospaths2_u91(colontmpD__6, s_2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA47_;
		{
			NIM_BOOL T64_;
			T64_ = (NIM_BOOL)0;
			T64_ = nosfileExists(found_2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA47_;
			if (!!(T64_)) goto LA65_;
			{
				NIM_BOOL T69_;
				NimStringV2 blitTmp_1;
				T69_ = (NIM_BOOL)0;
				T69_ = nosisAbsolute(s_2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA47_;
				if (!T69_) goto LA70_;
				blitTmp_1 = s_2;
				eqwasMoved___system_u2688((&s_2));
				eqsink___system_u2700((&found_2), blitTmp_1);
			}
			goto LA67_;
LA70_: ;
			{
				NimStringV2 T73_;
				T73_.len = 0; T73_.p = NIM_NIL;
				T73_ = findFile__options_u4081((*(*c_p0).graph).config, s_2, NIM_FALSE);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T73_); goto LA47_;}
				eqsink___system_u2700((&found_2), T73_);
				{
					NIM_BOOL T76_;
					NimStringV2 blitTmp_2;
					T76_ = (NIM_BOOL)0;
					T76_ = isEmpty__options_u4086(found_2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA47_;
					if (!T76_) goto LA77_;
					blitTmp_2 = s_2;
					eqwasMoved___system_u2688((&s_2));
					eqsink___system_u2700((&found_2), blitTmp_2);
				}
LA77_: ;
			}
LA67_: ;
		}
LA65_: ;
		colontmpD__7 = mangleModuleName__modulepaths_u40((*(*c_p0).graph).config, found_2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA47_;
		mangled_1 = completeCfilePath__extccomp_u929((*(*c_p0).graph).config, colontmpD__7, NIM_TRUE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA47_;
		obj_2 = toObjFile__extccomp_u934((*(*c_p0).graph).config, mangled_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA47_;
		nimZeroMem((void*)(&T79_), sizeof(tyProc__RR9bG3onntZdMX59cPU9cJE5g));
		T79_.ClP_0 = docompile__pragmas_u1052; T79_.ClE_0 = colonenv__1;
		T79_.ClE_0? T79_.ClP_0(c_p0, it_1, found_2, obj_2, customArgs_1, T79_.ClE_0):((TM__tPA3StZ6VsKyoznyrIfFxg_167)(T79_.ClP_0))(c_p0, it_1, found_2, obj_2, customArgs_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA47_;
		{
			LA47_:;
		}
		{
			eqdestroy___system_u2691(obj_2);
			eqdestroy___system_u2691(colontmpD__7);
			eqdestroy___system_u2691(mangled_1);
			eqdestroy___system_u2691(colontmpD__6);
			eqdestroy___system_u2691(colontmpD__5);
			eqdestroy___system_u2691(found_2);
			eqdestroy___system_u2691(customArgs_1);
			eqdestroy___system_u2691(s_2);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA12_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3252(it_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___pragmas_u2791(colonenv__1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, relativeFile__pragmas_u1040)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, NimStringV2 ext_p2) {
	NimStringV2 result;
	NimStringV2 s_1;
	tyTuple__7q7q3E6Oj24ZNVJb9aonhAg colontmpD_;
	NimStringV2 colontmpD__2;
	NimStringV2 colontmpD__3;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	s_1.len = 0; s_1.p = NIM_NIL;
	nimZeroMem((void*)(&colontmpD_), sizeof(tyTuple__7q7q3E6Oj24ZNVJb9aonhAg));
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
	s_1 = expectStrLit__pragmas_u308(c_p0, n_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NIM_BOOL T4_;
		NimStringV2 T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = (((NI)0) < ext_p2.len);
		if (!(T4_)) goto LA5_;
		nossplitFile(s_1, (&colontmpD_));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T4_ = (colontmpD_.Field2.len == 0);
LA5_: ;
		if (!T4_) goto LA6_;
		T8_.len = 0; T8_.p = NIM_NIL;
		T8_ = nosaddFileExt(s_1, ext_p2);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T8_); goto LA1_;}
		eqsink___system_u2700((&s_1), T8_);
	}
LA6_: ;
	colontmpD__2 = toFullPath__msgs_u624((*(*c_p0).graph).config, (*n_p1).info.fileIndex);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__3 = nosparentDir(colontmpD__2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	result = slash___stdZprivateZospaths2_u91(colontmpD__3, s_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NIM_BOOL T11_;
		T11_ = (NIM_BOOL)0;
		T11_ = nosfileExists(result);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!!(T11_)) goto LA12_;
		{
			NIM_BOOL T16_;
			NimStringV2 blitTmp_1;
			T16_ = (NIM_BOOL)0;
			T16_ = nosisAbsolute(s_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			if (!T16_) goto LA17_;
			blitTmp_1 = s_1;
			eqwasMoved___system_u2688((&s_1));
			eqsink___system_u2700((&result), blitTmp_1);
		}
		goto LA14_;
LA17_: ;
		{
			NimStringV2 T20_;
			T20_.len = 0; T20_.p = NIM_NIL;
			T20_ = findFile__options_u4081((*(*c_p0).graph).config, s_1, NIM_FALSE);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T20_); goto LA1_;}
			eqsink___system_u2700((&result), T20_);
			{
				NIM_BOOL T23_;
				NimStringV2 blitTmp_2;
				T23_ = (NIM_BOOL)0;
				T23_ = isEmpty__options_u4086(result);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				if (!T23_) goto LA24_;
				blitTmp_2 = s_1;
				eqwasMoved___system_u2688((&s_1));
				eqsink___system_u2700((&result), blitTmp_2);
			}
LA24_: ;
		}
LA14_: ;
	}
LA12_: ;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD__3);
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___pureZos_u200((&colontmpD_));
		eqdestroy___system_u2691(s_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, processLink__pragmas_u1092)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
	NimStringV2 found_1;
	tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T2_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	found_1.len = 0; found_1.p = NIM_NIL;
	found_1 = relativeFile__pragmas_u1040(c_p0, n_p1, CC__extccomp_u624[((*(*(*c_p0).graph).config).cCompiler)- 1].Field1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	addExternalFileToLink__extccomp_u977((*(*c_p0).graph).config, found_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T2_[0] = TM__tPA3StZ6VsKyoznyrIfFxg_169;
	T2_[1] = found_1;
	recordPragma__pragmas_u127(c_p0, n_p1, T2_, 2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(found_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(NIM_BOOL, isTopLevel__semdata_u4679)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0) {
	NIM_BOOL result;
	result = ((*(*c_p0).currentScope).depthLevel <= ((NI)2));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, processExperimental__pragmas_u842)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NIM_BOOL T3_;
		NI T5_;
		T3_ = (NIM_BOOL)0;
		T3_ = !(((*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)34) || (*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)27) || (*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)28)));
		if (T3_) goto LA4_;
		T5_ = (NI)0;
		T5_ = len__ast_u3190(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T3_ = !((T5_ == ((NI)2)));
LA4_: ;
		if (!T3_) goto LA6_;
		(*c_p0).features = ((*c_p0).features | 7);
	}
	goto LA1_;
LA6_: ;
	{
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T9_;
		T9_ = NIM_NIL;
		T9_ = (*c_p0).semConstExpr(c_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL));
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T9_); goto BeforeRet_;}
		eqsink___ast_u3261(&(*n_p1)._kind_6.sons.p->data[((NI)1)], T9_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		switch ((*(*n_p1)._kind_6.sons.p->data[((NI)1)]).kind) {
		case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)20):
		case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)21):
		case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)22):
		{
			tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ feature_1;
			tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ T12_;
			T12_ = (tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ)0;
			T12_ = parseEnum__commands_u900((*(*n_p1)._kind_6.sons.p->data[((NI)1)])._kind_3.strVal);
			if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
			feature_1 = T12_;
			(*c_p0).features |= ((NU32)1)<<(((feature_1)) & 31);
			{
				if (!(feature_1 == ((tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ)8))) goto LA15_;
				{
					NIM_BOOL T19_;
					T19_ = (NIM_BOOL)0;
					T19_ = isTopLevel__semdata_u4679(c_p0);
					if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
					if (!!(T19_)) goto LA20_;
					liMessage__msgs_u1227((*(*c_p0).graph).config, (*n_p1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), TM__tPA3StZ6VsKyoznyrIfFxg_180, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__tPA3StZ6VsKyoznyrIfFxg_181), NIM_FALSE, NIM_FALSE);
					if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
				}
LA20_: ;
				(*(*c_p0).module).flags |= ((NU64)1)<<(((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)4))) & 63);
			}
LA15_: ;
			if (NIM_UNLIKELY(*nimErr_)) {
				LA11_:;
				if (isObjDisplayCheck(nimBorrowCurrentException()->Sup.m_type, 3, 1871340544)) {
					*nimErr_ = NIM_FALSE;
					liMessage__msgs_u1227((*(*c_p0).graph).config, (*(*n_p1)._kind_6.sons.p->data[((NI)1)]).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), TM__tPA3StZ6VsKyoznyrIfFxg_183, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__tPA3StZ6VsKyoznyrIfFxg_184), NIM_FALSE, NIM_FALSE);
					if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
					popCurrentException();
					LA23_:;
				}
			}
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		break;
		default:
		{
			liMessage__msgs_u1227((*(*c_p0).graph).config, (*n_p1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), TM__tPA3StZ6VsKyoznyrIfFxg_185, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__tPA3StZ6VsKyoznyrIfFxg_186), NIM_FALSE, NIM_FALSE);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		break;
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
static N_INLINE(tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ, pragmaToOptions__pragmas_u839)(tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw w_p0) {
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ result;
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ T1_;
	switch (w_p0) {
	case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)156):
	{
		result = 3518;
	}
	break;
	case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)80):
	{
		result = 2;
	}
	break;
	case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)202):
	{
		result = 4;
	}
	break;
	case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)157):
	{
		result = 8;
	}
	break;
	case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)158):
	{
		result = 16;
	}
	break;
	case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)159):
	{
		result = 32;
	}
	break;
	case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)161):
	{
		result = 384;
	}
	break;
	case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)162):
	{
		result = 128;
	}
	break;
	case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)163):
	{
		result = 256;
	}
	break;
	case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)165):
	{
		result = 512;
	}
	break;
	case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)164):
	{
		result = 1024;
	}
	break;
	case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)168):
	{
		result = 2048;
	}
	break;
	case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)172):
	{
		result = 8192;
	}
	break;
	case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)173):
	{
		result = 16384;
	}
	break;
	case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)133):
	{
		result = 4096;
	}
	break;
	case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)134):
	{
		result = 131072;
	}
	break;
	case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)135):
	{
		result = 524288;
	}
	break;
	case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)142):
	{
		result = 1;
	}
	break;
	case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)78):
	{
		result = 18874368;
	}
	break;
	case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)79):
	{
		result = 16777216;
	}
	break;
	case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)243):
	{
		result = 1048576;
	}
	break;
	case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)220):
	{
		result = 4194304;
	}
	break;
	case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)169):
	case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)170):
	{
		result = 8388608;
	}
	break;
	case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)171):
	{
		result = 33554432;
	}
	break;
	case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)233):
	{
		result = 268435456;
	}
	break;
	default:
	{
		result = 0;
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, onOff__pragmas_u426)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ op_p2, tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ* resOptions_p3) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = isTurnedOn__pragmas_u411(c_p0, n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!T3_) goto LA4_;
		(*resOptions_p3) = ((*resOptions_p3) | op_p2);
	}
	goto LA1_;
LA4_: ;
	{
		(*resOptions_p3) = ((*resOptions_p3) & ~ op_p2);
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ, wordToCallConv__pragmas_u398)(tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw sw_p0) {
	tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ result;
	result = (tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ)0;
	result = ((tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ) ((NI)((NI)(((NI)0) + sw_p0) - ((NI)143))));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, processCallConv__pragmas_u495)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NIM_BOOL T3_;
		NIM_BOOL T4_;
		NI T6_;
		tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw sw_1;
		T3_ = (NIM_BOOL)0;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)34) || (*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)27) || (*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)28));
		if (!(T4_)) goto LA5_;
		T6_ = (NI)0;
		T6_ = len__ast_u3190(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T4_ = (T6_ == ((NI)2));
LA5_: ;
		T3_ = T4_;
		if (!(T3_)) goto LA7_;
		T3_ = ((*(*n_p1)._kind_6.sons.p->data[((NI)1)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)2));
LA7_: ;
		if (!T3_) goto LA8_;
		sw_1 = whichKeyword__idents_u360((*(*n_p1)._kind_6.sons.p->data[((NI)1)])._kind_5.ident);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		switch (sw_1) {
		case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)143) ... ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)153):
		{
			tyObject_TOptionEntry__KeABxBvAlGa1KroFfkcqAg** T11_;
			tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ T12_;
			T11_ = (tyObject_TOptionEntry__KeABxBvAlGa1KroFfkcqAg**)0;
			T11_ = X5BX5D___semdata_u454((((*c_p0).optionStack).p) ? ((*c_p0).optionStack.p->data) : NIM_NIL, (*c_p0).optionStack.len, ((NI)1));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			T12_ = (tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ)0;
			T12_ = wordToCallConv__pragmas_u398(sw_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			(*(*T11_)).defaultCC = T12_;
		}
		break;
		default:
		{
			liMessage__msgs_u1227((*(*c_p0).graph).config, (*n_p1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), TM__tPA3StZ6VsKyoznyrIfFxg_188, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__tPA3StZ6VsKyoznyrIfFxg_189), NIM_FALSE, NIM_FALSE);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		break;
		}
	}
	goto LA1_;
LA8_: ;
	{
		liMessage__msgs_u1227((*(*c_p0).graph).config, (*n_p1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), TM__tPA3StZ6VsKyoznyrIfFxg_190, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__tPA3StZ6VsKyoznyrIfFxg_191), NIM_FALSE, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, tryProcessOption__pragmas_u886)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ* resOptions_p2) {
	NIM_BOOL result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_TRUE;
	{
		NIM_BOOL T3_;
		NI T5_;
		T3_ = (NIM_BOOL)0;
		T3_ = !(((*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)34) || (*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)27) || (*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)28)));
		if (T3_) goto LA4_;
		T5_ = (NI)0;
		T5_ = len__ast_u3190(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T3_ = !((T5_ == ((NI)2)));
LA4_: ;
		if (!T3_) goto LA6_;
		result = NIM_FALSE;
	}
	goto LA1_;
LA6_: ;
	{
		if (!((*(*n_p1)._kind_6.sons.p->data[((NI)0)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)42))) goto LA9_;
		processNote__pragmas_u654(c_p0, n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA9_: ;
	{
		if (!!(((*(*n_p1)._kind_6.sons.p->data[((NI)0)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)2)))) goto LA12_;
		result = NIM_FALSE;
	}
	goto LA1_;
LA12_: ;
	{
		tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw sw_1;
		tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ opts_1;
		sw_1 = whichKeyword__idents_u360((*(*n_p1)._kind_6.sons.p->data[((NI)0)])._kind_5.ident);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		{
			if (!(sw_1 == ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)209))) goto LA17_;
			processExperimental__pragmas_u842(c_p0, n_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			result = NIM_TRUE;
			goto BeforeRet_;
		}
LA17_: ;
		opts_1 = pragmaToOptions__pragmas_u839(sw_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		{
			tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ T21_;
			T21_ = 0;
			if (!!((opts_1 == T21_))) goto LA22_;
			onOff__pragmas_u426(c_p0, n_p1, opts_1, resOptions_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		goto LA19_;
LA22_: ;
		{
			switch (sw_1) {
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)141):
			{
				processCallConv__pragmas_u495(c_p0, n_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)116):
			{
				processDynLib__pragmas_u612(c_p0, n_p1, ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL));
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)174):
			{
				{
					if (!!(((*(*n_p1)._kind_6.sons.p->data[((NI)1)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)2)))) goto LA30_;
					invalidPragma__pragmas_u142(c_p0, n_p1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				}
				goto LA28_;
LA30_: ;
				{
					NimStringV2 colontmpD_;
					colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
					colontmpD_ = nsuNormalize((*(*(*n_p1)._kind_6.sons.p->data[((NI)1)])._kind_5.ident).s);
					if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
					if (eqStrings(colontmpD_, TM__tPA3StZ6VsKyoznyrIfFxg_193)) goto LA34_;
					if (eqStrings(colontmpD_, TM__tPA3StZ6VsKyoznyrIfFxg_195)) goto LA35_;
					if (eqStrings(colontmpD_, TM__tPA3StZ6VsKyoznyrIfFxg_197)) goto LA36_;
					goto LA37_;
					LA34_: ;
					{
						(*resOptions_p2) |= ((NU32)1)<<(((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)15))) & 31);
						(*resOptions_p2) &= ~(((NU32)1) << (((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)16))) & 31));
					}
					goto LA38_;
					LA35_: ;
					{
						(*resOptions_p2) &= ~(((NU32)1) << (((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)15))) & 31));
						(*resOptions_p2) |= ((NU32)1)<<(((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)16))) & 31);
					}
					goto LA38_;
					LA36_: ;
					{
						(*resOptions_p2) &= ~(((NU32)1) << (((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)15))) & 31));
						(*resOptions_p2) &= ~(((NU32)1) << (((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)16))) & 31));
					}
					goto LA38_;
					LA37_: ;
					{
						liMessage__msgs_u1227((*(*c_p0).graph).config, (*n_p1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), TM__tPA3StZ6VsKyoznyrIfFxg_199, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__tPA3StZ6VsKyoznyrIfFxg_200), NIM_FALSE, NIM_FALSE);
						if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
					}
LA38_: ;
					{
						LA33_:;
					}
					{
						eqdestroy___system_u2691(colontmpD_);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				}
LA28_: ;
			}
			break;
			default:
			{
				result = NIM_FALSE;
			}
			break;
			}
		}
LA19_: ;
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, checkPushedPragma__pragmas_u945)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* key_1;
	NIM_BOOL keyDeep_1;
	NIM_BOOL T2_;
	NI T4_;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T5_;
NIM_BOOL oldNimErrFin15_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	key_1 = NIM_NIL;
	T2_ = (NIM_BOOL)0;
	T2_ = ((*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)34) || (*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)27) || (*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)28));
	if (!(T2_)) goto LA3_;
	T4_ = (NI)0;
	T4_ = len__ast_u3190(n_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T2_ = (((NI)1) < T4_);
LA3_: ;
	keyDeep_1 = T2_;
	T5_ = NIM_NIL;
	{
		if (!keyDeep_1) goto LA8_;
		eqcopy___ast_u3255(&key_1, (*n_p1)._kind_6.sons.p->data[((NI)0)]);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA6_;
LA8_: ;
	{
		eqcopy___ast_u3255(&key_1, n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA6_: ;
	{
		tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* ident_1;
		tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* userPragma_1;
		if (!((*key_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)2) || (*key_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3) || (*key_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)53) || (*key_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)57) || (*key_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)56) || (*key_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)165))) goto LA13_;
		ident_1 = NIM_NIL;
		userPragma_1 = NIM_NIL;
		ident_1 = considerQuotedIdent__lookups_u31(c_p0, key_1, ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL));
		if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
		userPragma_1 = strTableGet__astalgo_u2726((*c_p0).userPragmas, ident_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
		{
			tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw k_1;
			if (!(userPragma_1 == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL))) goto LA18_;
			k_1 = whichKeyword__idents_u360(ident_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
			{
				if (!(k_1 == ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)217))) goto LA22_;
				liMessage__msgs_u1227((*(*c_p0).graph).config, (*n_p1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), TM__tPA3StZ6VsKyoznyrIfFxg_202, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__tPA3StZ6VsKyoznyrIfFxg_203), NIM_FALSE, NIM_FALSE);
				if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
			}
LA22_: ;
		}
LA18_: ;
		{
			LA15_:;
		}
		{
			oldNimErrFin15_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u4574(userPragma_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___idents_u155(ident_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin15_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA13_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3252(key_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, processPush__pragmas_u969)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, NI start_p2) {
	tyObject_TOptionEntry__KeABxBvAlGa1KroFfkcqAg* x_1;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	x_1 = NIM_NIL;
	{
		if (!((*(*n_p1)._kind_6.sons.p->data[(NI)(start_p2 - ((NI)1))]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)34) || (*(*n_p1)._kind_6.sons.p->data[(NI)(start_p2 - ((NI)1))]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)27) || (*(*n_p1)._kind_6.sons.p->data[(NI)(start_p2 - ((NI)1))]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)28))) goto LA4_;
		liMessage__msgs_u1227((*(*c_p0).graph).config, (*n_p1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), TM__tPA3StZ6VsKyoznyrIfFxg_177, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__tPA3StZ6VsKyoznyrIfFxg_178), NIM_FALSE, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA4_: ;
	x_1 = pushOptionEntry__semdata_u2309(c_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NI i_1;
		NI colontmp_;
		NI i_2;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_u3190(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		i_2 = start_p2;
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA8;
				i_1 = i_2;
				{
					tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* T11_;
					NIM_BOOL T12_;
					T11_ = NIM_NIL;
					T11_ = c_p0;
					T12_ = (NIM_BOOL)0;
					T12_ = tryProcessOption__pragmas_u886(T11_, (*n_p1)._kind_6.sons.p->data[i_1], (&(*(*(*c_p0).graph).config).options));
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					if (!!(T12_)) goto LA13_;
					checkPushedPragma__pragmas_u945(c_p0, (*n_p1)._kind_6.sons.p->data[i_1]);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					{
						tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T19_;
						if (!((*x_1).otherPragmas == 0)) goto LA17_;
						T19_ = NIM_NIL;
						T19_ = newNodeI__ast_u4091(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)90), (*n_p1).info);
						if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T19_); goto LA1_;}
						eqsink___ast_u3261(&(*x_1).otherPragmas, T19_);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					}
LA17_: ;
					add__ast_u3215((*x_1).otherPragmas, (*n_p1)._kind_6.sons.p->data[i_1]);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				}
LA13_: ;
				i_2 += ((NI)1);
			} LA8: ;
		}
	}
	{
		if (!!((((*(*c_p0).optionStack.p->data[((NI)0)]).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)17)))&31U)))!=0))) goto LA22_;
		(*(*(*c_p0).graph).config).options &= ~(((NU32)1) << (((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)17))) & 31));
	}
LA22_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___semdata_u611(x_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, processPop__pragmas_u994)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NI T3_;
		T3_ = (*c_p0).optionStack.len;
		if (!(T3_ <= ((NI)1))) goto LA4_;
		liMessage__msgs_u1227((*(*c_p0).graph).config, (*n_p1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), TM__tPA3StZ6VsKyoznyrIfFxg_205, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__tPA3StZ6VsKyoznyrIfFxg_206), NIM_FALSE, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA4_: ;
	{
		popOptionEntry__semdata_u2337(c_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
}
static N_INLINE(tyObject_HSlice__JgojxK65oMA6E0HRsL2Wig, dotdot___stdZenumutils_u106)(NI a_p0, NI b_p1) {
	tyObject_HSlice__JgojxK65oMA6E0HRsL2Wig result;
	result.a = a_p0;
	result.b = b_p1;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, processPragma__pragmas_u1199)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, NI i_p2) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* it_1;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* userPragma_1;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD_;
	tySequence__9ahcSjIErJohSBBFLwuF56Q colontmpD__2;
	tyObject_HSlice__JgojxK65oMA6E0HRsL2Wig T47_;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T48_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	it_1 = NIM_NIL;
	userPragma_1 = NIM_NIL;
	colontmpD_ = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	eqcopy___ast_u3255(&it_1, (*n_p1)._kind_6.sons.p->data[i_p2]);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NIM_BOOL T4_;
		NI T6_;
		T4_ = (NIM_BOOL)0;
		T4_ = !(((*it_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)34) || (*it_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)27) || (*it_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)28)));
		if (!(T4_)) goto LA5_;
		T6_ = (NI)0;
		T6_ = safeLen__ast_u3197(it_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T4_ = (T6_ == ((NI)2));
LA5_: ;
		if (!T4_) goto LA7_;
		invalidPragma__pragmas_u142(c_p0, n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		eqdestroy___ast_u3696(colontmpD__2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u4574(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u4574(userPragma_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3252(it_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		goto BeforeRet_;
	}
	goto LA2_;
LA7_: ;
	{
		NIM_BOOL T10_;
		NIM_BOOL T11_;
		NI T12_;
		T10_ = (NIM_BOOL)0;
		T11_ = (NIM_BOOL)0;
		T12_ = (NI)0;
		T12_ = safeLen__ast_u3197(it_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T11_ = !((T12_ == ((NI)2)));
		if (T11_) goto LA13_;
		T11_ = !(((*(*it_1)._kind_6.sons.p->data[((NI)0)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)2)));
LA13_: ;
		T10_ = T11_;
		if (T10_) goto LA14_;
		T10_ = !(((*(*it_1)._kind_6.sons.p->data[((NI)1)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)2)));
LA14_: ;
		if (!T10_) goto LA15_;
		invalidPragma__pragmas_u142(c_p0, n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		eqdestroy___ast_u3696(colontmpD__2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u4574(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u4574(userPragma_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3252(it_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		goto BeforeRet_;
	}
	goto LA2_;
LA15_: ;
LA2_: ;
	userPragma_1 = newSym__ast_u4205(((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)18), (*(*it_1)._kind_6.sons.p->data[((NI)1)])._kind_5.ident, (*c_p0).Sup.idgen, (*c_p0).module, (*it_1).info, (*(*(*c_p0).graph).config).options);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NIM_BOOL T19_;
		NIM_BOOL T20_;
		NIM_BOOL T21_;
		NIM_BOOL T22_;
		NIM_BOOL T23_;
		NIM_BOOL T24_;
		NIM_BOOL T25_;
		NIM_BOOL T26_;
		NIM_BOOL T27_;
		NIM_BOOL T28_;
		NIM_BOOL T29_;
		tySet_tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A T31_;
		NIM_BOOL T40_;
		tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg T43_;
		T19_ = (NIM_BOOL)0;
		T20_ = (NIM_BOOL)0;
		T21_ = (NIM_BOOL)0;
		T22_ = (NIM_BOOL)0;
		T23_ = (NIM_BOOL)0;
		T24_ = (NIM_BOOL)0;
		T25_ = (NIM_BOOL)0;
		T26_ = (NIM_BOOL)0;
		T27_ = (NIM_BOOL)0;
		T28_ = (NIM_BOOL)0;
		T29_ = (NIM_BOOL)0;
		T29_ = (((*(*(*c_p0).graph).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)10)))&31U)))!=0);
		if (!(T29_)) goto LA30_;
		T31_ = 0;
		T29_ = !(((229376 & (*(*(*c_p0).graph).config).globalOptions) == T31_));
LA30_: ;
		T28_ = T29_;
		if (!(T28_)) goto LA32_;
		T28_ = (((*(*(*c_p0).graph).config).notes[(NU)((((tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw)107) - 20))>>3] &(1U<<((NU)((((tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw)107) - 20))&7U)))!=0);
LA32_: ;
		T27_ = T28_;
		if (!(T27_)) goto LA33_;
		colontmpD_ = getModule__modulegraphs_u14809((*c_p0).graph, (*userPragma_1).info.fileIndex);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T27_ = belongsToProjectPackageMaybeNil__packages_u85((*(*c_p0).graph).config, colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
LA33_: ;
		T26_ = T27_;
		if (!(T26_)) goto LA34_;
		T26_ = !((((*(*(*c_p0).graph).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)18)))&63U)))!=0));
LA34_: ;
		T25_ = T26_;
		if (!(T25_)) goto LA35_;
		T25_ = !(((*userPragma_1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)11)));
LA35_: ;
		T24_ = T25_;
		if (!(T24_)) goto LA36_;
		T24_ = !(((*userPragma_1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)5)));
LA36_: ;
		T23_ = T24_;
		if (!(T23_)) goto LA37_;
		T23_ = (((NU8)((*(*userPragma_1).name).s.p->data[((NI)0)])) >= ((NU8)(97)) && ((NU8)((*(*userPragma_1).name).s.p->data[((NI)0)])) <= ((NU8)(122)) || ((NU8)((*(*userPragma_1).name).s.p->data[((NI)0)])) >= ((NU8)(65)) && ((NU8)((*(*userPragma_1).name).s.p->data[((NI)0)])) <= ((NU8)(90)) || ((NU8)((*(*userPragma_1).name).s.p->data[((NI)0)])) >= ((NU8)(48)) && ((NU8)((*(*userPragma_1).name).s.p->data[((NI)0)])) <= ((NU8)(57)) || ((NU8)((*(*userPragma_1).name).s.p->data[((NI)0)])) >= ((NU8)(128)) && ((NU8)((*(*userPragma_1).name).s.p->data[((NI)0)])) <= ((NU8)(255)) || ((NU8)((*(*userPragma_1).name).s.p->data[((NI)0)])) == ((NU8)(95)));
LA37_: ;
		T22_ = T23_;
		if (!(T22_)) goto LA38_;
		T22_ = !(((*userPragma_1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)7) || (*userPragma_1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)4)));
LA38_: ;
		T21_ = T22_;
		if (!(T21_)) goto LA39_;
		T40_ = (NIM_BOOL)0;
		T40_ = ((*userPragma_1).typ == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL));
		if (T40_) goto LA41_;
		T40_ = !(((*(*userPragma_1).typ).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)8)));
LA41_: ;
		T21_ = T40_;
LA39_: ;
		T20_ = T21_;
		if (!(T20_)) goto LA42_;
		T43_ = 0;
		T20_ = ((192 & (*userPragma_1).flags) == T43_);
LA42_: ;
		T19_ = T20_;
		if (!(T19_)) goto LA44_;
		T19_ = !((((*userPragma_1).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)60)))&63U)))!=0));
LA44_: ;
		if (!T19_) goto LA45_;
		nep1CheckDefImpl__linter_u146((*(*c_p0).graph).config, (*userPragma_1).info, userPragma_1, (*userPragma_1).kind);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA45_: ;
	T47_ = dotdot___stdZenumutils_u106((NI)(i_p2 + ((NI)1)), ((NI)1));
	colontmpD__2 = X5BX5D___pragmas_u1282((((*n_p1)._kind_6.sons).p) ? ((*n_p1)._kind_6.sons.p->data) : NIM_NIL, (*n_p1)._kind_6.sons.len, T47_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T48_ = NIM_NIL;
	T48_ = newTreeI__ast_u4180(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)90), (*n_p1).info, ((colontmpD__2).p) ? (colontmpD__2.p->data) : NIM_NIL, colontmpD__2.len);
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T48_); goto LA1_;}
	eqsink___ast_u3261(&(*userPragma_1).ast, T48_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	strTableAdd__astalgo_u2666((&(*c_p0).userPragmas), userPragma_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3696(colontmpD__2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u4574(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u4574(userPragma_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3252(it_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, processCodegenDecl__pragmas_u345)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_p2) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	T1_ = NIM_NIL;
	T1_ = getStrLitNode__pragmas_u298(c_p0, n_p1);
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T1_); goto BeforeRet_;}
	eqsink___ast_u3261(&(*sym_p2).constraint, T1_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*sym_p2).flags |= ((NU64)1)<<(((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)53))) & 63);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, processOption__pragmas_u941)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ* resOptions_p2) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = tryProcessOption__pragmas_u886(c_p0, n_p1, resOptions_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!(T3_)) goto LA4_;
		liMessage__msgs_u1227((*(*c_p0).graph).config, (*n_p1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), TM__tPA3StZ6VsKyoznyrIfFxg_208, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__tPA3StZ6VsKyoznyrIfFxg_209), NIM_FALSE, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA4_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, semAsmOrEmit__pragmas_u1096)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* con_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, NIM_CHAR marker_p2) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
NIM_BOOL oldNimErrFin44_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	switch ((*(*n_p1)._kind_6.sons.p->data[((NI)1)]).kind) {
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)20):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)21):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)22):
	{
		tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw colontmpD_;
		tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw colontmpD__2;
		NimStringV2 str_1;
		tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw T2_;
		NI a_1;
		colontmpD_ = (tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)0;
		colontmpD__2 = (tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)0;
		str_1.len = 0; str_1.p = NIM_NIL;
		T2_ = (tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)0;
		{
			if (!((*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)89))) goto LA5_;
			colontmpD_ = ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)89);
			T2_ = colontmpD_;
		}
		goto LA3_;
LA5_: ;
		{
			colontmpD__2 = ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)152);
			T2_ = colontmpD__2;
		}
LA3_: ;
		result = newNodeI__ast_u4091(T2_, (*n_p1).info);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		{
			if (!((*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)89))) goto LA10_;
			add__ast_u3215(result, (*n_p1)._kind_6.sons.p->data[((NI)0)]);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA10_: ;
		str_1 = (*(*n_p1)._kind_6.sons.p->data[((NI)1)])._kind_3.strVal;
		{
			if (!(str_1.len == 0)) goto LA14_;
			liMessage__msgs_u1227((*(*con_p0).graph).config, (*n_p1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), TM__tPA3StZ6VsKyoznyrIfFxg_213, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__tPA3StZ6VsKyoznyrIfFxg_214), NIM_FALSE, NIM_FALSE);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			goto BeforeRet_;
		}
LA14_: ;
		a_1 = ((NI)0);
		{
			while (1) {
				NimStringV2 sub_1;
				NI b_1;
				NimStringV2 T19_;
				NI c_1;
				sub_1.len = 0; sub_1.p = NIM_NIL;
				b_1 = nsuFindChar(str_1, marker_p2, (a_1), ((NI)-1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
				T19_.len = 0; T19_.p = NIM_NIL;
				{
					if (!(b_1 < ((NI)0))) goto LA22_;
					sub_1 = substr__system_u8664(str_1, a_1);
				}
				goto LA20_;
LA22_: ;
				{
					sub_1 = substr__system_u8651(str_1, a_1, (NI)(b_1 - ((NI)1)));
				}
LA20_: ;
				{
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__3;
					if (!!((sub_1.len == 0))) goto LA27_;
					colontmpD__3 = NIM_NIL;
					colontmpD__3 = newStrNode__ast_u5422(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)20), sub_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
					add__ast_u3215(result, colontmpD__3);
					if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
					eqdestroy___ast_u3252(colontmpD__3);
					if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
				}
LA27_: ;
				{
					if (!(b_1 < ((NI)0))) goto LA31_;
					eqdestroy___system_u2691(sub_1);
					goto LA16;
				}
LA31_: ;
				c_1 = nsuFindChar(str_1, marker_p2, ((NI)(b_1 + ((NI)1))), ((NI)-1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
				{
					NimStringV2 T37_;
					if (!(c_1 < ((NI)0))) goto LA35_;
					T37_.len = 0; T37_.p = NIM_NIL;
					T37_ = substr__system_u8664(str_1, (NI)(b_1 + ((NI)1)));
					eqsink___system_u2700((&sub_1), T37_);
				}
				goto LA33_;
LA35_: ;
				{
					NimStringV2 T39_;
					T39_.len = 0; T39_.p = NIM_NIL;
					T39_ = substr__system_u8651(str_1, (NI)(b_1 + ((NI)1)), (NI)(c_1 - ((NI)1)));
					eqsink___system_u2700((&sub_1), T39_);
				}
LA33_: ;
				{
					tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* e_1;
					tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* colontmpD__4;
					NIM_BOOL amb_1;
					if (!!((sub_1.len == 0))) goto LA42_;
					e_1 = NIM_NIL;
					colontmpD__4 = NIM_NIL;
					amb_1 = NIM_FALSE;
					colontmpD__4 = getIdent__idents_u206((*con_p0).cache, sub_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA44_;
					e_1 = searchInScopes__lookups_u2425(con_p0, colontmpD__4, (&amb_1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA44_;
					{
						if (!!((e_1 == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)))) goto LA47_;
						(*e_1).flags |= ((NU64)1)<<(((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)0))) & 63);
						{
							NIM_BOOL T51_;
							tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__5;
							tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__6;
							T51_ = (NIM_BOOL)0;
							T51_ = isDefined__options_u959((*(*con_p0).graph).config, TM__tPA3StZ6VsKyoznyrIfFxg_216);
							if (NIM_UNLIKELY(*nimErr_)) goto LA44_;
							if (!T51_) goto LA52_;
							colontmpD__5 = NIM_NIL;
							colontmpD__6 = NIM_NIL;
							colontmpD__5 = newSymNode__ast_u5168(e_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA44_;
							colontmpD__6 = (*con_p0).semExprWithType(con_p0, colontmpD__5, 4194304, ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL));
							if (NIM_UNLIKELY(*nimErr_)) goto LA44_;
							add__ast_u3215(result, colontmpD__6);
							if (NIM_UNLIKELY(*nimErr_)) goto LA44_;
							eqdestroy___ast_u3252(colontmpD__6);
							if (NIM_UNLIKELY(*nimErr_)) goto LA44_;
							eqdestroy___ast_u3252(colontmpD__5);
							if (NIM_UNLIKELY(*nimErr_)) goto LA44_;
						}
						goto LA49_;
LA52_: ;
						{
							tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__7;
							colontmpD__7 = NIM_NIL;
							colontmpD__7 = newSymNode__ast_u5168(e_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA44_;
							add__ast_u3215(result, colontmpD__7);
							if (NIM_UNLIKELY(*nimErr_)) goto LA44_;
							eqdestroy___ast_u3252(colontmpD__7);
							if (NIM_UNLIKELY(*nimErr_)) goto LA44_;
						}
LA49_: ;
					}
					goto LA45_;
LA47_: ;
					{
						tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__8;
						colontmpD__8 = NIM_NIL;
						colontmpD__8 = newStrNode__ast_u5422(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)20), sub_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA44_;
						add__ast_u3215(result, colontmpD__8);
						if (NIM_UNLIKELY(*nimErr_)) goto LA44_;
						eqdestroy___ast_u3252(colontmpD__8);
						if (NIM_UNLIKELY(*nimErr_)) goto LA44_;
					}
LA45_: ;
					{
						LA44_:;
					}
					{
						oldNimErrFin44_ = *nimErr_; *nimErr_ = NIM_FALSE;
						eqdestroy___idents_u155(colontmpD__4);
						if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
						eqdestroy___ast_u4574(e_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
						*nimErr_ = oldNimErrFin44_;
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
				}
				goto LA40_;
LA42_: ;
				{
					NimStringV2 colontmpD__9;
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__10;
					colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
					colontmpD__10 = NIM_NIL;
					colontmpD__9 = nimCharToStr(marker_p2);
					colontmpD__10 = newStrNode__ast_u5422(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)20), colontmpD__9);
					if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
					add__ast_u3215(result, colontmpD__10);
					if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
					eqdestroy___ast_u3252(colontmpD__10);
					if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
					eqdestroy___system_u2691(colontmpD__9);
				}
LA40_: ;
				{
					if (!(c_1 < ((NI)0))) goto LA61_;
					eqdestroy___system_u2691(sub_1);
					goto LA16;
				}
LA61_: ;
				a_1 = (NI)(c_1 + ((NI)1));
				{
					LA18_:;
				}
				{
					eqdestroy___system_u2691(sub_1);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			}
		} LA16: ;
	}
	break;
	default:
	{
		illFormedAstLocal__semdata_u4668(n_p1, (*(*con_p0).graph).config);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		result = newNodeI__ast_u4091(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)89), (*n_p1).info);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		{
			if (!((*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)89))) goto LA68_;
			add__ast_u3215(result, (*n_p1)._kind_6.sons.p->data[((NI)0)]);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA68_: ;
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, pragmaEmit__pragmas_u1130)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
NIM_BOOL oldNimErrFin9_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NIM_BOOL T3_;
		NI T5_;
		T3_ = (NIM_BOOL)0;
		T3_ = !(((*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)34) || (*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)27) || (*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)28)));
		if (T3_) goto LA4_;
		T5_ = (NI)0;
		T5_ = len__ast_u3190(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T3_ = !((T5_ == ((NI)2)));
LA4_: ;
		if (!T3_) goto LA6_;
		liMessage__msgs_u1227((*(*c_p0).graph).config, (*n_p1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), TM__tPA3StZ6VsKyoznyrIfFxg_210, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__tPA3StZ6VsKyoznyrIfFxg_211), NIM_FALSE, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA6_: ;
	{
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n1_1;
		n1_1 = NIM_NIL;
		eqcopy___ast_u3255(&n1_1, (*n_p1)._kind_6.sons.p->data[((NI)1)]);
		if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
		{
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* b_1;
			NI T14_;
			if (!((*n1_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)41))) goto LA12_;
			b_1 = NIM_NIL;
			T14_ = (NI)0;
			T14_ = len__ast_u3190(n1_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
			b_1 = newNodeI__ast_u4095(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)41), (*n1_1).info, T14_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
			{
				NI i_1;
				NI colontmp_;
				NI i_2;
				i_1 = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = len__ast_u3190(n1_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
				i_2 = ((NI)0);
				{
					while (1) {
						tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T18_;
						if (!(i_2 < colontmp_)) goto LA17;
						i_1 = i_2;
						T18_ = NIM_NIL;
						T18_ = (*c_p0).semExprWithType(c_p0, (*n1_1)._kind_6.sons.p->data[i_1], 4194304, ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL));
						if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T18_); goto LA9_;}
						eqsink___ast_u3261(&(*b_1)._kind_6.sons.p->data[i_1], T18_);
						if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
						i_2 += ((NI)1);
					} LA17: ;
				}
			}
			eqsink___ast_u3261(&(*n_p1)._kind_6.sons.p->data[((NI)1)], b_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
		}
		goto LA10_;
LA12_: ;
		{
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T20_;
			T20_ = NIM_NIL;
			T20_ = (*c_p0).semConstExpr(c_p0, n1_1, ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL));
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T20_); goto LA9_;}
			eqsink___ast_u3261(&(*n_p1)._kind_6.sons.p->data[((NI)1)], T20_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
			switch ((*(*n_p1)._kind_6.sons.p->data[((NI)1)]).kind) {
			case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)20):
			case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)21):
			case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)22):
			{
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T22_;
				T22_ = NIM_NIL;
				T22_ = semAsmOrEmit__pragmas_u1096(c_p0, n_p1, 96);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T22_); goto LA9_;}
				eqsink___ast_u3261(&(*n_p1)._kind_6.sons.p->data[((NI)1)], T22_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
			}
			break;
			default:
			{
				liMessage__msgs_u1227((*(*c_p0).graph).config, (*n_p1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), TM__tPA3StZ6VsKyoznyrIfFxg_217, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__tPA3StZ6VsKyoznyrIfFxg_218), NIM_FALSE, NIM_FALSE);
				if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
			}
			break;
			}
		}
LA10_: ;
		{
			LA9_:;
		}
		{
			oldNimErrFin9_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3252(n1_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin9_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
}
static N_INLINE(NIM_BOOL, ltpercent___system_u1092)(NI x_p0, NI y_p1) {
	NIM_BOOL result;
	result = ((NU64)(((NU) (x_p0))) < (NU64)(((NU) (y_p1))));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, pragmaUnroll__pragmas_u1159)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!((*(*c_p0).p).nestedLoopCounter <= ((NI)0))) goto LA3_;
		invalidPragma__pragmas_u142(c_p0, n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA3_: ;
	{
		NIM_BOOL T6_;
		NI T8_;
		NI unrollFactor_1;
		T6_ = (NIM_BOOL)0;
		T6_ = ((*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)34) || (*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)27) || (*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)28));
		if (!(T6_)) goto LA7_;
		T8_ = (NI)0;
		T8_ = len__ast_u3190(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T6_ = (T8_ == ((NI)2));
LA7_: ;
		if (!T6_) goto LA9_;
		unrollFactor_1 = expectIntLit__pragmas_u312(c_p0, n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		{
			NIM_BOOL T13_;
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T16_;
			T13_ = (NIM_BOOL)0;
			T13_ = ltpercent___system_u1092(unrollFactor_1, ((NI)32));
			if (!T13_) goto LA14_;
			T16_ = NIM_NIL;
			T16_ = newIntNode__ast_u5200(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)6), ((NI64) (unrollFactor_1)));
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T16_); goto BeforeRet_;}
			eqsink___ast_u3261(&(*n_p1)._kind_6.sons.p->data[((NI)1)], T16_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		goto LA11_;
LA14_: ;
		{
			invalidPragma__pragmas_u142(c_p0, n_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA11_: ;
	}
	goto LA1_;
LA9_: ;
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, pragmaLine__pragmas_u1167)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
NIM_BOOL oldNimErrFin13_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NIM_BOOL T3_;
		NI T5_;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_1;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T8_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)34) || (*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)27) || (*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)28));
		if (!(T3_)) goto LA4_;
		T5_ = (NI)0;
		T5_ = len__ast_u3190(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T3_ = (T5_ == ((NI)2));
LA4_: ;
		if (!T3_) goto LA6_;
		a_1 = NIM_NIL;
		T8_ = NIM_NIL;
		T8_ = (*c_p0).semConstExpr(c_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL));
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T8_); goto BeforeRet_;}
		eqsink___ast_u3261(&(*n_p1)._kind_6.sons.p->data[((NI)1)], T8_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		a_1 = (*n_p1)._kind_6.sons.p->data[((NI)1)];
		{
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* x_1;
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* y_1;
			if (!((*a_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)37) || (*a_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)160))) goto LA11_;
			x_1 = NIM_NIL;
			y_1 = NIM_NIL;
			eqcopy___ast_u3255(&x_1, (*a_1)._kind_6.sons.p->data[((NI)0)]);
			if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
			eqcopy___ast_u3255(&y_1, (*a_1)._kind_6.sons.p->data[((NI)1)]);
			if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
			{
				if (!((*x_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)34))) goto LA16_;
				eqcopy___ast_u3255(&x_1, (*x_1)._kind_6.sons.p->data[((NI)1)]);
				if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
			}
LA16_: ;
			{
				if (!((*y_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)34))) goto LA20_;
				eqcopy___ast_u3255(&y_1, (*y_1)._kind_6.sons.p->data[((NI)1)]);
				if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
			}
LA20_: ;
			{
				if (!!(((*x_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)20)))) goto LA24_;
				liMessage__msgs_u1227((*(*c_p0).graph).config, (*n_p1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), TM__tPA3StZ6VsKyoznyrIfFxg_222, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__tPA3StZ6VsKyoznyrIfFxg_223), NIM_FALSE, NIM_FALSE);
				if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
			}
			goto LA22_;
LA24_: ;
			{
				if (!!(((*y_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)6)))) goto LA27_;
				liMessage__msgs_u1227((*(*c_p0).graph).config, (*n_p1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), TM__tPA3StZ6VsKyoznyrIfFxg_224, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__tPA3StZ6VsKyoznyrIfFxg_225), NIM_FALSE, NIM_FALSE);
				if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
			}
			goto LA22_;
LA27_: ;
			{
				NI32 T30_;
				T30_ = (NI32)0;
				T30_ = fileInfoIdx__msgs_u404((*(*c_p0).graph).config, (*x_1)._kind_3.strVal);
				if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
				(*n_p1).info.fileIndex = T30_;
				(*n_p1).info.line = ((NU16) ((*y_1)._kind_1.intVal));
			}
LA22_: ;
			{
				LA13_:;
			}
			{
				oldNimErrFin13_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u3252(y_1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				eqdestroy___ast_u3252(x_1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				*nimErr_ = oldNimErrFin13_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		goto LA9_;
LA11_: ;
		{
			liMessage__msgs_u1227((*(*c_p0).graph).config, (*n_p1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), TM__tPA3StZ6VsKyoznyrIfFxg_227, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__tPA3StZ6VsKyoznyrIfFxg_228), NIM_FALSE, NIM_FALSE);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA9_: ;
	}
	goto LA1_;
LA6_: ;
	{
		tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T35_;
		nimZeroMem((void*)(&T35_), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
		T35_ = getInfoContext__msgs_u602((*(*c_p0).graph).config, ((NI)-1));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*n_p1).info = T35_;
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, pragmaLockStmt__pragmas_u1330)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* it_p1) {
NIM_BOOL oldNimErrFin9_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NIM_BOOL T3_;
		NI T5_;
		T3_ = (NIM_BOOL)0;
		T3_ = !(((*it_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)34) || (*it_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)27) || (*it_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)28)));
		if (T3_) goto LA4_;
		T5_ = (NI)0;
		T5_ = len__ast_u3190(it_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T3_ = !((T5_ == ((NI)2)));
LA4_: ;
		if (!T3_) goto LA6_;
		invalidPragma__pragmas_u142(c_p0, it_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA6_: ;
	{
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_1;
		n_1 = NIM_NIL;
		eqcopy___ast_u3255(&n_1, (*it_p1)._kind_6.sons.p->data[((NI)1)]);
		if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
		{
			if (!!(((*n_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)41)))) goto LA12_;
			liMessage__msgs_u1227((*(*c_p0).graph).config, (*n_1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), TM__tPA3StZ6VsKyoznyrIfFxg_230, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__tPA3StZ6VsKyoznyrIfFxg_231), NIM_FALSE, NIM_FALSE);
			if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
		}
		goto LA10_;
LA12_: ;
		{
			{
				NI i_1;
				NI colontmp_;
				NI i_2;
				i_1 = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = len__ast_u3190(n_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
				i_2 = ((NI)0);
				{
					while (1) {
						tySet_tyEnum_TExprFlag__LJ8tOeZrTQZuHS9cNbj1XCg T18_;
						tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T19_;
						if (!(i_2 < colontmp_)) goto LA17;
						i_1 = i_2;
						T18_ = 0;
						T19_ = NIM_NIL;
						T19_ = (*c_p0).semExpr(c_p0, (*n_1)._kind_6.sons.p->data[i_1], T18_, ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL));
						if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T19_); goto LA9_;}
						eqsink___ast_u3261(&(*n_1)._kind_6.sons.p->data[i_1], T19_);
						if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
						i_2 += ((NI)1);
					} LA17: ;
				}
			}
		}
LA10_: ;
		{
			LA9_:;
		}
		{
			oldNimErrFin9_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3252(n_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin9_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, pragmaGuard__pragmas_u1401)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* it_p1, tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q kind_p2) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* result;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_1;
NIM_BOOL oldNimErrFin25_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	n_1 = NIM_NIL;
	{
		NIM_BOOL T4_;
		NI T6_;
		T4_ = (NIM_BOOL)0;
		T4_ = !(((*it_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)34) || (*it_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)27) || (*it_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)28)));
		if (T4_) goto LA5_;
		T6_ = (NI)0;
		T6_ = len__ast_u3190(it_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T4_ = !((T6_ == ((NI)2)));
LA5_: ;
		if (!T4_) goto LA7_;
		invalidPragma__pragmas_u142(c_p0, it_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		eqdestroy___ast_u3252(n_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		goto BeforeRet_;
	}
LA7_: ;
	eqcopy___ast_u3255(&n_1, (*it_p1)._kind_6.sons.p->data[((NI)1)]);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		if (!((*n_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3))) goto LA11_;
		eqcopy___ast_u4577(&result, (*n_1)._kind_4.sym);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA9_;
LA11_: ;
	{
		tySet_tyEnum_TLookupFlag__l9bvZMRwOrEZawdhQi29c5PQ T16_;
		if (!(kind_p2 == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)19))) goto LA14_;
		T16_ = 0;
		result = qualifiedLookUp__lookups_u5229(c_p0, n_1, T16_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		{
			NIM_BOOL T19_;
			NIM_BOOL T20_;
			tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* colontmpD_;
			tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* T26_;
			T19_ = (NIM_BOOL)0;
			T20_ = (NIM_BOOL)0;
			T20_ = (result == 0);
			if (T20_) goto LA21_;
			T20_ = !(((*result).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)9) || (*result).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)8)));
LA21_: ;
			T19_ = T20_;
			if (T19_) goto LA22_;
			T19_ = !((((*result).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)3)))&63U)))!=0));
LA22_: ;
			if (!T19_) goto LA23_;
			colontmpD_ = NIM_NIL;
			colontmpD_ = considerQuotedIdent__lookups_u31(c_p0, n_1, ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL));
			if (NIM_UNLIKELY(*nimErr_)) goto LA25_;
			T26_ = NIM_NIL;
			T26_ = newSym__ast_u4205(((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)0), colontmpD_, (*c_p0).Sup.idgen, ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL), (*n_1).info, (*(*(*c_p0).graph).config).options);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u4574(T26_); goto LA25_;}
			eqsink___ast_u4583(&result, T26_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA25_;
			{
				LA25_:;
			}
			{
				oldNimErrFin25_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___idents_u155(colontmpD_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				*nimErr_ = oldNimErrFin25_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA23_: ;
	}
	goto LA9_;
LA14_: ;
	{
		result = qualifiedLookUp__lookups_u5229(c_p0, n_1, 2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA9_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3252(n_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, pragmaProposition__pragmas_u157)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NIM_BOOL T3_;
		NI T5_;
		T3_ = (NIM_BOOL)0;
		T3_ = !(((*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)34) || (*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)27) || (*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)28)));
		if (T3_) goto LA4_;
		T5_ = (NI)0;
		T5_ = len__ast_u3190(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T3_ = !((T5_ == ((NI)2)));
LA4_: ;
		if (!T3_) goto LA6_;
		liMessage__msgs_u1227((*(*c_p0).graph).config, (*n_p1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), TM__tPA3StZ6VsKyoznyrIfFxg_244, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__tPA3StZ6VsKyoznyrIfFxg_245), NIM_FALSE, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA6_: ;
	{
		tySet_tyEnum_TExprFlag__LJ8tOeZrTQZuHS9cNbj1XCg T9_;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T10_;
		T9_ = 0;
		T10_ = NIM_NIL;
		T10_ = (*c_p0).semExpr(c_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], T9_, ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL));
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T10_); goto BeforeRet_;}
		eqsink___ast_u3261(&(*n_p1)._kind_6.sons.p->data[((NI)1)], T10_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
}
static N_INLINE(void, addDeclAt__lookups_u3781)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww* scope_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_p2) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	addDeclAt__lookups_u3253(c_p0, scope_p1, sym_p2, (*sym_p2).info);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(void, addDecl__lookups_u3789)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	addDeclAt__lookups_u3781(c_p0, (*c_p0).currentScope, sym_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, pragmaEnsures__pragmas_u166)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
NIM_BOOL oldNimErrFin18_;
NIM_BOOL oldNimErrFin9_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NIM_BOOL T3_;
		NI T5_;
		T3_ = (NIM_BOOL)0;
		T3_ = !(((*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)34) || (*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)27) || (*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)28)));
		if (T3_) goto LA4_;
		T5_ = (NI)0;
		T5_ = len__ast_u3190(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T3_ = !((T5_ == ((NI)2)));
LA4_: ;
		if (!T3_) goto LA6_;
		liMessage__msgs_u1227((*(*c_p0).graph).config, (*n_p1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), TM__tPA3StZ6VsKyoznyrIfFxg_246, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__tPA3StZ6VsKyoznyrIfFxg_247), NIM_FALSE, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA6_: ;
	{
		tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww* colontmpD_;
		tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* o_1;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__2;
		tySet_tyEnum_TExprFlag__LJ8tOeZrTQZuHS9cNbj1XCg T23_;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T24_;
		colontmpD_ = NIM_NIL;
		o_1 = NIM_NIL;
		colontmpD__2 = NIM_NIL;
		colontmpD_ = openScope__lookups_u65(c_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
		o_1 = getCurrOwner__semdata_u425(c_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
		{
			NIM_BOOL T12_;
			NIM_BOOL T13_;
			tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_1;
			tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* colontmpD__3;
			tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ T19_;
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* T20_;
			T12_ = (NIM_BOOL)0;
			T13_ = (NIM_BOOL)0;
			T13_ = ((*o_1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)12) || (*o_1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)13) || (*o_1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)14) || (*o_1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)15) || (*o_1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)16) || (*o_1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)17) || (*o_1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)18));
			if (!(T13_)) goto LA14_;
			T13_ = !(((*o_1).typ == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL)));
LA14_: ;
			T12_ = T13_;
			if (!(T12_)) goto LA15_;
			colontmpD__2 = returnType__ast_u5354((*o_1).typ);
			if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
			T12_ = !((colontmpD__2 == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL)));
LA15_: ;
			if (!T12_) goto LA16_;
			s_1 = NIM_NIL;
			colontmpD__3 = NIM_NIL;
			colontmpD__3 = getIdent__idents_u206((*c_p0).cache, TM__tPA3StZ6VsKyoznyrIfFxg_249);
			if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
			T19_ = 0;
			s_1 = newSym__ast_u4205(((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)11), colontmpD__3, (*c_p0).Sup.idgen, o_1, (*n_p1).info, T19_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
			T20_ = NIM_NIL;
			T20_ = returnType__ast_u5354((*o_1).typ);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3378(T20_); goto LA18_;}
			eqsink___ast_u3387(&(*s_1).typ, T20_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
			(*s_1).flags |= ((NU64)1)<<(((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)0))) & 63);
			addDecl__lookups_u3789(c_p0, s_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
			{
				LA18_:;
			}
			{
				oldNimErrFin18_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___idents_u155(colontmpD__3);
				if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
				eqdestroy___ast_u4574(s_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
				*nimErr_ = oldNimErrFin18_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
		}
LA16_: ;
		T23_ = 0;
		T24_ = NIM_NIL;
		T24_ = (*c_p0).semExpr(c_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], T23_, ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL));
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T24_); goto LA9_;}
		eqsink___ast_u3261(&(*n_p1)._kind_6.sons.p->data[((NI)1)], T24_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
		closeScope__lookups_u102(c_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
		{
			LA9_:;
		}
		{
			oldNimErrFin9_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3378(colontmpD__2);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			eqdestroy___ast_u4574(o_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			eqdestroy___lookups_u74(colontmpD_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin9_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, processVirtual__pragmas_u331)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p2, tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg flag_p3) {
	NimStringV2 colontmpD_;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T2_;
	NimStringV2 T3_;
	tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg T4_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD_ = getOptionalStr__pragmas_u322(c_p0, n_p1, TM__tPA3StZ6VsKyoznyrIfFxg_250);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T2_ = NIM_NIL;
	T2_ = newEmptyStrNode__pragmas_u293(c_p0, n_p1, colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T2_); goto LA1_;}
	eqsink___ast_u3261(&(*s_p2).constraint, T2_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T3_.len = 0; T3_.p = NIM_NIL;
	T3_ = nsuFormatSingleElem((*(*s_p2).constraint)._kind_3.strVal, (*(*s_p2).name).s);
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T3_); goto LA1_;}
	eqsink___system_u2700((&(*(*s_p2).constraint)._kind_3.strVal), T3_);
	T4_ = 0;
	T4_ |=((NU64)(1)<<(((flag_p3))%(sizeof(NU64)*8)));
	T4_ |=((NU64)(1)<<(((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)32)))%(sizeof(NU64)*8)));
	T4_ |=((NU64)(1)<<(((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)7)))%(sizeof(NU64)*8)));
	T4_ |=((NU64)(1)<<(((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)8)))%(sizeof(NU64)*8)));
	(*s_p2).flags = ((*s_p2).flags | T4_);
	(*(*s_p2).typ).callConv = ((tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ)11);
	(*(*(*c_p0).graph).config).globalOptions |= ((NU64)1)<<(((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)40))) & 63);
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD_);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, singlePragma__pragmas_u1506)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p2, NI* i_p3, tySet_tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw validPragmas_p4, NIM_BOOL comesFromPush_p5, NIM_BOOL isStatement_p6) {
	NIM_BOOL result;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* it_1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* key_1;
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* ident_1;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* userPragma_1;
	NIM_BOOL keyDeep_1;
	NIM_BOOL T2_;
	NI T4_;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T5_;
NIM_BOOL oldNimErrFin36_;
NIM_BOOL oldNimErrFin225_;
NIM_BOOL oldNimErrFin243_;
NIM_BOOL oldNimErrFin277_;
NIM_BOOL oldNimErrFin400_;
NIM_BOOL oldNimErrFin415_;
NIM_BOOL oldNimErrFin420_;
NIM_BOOL oldNimErrFin425_;
NIM_BOOL oldNimErrFin76_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	it_1 = NIM_NIL;
	key_1 = NIM_NIL;
	ident_1 = NIM_NIL;
	userPragma_1 = NIM_NIL;
	result = NIM_FALSE;
	eqcopy___ast_u3255(&it_1, (*n_p2)._kind_6.sons.p->data[(*i_p3)]);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T2_ = (NIM_BOOL)0;
	T2_ = ((*it_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)34) || (*it_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)27) || (*it_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)28));
	if (!(T2_)) goto LA3_;
	T4_ = (NI)0;
	T4_ = len__ast_u3190(it_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T2_ = (((NI)1) < T4_);
LA3_: ;
	keyDeep_1 = T2_;
	T5_ = NIM_NIL;
	{
		if (!keyDeep_1) goto LA8_;
		eqcopy___ast_u3255(&key_1, (*it_1)._kind_6.sons.p->data[((NI)0)]);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA6_;
LA8_: ;
	{
		eqcopy___ast_u3255(&key_1, it_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA6_: ;
	{
		if (!((*key_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)42))) goto LA13_;
		processNote__pragmas_u654(c_p0, it_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		eqdestroy___ast_u4574(userPragma_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___idents_u155(ident_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3252(key_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3252(it_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		goto BeforeRet_;
	}
	goto LA11_;
LA13_: ;
	{
		tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw T25_;
		if (!((*key_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)61))) goto LA16_;
		{
			if (!comesFromPush_p5) goto LA20_;
			liMessage__msgs_u1227((*(*c_p0).graph).config, (*n_p2).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), TM__tPA3StZ6VsKyoznyrIfFxg_7, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__tPA3StZ6VsKyoznyrIfFxg_8), NIM_FALSE, NIM_FALSE);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		goto LA18_;
LA20_: ;
		{
			if (!!(isStatement_p6)) goto LA23_;
			liMessage__msgs_u1227((*(*c_p0).graph).config, (*n_p2).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), TM__tPA3StZ6VsKyoznyrIfFxg_10, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__tPA3StZ6VsKyoznyrIfFxg_11), NIM_FALSE, NIM_FALSE);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		goto LA18_;
LA23_: ;
LA18_: ;
		T25_ = (tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)0;
		T25_ = whichPragma__trees_u218((*key_1)._kind_6.sons.p->data[((NI)1)]);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		switch (T25_) {
		case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)175):
		case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)180):
		case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)181):
		{
			pragmaRaisesOrTags__pragmas_u1305(c_p0, (*key_1)._kind_6.sons.p->data[((NI)1)]);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		break;
		default:
		{
		}
		break;
		}
		eqdestroy___ast_u4574(userPragma_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___idents_u155(ident_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3252(key_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3252(it_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		goto BeforeRet_;
	}
	goto LA11_;
LA16_: ;
	{
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T31_;
		if (!!(((*key_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)2) || (*key_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3) || (*key_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)53) || (*key_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)57) || (*key_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)56) || (*key_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)165)))) goto LA29_;
		T31_ = NIM_NIL;
		T31_ = semCustomPragma__pragmas_u1430(c_p0, it_1, sym_p1);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T31_); goto LA1_;}
		eqsink___ast_u3261(&(*n_p2)._kind_6.sons.p->data[(*i_p3)], T31_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		eqdestroy___ast_u4574(userPragma_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___idents_u155(ident_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3252(key_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3252(it_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		goto BeforeRet_;
	}
	goto LA11_;
LA29_: ;
LA11_: ;
	ident_1 = considerQuotedIdent__lookups_u31(c_p0, key_1, ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	userPragma_1 = strTableGet__astalgo_u2726((*c_p0).userPragmas, ident_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD_;
		tyObject_HSlice__OAVyDXS0QPw7LdXClfU2hA T65_;
		NI T66_;
		if (!!((userPragma_1 == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)))) goto LA34_;
		colontmpD_ = NIM_NIL;
		{
			NIM_BOOL T39_;
			NIM_BOOL T40_;
			NIM_BOOL T41_;
			NIM_BOOL T42_;
			NIM_BOOL T43_;
			tySet_tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A T44_;
			T39_ = (NIM_BOOL)0;
			T40_ = (NIM_BOOL)0;
			T41_ = (NIM_BOOL)0;
			T42_ = (NIM_BOOL)0;
			T43_ = (NIM_BOOL)0;
			T44_ = 0;
			T43_ = !(((229376 & (*(*(*c_p0).graph).config).globalOptions) == T44_));
			if (!(T43_)) goto LA45_;
			T43_ = (((*(*(*c_p0).graph).config).notes[(NU)((((tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw)107) - 20))>>3] &(1U<<((NU)((((tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw)107) - 20))&7U)))!=0);
LA45_: ;
			T42_ = T43_;
			if (!(T42_)) goto LA46_;
			colontmpD_ = getModule__modulegraphs_u14809((*c_p0).graph, (*key_1).info.fileIndex);
			if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
			T42_ = belongsToProjectPackageMaybeNil__packages_u85((*(*c_p0).graph).config, colontmpD_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
LA46_: ;
			T41_ = T42_;
			if (!(T41_)) goto LA47_;
			T41_ = !(((*userPragma_1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)5)));
LA47_: ;
			T40_ = T41_;
			if (!(T40_)) goto LA48_;
			T40_ = (((NU8)((*(*userPragma_1).name).s.p->data[((NI)0)])) >= ((NU8)(97)) && ((NU8)((*(*userPragma_1).name).s.p->data[((NI)0)])) <= ((NU8)(122)) || ((NU8)((*(*userPragma_1).name).s.p->data[((NI)0)])) >= ((NU8)(65)) && ((NU8)((*(*userPragma_1).name).s.p->data[((NI)0)])) <= ((NU8)(90)) || ((NU8)((*(*userPragma_1).name).s.p->data[((NI)0)])) >= ((NU8)(48)) && ((NU8)((*(*userPragma_1).name).s.p->data[((NI)0)])) <= ((NU8)(57)) || ((NU8)((*(*userPragma_1).name).s.p->data[((NI)0)])) >= ((NU8)(128)) && ((NU8)((*(*userPragma_1).name).s.p->data[((NI)0)])) <= ((NU8)(255)) || ((NU8)((*(*userPragma_1).name).s.p->data[((NI)0)])) == ((NU8)(95)));
LA48_: ;
			T39_ = T40_;
			if (!(T39_)) goto LA49_;
			T39_ = !((((*userPragma_1).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)60)))&63U)))!=0));
LA49_: ;
			if (!T39_) goto LA50_;
			styleCheckUseImpl__linter_u198((*(*c_p0).graph).config, (*key_1).info, userPragma_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
		}
LA50_: ;
		(*c_p0).instCounter += ((NI)1);
		{
			NimStringV2 colontmpD__2;
			NimStringV2 T58_;
			if (!(((NI)100) < (*c_p0).instCounter)) goto LA55_;
			colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
			T58_.len = 0; T58_.p = NIM_NIL;
			T58_ = rawNewString((*(*userPragma_1).name).s.len + 22);
appendString((&T58_), TM__tPA3StZ6VsKyoznyrIfFxg_33);
appendString((&T58_), (*(*userPragma_1).name).s);
			colontmpD__2 = T58_;
			liMessage__msgs_u1227((*(*c_p0).graph).config, (*it_1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), colontmpD__2, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)2), (&TM__tPA3StZ6VsKyoznyrIfFxg_34), NIM_FALSE, NIM_FALSE);
			if (NIM_UNLIKELY(*nimErr_)) goto LA57_;
			{
				LA57_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__2);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA52_;
		}
LA55_: ;
		{
			if (!keyDeep_1) goto LA63_;
			liMessage__msgs_u1227((*(*c_p0).graph).config, (*it_1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), TM__tPA3StZ6VsKyoznyrIfFxg_36, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__tPA3StZ6VsKyoznyrIfFxg_37), NIM_FALSE, NIM_FALSE);
			if (NIM_UNLIKELY(*nimErr_)) goto LA52_;
		}
LA63_: ;
		pragma__pragmas_u120(c_p0, sym_p1, (*userPragma_1).ast, validPragmas_p4, isStatement_p6, comesFromPush_p5);
		if (NIM_UNLIKELY(*nimErr_)) goto LA52_;
		T65_ = dotdot___stdZstrbasics_u49((*i_p3), (*i_p3));
		X5BX5Deq___pragmas_u1583((&(*n_p2)._kind_6.sons), T65_, (((*(*userPragma_1).ast)._kind_6.sons).p) ? ((*(*userPragma_1).ast)._kind_6.sons.p->data) : NIM_NIL, (*(*userPragma_1).ast)._kind_6.sons.len);
		if (NIM_UNLIKELY(*nimErr_)) goto LA52_;
		T66_ = (NI)0;
		T66_ = len__ast_u3190((*userPragma_1).ast);
		if (NIM_UNLIKELY(*nimErr_)) goto LA52_;
		(*i_p3) += (NI)(T66_ - ((NI)1));
		{
			LA52_:;
		}
		{
			(*c_p0).instCounter -= ((NI)1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
		{
			LA36_:;
		}
		{
			oldNimErrFin36_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u4574(colontmpD_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin36_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA32_;
LA34_: ;
	{
		tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw k_1;
		k_1 = whichKeyword__idents_u360(ident_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		{
			tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD__3;
			if (!((validPragmas_p4[(NU)((k_1))>>3] &(1U<<((NU)((k_1))&7U)))!=0)) goto LA74_;
			colontmpD__3 = NIM_NIL;
			{
				NIM_BOOL T79_;
				NIM_BOOL T80_;
				tySet_tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A T81_;
				T79_ = (NIM_BOOL)0;
				T80_ = (NIM_BOOL)0;
				T81_ = 0;
				T80_ = !(((229376 & (*(*(*c_p0).graph).config).globalOptions) == T81_));
				if (!(T80_)) goto LA82_;
				T80_ = (((*(*(*c_p0).graph).config).notes[(NU)((((tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw)107) - 20))>>3] &(1U<<((NU)((((tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw)107) - 20))&7U)))!=0);
LA82_: ;
				T79_ = T80_;
				if (!(T79_)) goto LA83_;
				colontmpD__3 = getModule__modulegraphs_u14809((*c_p0).graph, (*key_1).info.fileIndex);
				if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
				T79_ = belongsToProjectPackageMaybeNil__packages_u85((*(*c_p0).graph).config, colontmpD__3);
				if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
LA83_: ;
				if (!T79_) goto LA84_;
				checkPragmaUseImpl__linter_u241((*(*c_p0).graph).config, (*key_1).info, k_1, (*ident_1).s);
				if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
			}
LA84_: ;
			switch (k_1) {
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)100):
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)101):
			{
				NimStringV2 colontmpD__4;
				colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
				colontmpD__4 = getOptionalStr__pragmas_u322(c_p0, it_1, TM__tPA3StZ6VsKyoznyrIfFxg_53);
				if (NIM_UNLIKELY(*nimErr_)) goto LA87_;
				makeExternExport__pragmas_u215(c_p0, sym_p1, colontmpD__4, (*it_1).info);
				if (NIM_UNLIKELY(*nimErr_)) goto LA87_;
				{
					if (!(k_1 == ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)101))) goto LA90_;
					{
						NimStringV2 colontmpD__5;
						NimStringV2 colontmpD__6;
						NimStringV2 T97_;
						if (!!(((*(*(*c_p0).graph).config).backend == ((tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)2)))) goto LA94_;
						colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
						colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
						T97_.len = 0; T97_.p = NIM_NIL;
						colontmpD__5 = dollar___options_u144((*(*(*c_p0).graph).config).backend);
						T97_ = rawNewString(colontmpD__5.len + 39);
appendString((&T97_), TM__tPA3StZ6VsKyoznyrIfFxg_55);
appendString((&T97_), colontmpD__5);
						colontmpD__6 = T97_;
						liMessage__msgs_u1227((*(*c_p0).graph).config, (*it_1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), colontmpD__6, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__tPA3StZ6VsKyoznyrIfFxg_56), NIM_FALSE, NIM_FALSE);
						if (NIM_UNLIKELY(*nimErr_)) goto LA96_;
						{
							LA96_:;
						}
						{
							eqdestroy___system_u2691(colontmpD__6);
							eqdestroy___system_u2691(colontmpD__5);
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA87_;
					}
					goto LA92_;
LA94_: ;
					{
						(*sym_p1).flags |= ((NU64)1)<<(((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)8))) & 63);
					}
LA92_: ;
				}
LA90_: ;
				(*sym_p1).flags |= ((NU64)1)<<(((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)0))) & 63);
				{
					LA87_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__4);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)98):
			{
				NimStringV2 name_1;
				tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T105_;
				name_1.len = 0; name_1.p = NIM_NIL;
				name_1 = getOptionalStr__pragmas_u322(c_p0, it_1, TM__tPA3StZ6VsKyoznyrIfFxg_57);
				if (NIM_UNLIKELY(*nimErr_)) goto LA104_;
				cppDefine__options_u2159((*(*c_p0).graph).config, name_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA104_;
				T105_[0] = TM__tPA3StZ6VsKyoznyrIfFxg_59;
				T105_[1] = name_1;
				recordPragma__pragmas_u127(c_p0, it_1, T105_, 2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA104_;
				makeExternImport__pragmas_u202(c_p0, sym_p1, name_1, (*it_1).info);
				if (NIM_UNLIKELY(*nimErr_)) goto LA104_;
				{
					LA104_:;
				}
				{
					eqdestroy___system_u2691(name_1);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)97):
			{
				NimStringV2 name_2;
				tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T110_;
				name_2.len = 0; name_2.p = NIM_NIL;
				name_2 = getOptionalStr__pragmas_u322(c_p0, it_1, TM__tPA3StZ6VsKyoznyrIfFxg_60);
				if (NIM_UNLIKELY(*nimErr_)) goto LA109_;
				cppDefine__options_u2159((*(*c_p0).graph).config, name_2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA109_;
				T110_[0] = TM__tPA3StZ6VsKyoznyrIfFxg_61;
				T110_[1] = name_2;
				recordPragma__pragmas_u127(c_p0, it_1, T110_, 2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA109_;
				processImportCompilerProc__pragmas_u224(c_p0, sym_p1, name_2, (*it_1).info);
				if (NIM_UNLIKELY(*nimErr_)) goto LA109_;
				{
					LA109_:;
				}
				{
					eqdestroy___system_u2691(name_2);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)234):
			{
				NimStringV2 colontmpD__7;
				colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
				colontmpD__7 = expectStrLit__pragmas_u308(c_p0, it_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA114_;
				setExternName__pragmas_u193(c_p0, sym_p1, colontmpD__7, (*it_1).info);
				if (NIM_UNLIKELY(*nimErr_)) goto LA114_;
				{
					LA114_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__7);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)214):
			{
				{
					if (!((*sym_p1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)18))) goto LA120_;
					(*sym_p1).flags |= ((NU64)1)<<(((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)56))) & 63);
				}
				goto LA118_;
LA120_: ;
				{
					invalidPragma__pragmas_u142(c_p0, it_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
				}
LA118_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)231):
			{
				{
					if (!((*sym_p1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)18))) goto LA126_;
					(*sym_p1).flags |= ((NU64)1)<<(((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)62))) & 63);
				}
				goto LA124_;
LA126_: ;
				{
					invalidPragma__pragmas_u142(c_p0, it_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
				}
LA124_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)232):
			{
				{
					if (!((*sym_p1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)18))) goto LA132_;
					(*sym_p1).flags |= ((NU64)1)<<(((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)36))) & 63);
				}
				goto LA130_;
LA132_: ;
				{
					invalidPragma__pragmas_u142(c_p0, it_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
				}
LA130_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)94):
			{
				NimStringV2 colontmpD__8;
				colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
				colontmpD__8 = getOptionalStr__pragmas_u322(c_p0, it_1, TM__tPA3StZ6VsKyoznyrIfFxg_62);
				if (NIM_UNLIKELY(*nimErr_)) goto LA136_;
				processImportCpp__pragmas_u241(c_p0, sym_p1, colontmpD__8, (*it_1).info);
				if (NIM_UNLIKELY(*nimErr_)) goto LA136_;
				{
					LA136_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__8);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)95):
			{
				(*sym_p1).flags |= ((NU64)1)<<(((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)27))) & 63);
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)99):
			{
				NimStringV2 name_3;
				name_3.len = 0; name_3.p = NIM_NIL;
				{
					if (!!(((*(*(*c_p0).graph).config).backend == ((tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)3)))) goto LA144_;
					liMessage__msgs_u1227((*(*c_p0).graph).config, (*it_1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), TM__tPA3StZ6VsKyoznyrIfFxg_64, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__tPA3StZ6VsKyoznyrIfFxg_65), NIM_FALSE, NIM_FALSE);
					if (NIM_UNLIKELY(*nimErr_)) goto LA141_;
				}
LA144_: ;
				name_3 = getOptionalStr__pragmas_u322(c_p0, it_1, TM__tPA3StZ6VsKyoznyrIfFxg_66);
				if (NIM_UNLIKELY(*nimErr_)) goto LA141_;
				(*sym_p1).flags |= ((NU64)1)<<(((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)6))) & 63);
				(*sym_p1).flags |= ((NU64)1)<<(((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)32))) & 63);
				{
					NIM_BOOL T148_;
					NIM_BOOL T150_;
					T148_ = (NIM_BOOL)0;
					T148_ = ((*sym_p1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)12) || (*sym_p1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)13) || (*sym_p1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)18) || (*sym_p1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)17) || (*sym_p1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)15) || (*sym_p1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)14) || (*sym_p1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)16));
					if (!(T148_)) goto LA149_;
					T150_ = (NIM_BOOL)0;
					T150_ = contains__pureZstrutils_u1837(name_3, TM__tPA3StZ6VsKyoznyrIfFxg_67);
					if (NIM_UNLIKELY(*nimErr_)) goto LA141_;
					T148_ = !(T150_);
LA149_: ;
					if (!T148_) goto LA151_;
					liMessage__msgs_u1227((*(*c_p0).graph).config, (*n_p2).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), TM__tPA3StZ6VsKyoznyrIfFxg_69, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__tPA3StZ6VsKyoznyrIfFxg_70), NIM_FALSE, NIM_FALSE);
					if (NIM_UNLIKELY(*nimErr_)) goto LA141_;
				}
LA151_: ;
				setExternName__pragmas_u193(c_p0, sym_p1, name_3, (*it_1).info);
				if (NIM_UNLIKELY(*nimErr_)) goto LA141_;
				{
					LA141_:;
				}
				{
					eqdestroy___system_u2691(name_3);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)96):
			{
				NimStringV2 colontmpD__9;
				colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
				colontmpD__9 = getOptionalStr__pragmas_u322(c_p0, it_1, TM__tPA3StZ6VsKyoznyrIfFxg_71);
				if (NIM_UNLIKELY(*nimErr_)) goto LA156_;
				processImportObjC__pragmas_u271(c_p0, sym_p1, colontmpD__9, (*it_1).info);
				if (NIM_UNLIKELY(*nimErr_)) goto LA156_;
				{
					LA156_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__9);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)178):
			{
				NI size_1;
				{
					if (!((*sym_p1).typ == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL))) goto LA162_;
					invalidPragma__pragmas_u142(c_p0, it_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
				}
LA162_: ;
				size_1 = expectIntLit__pragmas_u312(c_p0, it_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
				{
					if (!(((*sym_p1).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)6)))&63U)))!=0)) goto LA166_;
					setImportedTypeSize__types_u3415((*(*c_p0).graph).config, (*sym_p1).typ, size_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
				}
				goto LA164_;
LA166_: ;
				{
					switch (size_1) {
					case ((NI)1):
					case ((NI)2):
					case ((NI)4):
					{
						(*(*sym_p1).typ).size = ((NI64) (size_1));
						(*(*sym_p1).typ).align = ((NI16) (size_1));
					}
					break;
					case ((NI)8):
					{
						NI16 T171_;
						(*(*sym_p1).typ).size = IL64(8);
						T171_ = (NI16)0;
						T171_ = floatInt64Align__options_u4319((*(*c_p0).graph).config);
						if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
						(*(*sym_p1).typ).align = T171_;
					}
					break;
					default:
					{
						liMessage__msgs_u1227((*(*c_p0).graph).config, (*it_1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), TM__tPA3StZ6VsKyoznyrIfFxg_78, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__tPA3StZ6VsKyoznyrIfFxg_79), NIM_FALSE, NIM_FALSE);
						if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
					}
					break;
					}
				}
LA164_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)106):
			{
				NI alignment_1;
				alignment_1 = expectIntLit__pragmas_u312(c_p0, it_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
				{
					NIM_BOOL T176_;
					T176_ = (NIM_BOOL)0;
					T176_ = isPowerOfTwo__pureZmath_u253(alignment_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
					if (!(T176_)) goto LA177_;
					T176_ = (((NI)0) < alignment_1);
LA177_: ;
					if (!T176_) goto LA178_;
					(*sym_p1)._kind_2.alignment = (((*sym_p1)._kind_2.alignment >= alignment_1) ? (*sym_p1)._kind_2.alignment : alignment_1);
				}
				goto LA174_;
LA178_: ;
				{
					liMessage__msgs_u1227((*(*c_p0).graph).config, (*it_1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), TM__tPA3StZ6VsKyoznyrIfFxg_81, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__tPA3StZ6VsKyoznyrIfFxg_82), NIM_FALSE, NIM_FALSE);
					if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
				}
LA174_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)107):
			{
				noVal__pragmas_u1152(c_p0, it_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
				(*sym_p1).loc.flags |= ((NU16)1)<<(((((tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg)2))) & 15);
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)108):
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)218):
			{
				noVal__pragmas_u1152(c_p0, it_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
				{
					if (!!((sym_p1 == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)))) goto LA185_;
					{
						NIM_BOOL T189_;
						T189_ = (NIM_BOOL)0;
						T189_ = (k_1 == ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)108));
						if (!(T189_)) goto LA190_;
						T189_ = ((*sym_p1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)12) || (*sym_p1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)13) || (*sym_p1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)14) || (*sym_p1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)15) || (*sym_p1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)16) || (*sym_p1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)17) || (*sym_p1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)18));
LA190_: ;
						if (!T189_) goto LA191_;
						invalidPragma__pragmas_u142(c_p0, it_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
					}
					goto LA187_;
LA191_: ;
					{
						(*sym_p1).flags |= ((NU64)1)<<(((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)11))) & 63);
					}
LA187_: ;
				}
LA185_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)240):
			{
				noVal__pragmas_u1152(c_p0, it_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
				(*sym_p1).flags |= ((NU64)1)<<(((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)9))) & 63);
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)84):
			{
				noVal__pragmas_u1152(c_p0, it_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
				(*sym_p1).flags |= ((NU64)1)<<(((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)41))) & 63);
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)236):
			{
				noVal__pragmas_u1152(c_p0, it_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
				(*sym_p1).flags |= ((NU64)1)<<(((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)10))) & 63);
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)85):
			{
				noVal__pragmas_u1152(c_p0, it_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
				(*sym_p1).flags |= ((NU64)1)<<(((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)47))) & 63);
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)86):
			{
				processEffectsOf__pragmas_u1467(c_p0, it_1, sym_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)216):
			{
				noVal__pragmas_u1152(c_p0, it_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
				(*sym_p1).flags = ((*sym_p1).flags | 67108872);
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)187):
			{
				warningDeprecated__msgs_u1572((*(*c_p0).graph).config, (*n_p2).info, TM__tPA3StZ6VsKyoznyrIfFxg_97);
				if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)190):
			{
				pragmaNoForward__pragmas_u441(c_p0, it_1, ((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)10));
				if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)191):
			{
				pragmaNoForward__pragmas_u441(c_p0, it_1, ((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)4));
				if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)75):
			{
				processMagic__pragmas_u353(c_p0, it_1, sym_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)195):
			{
				noVal__pragmas_u1152(c_p0, it_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
				{
					if (!comesFromPush_p5) goto LA207_;
					{
						if (!((*sym_p1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)12) || (*sym_p1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)13))) goto LA211_;
						(*sym_p1).flags |= ((NU64)1)<<(((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)28))) & 63);
					}
LA211_: ;
				}
				goto LA205_;
LA207_: ;
				{
					(*sym_p1).flags |= ((NU64)1)<<(((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)28))) & 63);
				}
LA205_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)221):
			{
				noVal__pragmas_u1152(c_p0, it_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
				(*sym_p1).flags |= ((NU64)1)<<(((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)3))) & 63);
				(*sym_p1).flags |= ((NU64)1)<<(((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)11))) & 63);
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)90):
			{
				(*sym_p1).flags |= ((NU64)1)<<(((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)29))) & 63);
				{
					NimStringV2 colontmpD__10;
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T221_;
					if (!!((((*sym_p1).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)6)))&63U)))!=0))) goto LA218_;
					colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
					colontmpD__10 = getOptionalStr__pragmas_u322(c_p0, it_1, TM__tPA3StZ6VsKyoznyrIfFxg_113);
					if (NIM_UNLIKELY(*nimErr_)) goto LA220_;
					T221_ = NIM_NIL;
					T221_ = newEmptyStrNode__pragmas_u293(c_p0, it_1, colontmpD__10);
					if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T221_); goto LA220_;}
					eqsink___ast_u3261(&(*sym_p1).constraint, T221_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA220_;
					eqcopy___system_u2694((&(*(*sym_p1).constraint)._kind_3.strVal), (*(*sym_p1).constraint)._kind_3.strVal);
					(*sym_p1).flags = ((*sym_p1).flags | 384);
					(*(*sym_p1).typ).callConv = ((tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ)10);
					{
						LA220_:;
					}
					{
						eqdestroy___system_u2691(colontmpD__10);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
				}
LA218_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)110):
			{
				tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig* lib_1;
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__11;
				lib_1 = NIM_NIL;
				colontmpD__11 = NIM_NIL;
				colontmpD__11 = getStrLitNode__pragmas_u298(c_p0, it_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA225_;
				lib_1 = getLib__pragmas_u511(c_p0, ((tyEnum_TLibKind__BkKL8ReLoyYDI7of9aQPV0A)0), colontmpD__11);
				if (NIM_UNLIKELY(*nimErr_)) goto LA225_;
				addToLib__semdata_u4365(lib_1, sym_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA225_;
				(*sym_p1).flags |= ((NU64)1)<<(((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)6))) & 63);
				(*sym_p1).loc.flags |= ((NU16)1)<<(((((tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg)5))) & 15);
				(*sym_p1).loc.flags |= ((NU16)1)<<(((((tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg)2))) & 15);
				{
					if (!((*sym_p1).loc.snippet.len == 0)) goto LA228_;
					eqcopy___system_u2694((&(*sym_p1).loc.snippet), (*(*sym_p1).name).s);
				}
LA228_: ;
				{
					LA225_:;
				}
				{
					oldNimErrFin225_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3252(colontmpD__11);
					if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
					eqdestroy___ast_u6216(lib_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
					*nimErr_ = oldNimErrFin225_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)111):
			{
				noVal__pragmas_u1152(c_p0, it_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
				{
					if (!!((sym_p1 == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)))) goto LA235_;
					(*sym_p1).flags |= ((NU64)1)<<(((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)12))) & 63);
					{
						if (!!(((*sym_p1).typ == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL)))) goto LA239_;
						(*(*sym_p1).typ).flags |= ((NU64)1)<<(((((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)1))) & 63);
					}
LA239_: ;
				}
LA235_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)109):
			{
				noVal__pragmas_u1152(c_p0, it_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
				(*sym_p1).flags |= ((NU64)1)<<(((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)13))) & 63);
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)113):
			{
				tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__12;
				colontmpD__12 = NIM_NIL;
				noVal__pragmas_u1152(c_p0, it_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA243_;
				{
					if (!!(((*(*(*c_p0).graph).config).exc == ((tyEnum_ExceptionSystem__dJ6sXW7k8NDYNNBUjVZmnw)4)))) goto LA246_;
					(*sym_p1).flags |= ((NU64)1)<<(((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)16))) & 63);
				}
LA246_: ;
				{
					colontmpD__12 = returnType__ast_u5354((*sym_p1).typ);
					if (NIM_UNLIKELY(*nimErr_)) goto LA243_;
					if (!!((colontmpD__12 == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL)))) goto LA250_;
					liMessage__msgs_u1227((*(*c_p0).graph).config, (*(*(*(*sym_p1).ast)._kind_6.sons.p->data[((NI)3)])._kind_6.sons.p->data[((NI)0)]).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), TM__tPA3StZ6VsKyoznyrIfFxg_115, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__tPA3StZ6VsKyoznyrIfFxg_116), NIM_FALSE, NIM_FALSE);
					if (NIM_UNLIKELY(*nimErr_)) goto LA243_;
				}
LA250_: ;
				{
					LA243_:;
				}
				{
					oldNimErrFin243_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3378(colontmpD__12);
					if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
					*nimErr_ = oldNimErrFin243_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)193):
			{
				noVal__pragmas_u1152(c_p0, it_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
				(*sym_p1).flags |= ((NU64)1)<<(((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)39))) & 63);
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)114):
			{
				noVal__pragmas_u1152(c_p0, it_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
				(*sym_p1).flags |= ((NU64)1)<<(((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)5))) & 63);
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)116):
			{
				processDynLib__pragmas_u612(c_p0, it_1, sym_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)117):
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)118):
			{
				tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T258_;
				noVal__pragmas_u1152(c_p0, it_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
				cppDefine__options_u2159((*(*c_p0).graph).config, (*(*sym_p1).name).s);
				if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
				T258_[0] = TM__tPA3StZ6VsKyoznyrIfFxg_123;
				T258_[1] = (*(*sym_p1).name).s;
				recordPragma__pragmas_u127(c_p0, it_1, T258_, 2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
				{
					if (!!((((*sym_p1).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)2)))&63U)))!=0))) goto LA261_;
					markCompilerProc__pragmas_u1366(c_p0, sym_p1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
				}
LA261_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)166):
			{
				(*sym_p1).flags |= ((NU64)1)<<(((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)38))) & 63);
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)119):
			{
				noVal__pragmas_u1152(c_p0, it_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)227):
			{
				(*sym_p1).flags |= ((NU64)1)<<(((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)23))) & 63);
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)139):
			{
				{
					NIM_BOOL T269_;
					T269_ = (NIM_BOOL)0;
					T269_ = !((sym_p1 == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)));
					if (!(T269_)) goto LA270_;
					T269_ = ((*sym_p1).kind >= ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)7) && (*sym_p1).kind <= ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)10) || (*sym_p1).kind >= ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)12) && (*sym_p1).kind <= ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)18));
LA270_: ;
					if (!T269_) goto LA271_;
					{
						tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__13;
						if (!((*it_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)34) || (*it_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)27) || (*it_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)28))) goto LA275_;
						colontmpD__13 = NIM_NIL;
						colontmpD__13 = getStrLitNode__pragmas_u298(c_p0, it_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA277_;
						(void)(colontmpD__13);
						{
							LA277_:;
						}
						{
							oldNimErrFin277_ = *nimErr_; *nimErr_ = NIM_FALSE;
							eqdestroy___ast_u3252(colontmpD__13);
							if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
							*nimErr_ = oldNimErrFin277_;
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
					}
LA275_: ;
					(*sym_p1).flags |= ((NU64)1)<<(((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)22))) & 63);
				}
				goto LA267_;
LA271_: ;
				{
					NIM_BOOL T281_;
					T281_ = (NIM_BOOL)0;
					T281_ = !((sym_p1 == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)));
					if (!(T281_)) goto LA282_;
					T281_ = !(((*sym_p1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)6)));
LA282_: ;
					if (!T281_) goto LA283_;
					{
						if (!((*it_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)34) || (*it_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)27) || (*it_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)28))) goto LA287_;
						liMessage__msgs_u1227((*(*c_p0).graph).config, (*it_1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), TM__tPA3StZ6VsKyoznyrIfFxg_128, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__tPA3StZ6VsKyoznyrIfFxg_129), NIM_FALSE, NIM_FALSE);
						if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
					}
LA287_: ;
					(*sym_p1).flags |= ((NU64)1)<<(((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)22))) & 63);
				}
				goto LA267_;
LA283_: ;
				{
					if (!((*it_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)34) || (*it_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)27) || (*it_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)28))) goto LA290_;
					deprecatedStmt__pragmas_u1385(c_p0, it_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
				}
				goto LA267_;
LA290_: ;
				{
					(*(*c_p0).module).flags |= ((NU64)1)<<(((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)22))) & 63);
				}
LA267_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)140):
			{
				noVal__pragmas_u1152(c_p0, it_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
				{
					if (!((*sym_p1).typ == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL))) goto LA296_;
					invalidPragma__pragmas_u142(c_p0, it_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
				}
				goto LA294_;
LA296_: ;
				{
					(*(*sym_p1).typ).flags |= ((NU64)1)<<(((((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)0))) & 63);
				}
LA294_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)200):
			{
				{
					if (!((*sym_p1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)7))) goto LA302_;
					typeBorrow__pragmas_u1349(c_p0, sym_p1, it_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
				}
				goto LA300_;
LA302_: ;
				{
					noVal__pragmas_u1152(c_p0, it_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
					(*sym_p1).flags |= ((NU64)1)<<(((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)31))) & 63);
				}
LA300_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)77):
			{
				noVal__pragmas_u1152(c_p0, it_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
				{
					if (!((*sym_p1).typ == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL))) goto LA308_;
					invalidPragma__pragmas_u142(c_p0, it_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
				}
				goto LA306_;
LA308_: ;
				{
					(*(*sym_p1).typ).flags |= ((NU64)1)<<(((((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)2))) & 63);
				}
LA306_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)215):
			{
				noVal__pragmas_u1152(c_p0, it_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
				{
					NIM_BOOL T314_;
					T314_ = (NIM_BOOL)0;
					T314_ = ((*sym_p1).typ == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL));
					if (T314_) goto LA315_;
					T314_ = (((*(*sym_p1).typ).flags &((NU64)1<<((NU)((((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)2)))&63U)))!=0);
LA315_: ;
					if (!T314_) goto LA316_;
					invalidPragma__pragmas_u142(c_p0, it_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
				}
				goto LA312_;
LA316_: ;
				{
					(*(*sym_p1).typ).flags |= ((NU64)1)<<(((((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)3))) & 63);
				}
LA312_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)189):
			{
				noVal__pragmas_u1152(c_p0, it_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
				{
					if (!((*sym_p1).typ == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL))) goto LA322_;
					invalidPragma__pragmas_u142(c_p0, it_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
				}
				goto LA320_;
LA322_: ;
				{
					(*sym_p1).flags |= ((NU64)1)<<(((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)4))) & 63);
				}
LA320_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)204):
			{
				noVal__pragmas_u1152(c_p0, it_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
				{
					if (!((*sym_p1).typ == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL))) goto LA328_;
					invalidPragma__pragmas_u142(c_p0, it_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
				}
				goto LA326_;
LA328_: ;
				{
					(*(*sym_p1).typ).flags |= ((NU64)1)<<(((((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)39))) & 63);
				}
LA326_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)205):
			{
				noVal__pragmas_u1152(c_p0, it_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
				{
					if (!((*sym_p1).typ == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL))) goto LA334_;
					invalidPragma__pragmas_u142(c_p0, it_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
				}
				goto LA332_;
LA334_: ;
				{
					(*(*sym_p1).typ).flags |= ((NU64)1)<<(((((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)6))) & 63);
				}
LA332_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)76):
			{
				noVal__pragmas_u1152(c_p0, it_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
				(*sym_p1).flags |= ((NU64)1)<<(((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)26))) & 63);
				{
					if (!!(((*sym_p1).typ == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL)))) goto LA340_;
					(*(*sym_p1).typ).flags |= ((NU64)1)<<(((((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)7))) & 63);
					{
						if (!((*(*sym_p1).typ).callConv == ((tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ)9))) goto LA344_;
						(*(*sym_p1).typ).callConv = ((tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ)0);
					}
LA344_: ;
				}
LA340_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)303):
			{
				noVal__pragmas_u1152(c_p0, it_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
				{
					NIM_BOOL T349_;
					T349_ = (NIM_BOOL)0;
					T349_ = !((sym_p1 == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)));
					if (!(T349_)) goto LA350_;
					T349_ = !(((*sym_p1).typ == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL)));
LA350_: ;
					if (!T349_) goto LA351_;
					(*(*sym_p1).typ).flags |= ((NU64)1)<<(((((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)46))) & 63);
				}
				goto LA347_;
LA351_: ;
				{
					invalidPragma__pragmas_u142(c_p0, it_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
				}
LA347_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)112):
			{
				noVal__pragmas_u1152(c_p0, it_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
				{
					if (!!((sym_p1 == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)))) goto LA357_;
					{
						if (!!(((*sym_p1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)7)))) goto LA361_;
						(*sym_p1).flags |= ((NU64)1)<<(((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)26))) & 63);
					}
LA361_: ;
					{
						if (!!(((*sym_p1).typ == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL)))) goto LA365_;
						(*(*sym_p1).typ).flags |= ((NU64)1)<<(((((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)7))) & 63);
					}
					goto LA363_;
LA365_: ;
					{
						invalidPragma__pragmas_u142(c_p0, it_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
					}
LA363_: ;
				}
				goto LA355_;
LA357_: ;
				{
				}
LA355_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)238):
			{
				noVal__pragmas_u1152(c_p0, it_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
				{
					if (!((*sym_p1).typ == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL))) goto LA372_;
					invalidPragma__pragmas_u142(c_p0, it_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
				}
				goto LA370_;
LA372_: ;
				{
					(*(*sym_p1).typ).flags |= ((NU64)1)<<(((((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)23))) & 63);
				}
LA370_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)125):
			{
				NimStringV2 s_1;
				tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T377_;
				s_1.len = 0; s_1.p = NIM_NIL;
				s_1 = expectStrLit__pragmas_u308(c_p0, it_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA376_;
				T377_[0] = TM__tPA3StZ6VsKyoznyrIfFxg_140;
				T377_[1] = s_1;
				recordPragma__pragmas_u127(c_p0, it_1, T377_, 2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA376_;
				liMessage__msgs_u1227((*(*c_p0).graph).config, (*it_1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)118), s_1, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__tPA3StZ6VsKyoznyrIfFxg_141), NIM_FALSE, NIM_FALSE);
				if (NIM_UNLIKELY(*nimErr_)) goto LA376_;
				{
					LA376_:;
				}
				{
					eqdestroy___system_u2691(s_1);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)124):
			{
				NimStringV2 s_2;
				tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T382_;
				s_2.len = 0; s_2.p = NIM_NIL;
				s_2 = expectStrLit__pragmas_u308(c_p0, it_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA381_;
				T382_[0] = TM__tPA3StZ6VsKyoznyrIfFxg_143;
				T382_[1] = s_2;
				recordPragma__pragmas_u127(c_p0, it_1, T382_, 2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA381_;
				liMessage__msgs_u1227((*(*c_p0).graph).config, (*it_1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)85), s_2, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__tPA3StZ6VsKyoznyrIfFxg_144), NIM_FALSE, NIM_FALSE);
				if (NIM_UNLIKELY(*nimErr_)) goto LA381_;
				{
					LA381_:;
				}
				{
					eqdestroy___system_u2691(s_2);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)123):
			{
				{
					NIM_BOOL T388_;
					NIM_BOOL T389_;
					NIM_BOOL T391_;
					T388_ = (NIM_BOOL)0;
					T389_ = (NIM_BOOL)0;
					T389_ = !((sym_p1 == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)));
					if (!(T389_)) goto LA390_;
					T391_ = (NIM_BOOL)0;
					T391_ = isRoutine__ast_u7152(sym_p1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
					if (T391_) goto LA392_;
					T391_ = ((*sym_p1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)7));
LA392_: ;
					T389_ = T391_;
LA390_: ;
					T388_ = T389_;
					if (!(T388_)) goto LA393_;
					T388_ = !(isStatement_p6);
LA393_: ;
					if (!T388_) goto LA394_;
					{
						tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__14;
						if (!((*it_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)34) || (*it_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)27) || (*it_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)28))) goto LA398_;
						colontmpD__14 = NIM_NIL;
						colontmpD__14 = getStrLitNode__pragmas_u298(c_p0, it_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA400_;
						(void)(colontmpD__14);
						{
							LA400_:;
						}
						{
							oldNimErrFin400_ = *nimErr_; *nimErr_ = NIM_FALSE;
							eqdestroy___ast_u3252(colontmpD__14);
							if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
							*nimErr_ = oldNimErrFin400_;
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
					}
LA398_: ;
					(*sym_p1).flags |= ((NU64)1)<<(((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)24))) & 63);
					(*sym_p1).flags &= ~(((NU64)1) << (((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)4))) & 63));
				}
				goto LA386_;
LA394_: ;
				{
					NimStringV2 s_3;
					tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T405_;
					s_3.len = 0; s_3.p = NIM_NIL;
					s_3 = expectStrLit__pragmas_u308(c_p0, it_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA404_;
					T405_[0] = TM__tPA3StZ6VsKyoznyrIfFxg_146;
					T405_[1] = s_3;
					recordPragma__pragmas_u127(c_p0, it_1, T405_, 2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA404_;
					liMessage__msgs_u1227((*(*c_p0).graph).config, (*it_1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)19), s_3, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__tPA3StZ6VsKyoznyrIfFxg_147), NIM_FALSE, NIM_FALSE);
					if (NIM_UNLIKELY(*nimErr_)) goto LA404_;
					{
						LA404_:;
					}
					{
						eqdestroy___system_u2691(s_3);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
				}
LA386_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)122):
			{
				NimStringV2 colontmpD__15;
				colontmpD__15.len = 0; colontmpD__15.p = NIM_NIL;
				colontmpD__15 = expectStrLit__pragmas_u308(c_p0, it_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA409_;
				liMessage__msgs_u1227((*(*c_p0).graph).config, (*it_1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)1), colontmpD__15, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)1), (&TM__tPA3StZ6VsKyoznyrIfFxg_148), NIM_FALSE, NIM_FALSE);
				if (NIM_UNLIKELY(*nimErr_)) goto LA409_;
				{
					LA409_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__15);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)131):
			{
				processDefine__pragmas_u1009(c_p0, it_1, sym_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)132):
			{
				processUndef__pragmas_u1029(c_p0, it_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)137):
			{
				tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* m_1;
				m_1 = NIM_NIL;
				m_1 = getModule__astalgo_u156(sym_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA415_;
				(*m_1).flags |= ((NU64)1)<<(((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)0))) & 63);
				processCompile__pragmas_u1049(c_p0, it_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA415_;
				{
					LA415_:;
				}
				{
					oldNimErrFin415_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u4574(m_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
					*nimErr_ = oldNimErrFin415_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)136):
			{
				processLink__pragmas_u1092(c_p0, it_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)198):
			{
				tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* m_2;
				NimStringV2 s_4;
				tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T421_;
				m_2 = NIM_NIL;
				s_4.len = 0; s_4.p = NIM_NIL;
				m_2 = getModule__astalgo_u156(sym_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA420_;
				(*m_2).flags |= ((NU64)1)<<(((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)0))) & 63);
				s_4 = expectStrLit__pragmas_u308(c_p0, it_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA420_;
				addLinkOption__extccomp_u906((*(*c_p0).graph).config, s_4);
				if (NIM_UNLIKELY(*nimErr_)) goto LA420_;
				T421_[0] = TM__tPA3StZ6VsKyoznyrIfFxg_171;
				T421_[1] = s_4;
				recordPragma__pragmas_u127(c_p0, it_1, T421_, 2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA420_;
				{
					LA420_:;
				}
				{
					oldNimErrFin420_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___system_u2691(s_4);
					eqdestroy___ast_u4574(m_2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
					*nimErr_ = oldNimErrFin420_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)197):
			{
				tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* m_3;
				NimStringV2 s_5;
				tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T426_;
				m_3 = NIM_NIL;
				s_5.len = 0; s_5.p = NIM_NIL;
				m_3 = getModule__astalgo_u156(sym_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA425_;
				(*m_3).flags |= ((NU64)1)<<(((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)0))) & 63);
				s_5 = expectStrLit__pragmas_u308(c_p0, it_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA425_;
				addCompileOption__extccomp_u909((*(*c_p0).graph).config, s_5);
				if (NIM_UNLIKELY(*nimErr_)) goto LA425_;
				T426_[0] = TM__tPA3StZ6VsKyoznyrIfFxg_173;
				T426_[1] = s_5;
				recordPragma__pragmas_u127(c_p0, it_1, T426_, 2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA425_;
				{
					LA425_:;
				}
				{
					oldNimErrFin425_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___system_u2691(s_5);
					eqdestroy___ast_u4574(m_3);
					if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
					*nimErr_ = oldNimErrFin425_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)199):
			{
				NimStringV2 s_6;
				NimStringV2 colontmpD__16;
				tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T431_;
				s_6.len = 0; s_6.p = NIM_NIL;
				colontmpD__16.len = 0; colontmpD__16.p = NIM_NIL;
				s_6 = expectStrLit__pragmas_u308(c_p0, it_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA430_;
				appendToModule__ast_u4652(sym_p1, n_p2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA430_;
				colontmpD__16 = toFullPathConsiderDirty__msgs_u657((*(*c_p0).graph).config, (*sym_p1).info.fileIndex);
				if (NIM_UNLIKELY(*nimErr_)) goto LA430_;
				addLocalCompileOption__extccomp_u961((*(*c_p0).graph).config, s_6, colontmpD__16);
				if (NIM_UNLIKELY(*nimErr_)) goto LA430_;
				T431_[0] = TM__tPA3StZ6VsKyoznyrIfFxg_175;
				T431_[1] = s_6;
				recordPragma__pragmas_u127(c_p0, it_1, T431_, 2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA430_;
				{
					LA430_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__16);
					eqdestroy___system_u2691(s_6);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)129):
			{
				processPush__pragmas_u969(c_p0, n_p2, (NI)((*i_p3) + ((NI)1)));
				if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
				result = NIM_TRUE;
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)130):
			{
				processPop__pragmas_u994(c_p0, it_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
				result = NIM_TRUE;
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)194):
			{
				{
					NIM_BOOL T439_;
					T439_ = (NIM_BOOL)0;
					T439_ = !((sym_p1 == 0));
					if (!(T439_)) goto LA440_;
					T439_ = ((*sym_p1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)18));
LA440_: ;
					if (!T439_) goto LA441_;
					(*sym_p1).flags |= ((NU64)1)<<(((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)57))) & 63);
				}
				goto LA437_;
LA441_: ;
				{
					processPragma__pragmas_u1199(c_p0, n_p2, (*i_p3));
					if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
					result = NIM_TRUE;
				}
LA437_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)201):
			{
				noVal__pragmas_u1152(c_p0, it_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
				{
					if (!!((sym_p1 == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)))) goto LA447_;
					(*sym_p1).flags |= ((NU64)1)<<(((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)34))) & 63);
				}
LA447_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)196):
			{
				noVal__pragmas_u1152(c_p0, it_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
				{
					if (!!((sym_p1 == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)))) goto LA452_;
					(*sym_p1).flags |= ((NU64)1)<<(((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)14))) & 63);
				}
LA452_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)222):
			{
				processCodegenDecl__pragmas_u345(c_p0, it_1, sym_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)156):
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)80):
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)202):
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)157):
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)158):
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)159):
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)160):
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)168):
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)172):
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)173):
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)133):
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)174):
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)165):
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)164):
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)141):
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)142):
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)78):
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)161):
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)162):
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)163):
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)169):
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)170):
			{
				tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* T456_;
				T456_ = NIM_NIL;
				T456_ = c_p0;
				processOption__pragmas_u941(T456_, it_1, (&(*(*(*c_p0).graph).config).options));
				if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)134):
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)135):
			{
				{
					if (!((*sym_p1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)12) || (*sym_p1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)14) || (*sym_p1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)16))) goto LA460_;
					processOption__pragmas_u941(c_p0, it_1, (&(*sym_p1).options));
					if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
				}
				goto LA458_;
LA460_: ;
				{
					tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* T463_;
					T463_ = NIM_NIL;
					T463_ = c_p0;
					processOption__pragmas_u941(T463_, it_1, (&(*(*(*c_p0).graph).config).options));
					if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
				}
LA458_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)143) ... ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)153):
			{
				{
					if (!((*sym_p1).typ == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL))) goto LA467_;
					invalidPragma__pragmas_u142(c_p0, it_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
				}
				goto LA465_;
LA467_: ;
				{
					tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ T470_;
					T470_ = (tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ)0;
					T470_ = wordToCallConv__pragmas_u398(k_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
					(*(*sym_p1).typ).callConv = T470_;
					(*(*sym_p1).typ).flags |= ((NU64)1)<<(((((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)42))) & 63);
				}
LA465_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)217):
			{
				pragmaEmit__pragmas_u1130(c_p0, it_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)206):
			{
				pragmaUnroll__pragmas_u1159(c_p0, it_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)207):
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)208):
			{
				noVal__pragmas_u1152(c_p0, it_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)179):
			{
				noVal__pragmas_u1152(c_p0, it_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)103):
			{
				noVal__pragmas_u1152(c_p0, it_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
				{
					if (!((*sym_p1).typ == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL))) goto LA478_;
					invalidPragma__pragmas_u142(c_p0, it_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
				}
				goto LA476_;
LA478_: ;
				{
					(*(*sym_p1).typ).flags |= ((NU64)1)<<(((((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)40))) & 63);
				}
LA476_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)104):
			{
				noVal__pragmas_u1152(c_p0, it_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
				{
					if (!((*sym_p1).typ == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL))) goto LA484_;
					invalidPragma__pragmas_u142(c_p0, it_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
				}
				goto LA482_;
LA484_: ;
				{
					(*(*sym_p1).typ).flags |= ((NU64)1)<<(((((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)41))) & 63);
				}
LA482_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)223):
			{
				noVal__pragmas_u1152(c_p0, it_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
				{
					NIM_BOOL T490_;
					T490_ = (NIM_BOOL)0;
					T490_ = ((*sym_p1).typ == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL));
					if (T490_) goto LA491_;
					T490_ = !(((*(*sym_p1).typ).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)16) || (*(*sym_p1).typ).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)49)));
LA491_: ;
					if (!T490_) goto LA492_;
					invalidPragma__pragmas_u142(c_p0, it_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
				}
				goto LA488_;
LA492_: ;
				{
					(*(*sym_p1).typ).kind = ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)49);
				}
LA488_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)237):
			{
				{
					if (!((*(*(*c_p0).graph).config).backend == ((tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)3))) goto LA498_;
					liMessage__msgs_u1227((*(*c_p0).graph).config, (*it_1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), TM__tPA3StZ6VsKyoznyrIfFxg_220, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__tPA3StZ6VsKyoznyrIfFxg_221), NIM_FALSE, NIM_FALSE);
					if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
				}
				goto LA496_;
LA498_: ;
				{
					noVal__pragmas_u1152(c_p0, it_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
					{
						if (!((*sym_p1).typ == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL))) goto LA503_;
						invalidPragma__pragmas_u142(c_p0, it_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
					}
					goto LA501_;
LA503_: ;
					{
						(*(*sym_p1).typ).flags |= ((NU64)1)<<(((((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)1))) & 63);
					}
LA501_: ;
				}
LA496_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)105):
			{
				noVal__pragmas_u1152(c_p0, it_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
				{
					if (!((*sym_p1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)19))) goto LA509_;
					(*sym_p1).flags |= ((NU64)1)<<(((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)21))) & 63);
				}
				goto LA507_;
LA509_: ;
				{
					if (!!(((*sym_p1).typ == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL)))) goto LA512_;
					(*(*sym_p1).typ).flags |= ((NU64)1)<<(((((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)19))) & 63);
				}
				goto LA507_;
LA512_: ;
				{
					invalidPragma__pragmas_u142(c_p0, it_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
				}
LA507_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)243):
			{
				noVal__pragmas_u1152(c_p0, it_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
				{
					NIM_BOOL T518_;
					T518_ = (NIM_BOOL)0;
					T518_ = !((sym_p1 == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)));
					if (!(T518_)) goto LA519_;
					T518_ = ((*sym_p1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)3));
LA519_: ;
					if (!T518_) goto LA520_;
					(*sym_p1).options |= ((NU32)1)<<(((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)20))) & 31);
				}
				goto LA516_;
LA520_: ;
				{
					NIM_BOOL T523_;
					tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* T527_;
					T523_ = (NIM_BOOL)0;
					T523_ = (sym_p1 == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL));
					if (T523_) goto LA524_;
					T523_ = ((*sym_p1).typ == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL));
LA524_: ;
					if (!T523_) goto LA525_;
					T527_ = NIM_NIL;
					T527_ = c_p0;
					processOption__pragmas_u941(T527_, it_1, (&(*(*(*c_p0).graph).config).options));
					if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
				}
				goto LA516_;
LA525_: ;
				{
					(*(*sym_p1).typ).flags |= ((NU64)1)<<(((((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)14))) & 63);
				}
LA516_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)242):
			{
				noVal__pragmas_u1152(c_p0, it_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
				{
					if (!((*sym_p1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)3))) goto LA532_;
					(*sym_p1).flags |= ((NU64)1)<<(((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)51))) & 63);
				}
				goto LA530_;
LA532_: ;
				{
					NIM_BOOL T535_;
					T535_ = (NIM_BOOL)0;
					T535_ = !(((*sym_p1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)7)));
					if (T535_) goto LA536_;
					T535_ = ((*sym_p1).typ == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL));
LA536_: ;
					if (!T535_) goto LA537_;
					invalidPragma__pragmas_u142(c_p0, it_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
				}
				goto LA530_;
LA537_: ;
				{
					(*(*sym_p1).typ).flags |= ((NU64)1)<<(((((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)13))) & 63);
				}
LA530_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)226):
			{
				noVal__pragmas_u1152(c_p0, it_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
				{
					NIM_BOOL T543_;
					T543_ = (NIM_BOOL)0;
					T543_ = !(((*sym_p1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)7)));
					if (T543_) goto LA544_;
					T543_ = ((*sym_p1).typ == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL));
LA544_: ;
					if (!T543_) goto LA545_;
					invalidPragma__pragmas_u142(c_p0, it_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
				}
				goto LA541_;
LA545_: ;
				{
					(*(*sym_p1).typ).flags |= ((NU64)1)<<(((((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)16))) & 63);
				}
LA541_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)213):
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)212):
			{
				noVal__pragmas_u1152(c_p0, it_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
				{
					if (!(sym_p1 == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL))) goto LA551_;
					invalidPragma__pragmas_u142(c_p0, it_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
				}
LA551_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)128):
			{
				pragmaLine__pragmas_u1167(c_p0, it_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)175):
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)180):
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)181):
			{
				pragmaRaisesOrTags__pragmas_u1305(c_p0, it_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)225):
			{
				{
					if (!(sym_p1 == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL))) goto LA558_;
					pragmaLockStmt__pragmas_u1330(c_p0, it_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
				}
				goto LA556_;
LA558_: ;
				{
					if (!((*sym_p1).typ == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL))) goto LA561_;
					invalidPragma__pragmas_u142(c_p0, it_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
				}
				goto LA556_;
LA561_: ;
				{
					warningDeprecated__msgs_u1572((*(*c_p0).graph).config, (*n_p2).info, TM__tPA3StZ6VsKyoznyrIfFxg_233);
					if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
				}
LA556_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)301):
			{
				{
					NIM_BOOL T567_;
					T567_ = (NIM_BOOL)0;
					T567_ = (sym_p1 == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL));
					if (T567_) goto LA568_;
					T567_ = !(((*sym_p1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)19)));
LA568_: ;
					if (!T567_) goto LA569_;
					invalidPragma__pragmas_u142(c_p0, it_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
				}
				goto LA565_;
LA569_: ;
				{
					NI T572_;
					T572_ = (NI)0;
					T572_ = expectIntLit__pragmas_u312(c_p0, it_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
					(*sym_p1)._kind_2.bitsize = T572_;
					{
						if (!((*sym_p1)._kind_2.bitsize <= ((NI)0))) goto LA575_;
						liMessage__msgs_u1227((*(*c_p0).graph).config, (*it_1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), TM__tPA3StZ6VsKyoznyrIfFxg_235, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__tPA3StZ6VsKyoznyrIfFxg_236), NIM_FALSE, NIM_FALSE);
						if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
					}
LA575_: ;
				}
LA565_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)224):
			{
				{
					NIM_BOOL T580_;
					T580_ = (NIM_BOOL)0;
					T580_ = (sym_p1 == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL));
					if (T580_) goto LA581_;
					T580_ = !(((*sym_p1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)8) || (*sym_p1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)9) || (*sym_p1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)19)));
LA581_: ;
					if (!T580_) goto LA582_;
					invalidPragma__pragmas_u142(c_p0, it_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
				}
				goto LA578_;
LA582_: ;
				{
					tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* T585_;
					T585_ = NIM_NIL;
					T585_ = pragmaGuard__pragmas_u1401(c_p0, it_1, (*sym_p1).kind);
					if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u4574(T585_); goto LA76_;}
					eqsink___ast_u4583(&(*sym_p1)._kind_2.guard, T585_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
				}
LA578_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)235):
			{
				{
					NIM_BOOL T589_;
					T589_ = (NIM_BOOL)0;
					T589_ = (sym_p1 == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL));
					if (T589_) goto LA590_;
					T589_ = !(((*sym_p1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)8) || (*sym_p1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)9)));
LA590_: ;
					if (!T589_) goto LA591_;
					invalidPragma__pragmas_u142(c_p0, it_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
				}
				goto LA587_;
LA591_: ;
				{
					(*sym_p1).flags |= ((NU64)1)<<(((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)59))) & 63);
				}
LA587_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)102):
			{
				{
					if (!(sym_p1 == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL))) goto LA597_;
					invalidPragma__pragmas_u142(c_p0, it_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
				}
				goto LA595_;
LA597_: ;
				{
					registerNimScriptSymbol__magicsys_u162((*c_p0).graph, sym_p1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
				}
LA595_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)209):
			{
				{
					NIM_BOOL T603_;
					T603_ = (NIM_BOOL)0;
					T603_ = isTopLevel__semdata_u4679(c_p0);
					if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
					if (!!(T603_)) goto LA604_;
					liMessage__msgs_u1227((*(*c_p0).graph).config, (*n_p2).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), TM__tPA3StZ6VsKyoznyrIfFxg_238, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__tPA3StZ6VsKyoznyrIfFxg_239), NIM_FALSE, NIM_FALSE);
					if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
				}
LA604_: ;
				processExperimental__pragmas_u842(c_p0, it_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)210):
			{
				{
					NIM_BOOL T609_;
					T609_ = (NIM_BOOL)0;
					T609_ = isTopLevel__semdata_u4679(c_p0);
					if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
					if (!!(T609_)) goto LA610_;
					liMessage__msgs_u1227((*(*c_p0).graph).config, (*n_p2).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), TM__tPA3StZ6VsKyoznyrIfFxg_241, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__tPA3StZ6VsKyoznyrIfFxg_242), NIM_FALSE, NIM_FALSE);
					if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
				}
LA610_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)192):
			{
				noVal__pragmas_u1152(c_p0, it_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)120):
			{
				noVal__pragmas_u1152(c_p0, it_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
				(*sym_p1).flags |= ((NU64)1)<<(((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)58))) & 63);
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)81):
			{
				processDefineConst__pragmas_u1000(c_p0, n_p2, sym_p1, ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)264));
				if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)82):
			{
				processDefineConst__pragmas_u1000(c_p0, n_p2, sym_p1, ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)265));
				if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)83):
			{
				processDefineConst__pragmas_u1000(c_p0, n_p2, sym_p1, ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)266));
				if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)121):
			{
				noVal__pragmas_u1152(c_p0, it_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
				{
					if (!(sym_p1 == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL))) goto LA620_;
					invalidPragma__pragmas_u142(c_p0, it_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
				}
				goto LA618_;
LA620_: ;
				{
					(*sym_p1).flags |= ((NU64)1)<<(((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)0))) & 63);
				}
LA618_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)228):
			{
				(*sym_p1).flags |= ((NU64)1)<<(((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)55))) & 63);
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)182):
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)184):
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)185):
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)186):
			{
				pragmaProposition__pragmas_u157(c_p0, it_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)183):
			{
				pragmaEnsures__pragmas_u166(c_p0, it_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)229):
			{
				(*sym_p1).flags |= ((NU64)1)<<(((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)43))) & 63);
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)233):
			{
				(*sym_p1).flags |= ((NU64)1)<<(((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)43))) & 63);
				{
					if (!((*sym_p1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)12) || (*sym_p1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)14) || (*sym_p1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)16) || (*sym_p1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)13) || (*sym_p1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)15))) goto LA630_;
					(*sym_p1).options |= ((NU32)1)<<(((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)28))) & 31);
				}
LA630_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)230):
			{
				(*sym_p1).flags |= ((NU64)1)<<(((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)44))) & 63);
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)239):
			{
				processVirtual__pragmas_u331(c_p0, it_1, sym_p1, ((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)50));
				if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
			}
			break;
			case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)241):
			{
				processVirtual__pragmas_u331(c_p0, it_1, sym_p1, ((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)52));
				if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
			}
			break;
			default:
			{
				invalidPragma__pragmas_u142(c_p0, it_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
			}
			break;
			}
			{
				LA76_:;
			}
			{
				oldNimErrFin76_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u4574(colontmpD__3);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				*nimErr_ = oldNimErrFin76_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		goto LA72_;
LA74_: ;
		{
			NIM_BOOL T639_;
			tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw T641_;
			T639_ = (NIM_BOOL)0;
			T639_ = comesFromPush_p5;
			if (!(T639_)) goto LA640_;
			T641_ = (tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)0;
			T641_ = whichKeyword__idents_u360(ident_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			T639_ = !((T641_ == ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)0)));
LA640_: ;
			if (!T639_) goto LA642_;
		}
		goto LA72_;
LA642_: ;
		{
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T645_;
			T645_ = NIM_NIL;
			T645_ = semCustomPragma__pragmas_u1430(c_p0, it_1, sym_p1);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T645_); goto LA1_;}
			eqsink___ast_u3261(&(*n_p2)._kind_6.sons.p->data[(*i_p3)], T645_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA72_: ;
	}
LA32_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u4574(userPragma_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___idents_u155(ident_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3252(key_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3252(it_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, pragmaRec__pragmas_u2509)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p2, tySet_tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw validPragmas_p3, NIM_BOOL isStatement_p4) {
	NI i_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!(n_p2 == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	i_1 = ((NI)0);
	{
		while (1) {
			NI T7_;
			T7_ = (NI)0;
			T7_ = len__ast_u3190(n_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!(i_1 < T7_)) goto LA6;
			{
				NIM_BOOL T10_;
				T10_ = (NIM_BOOL)0;
				T10_ = singlePragma__pragmas_u1506(c_p0, sym_p1, n_p2, (&i_1), validPragmas_p3, NIM_FALSE, isStatement_p4);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				if (!T10_) goto LA11_;
				goto LA5;
			}
LA11_: ;
			i_1 += ((NI)1);
		} LA6: ;
	} LA5: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, overwriteLineInfo__pragmas_u2346)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	(*n_p0).info = info_p1;
	{
		NI i_1;
		NI colontmp_;
		NI i_2;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = safeLen__ast_u3197(n_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		i_2 = ((NI)0);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA3;
				i_1 = i_2;
				overwriteLineInfo__pragmas_u2346((*n_p0)._kind_6.sons.p->data[i_1], info_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				i_2 += ((NI)1);
			} LA3: ;
		}
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, mergeValidPragmas__pragmas_u2363)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* pragmas_p1, tySet_tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw validPragmas_p2) {
NIM_BOOL oldNimErrFin15_;
NIM_BOOL oldNimErrFin7_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T5_;
		if (!((*(*n_p0)._kind_6.sons.p->data[((NI)4)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)1))) goto LA3_;
		T5_ = NIM_NIL;
		T5_ = newNodeI__ast_u4091(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)90), (*n_p0).info);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T5_); goto BeforeRet_;}
		eqsink___ast_u3261(&(*n_p0)._kind_6.sons.p->data[((NI)4)], T5_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA3_: ;
	{
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* p_1;
		p_1 = NIM_NIL;
		{
			NI i_1;
			NI colontmp_;
			NI i_2;
			i_1 = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = safeLen__ast_u3197(pragmas_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
			i_2 = ((NI)0);
			{
				while (1) {
					tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw prag_1;
					if (!(i_2 < colontmp_)) goto LA10;
					i_1 = i_2;
					eqcopy___ast_u3255(&p_1, (*pragmas_p1)._kind_6.sons.p->data[i_1]);
					if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
					prag_1 = whichPragma__trees_u218(p_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
					{
						tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* copy_1;
						if (!((validPragmas_p2[(NU)((prag_1))>>3] &(1U<<((NU)((prag_1))&7U)))!=0)) goto LA13_;
						copy_1 = NIM_NIL;
						copy_1 = copyTree__ast_u6891(p_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
						overwriteLineInfo__pragmas_u2346(copy_1, (*n_p0).info);
						if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
						add__ast_u3215((*n_p0)._kind_6.sons.p->data[((NI)4)], copy_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
						{
							LA15_:;
						}
						{
							oldNimErrFin15_ = *nimErr_; *nimErr_ = NIM_FALSE;
							eqdestroy___ast_u3252(copy_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
							*nimErr_ = oldNimErrFin15_;
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
					}
LA13_: ;
					i_2 += ((NI)1);
				} LA10: ;
			}
		}
		{
			LA7_:;
		}
		{
			oldNimErrFin7_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3252(p_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin7_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, implicitPragmas__pragmas_u2378)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_p1, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p2, tySet_tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw validPragmas_p3) {
NIM_BOOL oldNimErrFin12_;
NIM_BOOL oldNimErrFin7_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NIM_BOOL T3_;
		tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig* lib_1;
		tyObject_TOptionEntry__KeABxBvAlGa1KroFfkcqAg** T41_;
		T3_ = (NIM_BOOL)0;
		T3_ = !((sym_p1 == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)));
		if (!(T3_)) goto LA4_;
		T3_ = !(((*sym_p1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)6)));
LA4_: ;
		if (!T3_) goto LA5_;
		lib_1 = NIM_NIL;
		{
			tyObject_TOptionEntry__KeABxBvAlGa1KroFfkcqAg** it_1;
			NI i_1;
			NI L_1;
			NI T9_;
			it_1 = (tyObject_TOptionEntry__KeABxBvAlGa1KroFfkcqAg**)0;
			i_1 = ((NI)0);
			T9_ = (*c_p0).optionStack.len;
			L_1 = T9_;
			{
				while (1) {
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* o_1;
					if (!(i_1 < L_1)) goto LA11;
					o_1 = NIM_NIL;
					it_1 = &(*c_p0).optionStack.p->data[i_1];
					eqcopy___ast_u3255(&o_1, (*(*it_1)).otherPragmas);
					if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
					{
						NIM_BOOL T15_;
						NI i_2;
						T15_ = (NIM_BOOL)0;
						T15_ = !((o_1 == 0));
						if (!(T15_)) goto LA16_;
						T15_ = !((((*sym_p1).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)2)))&63U)))!=0));
LA16_: ;
						if (!T15_) goto LA17_;
						pushInfoContext__msgs_u569((*(*c_p0).graph).config, info_p2, TM__tPA3StZ6VsKyoznyrIfFxg_251);
						if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
						i_2 = ((NI)0);
						{
							while (1) {
								NI T21_;
								T21_ = (NI)0;
								T21_ = len__ast_u3190(o_1);
								if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
								if (!(i_2 < T21_)) goto LA20;
								{
									NIM_BOOL T24_;
									T24_ = (NIM_BOOL)0;
									T24_ = singlePragma__pragmas_u1506(c_p0, sym_p1, o_1, (&i_2), validPragmas_p3, NIM_TRUE, NIM_FALSE);
									if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
									if (!T24_) goto LA25_;
									internalErrorImpl__msgs_u1598((*(*c_p0).graph).config, info_p2, TM__tPA3StZ6VsKyoznyrIfFxg_253, (&TM__tPA3StZ6VsKyoznyrIfFxg_254));
									if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
								}
LA25_: ;
								i_2 += ((NI)1);
							} LA20: ;
						}
						popInfoContext__msgs_u593((*(*c_p0).graph).config);
						if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
						{
							NIM_BOOL T29_;
							T29_ = (NIM_BOOL)0;
							T29_ = ((*sym_p1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)12) || (*sym_p1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)13) || (*sym_p1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)14) || (*sym_p1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)15) || (*sym_p1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)16) || (*sym_p1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)17) || (*sym_p1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)18));
							if (!(T29_)) goto LA30_;
							T29_ = !(((*sym_p1).ast == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL)));
LA30_: ;
							if (!T29_) goto LA31_;
							mergeValidPragmas__pragmas_u2363((*sym_p1).ast, o_1, validPragmas_p3);
							if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
						}
LA31_: ;
					}
LA17_: ;
					i_1 += ((NI)1);
					{
						LA12_:;
					}
					{
						oldNimErrFin12_ = *nimErr_; *nimErr_ = NIM_FALSE;
						eqdestroy___ast_u3252(o_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
						*nimErr_ = oldNimErrFin12_;
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
				} LA11: ;
			}
		}
		{
			NIM_BOOL T37_;
			T37_ = (NIM_BOOL)0;
			T37_ = (((*sym_p1).loc.flags &((NU16)1<<((NU)((((tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg)4)))&15U)))!=0);
			if (!(T37_)) goto LA38_;
			T37_ = !((((*sym_p1).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)7)))&63U)))!=0));
LA38_: ;
			if (!T37_) goto LA39_;
			liMessage__msgs_u1227((*(*c_p0).graph).config, info_p2, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), TM__tPA3StZ6VsKyoznyrIfFxg_256, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__tPA3StZ6VsKyoznyrIfFxg_257), NIM_FALSE, NIM_FALSE);
			if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		}
LA39_: ;
		T41_ = (tyObject_TOptionEntry__KeABxBvAlGa1KroFfkcqAg**)0;
		T41_ = X5BX5D___semdata_u454((((*c_p0).optionStack).p) ? ((*c_p0).optionStack.p->data) : NIM_NIL, (*c_p0).optionStack.len, ((NI)1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		eqcopy___ast_u6219(&lib_1, (*(*T41_)).dynlib);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		{
			NIM_BOOL T44_;
			NIM_BOOL T45_;
			tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T46_;
			T44_ = (NIM_BOOL)0;
			T45_ = (NIM_BOOL)0;
			T46_ = 0;
			T45_ = ((40 & (*sym_p1).loc.flags) == T46_);
			if (!(T45_)) goto LA47_;
			T45_ = (((*sym_p1).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)6)))&63U)))!=0);
LA47_: ;
			T44_ = T45_;
			if (!(T44_)) goto LA48_;
			T44_ = !((lib_1 == ((tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig*) NIM_NIL)));
LA48_: ;
			if (!T44_) goto LA49_;
			(*sym_p1).loc.flags |= ((NU16)1)<<(((((tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg)3))) & 15);
			addToLib__semdata_u4365(lib_1, sym_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
			{
				if (!((*sym_p1).loc.snippet.len == 0)) goto LA53_;
				eqcopy___system_u2694((&(*sym_p1).loc.snippet), (*(*sym_p1).name).s);
			}
LA53_: ;
		}
LA49_: ;
		{
			LA7_:;
		}
		{
			oldNimErrFin7_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u6216(lib_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin7_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA5_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, pragma__pragmas_u120)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p2, tySet_tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw validPragmas_p3, NIM_BOOL isStatement_p4, NIM_BOOL comesFromPush_p5) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!(n_p2 == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	pragmaRec__pragmas_u2509(c_p0, sym_p1, n_p2, validPragmas_p3, isStatement_p4);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!!(comesFromPush_p5)) goto LA7_;
		implicitPragmas__pragmas_u2378(c_p0, sym_p1, (*n_p2).info, validPragmas_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA7_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, getPragmaVal__pragmas_u99)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* procAst_p0, tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw name_p1) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* p_1;
NIM_BOOL oldNimErrFin7_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	p_1 = NIM_NIL;
	result = ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL);
	eqcopy___ast_u3255(&p_1, (*procAst_p0)._kind_6.sons.p->data[((NI)4)]);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		if (!((*p_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)1))) goto LA4_;
		result = ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL);
		eqdestroy___ast_u3252(p_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		goto BeforeRet_;
	}
LA4_: ;
	{
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* it_1;
		it_1 = NIM_NIL;
		{
			NI i_1;
			NI colontmp_;
			NI i_2;
			i_1 = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = safeLen__ast_u3197(p_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
			i_2 = ((NI)0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA10;
					i_1 = i_2;
					eqcopy___ast_u3255(&it_1, (*p_1)._kind_6.sons.p->data[i_1]);
					if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
					{
						NIM_BOOL T13_;
						NIM_BOOL T14_;
						NIM_BOOL T15_;
						NI T17_;
						T13_ = (NIM_BOOL)0;
						T14_ = (NIM_BOOL)0;
						T15_ = (NIM_BOOL)0;
						T15_ = ((*it_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)34) || (*it_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)27) || (*it_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)28));
						if (!(T15_)) goto LA16_;
						T17_ = (NI)0;
						T17_ = len__ast_u3190(it_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
						T15_ = (T17_ == ((NI)2));
LA16_: ;
						T14_ = T15_;
						if (!(T14_)) goto LA18_;
						T14_ = ((*(*it_1)._kind_6.sons.p->data[((NI)0)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)2));
LA18_: ;
						T13_ = T14_;
						if (!(T13_)) goto LA19_;
						T13_ = ((*(*(*it_1)._kind_6.sons.p->data[((NI)0)])._kind_5.ident).id == name_p1);
LA19_: ;
						if (!T13_) goto LA20_;
						eqcopy___ast_u3255(&result, (*it_1)._kind_6.sons.p->data[((NI)1)]);
						if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
						eqdestroy___ast_u3252(it_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						eqdestroy___ast_u3252(p_1);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						goto BeforeRet_;
					}
LA20_: ;
					i_2 += ((NI)1);
				} LA10: ;
			}
		}
		{
			LA7_:;
		}
		{
			oldNimErrFin7_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3252(it_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin7_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3252(p_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasPragma__pragmas_u2487)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0, tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw pragma_p1) {
	NIM_BOOL result;
NIM_BOOL oldNimErrFin10_;
NIM_BOOL oldNimErrFin6_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	{
		if (!(n_p0 == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL))) goto LA3_;
		result = NIM_FALSE;
		goto BeforeRet_;
	}
LA3_: ;
	{
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* p_1;
		p_1 = NIM_NIL;
		{
			NI i_1;
			NI colontmp_;
			NI i_2;
			i_1 = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = safeLen__ast_u3197(n_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
			i_2 = ((NI)0);
			{
				while (1) {
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* key_1;
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T11_;
					if (!(i_2 < colontmp_)) goto LA9;
					key_1 = NIM_NIL;
					i_1 = i_2;
					eqcopy___ast_u3255(&p_1, (*n_p0)._kind_6.sons.p->data[i_1]);
					if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
					T11_ = NIM_NIL;
					{
						NIM_BOOL T14_;
						NI T16_;
						T14_ = (NIM_BOOL)0;
						T14_ = ((*p_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)34) || (*p_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)27) || (*p_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)28));
						if (!(T14_)) goto LA15_;
						T16_ = (NI)0;
						T16_ = len__ast_u3190(p_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
						T14_ = (((NI)1) < T16_);
LA15_: ;
						if (!T14_) goto LA17_;
						eqcopy___ast_u3255(&key_1, (*p_1)._kind_6.sons.p->data[((NI)0)]);
						if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
					}
					goto LA12_;
LA17_: ;
					{
						key_1 = p_1;
						eqwasMoved___ast_u3249(&p_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
					}
LA12_: ;
					{
						NIM_BOOL T22_;
						tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw T24_;
						T22_ = (NIM_BOOL)0;
						T22_ = ((*key_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)2));
						if (!(T22_)) goto LA23_;
						T24_ = (tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)0;
						T24_ = whichKeyword__idents_u360((*key_1)._kind_5.ident);
						if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
						T22_ = (T24_ == pragma_p1);
LA23_: ;
						if (!T22_) goto LA25_;
						result = NIM_TRUE;
						eqdestroy___ast_u3252(key_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
						eqdestroy___ast_u3252(p_1);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						goto BeforeRet_;
					}
LA25_: ;
					i_2 += ((NI)1);
					{
						LA10_:;
					}
					{
						oldNimErrFin10_ = *nimErr_; *nimErr_ = NIM_FALSE;
						eqdestroy___ast_u3252(key_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
						*nimErr_ = oldNimErrFin10_;
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
				} LA9: ;
			}
		}
		{
			LA6_:;
		}
		{
			oldNimErrFin6_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3252(p_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin6_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	result = NIM_FALSE;
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, pragmaCallable__pragmas_u2536)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p2, tySet_tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw validPragmas_p3, NIM_BOOL isStatement_p4) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!(n_p2 == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	{
		if (!!(((*(*n_p2)._kind_6.sons.p->data[((NI)4)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)1)))) goto LA7_;
		pragmaRec__pragmas_u2509(c_p0, sym_p1, (*n_p2)._kind_6.sons.p->data[((NI)4)], validPragmas_p3, isStatement_p4);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA7_: ;
	}BeforeRet_: ;
}
static N_INLINE(NI, find__stdZenumutils_u56)(NimStringV2* a_p0, NI a_p0Len_0, NimStringV2 item_p1) {
	NI result;
{	result = ((NI)0);
	{
		NimStringV2* i_1;
		NI i_2;
		i_1 = (NimStringV2*)0;
		i_2 = ((NI)0);
		{
			while (1) {
				if (!(i_2 < a_p0Len_0)) goto LA3;
				i_1 = (&a_p0[i_2]);
				{
					if (!eqStrings((*i_1), item_p1)) goto LA6_;
					goto BeforeRet_;
				}
LA6_: ;
				result += ((NI)1);
				i_2 += ((NI)1);
			} LA3: ;
		}
	}
	result = ((NI)-1);
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, contains__stdZenumutils_u51)(NimStringV2* a_p0, NI a_p0Len_0, NimStringV2 item_p1) {
	NIM_BOOL result;
	NI T1_;
{	T1_ = (NI)0;
	T1_ = find__stdZenumutils_u56(a_p0, a_p0Len_0, item_p1);
	result = (((NI)0) <= T1_);
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_CHAR, pragmaAsm__pragmas_u462)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
	NIM_CHAR result;
NIM_BOOL oldNimErrFin8_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = 0;
	{
		if (!!((n_p1 == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL)))) goto LA3_;
		{
			NI i_1;
			NI colontmp_;
			NI i_2;
			i_1 = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__ast_u3190(n_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			i_2 = ((NI)0);
			{
				while (1) {
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* it_1;
					if (!(i_2 < colontmp_)) goto LA7;
					it_1 = NIM_NIL;
					i_1 = i_2;
					eqcopy___ast_u3255(&it_1, (*n_p1)._kind_6.sons.p->data[i_1]);
					if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
					{
						NIM_BOOL T11_;
						NIM_BOOL T12_;
						NI T14_;
						tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw T18_;
						T11_ = (NIM_BOOL)0;
						T12_ = (NIM_BOOL)0;
						T12_ = ((*it_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)34) || (*it_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)27) || (*it_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)28));
						if (!(T12_)) goto LA13_;
						T14_ = (NI)0;
						T14_ = len__ast_u3190(it_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
						T12_ = (T14_ == ((NI)2));
LA13_: ;
						T11_ = T12_;
						if (!(T11_)) goto LA15_;
						T11_ = ((*(*it_1)._kind_6.sons.p->data[((NI)0)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)2));
LA15_: ;
						if (!T11_) goto LA16_;
						T18_ = (tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)0;
						T18_ = whichKeyword__idents_u360((*(*it_1)._kind_6.sons.p->data[((NI)0)])._kind_5.ident);
						if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
						switch (T18_) {
						case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)203):
						{
							{
								if (!((*(*it_1)._kind_6.sons.p->data[((NI)1)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)5))) goto LA22_;
								result = ((NIM_CHAR) ((((NI) ((*(*it_1)._kind_6.sons.p->data[((NI)1)])._kind_1.intVal)))));
							}
							goto LA20_;
LA22_: ;
							{
								invalidPragma__pragmas_u142(c_p0, it_1);
								if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
							}
LA20_: ;
						}
						break;
						case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)219):
						{
							NimStringV2 s_1;
							s_1.len = 0; s_1.p = NIM_NIL;
							s_1 = expectStrLit__pragmas_u308(c_p0, it_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
							{
								NIM_BOOL T29_;
								T29_ = (NIM_BOOL)0;
								T29_ = contains__stdZenumutils_u51(TM__tPA3StZ6VsKyoznyrIfFxg_258, 2, s_1);
								if (!!(T29_)) goto LA30_;
								invalidPragma__pragmas_u142(c_p0, it_1);
								if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
							}
LA30_: ;
							{
								LA26_:;
							}
							{
								eqdestroy___system_u2691(s_1);
							}
							if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
						}
						break;
						default:
						{
							invalidPragma__pragmas_u142(c_p0, it_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
						}
						break;
						}
					}
					goto LA9_;
LA16_: ;
					{
						invalidPragma__pragmas_u142(c_p0, it_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
					}
LA9_: ;
					i_2 += ((NI)1);
					{
						LA8_:;
					}
					{
						oldNimErrFin8_ = *nimErr_; *nimErr_ = NIM_FALSE;
						eqdestroy___ast_u3252(it_1);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						*nimErr_ = oldNimErrFin8_;
					}
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				} LA7: ;
			}
		}
	}
LA3_: ;
	}BeforeRet_: ;
	return result;
}
