/* Generated by Nim Compiler v2.2.10 */
#define NIM_INTBITS 32
#define NIM_EmulateOverflowChecks

#include "nimbase.h"
#include <string.h>
#include <math.h>
#include <stdlib.h>
#include <dirent.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <time.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix
typedef struct tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ;
typedef struct tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg;
typedef struct tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug;
typedef struct tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw;
typedef struct tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew;
typedef struct RootObj RootObj;
typedef struct tyObject_TStackFrame__a20zU43j9cYHpYOOr1c2hZQ tyObject_TStackFrame__a20zU43j9cYHpYOOr1c2hZQ;
typedef struct tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A;
typedef struct tySequence__TfHJycarvNts8E4mVG4Mfg tySequence__TfHJycarvNts8E4mVG4Mfg;
typedef struct tySequence__TfHJycarvNts8E4mVG4Mfg_Content tySequence__TfHJycarvNts8E4mVG4Mfg_Content;
typedef struct tyObject_PackedModuleGraph__vzv9a6xTiz616FotDgUeo9bg tyObject_PackedModuleGraph__vzv9a6xTiz616FotDgUeo9bg;
typedef struct tySequence__5reviU45axUMPQgL9aoENrg tySequence__5reviU45axUMPQgL9aoENrg;
typedef struct tySequence__5reviU45axUMPQgL9aoENrg_Content tySequence__5reviU45axUMPQgL9aoENrg_Content;
typedef struct tySequence__dtr79aXjHrgHuH79ac55I2aw tySequence__dtr79aXjHrgHuH79ac55I2aw;
typedef struct tySequence__dtr79aXjHrgHuH79ac55I2aw_Content tySequence__dtr79aXjHrgHuH79ac55I2aw_Content;
typedef struct tyObject_Table__EBJpp1hXwvFl9cyekUv4qHg tyObject_Table__EBJpp1hXwvFl9cyekUv4qHg;
typedef struct tySequence__8y0Gi4GwtXi2wk2mK1IOzw tySequence__8y0Gi4GwtXi2wk2mK1IOzw;
typedef struct tySequence__8y0Gi4GwtXi2wk2mK1IOzw_Content tySequence__8y0Gi4GwtXi2wk2mK1IOzw_Content;
typedef struct tyObject_Table__nn0jq9adRZXGGj9assM9c9bR0w tyObject_Table__nn0jq9adRZXGGj9assM9c9bR0w;
typedef struct tySequence__C2ivDnhTZ6IxAdui1rfuqw tySequence__C2ivDnhTZ6IxAdui1rfuqw;
typedef struct tySequence__C2ivDnhTZ6IxAdui1rfuqw_Content tySequence__C2ivDnhTZ6IxAdui1rfuqw_Content;
typedef struct tyObject_Table__ChMwcRY3QzpOEBWbGAfvcA tyObject_Table__ChMwcRY3QzpOEBWbGAfvcA;
typedef struct tySequence__3vEEVfBECLN6NIRA3FIp5g tySequence__3vEEVfBECLN6NIRA3FIp5g;
typedef struct tySequence__3vEEVfBECLN6NIRA3FIp5g_Content tySequence__3vEEVfBECLN6NIRA3FIp5g_Content;
typedef struct tyObject_Table__tEqt8LkShErhjQ9acvGyE7g tyObject_Table__tEqt8LkShErhjQ9acvGyE7g;
typedef struct tySequence__9aSa87aKMiolq9a7z3kC0jTw tySequence__9aSa87aKMiolq9a7z3kC0jTw;
typedef struct tySequence__9aSa87aKMiolq9a7z3kC0jTw_Content tySequence__9aSa87aKMiolq9a7z3kC0jTw_Content;
typedef struct tyObject_Table__QS2Z9cQjmvkp1aaFGq4ippw tyObject_Table__QS2Z9cQjmvkp1aaFGq4ippw;
typedef struct tySequence__N589c2UsUgqqOITU2JfIuAQ tySequence__N589c2UsUgqqOITU2JfIuAQ;
typedef struct tySequence__N589c2UsUgqqOITU2JfIuAQ_Content tySequence__N589c2UsUgqqOITU2JfIuAQ_Content;
typedef struct tyObject_Table__bnfVX2VJ9aUicVujDM0GIhw tyObject_Table__bnfVX2VJ9aUicVujDM0GIhw;
typedef struct tySequence__GYDW6wGgERshoSd16jJ3eQ tySequence__GYDW6wGgERshoSd16jJ3eQ;
typedef struct tySequence__GYDW6wGgERshoSd16jJ3eQ_Content tySequence__GYDW6wGgERshoSd16jJ3eQ_Content;
typedef struct tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw tySequence__7lEisrXlQEzwtUKW5pzRCw;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw_Content tySequence__7lEisrXlQEzwtUKW5pzRCw_Content;
typedef struct tyObject_PackedConfig__Hpn673wkKPDorr1HY9bOaDQ tyObject_PackedConfig__Hpn673wkKPDorr1HY9bOaDQ;
typedef struct tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg;
typedef struct tySequence__ZCZaCk14bTmSb6LMW9aWPVA tySequence__ZCZaCk14bTmSb6LMW9aWPVA;
typedef struct tySequence__ZCZaCk14bTmSb6LMW9aWPVA_Content tySequence__ZCZaCk14bTmSb6LMW9aWPVA_Content;
typedef struct tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA;
typedef struct tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA;
typedef struct tySequence__ZeWVlH6DqG79b1pTDhrrUYA tySequence__ZeWVlH6DqG79b1pTDhrrUYA;
typedef struct tySequence__ZeWVlH6DqG79b1pTDhrrUYA_Content tySequence__ZeWVlH6DqG79b1pTDhrrUYA_Content;
typedef struct tyObject_Table__79b4rr6WWQqgRr9b4NH4UF9cw tyObject_Table__79b4rr6WWQqgRr9b4NH4UF9cw;
typedef struct tySequence__fdmz6VkIf1ewwrssKYqRFg tySequence__fdmz6VkIf1ewwrssKYqRFg;
typedef struct tySequence__fdmz6VkIf1ewwrssKYqRFg_Content tySequence__fdmz6VkIf1ewwrssKYqRFg_Content;
typedef struct tyObject_Table__AC9bec2JdoOuC3xQePGWgmA tyObject_Table__AC9bec2JdoOuC3xQePGWgmA;
typedef struct tySequence__kxu4GK0onha2t9bo86mdVAg tySequence__kxu4GK0onha2t9bo86mdVAg;
typedef struct tySequence__kxu4GK0onha2t9bo86mdVAg_Content tySequence__kxu4GK0onha2t9bo86mdVAg_Content;
typedef struct tySequence__48JTohSgTy339bRxHzUD8KA tySequence__48JTohSgTy339bRxHzUD8KA;
typedef struct tySequence__48JTohSgTy339bRxHzUD8KA_Content tySequence__48JTohSgTy339bRxHzUD8KA_Content;
typedef struct tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg;
typedef struct tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA;
typedef struct tyObject_Table__bHTcQUCehDW9clHfFZXI7lQ tyObject_Table__bHTcQUCehDW9clHfFZXI7lQ;
typedef struct tySequence__fz0REU1l0nYmKHXgMLRrIg tySequence__fz0REU1l0nYmKHXgMLRrIg;
typedef struct tySequence__fz0REU1l0nYmKHXgMLRrIg_Content tySequence__fz0REU1l0nYmKHXgMLRrIg_Content;
typedef struct tyObject_Table__w2vCG1OPnHmNolvQVT168g tyObject_Table__w2vCG1OPnHmNolvQVT168g;
typedef struct tySequence__Ip9aV1IKO2gVdheNOM31DCQ tySequence__Ip9aV1IKO2gVdheNOM31DCQ;
typedef struct tySequence__Ip9aV1IKO2gVdheNOM31DCQ_Content tySequence__Ip9aV1IKO2gVdheNOM31DCQ_Content;
typedef struct tySequence__kHjIdgrpmuSn9cUIIKpSiDg tySequence__kHjIdgrpmuSn9cUIIKpSiDg;
typedef struct tySequence__kHjIdgrpmuSn9cUIIKpSiDg_Content tySequence__kHjIdgrpmuSn9cUIIKpSiDg_Content;
typedef struct tyObject_CountTable__qvMelb9coODdwoghoAPc9c9aA tyObject_CountTable__qvMelb9coODdwoghoAPc9c9aA;
typedef struct tySequence__Wd0Vle6gxRCPPoSlNEvfTA tySequence__Wd0Vle6gxRCPPoSlNEvfTA;
typedef struct tySequence__Wd0Vle6gxRCPPoSlNEvfTA_Content tySequence__Wd0Vle6gxRCPPoSlNEvfTA_Content;
typedef struct tyObject_Table__fZyCWkMwhdvr3pauCNDaag tyObject_Table__fZyCWkMwhdvr3pauCNDaag;
typedef struct tySequence__T7nNEWoEbKBa0G5Htr45Xw tySequence__T7nNEWoEbKBa0G5Htr45Xw;
typedef struct tySequence__T7nNEWoEbKBa0G5Htr45Xw_Content tySequence__T7nNEWoEbKBa0G5Htr45Xw_Content;
typedef struct tyObject_Table__5vmBY49areSIlgIs4A1LLKQ tyObject_Table__5vmBY49areSIlgIs4A1LLKQ;
typedef struct tySequence__q9cHvMDDxYU1hSCdG4YwIhA tySequence__q9cHvMDDxYU1hSCdG4YwIhA;
typedef struct tySequence__q9cHvMDDxYU1hSCdG4YwIhA_Content tySequence__q9cHvMDDxYU1hSCdG4YwIhA_Content;
typedef struct tySequence__olFOFaYzOJN9aV5BWqK4b9bA tySequence__olFOFaYzOJN9aV5BWqK4b9bA;
typedef struct tySequence__olFOFaYzOJN9aV5BWqK4b9bA_Content tySequence__olFOFaYzOJN9aV5BWqK4b9bA_Content;
typedef struct tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg;
typedef struct tyObject_Table__9bmd0cvHWe1s4FTDn5BPmfw tyObject_Table__9bmd0cvHWe1s4FTDn5BPmfw;
typedef struct tySequence__vJcM7B74R2U5db9cxyXT9coA tySequence__vJcM7B74R2U5db9cxyXT9coA;
typedef struct tySequence__vJcM7B74R2U5db9cxyXT9coA_Content tySequence__vJcM7B74R2U5db9cxyXT9coA_Content;
typedef struct tyObject_Table__GhjCMuklnRqwdX9bZo9bCoNg tyObject_Table__GhjCMuklnRqwdX9bZo9bCoNg;
typedef struct tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg;
typedef struct tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg_Content tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg_Content;
typedef struct tyObject_Table__pI3mJh4Ap2XujSCfcSeUvQ tyObject_Table__pI3mJh4Ap2XujSCfcSeUvQ;
typedef struct tySequence__R9c39btP6BwOBBPnbaNUtMQg tySequence__R9c39btP6BwOBBPnbaNUtMQg;
typedef struct tySequence__R9c39btP6BwOBBPnbaNUtMQg_Content tySequence__R9c39btP6BwOBBPnbaNUtMQg_Content;
typedef struct tyObject_Table__MsPmCuYz1KcEw6lr7P9cGkw tyObject_Table__MsPmCuYz1KcEw6lr7P9cGkw;
typedef struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA tySequence__squ9b9bUH4OLHf6cEMrt6hVA;
typedef struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA_Content tySequence__squ9b9bUH4OLHf6cEMrt6hVA_Content;
typedef struct tyObject_Table__1HJsK7ponJ4Vb1lJgVFVTQ tyObject_Table__1HJsK7ponJ4Vb1lJgVFVTQ;
typedef struct tySequence__3nALyQgqjnfK2Qjc6ny2Uw tySequence__3nALyQgqjnfK2Qjc6ny2Uw;
typedef struct tySequence__3nALyQgqjnfK2Qjc6ny2Uw_Content tySequence__3nALyQgqjnfK2Qjc6ny2Uw_Content;
typedef struct tySequence__WbW5Q8QVks0bQpUJSGmuVg tySequence__WbW5Q8QVks0bQpUJSGmuVg;
typedef struct tySequence__WbW5Q8QVks0bQpUJSGmuVg_Content tySequence__WbW5Q8QVks0bQpUJSGmuVg_Content;
typedef struct tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA;
typedef struct tySequence__9ahcSjIErJohSBBFLwuF56Q tySequence__9ahcSjIErJohSBBFLwuF56Q;
typedef struct tySequence__9ahcSjIErJohSBBFLwuF56Q_Content tySequence__9ahcSjIErJohSBBFLwuF56Q_Content;
typedef struct tyObject_Operators__yrAfvKhiysDamJlcGNgVfQ tyObject_Operators__yrAfvKhiysDamJlcGNgVfQ;
typedef struct tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg;
typedef struct tyObject_Target__GzbDkV2u8Pgzlf9azvC43FA tyObject_Target__GzbDkV2u8Pgzlf9azvC43FA;
typedef struct NimStrPayload NimStrPayload;
typedef struct NimStringV2 NimStringV2;
typedef struct tyObject_MsgConfig__E1VAUnnaNIOngCdEgTI2Dw tyObject_MsgConfig__E1VAUnnaNIOngCdEgTI2Dw;
typedef struct tySequence__E0kio2ZnplNTuln9bsnljSA tySequence__E0kio2ZnplNTuln9bsnljSA;
typedef struct tySequence__E0kio2ZnplNTuln9bsnljSA_Content tySequence__E0kio2ZnplNTuln9bsnljSA_Content;
typedef struct tySequence__hTEiKNj3evQAjIXUI21elA tySequence__hTEiKNj3evQAjIXUI21elA;
typedef struct tySequence__hTEiKNj3evQAjIXUI21elA_Content tySequence__hTEiKNj3evQAjIXUI21elA_Content;
typedef struct tyObject_HashSet__8IGL0eIK5PYDsNGVA78Wmw tyObject_HashSet__8IGL0eIK5PYDsNGVA78Wmw;
typedef struct tySequence__4eRCaZmrYLLw2k30GPTiMw tySequence__4eRCaZmrYLLw2k30GPTiMw;
typedef struct tySequence__4eRCaZmrYLLw2k30GPTiMw_Content tySequence__4eRCaZmrYLLw2k30GPTiMw_Content;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ tySequence__sM4lkSb7zS6F7OVMvW9cffQ;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content;
typedef struct tySequence__xOJ2kx2lq9bBfIm3IXnde3Q tySequence__xOJ2kx2lq9bBfIm3IXnde3Q;
typedef struct tySequence__xOJ2kx2lq9bBfIm3IXnde3Q_Content tySequence__xOJ2kx2lq9bBfIm3IXnde3Q_Content;
typedef struct tyObject_SuggestcolonObjectType___UyASNXAqAMRY5zJmcRD9ccA tyObject_SuggestcolonObjectType___UyASNXAqAMRY5zJmcRD9ccA;
typedef struct tyObject_ProfileDatacolonObjectType___R9cEb9cNTzPRldVmD9bCDO0xQ tyObject_ProfileDatacolonObjectType___R9cEb9cNTzPRldVmD9bCDO0xQ;
typedef struct tyTuple__kN8up2W6YKc5YA9avn5mV5w tyTuple__kN8up2W6YKc5YA9avn5mV5w;
typedef struct tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA;
typedef struct tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA;
typedef struct tySequence__d8ZV4IMgHt9biik9cS9a0hrmg tySequence__d8ZV4IMgHt9biik9cS9a0hrmg;
typedef struct tySequence__d8ZV4IMgHt9biik9cS9a0hrmg_Content tySequence__d8ZV4IMgHt9biik9cS9a0hrmg_Content;
typedef struct tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw;
typedef struct tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig;
typedef struct tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ;
typedef struct TNimTypeV2 TNimTypeV2;
typedef struct tySequence__YdLNCDKYeipzJx3I8Xw82Q tySequence__YdLNCDKYeipzJx3I8Xw82Q;
typedef struct tySequence__YdLNCDKYeipzJx3I8Xw82Q_Content tySequence__YdLNCDKYeipzJx3I8Xw82Q_Content;
typedef struct tySequence__TLbZ2GqL3Zio1f8bNpj2NA tySequence__TLbZ2GqL3Zio1f8bNpj2NA;
typedef struct tySequence__TLbZ2GqL3Zio1f8bNpj2NA_Content tySequence__TLbZ2GqL3Zio1f8bNpj2NA_Content;
typedef struct tyObject_TNodeTable__RKuYIY5Phq1xnepo5DZI2g tyObject_TNodeTable__RKuYIY5Phq1xnepo5DZI2g;
typedef struct tySequence__GH1mmNKNA2QP4n1tnxJf1w tySequence__GH1mmNKNA2QP4n1tnxJf1w;
typedef struct tySequence__GH1mmNKNA2QP4n1tnxJf1w_Content tySequence__GH1mmNKNA2QP4n1tnxJf1w_Content;
typedef struct tyObject_PProccolonObjectType___BUXHs9a6Ck9awUko3NbJ3Fyg tyObject_PProccolonObjectType___BUXHs9a6Ck9awUko3NbJ3Fyg;
typedef struct tySequence__TEgqV1E9aHqnwBUoeXjBI9aA tySequence__TEgqV1E9aHqnwBUoeXjBI9aA;
typedef struct tySequence__TEgqV1E9aHqnwBUoeXjBI9aA_Content tySequence__TEgqV1E9aHqnwBUoeXjBI9aA_Content;
typedef struct tyObject_Table__tro5f9chxPVpES1mQpDwZtQ tyObject_Table__tro5f9chxPVpES1mQpDwZtQ;
typedef struct tySequence__pUxI6Ljo6IKKHXKOZkQ7Og tySequence__pUxI6Ljo6IKKHXKOZkQ7Og;
typedef struct tySequence__pUxI6Ljo6IKKHXKOZkQ7Og_Content tySequence__pUxI6Ljo6IKKHXKOZkQ7Og_Content;
typedef struct tyObject_Profiler__YI4zs2CaXXndlYireD0I8A tyObject_Profiler__YI4zs2CaXXndlYireD0I8A;
typedef struct tySequence__fnH5Zt4fsGx0AgDTOw8pKw tySequence__fnH5Zt4fsGx0AgDTOw8pKw;
typedef struct tySequence__fnH5Zt4fsGx0AgDTOw8pKw_Content tySequence__fnH5Zt4fsGx0AgDTOw8pKw_Content;
typedef struct tyObject_Table__lPs28yjGTxD0LzUoPspSBQ tyObject_Table__lPs28yjGTxD0LzUoPspSBQ;
typedef struct tySequence__Fc8Q26tsngy2yxcpyrnT4Q tySequence__Fc8Q26tsngy2yxcpyrnT4Q;
typedef struct tySequence__Fc8Q26tsngy2yxcpyrnT4Q_Content tySequence__Fc8Q26tsngy2yxcpyrnT4Q_Content;
typedef struct tyObject_Env_vmopsdotnim_registerAdditionalOps___VDnIL6fWGTCjJE9c9cTQGKGw tyObject_Env_vmopsdotnim_registerAdditionalOps___VDnIL6fWGTCjJE9c9cTQGKGw;
typedef struct tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A;
typedef struct tyObject_GcEnv__HccVszwojlCZRN46BE9cG8w tyObject_GcEnv__HccVszwojlCZRN46BE9cG8w;
typedef struct tyObject_CellSeq__gW9aeWLFbrNaeUKXqxYBXhg tyObject_CellSeq__gW9aeWLFbrNaeUKXqxYBXhg;
typedef struct tyTuple__N4J9cV4JZGem3ljqqj5rT0Q tyTuple__N4J9cV4JZGem3ljqqj5rT0Q;
typedef struct tyObject_CellSeq__IHvIqxITv1yMjJj8lwLrhg tyObject_CellSeq__IHvIqxITv1yMjJj8lwLrhg;
typedef struct tyTuple__DTRsWi2kgTewbhN2TT5mbA tyTuple__DTRsWi2kgTewbhN2TT5mbA;
typedef struct tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg;
typedef struct tyTuple__igdSbLMeeUm9brp9bUKtC70w tyTuple__igdSbLMeeUm9brp9bUKtC70w;
typedef struct tyTuple__wjbnfGBIEcH6aaevyJWrgw tyTuple__wjbnfGBIEcH6aaevyJWrgw;
typedef struct tyTuple__RQuzKb7YBI25p4z9cTFFLeQ tyTuple__RQuzKb7YBI25p4z9cTFFLeQ;
typedef struct tyTuple__XOVT24GHXwqiEj5GCsEGCA tyTuple__XOVT24GHXwqiEj5GCsEGCA;
typedef struct tySequence__9c9aWmheGsuf9aHtY7gTnUcPA tySequence__9c9aWmheGsuf9aHtY7gTnUcPA;
typedef struct tySequence__9c9aWmheGsuf9aHtY7gTnUcPA_Content tySequence__9c9aWmheGsuf9aHtY7gTnUcPA_Content;
typedef struct tySequence__qwqHTkRvwhrRyENtudHQ7g tySequence__qwqHTkRvwhrRyENtudHQ7g;
typedef struct tySequence__qwqHTkRvwhrRyENtudHQ7g_Content tySequence__qwqHTkRvwhrRyENtudHQ7g_Content;
typedef struct tyObject_TFileInfo__xPdjmgevOVG8T0Aq8BK7jw tyObject_TFileInfo__xPdjmgevOVG8T0Aq8BK7jw;
typedef struct tySequence__b9bG03Q6unwlMU0dM7uOPIA tySequence__b9bG03Q6unwlMU0dM7uOPIA;
typedef struct tySequence__b9bG03Q6unwlMU0dM7uOPIA_Content tySequence__b9bG03Q6unwlMU0dM7uOPIA_Content;
typedef struct tySequence__grdS5PdBBxkq9bxi4lFAdAw tySequence__grdS5PdBBxkq9bxi4lFAdAw;
typedef struct tySequence__grdS5PdBBxkq9bxi4lFAdAw_Content tySequence__grdS5PdBBxkq9bxi4lFAdAw_Content;
typedef struct tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw;
typedef struct tyObject_NodecolonObjectType___U4ON6JZL9cIHezBQjmQzJ8Q tyObject_NodecolonObjectType___U4ON6JZL9cIHezBQjmQzJ8Q;
typedef struct tySequence__6H5Oh5UUvVCLiakt9aTwtUQ tySequence__6H5Oh5UUvVCLiakt9aTwtUQ;
typedef struct tySequence__6H5Oh5UUvVCLiakt9aTwtUQ_Content tySequence__6H5Oh5UUvVCLiakt9aTwtUQ_Content;
typedef struct tyObject_Time__f9czJU2iP3D49bUN3jzSsOfA tyObject_Time__f9czJU2iP3D49bUN3jzSsOfA;
typedef struct tySequence__4eQHGndY6XBYpFOH09apV8Q tySequence__4eQHGndY6XBYpFOH09apV8Q;
typedef struct tySequence__4eQHGndY6XBYpFOH09apV8Q_Content tySequence__4eQHGndY6XBYpFOH09apV8Q_Content;
typedef struct tyTuple__UV3llMMYFckfui8YMBuUZA tyTuple__UV3llMMYFckfui8YMBuUZA;
typedef struct tyObject_VmProcInfo__Jux30icZSrOlvcFTG81Ljg tyObject_VmProcInfo__Jux30icZSrOlvcFTG81Ljg;
typedef struct tyObject_Env_vmdotnim_rawExecute___hNEyCf8VhTK2S3ZJXhlD9cg tyObject_Env_vmdotnim_rawExecute___hNEyCf8VhTK2S3ZJXhlD9cg;
typedef struct tyObject_HSlice__QbYBq0DTmYHIHa8KuurQ6Q tyObject_HSlice__QbYBq0DTmYHIHa8KuurQ6Q;
typedef struct tyTuple__NF6bgG5XEXlP7DfqszlNdg tyTuple__NF6bgG5XEXlP7DfqszlNdg;
typedef struct tyTuple__dsvP9bgd7x7RN0ykJDjb3Sg tyTuple__dsvP9bgd7x7RN0ykJDjb3Sg;
typedef struct tyTuple__BQblRMJ3qVZJdz8oXhBMaQ tyTuple__BQblRMJ3qVZJdz8oXhBMaQ;
typedef struct tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg;
typedef struct tyTuple__4wIKrvA4KpCWPy4McN64Pg tyTuple__4wIKrvA4KpCWPy4McN64Pg;
typedef struct tyObject_Iface__j1FkQxwEAKMJy1o9bap1xow tyObject_Iface__j1FkQxwEAKMJy1o9bap1xow;
typedef struct tyObject_LoadedModule__7NEKRkz5hkiOxQy5guqIHA tyObject_LoadedModule__7NEKRkz5hkiOxQy5guqIHA;
typedef struct tyObject_PackedModule__sRHd9aQ2ZMII76xRsfAbE9aQ tyObject_PackedModule__sRHd9aQ2ZMII76xRsfAbE9aQ;
typedef struct tySequence__PXIzfWocnrafGz5p3CP5LA tySequence__PXIzfWocnrafGz5p3CP5LA;
typedef struct tySequence__PXIzfWocnrafGz5p3CP5LA_Content tySequence__PXIzfWocnrafGz5p3CP5LA_Content;
typedef struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA tySequence__9bAGqSvkAaFL9bWjsEPslrFA;
typedef struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA_Content tySequence__9bAGqSvkAaFL9bWjsEPslrFA_Content;
typedef struct tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w;
typedef struct tySequence__OxRbUT0qZaZN5UjnqQjGPA tySequence__OxRbUT0qZaZN5UjnqQjGPA;
typedef struct tySequence__OxRbUT0qZaZN5UjnqQjGPA_Content tySequence__OxRbUT0qZaZN5UjnqQjGPA_Content;
typedef struct tySequence__ezS5mGPcRfBURJyMgqYVzA tySequence__ezS5mGPcRfBURJyMgqYVzA;
typedef struct tySequence__ezS5mGPcRfBURJyMgqYVzA_Content tySequence__ezS5mGPcRfBURJyMgqYVzA_Content;
typedef struct tySequence__wW7xkohjuUKO9aMaB0nt9cqA tySequence__wW7xkohjuUKO9aMaB0nt9cqA;
typedef struct tySequence__wW7xkohjuUKO9aMaB0nt9cqA_Content tySequence__wW7xkohjuUKO9aMaB0nt9cqA_Content;
typedef struct tySequence__b89aLriiJnVTD186H6zNIgg tySequence__b89aLriiJnVTD186H6zNIgg;
typedef struct tySequence__b89aLriiJnVTD186H6zNIgg_Content tySequence__b89aLriiJnVTD186H6zNIgg_Content;
typedef struct tySequence__hIPTk9aFdaMMVAOzEbnPyqg tySequence__hIPTk9aFdaMMVAOzEbnPyqg;
typedef struct tySequence__hIPTk9aFdaMMVAOzEbnPyqg_Content tySequence__hIPTk9aFdaMMVAOzEbnPyqg_Content;
typedef struct tySequence__YYy1721YAuPF0ajBYHd8Wg tySequence__YYy1721YAuPF0ajBYHd8Wg;
typedef struct tySequence__YYy1721YAuPF0ajBYHd8Wg_Content tySequence__YYy1721YAuPF0ajBYHd8Wg_Content;
typedef struct tySequence__UODJbvzmu39c3Ho9cqhSk9agQ tySequence__UODJbvzmu39c3Ho9cqhSk9agQ;
typedef struct tySequence__UODJbvzmu39c3Ho9cqhSk9agQ_Content tySequence__UODJbvzmu39c3Ho9cqhSk9agQ_Content;
typedef struct tySequence__F1qNdU7m0Czu7Y2q0eksXw tySequence__F1qNdU7m0Czu7Y2q0eksXw;
typedef struct tySequence__F1qNdU7m0Czu7Y2q0eksXw_Content tySequence__F1qNdU7m0Czu7Y2q0eksXw_Content;
typedef struct tySequence__r3Kz9breImOXyFFoJ29aBM8Q tySequence__r3Kz9breImOXyFFoJ29aBM8Q;
typedef struct tySequence__r3Kz9breImOXyFFoJ29aBM8Q_Content tySequence__r3Kz9breImOXyFFoJ29aBM8Q_Content;
typedef struct tySequence__qBes3XzcQQ9cyia9bRwnmbJw tySequence__qBes3XzcQQ9cyia9bRwnmbJw;
typedef struct tySequence__qBes3XzcQQ9cyia9bRwnmbJw_Content tySequence__qBes3XzcQQ9cyia9bRwnmbJw_Content;
typedef struct tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw;
typedef struct tySequence__Vl1abU3gfp0RqCb1KKfmDA tySequence__Vl1abU3gfp0RqCb1KKfmDA;
typedef struct tySequence__Vl1abU3gfp0RqCb1KKfmDA_Content tySequence__Vl1abU3gfp0RqCb1KKfmDA_Content;
typedef struct tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw;
typedef struct tySequence__qyyNkmlc4fzOzelC8spUkQ tySequence__qyyNkmlc4fzOzelC8spUkQ;
typedef struct tySequence__qyyNkmlc4fzOzelC8spUkQ_Content tySequence__qyyNkmlc4fzOzelC8spUkQ_Content;
typedef struct tyObject_BiTable__KR9c7QZguPO3OKZOIcphgcA tyObject_BiTable__KR9c7QZguPO3OKZOIcphgcA;
typedef struct tyObject_BiTable__9aUXwPoJbNPqj9a249c0iSmlg tyObject_BiTable__9aUXwPoJbNPqj9a249c0iSmlg;
typedef struct tySequence__IHUFRsFxZNv7YydiUO2esQ tySequence__IHUFRsFxZNv7YydiUO2esQ;
typedef struct tySequence__IHUFRsFxZNv7YydiUO2esQ_Content tySequence__IHUFRsFxZNv7YydiUO2esQ_Content;
typedef struct tyObject_LineInfoManager__TTy646Kfh1cVyXU9aSMasUQ tyObject_LineInfoManager__TTy646Kfh1cVyXU9aSMasUQ;
typedef struct tySequence__orxtl6CusdjXleqrxi67gw tySequence__orxtl6CusdjXleqrxi67gw;
typedef struct tySequence__orxtl6CusdjXleqrxi67gw_Content tySequence__orxtl6CusdjXleqrxi67gw_Content;
typedef struct tyObject_OrderedTable__h8mIUVGY8LJXF9cakgvB9bqQ tyObject_OrderedTable__h8mIUVGY8LJXF9cakgvB9bqQ;
typedef struct tySequence__K0j67V58u5FW0dCC534FQw tySequence__K0j67V58u5FW0dCC534FQw;
typedef struct tySequence__K0j67V58u5FW0dCC534FQw_Content tySequence__K0j67V58u5FW0dCC534FQw_Content;
typedef struct tyObject_OrderedTable__DED9c7j9bI3Lh5w4GQakK8yQ tyObject_OrderedTable__DED9c7j9bI3Lh5w4GQakK8yQ;
typedef struct tySequence__UE4b6iUkm1b3zTPamTTkDw tySequence__UE4b6iUkm1b3zTPamTTkDw;
typedef struct tySequence__UE4b6iUkm1b3zTPamTTkDw_Content tySequence__UE4b6iUkm1b3zTPamTTkDw_Content;
typedef struct tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg;
typedef struct tySequence__FmsTQiIcS9arxHxs3QY48vA tySequence__FmsTQiIcS9arxHxs3QY48vA;
typedef struct tySequence__FmsTQiIcS9arxHxs3QY48vA_Content tySequence__FmsTQiIcS9arxHxs3QY48vA_Content;
typedef struct tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ;
typedef struct tyObject_Table__uaQEKxLZNO5fpFluyxnhTg tyObject_Table__uaQEKxLZNO5fpFluyxnhTg;
typedef struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ tySequence__9cnx3zXnWzeclW8Ko4oUgAQ;
typedef struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ_Content tySequence__9cnx3zXnWzeclW8Ko4oUgAQ_Content;
typedef struct tyTuple__7TXOq9czx9cn1FWKG5gXNK8Q tyTuple__7TXOq9czx9cn1FWKG5gXNK8Q;
typedef struct tySequence__vb3AGHvMJTxdOSSwMmBmTQ tySequence__vb3AGHvMJTxdOSSwMmBmTQ;
typedef struct tySequence__vb3AGHvMJTxdOSSwMmBmTQ_Content tySequence__vb3AGHvMJTxdOSSwMmBmTQ_Content;
typedef struct tyTuple__F1mMODXmKFMNQ5rLCtcv0Q tyTuple__F1mMODXmKFMNQ5rLCtcv0Q;
typedef struct tySequence__apM9bRAO19cVjhWlxqd1PGeA tySequence__apM9bRAO19cVjhWlxqd1PGeA;
typedef struct tySequence__apM9bRAO19cVjhWlxqd1PGeA_Content tySequence__apM9bRAO19cVjhWlxqd1PGeA_Content;
typedef struct tyTuple__vHfXSpEC1R9b9cKgfFB9a58gw tyTuple__vHfXSpEC1R9b9cKgfFB9a58gw;
typedef struct tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA;
typedef struct tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ;
typedef struct tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig;
typedef struct tyTuple__4iq9bD09amB7Ah0r9cBB0nSPQ tyTuple__4iq9bD09amB7Ah0r9cBB0nSPQ;
typedef struct tySequence__9bW2eTK9b7vXE70Sx5VPH1mw tySequence__9bW2eTK9b7vXE70Sx5VPH1mw;
typedef struct tySequence__9bW2eTK9b7vXE70Sx5VPH1mw_Content tySequence__9bW2eTK9b7vXE70Sx5VPH1mw_Content;
typedef struct tyTuple__bnJwOH0eJlAwCAMbr1inhw tyTuple__bnJwOH0eJlAwCAMbr1inhw;
typedef struct tyTuple__YG7h1OUHzgfgTeH9cl0U0dw tyTuple__YG7h1OUHzgfgTeH9cl0U0dw;
typedef struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw tyTuple__xYhUhS7X82rKTqbT9bRfCnw;
typedef struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q;
typedef struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ tyTuple__xDU9bZmv1ZbZkJDaATBekIQ;
typedef struct tyTuple__tG5yYi8DnD7bl00aT9cgctQ tyTuple__tG5yYi8DnD7bl00aT9cgctQ;
typedef struct tyObject_SuggestFileSymbolDatabase__o0ahEzaLn5a7TdNqH4OVqQ tyObject_SuggestFileSymbolDatabase__o0ahEzaLn5a7TdNqH4OVqQ;
typedef struct tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg;
typedef struct tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg_Content tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg_Content;
typedef struct tySequence__yUWoZehF86MIc40opFgacw tySequence__yUWoZehF86MIc40opFgacw;
typedef struct tySequence__yUWoZehF86MIc40opFgacw_Content tySequence__yUWoZehF86MIc40opFgacw_Content;
typedef struct tyObject_PackedBoolArray__1pk9boftqWMNDE1oh5HcIhw tyObject_PackedBoolArray__1pk9boftqWMNDE1oh5HcIhw;
typedef struct tyTuple__gnRkA1L4XiR4uByriyHW8Q tyTuple__gnRkA1L4XiR4uByriyHW8Q;
typedef struct tySequence__nSO1ltijM4vhc0UrrXKEqA tySequence__nSO1ltijM4vhc0UrrXKEqA;
typedef struct tySequence__nSO1ltijM4vhc0UrrXKEqA_Content tySequence__nSO1ltijM4vhc0UrrXKEqA_Content;
typedef struct tyTuple__CvjVmQeIfivirDme2r5MRw tyTuple__CvjVmQeIfivirDme2r5MRw;
typedef struct tyTuple__2QDyOgS51ZMPO0W1pWCY6g tyTuple__2QDyOgS51ZMPO0W1pWCY6g;
typedef struct tyTuple__UbCNQED4XJUgxOgPHJUcAQ tyTuple__UbCNQED4XJUgxOgPHJUcAQ;
typedef struct tySequence__juxPMVNF1FoR2ltzeQu8NQ tySequence__juxPMVNF1FoR2ltzeQu8NQ;
typedef struct tySequence__juxPMVNF1FoR2ltzeQu8NQ_Content tySequence__juxPMVNF1FoR2ltzeQu8NQ_Content;
typedef struct tyTuple__zExIg9bDTcVf2FHROUpzoow tyTuple__zExIg9bDTcVf2FHROUpzoow;
typedef struct tyTuple__XrHNJHOzS3O7uwF9bvCySiA tyTuple__XrHNJHOzS3O7uwF9bvCySiA;
typedef struct tyTuple__EdLY4EJQ37VFgbAn5g5rXQ tyTuple__EdLY4EJQ37VFgbAn5g5rXQ;
typedef struct tyTuple__OtlgAx3kBps9cOSMNDZSzBA tyTuple__OtlgAx3kBps9cOSMNDZSzBA;
typedef struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg tyTuple__F3gkSrMB1qp2Tvf9bixVXwg;
typedef struct tyTuple__RFOJ4fF7D9bpvmh9birH1JhQ tyTuple__RFOJ4fF7D9bpvmh9birH1JhQ;
typedef struct tyTuple__O3g9a8zTXSX36ljWponcAoA tyTuple__O3g9a8zTXSX36ljWponcAoA;
typedef struct tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ;
typedef struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw tyTuple__QeWl6B6ffS4pU6WWrtcrDw;
typedef struct tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg;
typedef struct tyObject_TNodePair__KE5IEbxbTGxhrXo6rzddjQ tyObject_TNodePair__KE5IEbxbTGxhrXo6rzddjQ;
typedef struct tyTuple__sr3s7uVHpu9cEbbDnCSg8yQ tyTuple__sr3s7uVHpu9cEbbDnCSg8yQ;
typedef struct tyTuple__ZQn9aE2eP9aC9aAInis8k8aDQ tyTuple__ZQn9aE2eP9aC9aAInis8k8aDQ;
typedef struct tyTuple__y6bKAf9a9aaVwun6lVDxSX7g tyTuple__y6bKAf9a9aaVwun6lVDxSX7g;
typedef struct tyObject_TBlock__jSiqQOXIz3L9a8VW9a9a3HAuA tyObject_TBlock__jSiqQOXIz3L9a8VW9a9a3HAuA;
typedef struct tyTuple__9ap1MJ9bVBlP34AqrUq01n8w tyTuple__9ap1MJ9bVBlP34AqrUq01n8w;
typedef struct tyTuple__0q9cmhneJEKnQERTpXXdz6Q tyTuple__0q9cmhneJEKnQERTpXXdz6Q;
typedef struct tyObject_PackedNode__YxKk4C732K04CNgtMhmc0w tyObject_PackedNode__YxKk4C732K04CNgtMhmc0w;
typedef struct tyTuple__48iPM3yLBKU5nyEuYwJvuQ tyTuple__48iPM3yLBKU5nyEuYwJvuQ;
typedef struct tyTuple__R3ddFrA0G9buJY57Qhf9cTpg tyTuple__R3ddFrA0G9buJY57Qhf9cTpg;
typedef struct tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ;
typedef struct tyTuple__7rmdAMLZ8fDd79brQn2ixZA tyTuple__7rmdAMLZ8fDd79brQn2ixZA;
typedef struct tyTuple__qPXRCRNQuZLLKto7CIIEzw tyTuple__qPXRCRNQuZLLKto7CIIEzw;
typedef struct tyObject_PackedInstantiation__C3FSePJFY8gUIMObsjT2dg tyObject_PackedInstantiation__C3FSePJFY8gUIMObsjT2dg;
typedef struct tyTuple__6kG8KAxm9aXPdLdlxcxqJJw tyTuple__6kG8KAxm9aXPdLdlxcxqJJw;
typedef struct tyTuple__TRK7rrwoha9bbDAdPWsqJMw tyTuple__TRK7rrwoha9bbDAdPWsqJMw;
typedef struct tyTuple__V1VWX9bHapuzCjpMfFfys5Q tyTuple__V1VWX9bHapuzCjpMfFfys5Q;
typedef struct tyObject_PackedSym__KKnx6w8Cc9aaVsaPOpaqxbw tyObject_PackedSym__KKnx6w8Cc9aaVsaPOpaqxbw;
typedef struct tyObject_PackedLib__EpwVLk0Fuc5Q9agKLMWedbg tyObject_PackedLib__EpwVLk0Fuc5Q9agKLMWedbg;
typedef struct tyTuple__anemVmHCFglLFt6LiEhFvg tyTuple__anemVmHCFglLFt6LiEhFvg;
typedef struct tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ;
typedef struct tyTuple__MaWaKZwaGUqCXKsSK12rVg tyTuple__MaWaKZwaGUqCXKsSK12rVg;
typedef struct tyTuple__nL9cBxaIV4ZA9b9ceY79coA5eA tyTuple__nL9cBxaIV4ZA9b9ceY79coA5eA;
typedef struct tyTuple__1xWeGeoNoZxaLhTUDDWYyA tyTuple__1xWeGeoNoZxaLhTUDDWYyA;
typedef struct tyTuple__MZVSn3SE3XUBJOaMu7ofRQ tyTuple__MZVSn3SE3XUBJOaMu7ofRQ;
typedef struct tyTuple__UvldbCB6B9ayi9bGYW7vJNLA tyTuple__UvldbCB6B9ayi9bGYW7vJNLA;
typedef struct tyObject_LazyType__dsEGDq9cOhnzsRvTUTwwwuA tyObject_LazyType__dsEGDq9cOhnzsRvTUTwwwuA;
typedef struct tyObject_LazyInstantiation__n72c7MnOoHWBy9c9akgwGqEA tyObject_LazyInstantiation__n72c7MnOoHWBy9c9akgwGqEA;
typedef struct tySequence__YxH9cgSorHRI8ZPzHf47NNQ tySequence__YxH9cgSorHRI8ZPzHf47NNQ;
typedef struct tySequence__YxH9cgSorHRI8ZPzHf47NNQ_Content tySequence__YxH9cgSorHRI8ZPzHf47NNQ_Content;
typedef struct tyObject_TInstantiation__jr8MibvPn2sQBnO7XCoZRQ tyObject_TInstantiation__jr8MibvPn2sQBnO7XCoZRQ;
typedef struct tyTuple__lGHLhAAUpxgfrnQkIzNrMw tyTuple__lGHLhAAUpxgfrnQkIzNrMw;
typedef struct tyObject_TinyLineInfo__qW2GTIPjeOQ42q9c2MPWLLA tyObject_TinyLineInfo__qW2GTIPjeOQ42q9c2MPWLLA;
typedef struct tyTuple__V6P73hvHy70PBBwharKjig tyTuple__V6P73hvHy70PBBwharKjig;
typedef NU8 tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA;
struct tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A {
	tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA kind;
union{
	NI64 intVal;
	NF floatVal;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* node;
	tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A* regAddr;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** nodeAddr;
};
};
struct tySequence__TfHJycarvNts8E4mVG4Mfg {
  NI len; tySequence__TfHJycarvNts8E4mVG4Mfg_Content* p;
};
struct tySequence__5reviU45axUMPQgL9aoENrg {
  NI len; tySequence__5reviU45axUMPQgL9aoENrg_Content* p;
};
struct tyObject_PackedModuleGraph__vzv9a6xTiz616FotDgUeo9bg {
	tySequence__5reviU45axUMPQgL9aoENrg pm;
};
struct tySequence__dtr79aXjHrgHuH79ac55I2aw {
  NI len; tySequence__dtr79aXjHrgHuH79ac55I2aw_Content* p;
};
struct tySequence__8y0Gi4GwtXi2wk2mK1IOzw {
  NI len; tySequence__8y0Gi4GwtXi2wk2mK1IOzw_Content* p;
};
struct tyObject_Table__EBJpp1hXwvFl9cyekUv4qHg {
	tySequence__8y0Gi4GwtXi2wk2mK1IOzw data;
	NI counter;
};
struct tySequence__C2ivDnhTZ6IxAdui1rfuqw {
  NI len; tySequence__C2ivDnhTZ6IxAdui1rfuqw_Content* p;
};
struct tyObject_Table__nn0jq9adRZXGGj9assM9c9bR0w {
	tySequence__C2ivDnhTZ6IxAdui1rfuqw data;
	NI counter;
};
struct tySequence__3vEEVfBECLN6NIRA3FIp5g {
  NI len; tySequence__3vEEVfBECLN6NIRA3FIp5g_Content* p;
};
struct tyObject_Table__ChMwcRY3QzpOEBWbGAfvcA {
	tySequence__3vEEVfBECLN6NIRA3FIp5g data;
	NI counter;
};
typedef tyObject_Table__ChMwcRY3QzpOEBWbGAfvcA tyArray__HTPiakF26bUQGH9bgtmrtkA[7];
struct tySequence__9aSa87aKMiolq9a7z3kC0jTw {
  NI len; tySequence__9aSa87aKMiolq9a7z3kC0jTw_Content* p;
};
struct tyObject_Table__tEqt8LkShErhjQ9acvGyE7g {
	tySequence__9aSa87aKMiolq9a7z3kC0jTw data;
	NI counter;
};
struct tySequence__N589c2UsUgqqOITU2JfIuAQ {
  NI len; tySequence__N589c2UsUgqqOITU2JfIuAQ_Content* p;
};
struct tyObject_Table__QS2Z9cQjmvkp1aaFGq4ippw {
	tySequence__N589c2UsUgqqOITU2JfIuAQ data;
	NI counter;
};
struct tySequence__GYDW6wGgERshoSd16jJ3eQ {
  NI len; tySequence__GYDW6wGgERshoSd16jJ3eQ_Content* p;
};
struct tyObject_Table__bnfVX2VJ9aUicVujDM0GIhw {
	tySequence__GYDW6wGgERshoSd16jJ3eQ data;
	NI counter;
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw {
  NI len; tySequence__7lEisrXlQEzwtUKW5pzRCw_Content* p;
};
struct tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A {
	tySequence__7lEisrXlQEzwtUKW5pzRCw data;
	NI counter;
};
typedef NU8 tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw;
typedef NU8 tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg;
typedef NU8 tyEnum_TSystemCC__A5wZwpTXF1SiKGvwgH1wrA;
typedef NU32 tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ;
typedef NU64 tySet_tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A;
struct tyObject_PackedConfig__Hpn673wkKPDorr1HY9bOaDQ {
	tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw backend;
	tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg selectedGC;
	tyEnum_TSystemCC__A5wZwpTXF1SiKGvwgH1wrA cCompiler;
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ options;
	tySet_tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A globalOptions;
};
struct tySequence__ZCZaCk14bTmSb6LMW9aWPVA {
  NI len; tySequence__ZCZaCk14bTmSb6LMW9aWPVA_Content* p;
};
struct tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg {
	NI counter;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA data;
};
struct tySequence__ZeWVlH6DqG79b1pTDhrrUYA {
  NI len; tySequence__ZeWVlH6DqG79b1pTDhrrUYA_Content* p;
};
typedef NI tyArray__k7D0lwfLmYccbQxUd49bbcQ[34];
struct tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA {
	NI elems;
	NI counter;
	NI max;
	tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA* head;
	tySequence__ZeWVlH6DqG79b1pTDhrrUYA data;
	tyArray__k7D0lwfLmYccbQxUd49bbcQ a;
};
struct tySequence__fdmz6VkIf1ewwrssKYqRFg {
  NI len; tySequence__fdmz6VkIf1ewwrssKYqRFg_Content* p;
};
struct tyObject_Table__79b4rr6WWQqgRr9b4NH4UF9cw {
	tySequence__fdmz6VkIf1ewwrssKYqRFg data;
	NI counter;
};
struct tySequence__kxu4GK0onha2t9bo86mdVAg {
  NI len; tySequence__kxu4GK0onha2t9bo86mdVAg_Content* p;
};
struct tyObject_Table__AC9bec2JdoOuC3xQePGWgmA {
	tySequence__kxu4GK0onha2t9bo86mdVAg data;
	NI counter;
};
struct tySequence__48JTohSgTy339bRxHzUD8KA {
  NI len; tySequence__48JTohSgTy339bRxHzUD8KA_Content* p;
};
typedef struct {
N_NIMCALL_PTR(NIM_BOOL, ClP_0) (void* ClE_0);
void* ClE_0;
} tyProc__In3g79a0qTcRmbTbJp9ba9ctg;
struct tySequence__fz0REU1l0nYmKHXgMLRrIg {
  NI len; tySequence__fz0REU1l0nYmKHXgMLRrIg_Content* p;
};
struct tyObject_Table__bHTcQUCehDW9clHfFZXI7lQ {
	tySequence__fz0REU1l0nYmKHXgMLRrIg data;
	NI counter;
};
struct tySequence__Ip9aV1IKO2gVdheNOM31DCQ {
  NI len; tySequence__Ip9aV1IKO2gVdheNOM31DCQ_Content* p;
};
struct tyObject_Table__w2vCG1OPnHmNolvQVT168g {
	tySequence__Ip9aV1IKO2gVdheNOM31DCQ data;
	NI counter;
};
struct tySequence__kHjIdgrpmuSn9cUIIKpSiDg {
  NI len; tySequence__kHjIdgrpmuSn9cUIIKpSiDg_Content* p;
};
struct tySequence__Wd0Vle6gxRCPPoSlNEvfTA {
  NI len; tySequence__Wd0Vle6gxRCPPoSlNEvfTA_Content* p;
};
struct tyObject_CountTable__qvMelb9coODdwoghoAPc9c9aA {
	tySequence__Wd0Vle6gxRCPPoSlNEvfTA data;
	NI counter;
	NIM_BOOL isSorted;
};
struct tySequence__T7nNEWoEbKBa0G5Htr45Xw {
  NI len; tySequence__T7nNEWoEbKBa0G5Htr45Xw_Content* p;
};
struct tyObject_Table__fZyCWkMwhdvr3pauCNDaag {
	tySequence__T7nNEWoEbKBa0G5Htr45Xw data;
	NI counter;
};
struct tySequence__q9cHvMDDxYU1hSCdG4YwIhA {
  NI len; tySequence__q9cHvMDDxYU1hSCdG4YwIhA_Content* p;
};
struct tyObject_Table__5vmBY49areSIlgIs4A1LLKQ {
	tySequence__q9cHvMDDxYU1hSCdG4YwIhA data;
	NI counter;
};
struct tySequence__olFOFaYzOJN9aV5BWqK4b9bA {
  NI len; tySequence__olFOFaYzOJN9aV5BWqK4b9bA_Content* p;
};
typedef tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* tyArray__EOkbZZXacNOZHC8p7xc7hw[65];
struct tySequence__vJcM7B74R2U5db9cxyXT9coA {
  NI len; tySequence__vJcM7B74R2U5db9cxyXT9coA_Content* p;
};
struct tyObject_Table__9bmd0cvHWe1s4FTDn5BPmfw {
	tySequence__vJcM7B74R2U5db9cxyXT9coA data;
	NI counter;
};
struct tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg {
  NI len; tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg_Content* p;
};
struct tyObject_Table__GhjCMuklnRqwdX9bZo9bCoNg {
	tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg data;
	NI counter;
};
typedef N_NIMCALL_PTR(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, tyProc__QieBhPPkGvcmpFg89a4ftcA) (tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* m_p1, NI32 fileIdx_p2);
typedef N_NIMCALL_PTR(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, tyProc__F2ahyGAjs3aNLJYEXzu07g) (tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* m_p1, NI32 fileIdx_p2);
struct tySequence__R9c39btP6BwOBBPnbaNUtMQg {
  NI len; tySequence__R9c39btP6BwOBBPnbaNUtMQg_Content* p;
};
struct tyObject_Table__pI3mJh4Ap2XujSCfcSeUvQ {
	tySequence__R9c39btP6BwOBBPnbaNUtMQg data;
	NI counter;
};
struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA {
  NI len; tySequence__squ9b9bUH4OLHf6cEMrt6hVA_Content* p;
};
struct tyObject_Table__MsPmCuYz1KcEw6lr7P9cGkw {
	tySequence__squ9b9bUH4OLHf6cEMrt6hVA data;
	NI counter;
};
struct tySequence__3nALyQgqjnfK2Qjc6ny2Uw {
  NI len; tySequence__3nALyQgqjnfK2Qjc6ny2Uw_Content* p;
};
struct tyObject_Table__1HJsK7ponJ4Vb1lJgVFVTQ {
	tySequence__3nALyQgqjnfK2Qjc6ny2Uw data;
	NI counter;
};
struct tySequence__WbW5Q8QVks0bQpUJSGmuVg {
  NI len; tySequence__WbW5Q8QVks0bQpUJSGmuVg_Content* p;
};
typedef NU8 tyEnum_PipelinePass__kO50VlNfBJZtrNuD4VL9aTg;
typedef N_NIMCALL_PTR(void, tyProc__c9a5q9aZQWYYOu1vHoRoq9bVQ) (tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p2);
struct tySequence__9ahcSjIErJohSBBFLwuF56Q {
  NI len; tySequence__9ahcSjIErJohSBBFLwuF56Q_Content* p;
};
typedef N_NIMCALL_PTR(void, tyProc__kj3TYePLaHBuXxhRznQQNQ) (tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* owner_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* body_p2);
typedef N_NIMCALL_PTR(NIM_BOOL, tyProc__D3Q9bYoPIpHZVLfEIxpBssA) (tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* formal_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* actual_p2);
struct tyObject_Operators__yrAfvKhiysDamJlcGNgVfQ {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opNot;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opContains;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opLe;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opLt;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opAnd;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opOr;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opIsNil;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opEq;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opAdd;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opSub;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opMul;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opDiv;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opLen;
};
struct tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw {
	tySequence__TfHJycarvNts8E4mVG4Mfg ifaces;
	tyObject_PackedModuleGraph__vzv9a6xTiz616FotDgUeo9bg packed_0;
	tySequence__dtr79aXjHrgHuH79ac55I2aw encoders;
	tyObject_Table__EBJpp1hXwvFl9cyekUv4qHg typeInstCache;
	tyObject_Table__nn0jq9adRZXGGj9assM9c9bR0w procInstCache;
	tyArray__HTPiakF26bUQGH9bgtmrtkA attachedOps;
	tyObject_Table__tEqt8LkShErhjQ9acvGyE7g methodsPerGenericType;
	tyObject_Table__QS2Z9cQjmvkp1aaFGq4ippw memberProcsPerType;
	tyObject_Table__bnfVX2VJ9aUicVujDM0GIhw initializersPerType;
	tyObject_Table__ChMwcRY3QzpOEBWbGAfvcA enumToStringProcs;
	tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A emittedTypeInfo;
	tyObject_PackedConfig__Hpn673wkKPDorr1HY9bOaDQ startupPackedConfig;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg packageSyms;
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA deps;
	tyObject_Table__79b4rr6WWQqgRr9b4NH4UF9cw importDeps;
	NIM_BOOL suggestMode;
	NIM_BOOL invalidTransitiveClosure;
	NIM_BOOL interactive;
	NIM_BOOL withinSystem;
	tyObject_Table__AC9bec2JdoOuC3xQePGWgmA inclToMod;
	tySequence__48JTohSgTy339bRxHzUD8KA importStack;
	RootObj* backend;
	tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* config;
	tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* cache;
	RootObj* vm;
	RootObj* repl;
	tyProc__In3g79a0qTcRmbTbJp9ba9ctg doStopCompile;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* usageSym;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA owners;
	tyObject_Table__bHTcQUCehDW9clHfFZXI7lQ suggestSymbols;
	tyObject_Table__w2vCG1OPnHmNolvQVT168g suggestErrors;
	tySequence__kHjIdgrpmuSn9cUIIKpSiDg methods;
	tyObject_CountTable__qvMelb9coODdwoghoAPc9c9aA bucketTable;
	tyObject_Table__fZyCWkMwhdvr3pauCNDaag objectTree;
	tyObject_Table__5vmBY49areSIlgIs4A1LLKQ methodsPerType;
	tySequence__olFOFaYzOJN9aV5BWqK4b9bA dispatchers;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* systemModule;
	tyArray__EOkbZZXacNOZHC8p7xc7hw sysTypes;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg compilerprocs;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg exposed;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg packageTypes;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* emptyNode;
	tyObject_Table__9bmd0cvHWe1s4FTDn5BPmfw canonTypes;
	tyObject_Table__GhjCMuklnRqwdX9bZo9bCoNg symBodyHashes;
	tyProc__QieBhPPkGvcmpFg89a4ftcA importModuleCallback;
	tyProc__F2ahyGAjs3aNLJYEXzu07g includeFileCallback;
	tyObject_Table__pI3mJh4Ap2XujSCfcSeUvQ cacheSeqs;
	tyObject_Table__MsPmCuYz1KcEw6lr7P9cGkw cacheCounters;
	tyObject_Table__1HJsK7ponJ4Vb1lJgVFVTQ cacheTables;
	tySequence__WbW5Q8QVks0bQpUJSGmuVg passes;
	tyEnum_PipelinePass__kO50VlNfBJZtrNuD4VL9aTg pipelinePass;
	tyProc__c9a5q9aZQWYYOu1vHoRoq9bVQ onDefinition;
	tyProc__c9a5q9aZQWYYOu1vHoRoq9bVQ onDefinitionResolveForward;
	tyProc__c9a5q9aZQWYYOu1vHoRoq9bVQ onUsage;
	tySequence__9ahcSjIErJohSBBFLwuF56Q globalDestructors;
	tyProc__kj3TYePLaHBuXxhRznQQNQ strongSemCheck;
	tyProc__D3Q9bYoPIpHZVLfEIxpBssA compatibleProps;
	tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen;
	tyObject_Operators__yrAfvKhiysDamJlcGNgVfQ operators;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* cachedFiles;
	tySequence__9ahcSjIErJohSBBFLwuF56Q procGlobals;
};
typedef NU8 tyEnum_TSystemCPU__3f9cinURS2hpZEHtBX69bm9cw;
typedef NU8 tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw;
struct NimStrPayload {
	NI cap;
	NIM_CHAR data[SEQ_DECL_SIZE];
};
struct NimStringV2 {
	NI len;
	NimStrPayload* p;
};
struct tyObject_Target__GzbDkV2u8Pgzlf9azvC43FA {
	tyEnum_TSystemCPU__3f9cinURS2hpZEHtBX69bm9cw targetCPU;
	tyEnum_TSystemCPU__3f9cinURS2hpZEHtBX69bm9cw hostCPU;
	tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw targetOS;
	tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw hostOS;
	NI intSize;
	NI floatSize;
	NI ptrSize;
	NimStringV2 tnl;
};
struct tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA {
	NU16 line;
	NI16 col;
	NI32 fileIndex;
};
typedef NU8 tySet_tyEnum_TErrorOutput__wGgqZXVnY1wkKEe8EL9cL9aw;
struct tySequence__E0kio2ZnplNTuln9bsnljSA {
  NI len; tySequence__E0kio2ZnplNTuln9bsnljSA_Content* p;
};
struct tySequence__hTEiKNj3evQAjIXUI21elA {
  NI len; tySequence__hTEiKNj3evQAjIXUI21elA_Content* p;
};
struct tyObject_MsgConfig__E1VAUnnaNIOngCdEgTI2Dw {
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA trackPos;
	NIM_BOOL trackPosAttached;
	tySet_tyEnum_TErrorOutput__wGgqZXVnY1wkKEe8EL9cL9aw errorOutputs;
	tySequence__E0kio2ZnplNTuln9bsnljSA msgContext;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA lastError;
	tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A filenameToIndexTbl;
	tySequence__hTEiKNj3evQAjIXUI21elA fileInfos;
	NI32 systemFileIdx;
};
typedef NU8 tyEnum_FilenameOption__o3jmnnVs6HdBg5KcNAzYiQ;
typedef NU8 tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ;
typedef NU8 tyEnum_ExceptionSystem__dJ6sXW7k8NDYNNBUjVZmnw;
typedef NU8 tyEnum_SymbolFilesOption__2eyIIreuRXhYT9buPPZbBYA;
struct tySequence__4eRCaZmrYLLw2k30GPTiMw {
  NI len; tySequence__4eRCaZmrYLLw2k30GPTiMw_Content* p;
};
struct tyObject_HashSet__8IGL0eIK5PYDsNGVA78Wmw {
	tySequence__4eRCaZmrYLLw2k30GPTiMw data;
	NI counter;
};
typedef NU32 tySet_tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ;
typedef NU8 tySet_tyEnum_LegacyFeature__yvNVqOQTgcxHpvo1MvfBfA;
typedef NU8 tyEnum_IdeCmd__mZiSMTDWSAKKDbZfXDQwng;
typedef NU8 tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw[13];
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ {
  NI len; tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content* p;
};
typedef NU8 tySet_tyEnum_StdOrrKind__so1PI9cHP1cN622ePtqa0yw;
struct tySequence__xOJ2kx2lq9bBfIm3IXnde3Q {
  NI len; tySequence__xOJ2kx2lq9bBfIm3IXnde3Q_Content* p;
};
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_SuggestcolonObjectType___UyASNXAqAMRY5zJmcRD9ccA* result_p0, void* ClE_0);
void* ClE_0;
} tyProc__QQyR5yGA47tr5TwLxcC4Gw;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (NimStringV2 output_p0, void* ClE_0);
void* ClE_0;
} tyProc__k2HFjxisIgDALbEUFojxaQ;
typedef NU8 tyEnum_Severity__mHEDvws7FmOtnFhcQsM8UA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* config_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, NimStringV2 msg_p2, tyEnum_Severity__mHEDvws7FmOtnFhcQsM8UA severity_p3, void* ClE_0);
void* ClE_0;
} tyProc__DA9aR62IikoxFqfC5rIT9cuw;
struct tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg {
	tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw backend;
	tyObject_Target__GzbDkV2u8Pgzlf9azvC43FA target;
	NI linesCompiled;
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ options;
	tySet_tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A globalOptions;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* macrosToExpand;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* arcToExpand;
	tyObject_MsgConfig__E1VAUnnaNIOngCdEgTI2Dw m;
	tyEnum_FilenameOption__o3jmnnVs6HdBg5KcNAzYiQ filenameOption;
	NimStringV2 unitSep;
	NI evalTemplateCounter;
	NI evalMacroCounter;
	NI8 exitcode;
	tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ cmd;
	NimStringV2 cmdInput;
	NIM_BOOL projectIsCmd;
	NIM_BOOL implicitCmd;
	tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg selectedGC;
	tyEnum_ExceptionSystem__dJ6sXW7k8NDYNNBUjVZmnw exc;
	NIM_BOOL hintProcessingDots;
	NI verbosity;
	NI numberOfProcessors;
	NF lastCmdTime;
	tyEnum_SymbolFilesOption__2eyIIreuRXhYT9buPPZbBYA symbolFiles;
	NI spellSuggestMax;
	tyObject_HashSet__8IGL0eIK5PYDsNGVA78Wmw cppDefines;
	NimStringV2 headerFile;
	NimStringV2 nimbasePattern;
	tySet_tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ features;
	tySet_tyEnum_LegacyFeature__yvNVqOQTgcxHpvo1MvfBfA legacyFeatures;
	NimStringV2 arguments;
	tyEnum_IdeCmd__mZiSMTDWSAKKDbZfXDQwng ideCmd;
	tyEnum_TSystemCC__A5wZwpTXF1SiKGvwgH1wrA cCompiler;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw modifiedyNotes;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw cmdlineNotes;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw foreignPackageNotes;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw notes;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw warningAsErrors;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw mainPackageNotes;
	NI mainPackageId;
	NI errorCounter;
	NI hintCounter;
	NI warnCounter;
	NI errorMax;
	NI maxLoopIterationsVM;
	NI maxCallDepthVM;
	NIM_BOOL isVmTrace;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* configVars;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* symbols;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* packageCache;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ nimblePaths;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ searchPaths;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ lazyPaths;
	NimStringV2 outFile;
	NimStringV2 outDir;
	NimStringV2 jsonBuildFile;
	NimStringV2 prefixDir;
	NimStringV2 libpath;
	NimStringV2 nimcacheDir;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* dllOverrides;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* moduleOverrides;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* cfileSpecificOptions;
	NimStringV2 projectName;
	NimStringV2 projectPath;
	NimStringV2 projectFull;
	NIM_BOOL projectIsStdin;
	NimStringV2 stdinFile;
	tySet_tyEnum_StdOrrKind__so1PI9cHP1cN622ePtqa0yw lastMsgWasDot;
	NI32 projectMainIdx;
	NI32 projectMainIdx2;
	NimStringV2 command;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ commandArgs;
	NimStringV2 commandLine;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ extraCmds;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ implicitImports;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ implicitIncludes;
	NimStringV2 docSeeSrcUrl;
	NimStringV2 docRoot;
	NimStringV2 docCmd;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ configFiles;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ cIncludes;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ cLibs;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ cLinkedLibs;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ externalToLink;
	NimStringV2 linkOptionsCmd;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ compileOptionsCmd;
	NimStringV2 linkOptions;
	NimStringV2 compileOptions;
	NimStringV2 cCompilerPath;
	tySequence__xOJ2kx2lq9bBfIm3IXnde3Q toCompile;
	tyProc__QQyR5yGA47tr5TwLxcC4Gw suggestionResultHook;
	NI suggestVersion;
	NI suggestMaxResults;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA lastLineInfo;
	tyProc__k2HFjxisIgDALbEUFojxaQ writelnHook;
	tyProc__DA9aR62IikoxFqfC5rIT9cuw structuredErrorHook;
	NimStringV2 cppCustomNamespace;
	NimStringV2 nimMainPrefix;
	tyObject_ProfileDatacolonObjectType___R9cEb9cNTzPRldVmD9bCDO0xQ* vmProfileData;
	NIM_BOOL expandProgress;
	NI expandLevels;
	NimStringV2 expandNodeResult;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA expandPosition;
	NimStringV2 currentConfigDir;
	NI clientProcessId;
};
typedef NU8 tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA;
typedef NU8 tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w;
struct tyTuple__kN8up2W6YKc5YA9avn5mV5w {
	NimStringV2 Field0;
	NI Field1;
	NI Field2;
};
typedef NU32 tySet_tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw;
typedef NU8 tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw;
struct tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typField;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info;
	tySet_tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw flags;
	tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw kind;
union{
	struct {
	NI64 intVal;
} _kind_1;
	struct {
	NF floatVal;
} _kind_2;
	struct {
	NimStringV2 strVal;
} _kind_3;
	struct {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym;
} _kind_4;
	struct {
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* ident;
} _kind_5;
	struct {
	tySequence__9ahcSjIErJohSBBFLwuF56Q sons;
} _kind_6;
};
};
struct tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA {
	NI32 module;
	NI32 item;
};
typedef NU8 tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg;
typedef NU8 tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ;
typedef NU64 tySet_tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A;
struct tySequence__d8ZV4IMgHt9biik9cS9a0hrmg {
  NI len; tySequence__d8ZV4IMgHt9biik9cS9a0hrmg_Content* p;
};
typedef NU8 tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ;
typedef NU8 tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg;
typedef NU16 tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg;
struct tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw {
	tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ k;
	tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg storage;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg flags;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* lode;
	NimStringV2 snippet;
};
struct tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg {
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA itemId;
	tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg kind;
	tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ callConv;
	tySet_tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A flags;
	tySequence__d8ZV4IMgHt9biik9cS9a0hrmg sons;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* ownerField;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym;
	NI64 size;
	NI16 align;
	NI16 paddingAtEnd;
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw loc;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typeInst;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA uniqueId;
};
typedef NU8 tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q;
typedef NU16 tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg;
typedef NU64 tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg;
struct tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg {
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA itemId;
	tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q kind;
union{
	struct {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* gcUnsafetyReason;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* transformedBody;
} _kind_1;
	struct {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* guard;
	NI bitsize;
	NI alignment;
} _kind_2;
};
	tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg magic;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ;
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* name;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* ownerField;
	tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg flags;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* ast;
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ options;
	NI position;
	NI32 offset;
	NI32 disamb;
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw loc;
	tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig* annex;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* constraint;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* instantiatedFrom;
};
typedef NimStringV2 tyArray__dyW7vpmfeTYw8kX3EXuaJA[3];
typedef NU16 tySet_tyEnum_TRenderFlag__Il2q467fyuki59ci9aspexFg;
struct TNimTypeV2 {
	void* destructor;
	NI size;
	NI16 align;
	NI16 depth;
	NU32* display;
	void* traceImpl;
	void* typeInfoV1;
	NI flags;
	void* vTable[SEQ_DECL_SIZE];
};
struct RootObj {
	TNimTypeV2* m_type;
};
struct tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ {
	RootObj Sup;
	tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen;
};
struct tySequence__YdLNCDKYeipzJx3I8Xw82Q {
  NI len; tySequence__YdLNCDKYeipzJx3I8Xw82Q_Content* p;
};
struct tySequence__TLbZ2GqL3Zio1f8bNpj2NA {
  NI len; tySequence__TLbZ2GqL3Zio1f8bNpj2NA_Content* p;
};
struct tySequence__GH1mmNKNA2QP4n1tnxJf1w {
  NI len; tySequence__GH1mmNKNA2QP4n1tnxJf1w_Content* p;
};
struct tyObject_TNodeTable__RKuYIY5Phq1xnepo5DZI2g {
	NI counter;
	tySequence__GH1mmNKNA2QP4n1tnxJf1w data;
	NIM_BOOL ignoreTypes;
};
typedef NU8 tyEnum_TEvalMode__sQljSFf0fjnsNV1fpgXakg;
typedef NU8 tySet_tyEnum_TSandboxFlag__II2KpGKWwJH9bdjbBum5d1g;
struct tySequence__TEgqV1E9aHqnwBUoeXjBI9aA {
  NI len; tySequence__TEgqV1E9aHqnwBUoeXjBI9aA_Content* p;
};
struct tySequence__pUxI6Ljo6IKKHXKOZkQ7Og {
  NI len; tySequence__pUxI6Ljo6IKKHXKOZkQ7Og_Content* p;
};
struct tyObject_Table__tro5f9chxPVpES1mQpDwZtQ {
	tySequence__pUxI6Ljo6IKKHXKOZkQ7Og data;
	NI counter;
};
struct tyObject_Profiler__YI4zs2CaXXndlYireD0I8A {
	NF tEnter;
	tyObject_TStackFrame__a20zU43j9cYHpYOOr1c2hZQ* tos;
};
struct tySequence__fnH5Zt4fsGx0AgDTOw8pKw {
  NI len; tySequence__fnH5Zt4fsGx0AgDTOw8pKw_Content* p;
};
struct tySequence__Fc8Q26tsngy2yxcpyrnT4Q {
  NI len; tySequence__Fc8Q26tsngy2yxcpyrnT4Q_Content* p;
};
struct tyObject_Table__lPs28yjGTxD0LzUoPspSBQ {
	tySequence__Fc8Q26tsngy2yxcpyrnT4Q data;
	NI counter;
};
struct tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew {
	tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ Sup;
	tySequence__YdLNCDKYeipzJx3I8Xw82Q code;
	tySequence__TLbZ2GqL3Zio1f8bNpj2NA debug;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* globals;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* constants;
	tyObject_TNodeTable__RKuYIY5Phq1xnepo5DZI2g contstantTab;
	tySequence__d8ZV4IMgHt9biik9cS9a0hrmg types;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* currentExceptionA;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* currentExceptionB;
	NI exceptionInstr;
	tyObject_PProccolonObjectType___BUXHs9a6Ck9awUko3NbJ3Fyg* prc;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* callsite;
	tyEnum_TEvalMode__sQljSFf0fjnsNV1fpgXakg mode;
	tySet_tyEnum_TSandboxFlag__II2KpGKWwJH9bdjbBum5d1g features;
	NIM_BOOL traceActive;
	NI loopIterations;
	NI callDepth;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA comesFromHeuristic;
	tySequence__TEgqV1E9aHqnwBUoeXjBI9aA callbacks;
	tyObject_Table__tro5f9chxPVpES1mQpDwZtQ callbackIndex;
	NimStringV2 errorFlag;
	tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* cache;
	tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* config;
	tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph;
	NI oldErrorCount;
	tyObject_Profiler__YI4zs2CaXXndlYireD0I8A profiler;
	NI* templInstCounter;
	tySequence__fnH5Zt4fsGx0AgDTOw8pKw vmstateDiff;
	tyObject_Table__lPs28yjGTxD0LzUoPspSBQ procToCodePos;
	NIM_BOOL cannotEval;
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA locals;
};
struct tyObject_Env_vmopsdotnim_registerAdditionalOps___VDnIL6fWGTCjJE9c9cTQGKGw {
	RootObj Sup;
	tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew* c0;
};
struct tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A {
	NI rc;
	NI rootIdx;
};
struct tyObject_CellSeq__gW9aeWLFbrNaeUKXqxYBXhg {
	NI len;
	NI cap;
	tyTuple__N4J9cV4JZGem3ljqqj5rT0Q* d;
};
struct tyObject_CellSeq__IHvIqxITv1yMjJj8lwLrhg {
	NI len;
	NI cap;
	tyTuple__DTRsWi2kgTewbhN2TT5mbA* d;
};
struct tyObject_GcEnv__HccVszwojlCZRN46BE9cG8w {
	tyObject_CellSeq__gW9aeWLFbrNaeUKXqxYBXhg traceStack;
	tyObject_CellSeq__IHvIqxITv1yMjJj8lwLrhg toFree;
	NI freed;
	NI touched;
	NI edges;
	NI rcSum;
	NIM_BOOL keepThreshold;
};
struct tyTuple__N4J9cV4JZGem3ljqqj5rT0Q {
	void** Field0;
	TNimTypeV2* Field1;
};
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* args_p0, void* ClE_0);
void* ClE_0;
} tyProc__c9bXGQkBnyyGGVw063jrwZw;
struct tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg {
	NI ra;
	NI rb;
	NI rc;
	tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A* slots;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* currentException;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA currentLineInfo;
};
typedef N_CLOSURE_PTR(void, TM__pyAIA9cUF0h9c4j2HfNQPfYw_18) (tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* args_p0, void* ClE_0);
typedef N_CLOSURE_PTR(void, TM__pyAIA9cUF0h9c4j2HfNQPfYw_22) (tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* args_p0, void* ClE_0);
typedef N_CLOSURE_PTR(void, TM__pyAIA9cUF0h9c4j2HfNQPfYw_26) (tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* args_p0, void* ClE_0);
typedef N_CLOSURE_PTR(void, TM__pyAIA9cUF0h9c4j2HfNQPfYw_30) (tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* args_p0, void* ClE_0);
typedef N_CLOSURE_PTR(void, TM__pyAIA9cUF0h9c4j2HfNQPfYw_34) (tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* args_p0, void* ClE_0);
typedef N_CLOSURE_PTR(void, TM__pyAIA9cUF0h9c4j2HfNQPfYw_38) (tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* args_p0, void* ClE_0);
typedef N_CLOSURE_PTR(void, TM__pyAIA9cUF0h9c4j2HfNQPfYw_42) (tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* args_p0, void* ClE_0);
typedef N_CLOSURE_PTR(void, TM__pyAIA9cUF0h9c4j2HfNQPfYw_46) (tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* args_p0, void* ClE_0);
typedef N_CLOSURE_PTR(void, TM__pyAIA9cUF0h9c4j2HfNQPfYw_50) (tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* args_p0, void* ClE_0);
typedef N_CLOSURE_PTR(void, TM__pyAIA9cUF0h9c4j2HfNQPfYw_54) (tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* args_p0, void* ClE_0);
typedef N_CLOSURE_PTR(void, TM__pyAIA9cUF0h9c4j2HfNQPfYw_58) (tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* args_p0, void* ClE_0);
typedef N_CLOSURE_PTR(void, TM__pyAIA9cUF0h9c4j2HfNQPfYw_62) (tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* args_p0, void* ClE_0);
typedef N_CLOSURE_PTR(void, TM__pyAIA9cUF0h9c4j2HfNQPfYw_65) (tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* args_p0, void* ClE_0);
typedef N_CLOSURE_PTR(void, TM__pyAIA9cUF0h9c4j2HfNQPfYw_69) (tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* args_p0, void* ClE_0);
typedef N_CLOSURE_PTR(void, TM__pyAIA9cUF0h9c4j2HfNQPfYw_73) (tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* args_p0, void* ClE_0);
typedef N_CLOSURE_PTR(void, TM__pyAIA9cUF0h9c4j2HfNQPfYw_76) (tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* args_p0, void* ClE_0);
typedef N_CLOSURE_PTR(void, TM__pyAIA9cUF0h9c4j2HfNQPfYw_80) (tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* args_p0, void* ClE_0);
typedef N_CLOSURE_PTR(void, TM__pyAIA9cUF0h9c4j2HfNQPfYw_84) (tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* args_p0, void* ClE_0);
typedef N_CLOSURE_PTR(void, TM__pyAIA9cUF0h9c4j2HfNQPfYw_88) (tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* args_p0, void* ClE_0);
typedef N_CLOSURE_PTR(void, TM__pyAIA9cUF0h9c4j2HfNQPfYw_92) (tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* args_p0, void* ClE_0);
typedef N_CLOSURE_PTR(void, TM__pyAIA9cUF0h9c4j2HfNQPfYw_95) (tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* args_p0, void* ClE_0);
typedef N_CLOSURE_PTR(void, TM__pyAIA9cUF0h9c4j2HfNQPfYw_99) (tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* args_p0, void* ClE_0);
typedef N_CLOSURE_PTR(void, TM__pyAIA9cUF0h9c4j2HfNQPfYw_103) (tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* args_p0, void* ClE_0);
typedef N_CLOSURE_PTR(void, TM__pyAIA9cUF0h9c4j2HfNQPfYw_107) (tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* args_p0, void* ClE_0);
typedef N_CLOSURE_PTR(void, TM__pyAIA9cUF0h9c4j2HfNQPfYw_111) (tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* args_p0, void* ClE_0);
typedef N_CLOSURE_PTR(void, TM__pyAIA9cUF0h9c4j2HfNQPfYw_115) (tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* args_p0, void* ClE_0);
typedef N_CLOSURE_PTR(void, TM__pyAIA9cUF0h9c4j2HfNQPfYw_119) (tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* args_p0, void* ClE_0);
typedef N_CLOSURE_PTR(void, TM__pyAIA9cUF0h9c4j2HfNQPfYw_123) (tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* args_p0, void* ClE_0);
struct tyTuple__igdSbLMeeUm9brp9bUKtC70w {
	NI64 Field0;
	NI64 Field1;
};
typedef N_CLOSURE_PTR(void, TM__pyAIA9cUF0h9c4j2HfNQPfYw_129) (tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* args_p0, void* ClE_0);
typedef N_CLOSURE_PTR(void, TM__pyAIA9cUF0h9c4j2HfNQPfYw_132) (tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* args_p0, void* ClE_0);
typedef N_CLOSURE_PTR(void, TM__pyAIA9cUF0h9c4j2HfNQPfYw_136) (tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* args_p0, void* ClE_0);
typedef N_CLOSURE_PTR(void, TM__pyAIA9cUF0h9c4j2HfNQPfYw_139) (tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* args_p0, void* ClE_0);
typedef N_CLOSURE_PTR(void, TM__pyAIA9cUF0h9c4j2HfNQPfYw_142) (tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* args_p0, void* ClE_0);
typedef N_CLOSURE_PTR(void, TM__pyAIA9cUF0h9c4j2HfNQPfYw_148) (tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* args_p0, void* ClE_0);
typedef N_CLOSURE_PTR(void, TM__pyAIA9cUF0h9c4j2HfNQPfYw_151) (tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* args_p0, void* ClE_0);
typedef N_CLOSURE_PTR(void, TM__pyAIA9cUF0h9c4j2HfNQPfYw_154) (tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* args_p0, void* ClE_0);
typedef N_CLOSURE_PTR(void, TM__pyAIA9cUF0h9c4j2HfNQPfYw_157) (tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* args_p0, void* ClE_0);
typedef N_CLOSURE_PTR(void, TM__pyAIA9cUF0h9c4j2HfNQPfYw_160) (tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* args_p0, void* ClE_0);
typedef N_CLOSURE_PTR(void, TM__pyAIA9cUF0h9c4j2HfNQPfYw_163) (tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* args_p0, void* ClE_0);
typedef NU8 tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ;
typedef N_CLOSURE_PTR(void, TM__pyAIA9cUF0h9c4j2HfNQPfYw_166) (tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* args_p0, void* ClE_0);
typedef N_CLOSURE_PTR(void, TM__pyAIA9cUF0h9c4j2HfNQPfYw_168) (tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* args_p0, void* ClE_0);
typedef N_CLOSURE_PTR(void, TM__pyAIA9cUF0h9c4j2HfNQPfYw_171) (tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* args_p0, void* ClE_0);
typedef N_CLOSURE_PTR(void, TM__pyAIA9cUF0h9c4j2HfNQPfYw_173) (tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* args_p0, void* ClE_0);
typedef N_CLOSURE_PTR(void, TM__pyAIA9cUF0h9c4j2HfNQPfYw_176) (tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* args_p0, void* ClE_0);
typedef N_CLOSURE_PTR(void, TM__pyAIA9cUF0h9c4j2HfNQPfYw_179) (tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* args_p0, void* ClE_0);
typedef N_CLOSURE_PTR(void, TM__pyAIA9cUF0h9c4j2HfNQPfYw_184) (tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* args_p0, void* ClE_0);
typedef N_CLOSURE_PTR(void, TM__pyAIA9cUF0h9c4j2HfNQPfYw_187) (tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* args_p0, void* ClE_0);
typedef N_CLOSURE_PTR(void, TM__pyAIA9cUF0h9c4j2HfNQPfYw_190) (tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* args_p0, void* ClE_0);
typedef NU8 tyEnum_PathComponent__daMOTwam9cW3AQtl6fxq4sQ;
typedef NIM_CHAR tyArray__bErjiHmvISNmC2iIqkq21Q[256];
struct tyTuple__wjbnfGBIEcH6aaevyJWrgw {
	tyEnum_PathComponent__daMOTwam9cW3AQtl6fxq4sQ Field0;
	NIM_BOOL Field1;
};
struct tyTuple__RQuzKb7YBI25p4z9cTFFLeQ {
	tyEnum_PathComponent__daMOTwam9cW3AQtl6fxq4sQ Field0;
	NimStringV2 Field1;
};
typedef N_CLOSURE_PTR(void, TM__pyAIA9cUF0h9c4j2HfNQPfYw_197) (tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* args_p0, void* ClE_0);
typedef N_CLOSURE_PTR(void, TM__pyAIA9cUF0h9c4j2HfNQPfYw_200) (tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* args_p0, void* ClE_0);
typedef N_CLOSURE_PTR(void, TM__pyAIA9cUF0h9c4j2HfNQPfYw_203) (tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* args_p0, void* ClE_0);
typedef NU8 tyEnum_SingleValueSetting__HRmc2gxK9bXtRNyOdKDv9c3g;
typedef NU8 tyEnum_MultipleValueSetting__9afzpxz1DiqdeW9a0ZsAq8Kg;
struct tyTuple__XOVT24GHXwqiEj5GCsEGCA {
	NimStringV2 Field0;
	NI Field1;
};
typedef N_CLOSURE_PTR(void, TM__pyAIA9cUF0h9c4j2HfNQPfYw_214) (tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* args_p0, void* ClE_0);
typedef NU8 tySet_tyEnum_MsgFlag__uOe9ahJyFezfCR4dA8VRyQw;
struct tySequence__9c9aWmheGsuf9aHtY7gTnUcPA {
  NI len; tySequence__9c9aWmheGsuf9aHtY7gTnUcPA_Content* p;
};
struct tySequence__qwqHTkRvwhrRyENtudHQ7g {
  NI len; tySequence__qwqHTkRvwhrRyENtudHQ7g_Content* p;
};
struct tyObject_TStackFrame__a20zU43j9cYHpYOOr1c2hZQ {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* prc;
	tySequence__9c9aWmheGsuf9aHtY7gTnUcPA slots;
	tyObject_TStackFrame__a20zU43j9cYHpYOOr1c2hZQ* next;
	NI comesFrom;
	tySequence__qwqHTkRvwhrRyENtudHQ7g safePoints;
};
typedef NU8 tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A;
struct tyObject_TFileInfo__xPdjmgevOVG8T0Aq8BK7jw {
	NimStringV2 fullPath;
	NimStringV2 projPath;
	NimStringV2 shortName;
	NimStringV2 quotedName;
	NimStringV2 quotedFullName;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ lines;
	NimStringV2 dirtyFile;
	NimStringV2 hash;
	NIM_BOOL dirty;
};
struct tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA {
	NI id;
	NimStringV2 s;
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* next;
	NI h;
};
struct tySequence__b9bG03Q6unwlMU0dM7uOPIA {
  NI len; tySequence__b9bG03Q6unwlMU0dM7uOPIA_Content* p;
};
struct tySequence__grdS5PdBBxkq9bxi4lFAdAw {
  NI len; tySequence__grdS5PdBBxkq9bxi4lFAdAw_Content* p;
};
struct tyObject_PProccolonObjectType___BUXHs9a6Ck9awUko3NbJ3Fyg {
	tySequence__b9bG03Q6unwlMU0dM7uOPIA blocks;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym;
	tySequence__grdS5PdBBxkq9bxi4lFAdAw regInfo;
};
typedef NimStringV2 tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ[2];
typedef NU8 tyArray__dnD8kjh6rJ1Yy5jHvid0Ow[16];
typedef NU8 tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg;
struct tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw {
	tyObject_NodecolonObjectType___U4ON6JZL9cIHezBQjmQzJ8Q* root;
	NI entries;
};
struct tySequence__6H5Oh5UUvVCLiakt9aTwtUQ {
  NI len; tySequence__6H5Oh5UUvVCLiakt9aTwtUQ_Content* p;
};
typedef N_CLOSURE_PTR(void, TM__pyAIA9cUF0h9c4j2HfNQPfYw_249) (tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* args_p0, void* ClE_0);
typedef N_CLOSURE_PTR(void, TM__pyAIA9cUF0h9c4j2HfNQPfYw_252) (tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* args_p0, void* ClE_0);
typedef N_CLOSURE_PTR(void, TM__pyAIA9cUF0h9c4j2HfNQPfYw_255) (tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* args_p0, void* ClE_0);
typedef N_CLOSURE_PTR(void, TM__pyAIA9cUF0h9c4j2HfNQPfYw_257) (tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* args_p0, void* ClE_0);
typedef N_CLOSURE_PTR(void, TM__pyAIA9cUF0h9c4j2HfNQPfYw_260) (tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* args_p0, void* ClE_0);
typedef NU8 tySet_tyEnum_ProcessOption__f8zQPCJAq3Y51oMx2CR9cxw;
typedef N_CLOSURE_PTR(void, TM__pyAIA9cUF0h9c4j2HfNQPfYw_265) (tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* args_p0, void* ClE_0);
struct tyObject_Time__f9czJU2iP3D49bUN3jzSsOfA {
	NI64 seconds;
	NI nanosecond;
};
typedef NU8 tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg[9];
typedef NU8 tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A;
typedef N_CLOSURE_PTR(void, TM__pyAIA9cUF0h9c4j2HfNQPfYw_279) (tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* args_p0, void* ClE_0);
typedef N_CLOSURE_PTR(void, TM__pyAIA9cUF0h9c4j2HfNQPfYw_282) (tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* args_p0, void* ClE_0);
typedef N_CLOSURE_PTR(void, TM__pyAIA9cUF0h9c4j2HfNQPfYw_285) (tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* args_p0, void* ClE_0);
typedef N_CLOSURE_PTR(void, TM__pyAIA9cUF0h9c4j2HfNQPfYw_289) (tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* args_p0, void* ClE_0);
typedef N_CLOSURE_PTR(void, TM__pyAIA9cUF0h9c4j2HfNQPfYw_292) (tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* args_p0, void* ClE_0);
typedef NU8 tyEnum_FloatFormatMode__CTUpdhZ6zDNw9cC9acViKeYg;
typedef N_CLOSURE_PTR(void, TM__pyAIA9cUF0h9c4j2HfNQPfYw_295) (tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* args_p0, void* ClE_0);
struct tySequence__4eQHGndY6XBYpFOH09apV8Q {
  NI len; tySequence__4eQHGndY6XBYpFOH09apV8Q_Content* p;
};
struct tyTuple__UV3llMMYFckfui8YMBuUZA {
	NimStringV2 Field0;
	NimStringV2 Field1;
};
typedef N_CLOSURE_PTR(void, TM__pyAIA9cUF0h9c4j2HfNQPfYw_298) (tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* args_p0, void* ClE_0);
struct tyObject_VmProcInfo__Jux30icZSrOlvcFTG81Ljg {
	NI32 pc;
	NI32 usedRegisters;
};
typedef NU8 tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw;
struct tyObject_Env_vmdotnim_rawExecute___hNEyCf8VhTK2S3ZJXhlD9cg {
	RootObj Sup;
	tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew* c0;
	tyObject_TStackFrame__a20zU43j9cYHpYOOr1c2hZQ* tos1;
	NI pc2;
	NimStringV2 error3;
	NimStringV2 error4;
};
typedef NimStringV2 tyArray__YgExxhfgKcesA5EOUj1MOA[1];
typedef NU8 tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (NI64 left_p0, NI64 right_p1, NI64 safeLen_p2, void* ClE_0);
void* ClE_0;
} tyProc__TSOsjF4c9aXotPerq9cEE56A;
typedef N_CLOSURE_PTR(void, TM__pyAIA9cUF0h9c4j2HfNQPfYw_333) (NI64 left_p0, NI64 right_p1, NI64 safeLen_p2);
typedef tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* tyArray__JEzAlj49cAK8qpM6I2Q9bfcQ[3];
typedef N_CLOSURE_PTR(void, TM__pyAIA9cUF0h9c4j2HfNQPfYw_334) (NI64 left_p0, NI64 right_p1, NI64 safeLen_p2);
struct tyObject_HSlice__QbYBq0DTmYHIHa8KuurQ6Q {
	NI a;
	NI64 b;
};
struct tyTuple__NF6bgG5XEXlP7DfqszlNdg {
	NimStringV2 Field0;
	tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw Field1;
	NimStringV2 Field2;
	NimStringV2 Field3;
	NimStringV2 Field4;
	NI Field5;
};
typedef NU8 tyEnum_TPreferedDesc__ddj0M89bv09cBYthgD4XTq3Q;
struct tyTuple__dsvP9bgd7x7RN0ykJDjb3Sg {
	NimStringV2 Field0;
	tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg Field1;
};
typedef NU16 tySet_tyEnum_TTypeCmpFlag__1219bojhd9apB6FQkQGJbzzQ;
typedef NU8 tySet_tyEnum_TransformFlag__CzUOfRCXpoYcP43GAlt9cnA;
typedef N_CLOSURE_PTR(void, TM__pyAIA9cUF0h9c4j2HfNQPfYw_439) (tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* args_p0);
typedef NU8 tyEnum_TSandboxFlag__II2KpGKWwJH9bdjbBum5d1g;
typedef NU8 tyEnum_ExceptionGoto__UXGPMKK1kMiyMPS9b1jNcmg;
struct tyTuple__BQblRMJ3qVZJdz8oXhBMaQ {
	tyEnum_ExceptionGoto__UXGPMKK1kMiyMPS9b1jNcmg Field0;
	NI Field1;
};
typedef NU32 tyArray__PPSU5X9aizf5OJq0lL4Og7A[4];
struct tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg {
	tyArray__PPSU5X9aizf5OJq0lL4Og7A udata;
};
typedef N_CLOSURE_PTR(void, TM__pyAIA9cUF0h9c4j2HfNQPfYw_480) (tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* args_p0);
typedef NU8 tyEnum_LegacyFeature__yvNVqOQTgcxHpvo1MvfBfA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA msg_p2, NimStringV2 arg_p3, void* ClE_0);
void* ClE_0;
} tyProc__urLEtt9bmeGdJpEukhLR9a1A;
typedef tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* tyArray__s9a2jZbmN9cnqFaNnzUrYEjg[8192];
struct tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA {
	tyArray__s9a2jZbmN9cnqFaNnzUrYEjg buckets;
	NI wordCounter;
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* idAnon;
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* idDelegator;
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* emptyIdent;
};
typedef tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* tyArray__TAsXwXSUBvAawE1kIQ5ziQ[1];
struct tyTuple__4wIKrvA4KpCWPy4McN64Pg {
	NimStringV2 Field0;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* Field1;
	NI Field2;
};
struct tyObject_Iface__j1FkQxwEAKMJy1o9bap1xow {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module;
	tySequence__olFOFaYzOJN9aV5BWqK4b9bA converters;
	tySequence__olFOFaYzOJN9aV5BWqK4b9bA patterns;
	tySequence__olFOFaYzOJN9aV5BWqK4b9bA pureEnums;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg interf;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg interfHidden;
	NimStringV2 uniqueName;
};
struct tySequence__TfHJycarvNts8E4mVG4Mfg_Content { NI cap; tyObject_Iface__j1FkQxwEAKMJy1o9bap1xow data[SEQ_DECL_SIZE]; };
typedef NU8 tyEnum_ModuleStatus__uT4B39a2dNaG9a9aunVdyhQtQ;
struct tySequence__PXIzfWocnrafGz5p3CP5LA {
  NI len; tySequence__PXIzfWocnrafGz5p3CP5LA_Content* p;
};
struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA {
  NI len; tySequence__9bAGqSvkAaFL9bWjsEPslrFA_Content* p;
};
struct tySequence__OxRbUT0qZaZN5UjnqQjGPA {
  NI len; tySequence__OxRbUT0qZaZN5UjnqQjGPA_Content* p;
};
struct tySequence__ezS5mGPcRfBURJyMgqYVzA {
  NI len; tySequence__ezS5mGPcRfBURJyMgqYVzA_Content* p;
};
struct tySequence__wW7xkohjuUKO9aMaB0nt9cqA {
  NI len; tySequence__wW7xkohjuUKO9aMaB0nt9cqA_Content* p;
};
struct tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w {
	tySequence__OxRbUT0qZaZN5UjnqQjGPA nodes;
	tySequence__ezS5mGPcRfBURJyMgqYVzA withFlags;
	tySequence__wW7xkohjuUKO9aMaB0nt9cqA withTypes;
};
struct tySequence__b89aLriiJnVTD186H6zNIgg {
  NI len; tySequence__b89aLriiJnVTD186H6zNIgg_Content* p;
};
struct tySequence__hIPTk9aFdaMMVAOzEbnPyqg {
  NI len; tySequence__hIPTk9aFdaMMVAOzEbnPyqg_Content* p;
};
struct tySequence__YYy1721YAuPF0ajBYHd8Wg {
  NI len; tySequence__YYy1721YAuPF0ajBYHd8Wg_Content* p;
};
struct tySequence__UODJbvzmu39c3Ho9cqhSk9agQ {
  NI len; tySequence__UODJbvzmu39c3Ho9cqhSk9agQ_Content* p;
};
struct tySequence__F1qNdU7m0Czu7Y2q0eksXw {
  NI len; tySequence__F1qNdU7m0Czu7Y2q0eksXw_Content* p;
};
struct tySequence__r3Kz9breImOXyFFoJ29aBM8Q {
  NI len; tySequence__r3Kz9breImOXyFFoJ29aBM8Q_Content* p;
};
struct tySequence__qBes3XzcQQ9cyia9bRwnmbJw {
  NI len; tySequence__qBes3XzcQQ9cyia9bRwnmbJw_Content* p;
};
typedef NU8 tySet_tyEnum_ModuleBackendFlag__5FvIlwIIbpcHU0ZRU9a5hrQ;
struct tySequence__Vl1abU3gfp0RqCb1KKfmDA {
  NI len; tySequence__Vl1abU3gfp0RqCb1KKfmDA_Content* p;
};
struct tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw {
	tySequence__Vl1abU3gfp0RqCb1KKfmDA data;
	NI counter;
	NI first;
	NI last;
};
struct tySequence__qyyNkmlc4fzOzelC8spUkQ {
  NI len; tySequence__qyyNkmlc4fzOzelC8spUkQ_Content* p;
};
struct tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw {
	tySequence__qyyNkmlc4fzOzelC8spUkQ data;
	NI counter;
	NI first;
	NI last;
};
struct tyObject_BiTable__KR9c7QZguPO3OKZOIcphgcA {
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ vals;
	tySequence__9bAGqSvkAaFL9bWjsEPslrFA keys;
};
struct tySequence__IHUFRsFxZNv7YydiUO2esQ {
  NI len; tySequence__IHUFRsFxZNv7YydiUO2esQ_Content* p;
};
struct tyObject_BiTable__9aUXwPoJbNPqj9a249c0iSmlg {
	tySequence__IHUFRsFxZNv7YydiUO2esQ vals;
	tySequence__9bAGqSvkAaFL9bWjsEPslrFA keys;
};
struct tySequence__orxtl6CusdjXleqrxi67gw {
  NI len; tySequence__orxtl6CusdjXleqrxi67gw_Content* p;
};
struct tyObject_LineInfoManager__TTy646Kfh1cVyXU9aSMasUQ {
	tySequence__orxtl6CusdjXleqrxi67gw aside;
};
struct tyObject_PackedModule__sRHd9aQ2ZMII76xRsfAbE9aQ {
	NimStringV2 definedSymbols;
	tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg moduleFlags;
	tySequence__PXIzfWocnrafGz5p3CP5LA includes;
	tySequence__9bAGqSvkAaFL9bWjsEPslrFA imports;
	tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w toReplay;
	tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w topLevel;
	tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w bodies;
	tySequence__b89aLriiJnVTD186H6zNIgg exports;
	tySequence__b89aLriiJnVTD186H6zNIgg hidden;
	tySequence__hIPTk9aFdaMMVAOzEbnPyqg reexports;
	tySequence__b89aLriiJnVTD186H6zNIgg compilerProcs;
	tySequence__48JTohSgTy339bRxHzUD8KA converters;
	tySequence__48JTohSgTy339bRxHzUD8KA methods;
	tySequence__48JTohSgTy339bRxHzUD8KA trmacros;
	tySequence__48JTohSgTy339bRxHzUD8KA pureEnums;
	tySequence__YYy1721YAuPF0ajBYHd8Wg typeInstCache;
	tySequence__UODJbvzmu39c3Ho9cqhSk9agQ procInstCache;
	tySequence__F1qNdU7m0Czu7Y2q0eksXw attachedOps;
	tySequence__r3Kz9breImOXyFFoJ29aBM8Q methodsPerGenericType;
	tySequence__YYy1721YAuPF0ajBYHd8Wg enumToStringProcs;
	tySequence__YYy1721YAuPF0ajBYHd8Wg methodsPerType;
	tySequence__qBes3XzcQQ9cyia9bRwnmbJw dispatchers;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ emittedTypeInfo;
	tySet_tyEnum_ModuleBackendFlag__5FvIlwIIbpcHU0ZRU9a5hrQ backendFlags;
	tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw syms;
	tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw types;
	tyObject_BiTable__KR9c7QZguPO3OKZOIcphgcA strings;
	tyObject_BiTable__9aUXwPoJbNPqj9a249c0iSmlg numbers;
	tyObject_LineInfoManager__TTy646Kfh1cVyXU9aSMasUQ man;
	tyObject_PackedConfig__Hpn673wkKPDorr1HY9bOaDQ cfg;
};
struct tySequence__K0j67V58u5FW0dCC534FQw {
  NI len; tySequence__K0j67V58u5FW0dCC534FQw_Content* p;
};
struct tyObject_OrderedTable__h8mIUVGY8LJXF9cakgvB9bqQ {
	tySequence__K0j67V58u5FW0dCC534FQw data;
	NI counter;
	NI first;
	NI last;
};
struct tySequence__UE4b6iUkm1b3zTPamTTkDw {
  NI len; tySequence__UE4b6iUkm1b3zTPamTTkDw_Content* p;
};
struct tyObject_OrderedTable__DED9c7j9bI3Lh5w4GQakK8yQ {
	tySequence__UE4b6iUkm1b3zTPamTTkDw data;
	NI counter;
	NI first;
	NI last;
};
struct tySequence__FmsTQiIcS9arxHxs3QY48vA {
  NI len; tySequence__FmsTQiIcS9arxHxs3QY48vA_Content* p;
};
struct tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg {
	tySequence__FmsTQiIcS9arxHxs3QY48vA data;
	NI counter;
};
struct tyObject_LoadedModule__7NEKRkz5hkiOxQy5guqIHA {
	tyEnum_ModuleStatus__uT4B39a2dNaG9a9aunVdyhQtQ status;
	NIM_BOOL symsInit;
	NIM_BOOL typesInit;
	NIM_BOOL loadedButAliveSetChanged;
	tyObject_PackedModule__sRHd9aQ2ZMII76xRsfAbE9aQ fromDisk;
	tyObject_OrderedTable__h8mIUVGY8LJXF9cakgvB9bqQ syms;
	tyObject_OrderedTable__DED9c7j9bI3Lh5w4GQakK8yQ types;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module;
	tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg iface;
	tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg ifaceHidden;
};
struct tySequence__5reviU45axUMPQgL9aoENrg_Content { NI cap; tyObject_LoadedModule__7NEKRkz5hkiOxQy5guqIHA data[SEQ_DECL_SIZE]; };
struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ {
  NI len; tySequence__9cnx3zXnWzeclW8Ko4oUgAQ_Content* p;
};
struct tyObject_Table__uaQEKxLZNO5fpFluyxnhTg {
	tySequence__9cnx3zXnWzeclW8Ko4oUgAQ data;
	NI counter;
};
struct tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ {
	NI32 thisModule;
	NI32 lastFile;
	NU32 lastLit;
	tyObject_Table__uaQEKxLZNO5fpFluyxnhTg filenames;
	tySequence__d8ZV4IMgHt9biik9cS9a0hrmg pendingTypes;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA pendingSyms;
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA typeMarker;
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA symMarker;
	tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* config;
};
struct tySequence__dtr79aXjHrgHuH79ac55I2aw_Content { NI cap; tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ data[SEQ_DECL_SIZE]; };
struct tySequence__vb3AGHvMJTxdOSSwMmBmTQ {
  NI len; tySequence__vb3AGHvMJTxdOSSwMmBmTQ_Content* p;
};
struct tyTuple__7TXOq9czx9cn1FWKG5gXNK8Q {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tySequence__vb3AGHvMJTxdOSSwMmBmTQ Field2;
};
struct tySequence__8y0Gi4GwtXi2wk2mK1IOzw_Content { NI cap; tyTuple__7TXOq9czx9cn1FWKG5gXNK8Q data[SEQ_DECL_SIZE]; };
struct tySequence__apM9bRAO19cVjhWlxqd1PGeA {
  NI len; tySequence__apM9bRAO19cVjhWlxqd1PGeA_Content* p;
};
struct tyTuple__F1mMODXmKFMNQ5rLCtcv0Q {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tySequence__apM9bRAO19cVjhWlxqd1PGeA Field2;
};
struct tySequence__C2ivDnhTZ6IxAdui1rfuqw_Content { NI cap; tyTuple__F1mMODXmKFMNQ5rLCtcv0Q data[SEQ_DECL_SIZE]; };
struct tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig {
	NU32 module;
	NI32 item;
};
struct tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ {
	NI module;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig packed_0;
};
struct tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA {
	tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ id;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym;
};
struct tyTuple__vHfXSpEC1R9b9cKgfFB9a58gw {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA Field2;
};
struct tySequence__3vEEVfBECLN6NIRA3FIp5g_Content { NI cap; tyTuple__vHfXSpEC1R9b9cKgfFB9a58gw data[SEQ_DECL_SIZE]; };
struct tySequence__9bW2eTK9b7vXE70Sx5VPH1mw {
  NI len; tySequence__9bW2eTK9b7vXE70Sx5VPH1mw_Content* p;
};
struct tyTuple__4iq9bD09amB7Ah0r9cBB0nSPQ {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tySequence__9bW2eTK9b7vXE70Sx5VPH1mw Field2;
};
struct tySequence__9aSa87aKMiolq9a7z3kC0jTw_Content { NI cap; tyTuple__4iq9bD09amB7Ah0r9cBB0nSPQ data[SEQ_DECL_SIZE]; };
struct tyTuple__bnJwOH0eJlAwCAMbr1inhw {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA Field2;
};
struct tySequence__N589c2UsUgqqOITU2JfIuAQ_Content { NI cap; tyTuple__bnJwOH0eJlAwCAMbr1inhw data[SEQ_DECL_SIZE]; };
struct tyTuple__YG7h1OUHzgfgTeH9cl0U0dw {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* Field2;
};
struct tySequence__GYDW6wGgERshoSd16jJ3eQ_Content { NI cap; tyTuple__YG7h1OUHzgfgTeH9cl0U0dw data[SEQ_DECL_SIZE]; };
struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw {
	NI Field0;
	NimStringV2 Field1;
	NI32 Field2;
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw_Content { NI cap; tyTuple__xYhUhS7X82rKTqbT9bRfCnw data[SEQ_DECL_SIZE]; };
struct tySequence__ZCZaCk14bTmSb6LMW9aWPVA_Content { NI cap; tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* data[SEQ_DECL_SIZE]; };
struct tySequence__ZeWVlH6DqG79b1pTDhrrUYA_Content { NI cap; tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA* data[SEQ_DECL_SIZE]; };
struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q {
	NI Field0;
	NI32 Field1;
	tySequence__48JTohSgTy339bRxHzUD8KA Field2;
};
struct tySequence__fdmz6VkIf1ewwrssKYqRFg_Content { NI cap; tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q data[SEQ_DECL_SIZE]; };
struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ {
	NI Field0;
	NI32 Field1;
	NI32 Field2;
};
struct tySequence__kxu4GK0onha2t9bo86mdVAg_Content { NI cap; tyTuple__xDU9bZmv1ZbZkJDaATBekIQ data[SEQ_DECL_SIZE]; };
struct tySequence__48JTohSgTy339bRxHzUD8KA_Content { NI cap; NI32 data[SEQ_DECL_SIZE]; };
struct tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg {
  NI len; tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg_Content* p;
};
struct tySequence__yUWoZehF86MIc40opFgacw {
  NI len; tySequence__yUWoZehF86MIc40opFgacw_Content* p;
};
struct tyObject_PackedBoolArray__1pk9boftqWMNDE1oh5HcIhw {
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA s;
	NI len;
};
struct tyObject_SuggestFileSymbolDatabase__o0ahEzaLn5a7TdNqH4OVqQ {
	tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg lineInfo;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA sym;
	tySequence__yUWoZehF86MIc40opFgacw caughtExceptions;
	tyObject_PackedBoolArray__1pk9boftqWMNDE1oh5HcIhw caughtExceptionsSet;
	tyObject_PackedBoolArray__1pk9boftqWMNDE1oh5HcIhw isDecl;
	tyObject_PackedBoolArray__1pk9boftqWMNDE1oh5HcIhw isGenericInstance;
	NI32 fileIndex;
	NIM_BOOL trackCaughtExceptions;
	NIM_BOOL isSorted;
};
struct tyTuple__tG5yYi8DnD7bl00aT9cgctQ {
	NI Field0;
	NI32 Field1;
	tyObject_SuggestFileSymbolDatabase__o0ahEzaLn5a7TdNqH4OVqQ Field2;
};
struct tySequence__fz0REU1l0nYmKHXgMLRrIg_Content { NI cap; tyTuple__tG5yYi8DnD7bl00aT9cgctQ data[SEQ_DECL_SIZE]; };
struct tySequence__nSO1ltijM4vhc0UrrXKEqA {
  NI len; tySequence__nSO1ltijM4vhc0UrrXKEqA_Content* p;
};
struct tyTuple__gnRkA1L4XiR4uByriyHW8Q {
	NI Field0;
	NI32 Field1;
	tySequence__nSO1ltijM4vhc0UrrXKEqA Field2;
};
struct tySequence__Ip9aV1IKO2gVdheNOM31DCQ_Content { NI cap; tyTuple__gnRkA1L4XiR4uByriyHW8Q data[SEQ_DECL_SIZE]; };
struct tyTuple__CvjVmQeIfivirDme2r5MRw {
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA Field0;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* Field1;
};
struct tySequence__kHjIdgrpmuSn9cUIIKpSiDg_Content { NI cap; tyTuple__CvjVmQeIfivirDme2r5MRw data[SEQ_DECL_SIZE]; };
struct tyTuple__2QDyOgS51ZMPO0W1pWCY6g {
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field0;
	NI Field1;
};
struct tySequence__Wd0Vle6gxRCPPoSlNEvfTA_Content { NI cap; tyTuple__2QDyOgS51ZMPO0W1pWCY6g data[SEQ_DECL_SIZE]; };
struct tySequence__juxPMVNF1FoR2ltzeQu8NQ {
  NI len; tySequence__juxPMVNF1FoR2ltzeQu8NQ_Content* p;
};
struct tyTuple__UbCNQED4XJUgxOgPHJUcAQ {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tySequence__juxPMVNF1FoR2ltzeQu8NQ Field2;
};
struct tySequence__T7nNEWoEbKBa0G5Htr45Xw_Content { NI cap; tyTuple__UbCNQED4XJUgxOgPHJUcAQ data[SEQ_DECL_SIZE]; };
struct tyTuple__zExIg9bDTcVf2FHROUpzoow {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tySequence__olFOFaYzOJN9aV5BWqK4b9bA Field2;
};
struct tySequence__q9cHvMDDxYU1hSCdG4YwIhA_Content { NI cap; tyTuple__zExIg9bDTcVf2FHROUpzoow data[SEQ_DECL_SIZE]; };
struct tySequence__olFOFaYzOJN9aV5BWqK4b9bA_Content { NI cap; tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA data[SEQ_DECL_SIZE]; };
struct tyTuple__XrHNJHOzS3O7uwF9bvCySiA {
	NI Field0;
	tyArray__dnD8kjh6rJ1Yy5jHvid0Ow Field1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* Field2;
};
struct tySequence__vJcM7B74R2U5db9cxyXT9coA_Content { NI cap; tyTuple__XrHNJHOzS3O7uwF9bvCySiA data[SEQ_DECL_SIZE]; };
struct tyTuple__EdLY4EJQ37VFgbAn5g5rXQ {
	NI Field0;
	NI Field1;
	tyArray__dnD8kjh6rJ1Yy5jHvid0Ow Field2;
};
struct tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg_Content { NI cap; tyTuple__EdLY4EJQ37VFgbAn5g5rXQ data[SEQ_DECL_SIZE]; };
struct tyTuple__OtlgAx3kBps9cOSMNDZSzBA {
	NI Field0;
	NimStringV2 Field1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* Field2;
};
struct tySequence__R9c39btP6BwOBBPnbaNUtMQg_Content { NI cap; tyTuple__OtlgAx3kBps9cOSMNDZSzBA data[SEQ_DECL_SIZE]; };
struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg {
	NI Field0;
	NimStringV2 Field1;
	NI64 Field2;
};
struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA_Content { NI cap; tyTuple__F3gkSrMB1qp2Tvf9bixVXwg data[SEQ_DECL_SIZE]; };
struct tyTuple__RFOJ4fF7D9bpvmh9birH1JhQ {
	NI Field0;
	NimStringV2 Field1;
	tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw Field2;
};
struct tySequence__3nALyQgqjnfK2Qjc6ny2Uw_Content { NI cap; tyTuple__RFOJ4fF7D9bpvmh9birH1JhQ data[SEQ_DECL_SIZE]; };
typedef N_NIMCALL_PTR(tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ*, tyProc__TVHQTM3bKm4Mi6Ul6zgzuQ) (tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module_p1, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p2);
typedef N_NIMCALL_PTR(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, tyProc__74nHWc2UIRu3iSR9akqDDBg) (tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* topLevelStmt_p1);
typedef N_NIMCALL_PTR(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, tyProc__S9bLWKf8jgjzoiotAmEyFSw) (tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ* p_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p2);
struct tyTuple__O3g9a8zTXSX36ljWponcAoA {
	tyProc__TVHQTM3bKm4Mi6Ul6zgzuQ Field0;
	tyProc__74nHWc2UIRu3iSR9akqDDBg Field1;
	tyProc__S9bLWKf8jgjzoiotAmEyFSw Field2;
	NIM_BOOL Field3;
};
struct tySequence__WbW5Q8QVks0bQpUJSGmuVg_Content { NI cap; tyTuple__O3g9a8zTXSX36ljWponcAoA data[SEQ_DECL_SIZE]; };
struct tySequence__9ahcSjIErJohSBBFLwuF56Q_Content { NI cap; tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* data[SEQ_DECL_SIZE]; };
struct tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ {
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA Field0;
	NimStringV2 Field1;
};
struct tySequence__E0kio2ZnplNTuln9bsnljSA_Content { NI cap; tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ data[SEQ_DECL_SIZE]; };
struct tySequence__hTEiKNj3evQAjIXUI21elA_Content { NI cap; tyObject_TFileInfo__xPdjmgevOVG8T0Aq8BK7jw data[SEQ_DECL_SIZE]; };
struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw {
	NI Field0;
	NimStringV2 Field1;
};
struct tySequence__4eRCaZmrYLLw2k30GPTiMw_Content { NI cap; tyTuple__QeWl6B6ffS4pU6WWrtcrDw data[SEQ_DECL_SIZE]; };
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content { NI cap; NimStringV2 data[SEQ_DECL_SIZE]; };
typedef NU8 tySet_tyEnum_CfileFlag__qhMBL5cBz484papsb5WgFQ;
struct tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg {
	NimStringV2 nimname;
	NimStringV2 cname;
	NimStringV2 obj;
	tySet_tyEnum_CfileFlag__qhMBL5cBz484papsb5WgFQ flags;
	NimStringV2 customArgs;
};
struct tySequence__xOJ2kx2lq9bBfIm3IXnde3Q_Content { NI cap; tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg data[SEQ_DECL_SIZE]; };
struct tySequence__d8ZV4IMgHt9biik9cS9a0hrmg_Content { NI cap; tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* data[SEQ_DECL_SIZE]; };
struct tySequence__YdLNCDKYeipzJx3I8Xw82Q_Content { NI cap; NU64 data[SEQ_DECL_SIZE]; };
struct tySequence__TLbZ2GqL3Zio1f8bNpj2NA_Content { NI cap; tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA data[SEQ_DECL_SIZE]; };
struct tyObject_TNodePair__KE5IEbxbTGxhrXo6rzddjQ {
	NI h;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* key;
	NI val;
};
struct tySequence__GH1mmNKNA2QP4n1tnxJf1w_Content { NI cap; tyObject_TNodePair__KE5IEbxbTGxhrXo6rzddjQ data[SEQ_DECL_SIZE]; };
struct tySequence__TEgqV1E9aHqnwBUoeXjBI9aA_Content { NI cap; tyProc__c9bXGQkBnyyGGVw063jrwZw data[SEQ_DECL_SIZE]; };
struct tyTuple__sr3s7uVHpu9cEbbDnCSg8yQ {
	NI Field0;
	NimStringV2 Field1;
	NI Field2;
};
struct tySequence__pUxI6Ljo6IKKHXKOZkQ7Og_Content { NI cap; tyTuple__sr3s7uVHpu9cEbbDnCSg8yQ data[SEQ_DECL_SIZE]; };
struct tyTuple__ZQn9aE2eP9aC9aAInis8k8aDQ {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* Field0;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* Field1;
};
struct tySequence__fnH5Zt4fsGx0AgDTOw8pKw_Content { NI cap; tyTuple__ZQn9aE2eP9aC9aAInis8k8aDQ data[SEQ_DECL_SIZE]; };
struct tyTuple__y6bKAf9a9aaVwun6lVDxSX7g {
	NI Field0;
	NI Field1;
	tyObject_VmProcInfo__Jux30icZSrOlvcFTG81Ljg Field2;
};
struct tySequence__Fc8Q26tsngy2yxcpyrnT4Q_Content { NI cap; tyTuple__y6bKAf9a9aaVwun6lVDxSX7g data[SEQ_DECL_SIZE]; };
struct tySequence__9c9aWmheGsuf9aHtY7gTnUcPA_Content { NI cap; tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A data[SEQ_DECL_SIZE]; };
struct tySequence__qwqHTkRvwhrRyENtudHQ7g_Content { NI cap; NI data[SEQ_DECL_SIZE]; };
struct tyObject_TBlock__jSiqQOXIz3L9a8VW9a9a3HAuA {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* label;
	tySequence__qwqHTkRvwhrRyENtudHQ7g fixups;
};
struct tySequence__b9bG03Q6unwlMU0dM7uOPIA_Content { NI cap; tyObject_TBlock__jSiqQOXIz3L9a8VW9a9a3HAuA data[SEQ_DECL_SIZE]; };
typedef NU8 tyEnum_TSlotKind__oo9bgjIHoNBV9c9cKJRycJW4A;
struct tyTuple__9ap1MJ9bVBlP34AqrUq01n8w {
	NIM_BOOL Field0;
	tyEnum_TSlotKind__oo9bgjIHoNBV9c9cKJRycJW4A Field1;
};
struct tySequence__grdS5PdBBxkq9bxi4lFAdAw_Content { NI cap; tyTuple__9ap1MJ9bVBlP34AqrUq01n8w data[SEQ_DECL_SIZE]; };
struct tySequence__6H5Oh5UUvVCLiakt9aTwtUQ_Content { NI cap; NU8 data[SEQ_DECL_SIZE]; };
struct tySequence__4eQHGndY6XBYpFOH09apV8Q_Content { NI cap; tyTuple__UV3llMMYFckfui8YMBuUZA data[SEQ_DECL_SIZE]; };
struct tyTuple__0q9cmhneJEKnQERTpXXdz6Q {
	NU32 Field0;
	NimStringV2 Field1;
};
struct tySequence__PXIzfWocnrafGz5p3CP5LA_Content { NI cap; tyTuple__0q9cmhneJEKnQERTpXXdz6Q data[SEQ_DECL_SIZE]; };
struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA_Content { NI cap; NU32 data[SEQ_DECL_SIZE]; };
struct tyObject_PackedNode__YxKk4C732K04CNgtMhmc0w {
	NU32 x;
	NU32 info;
};
struct tySequence__OxRbUT0qZaZN5UjnqQjGPA_Content { NI cap; tyObject_PackedNode__YxKk4C732K04CNgtMhmc0w data[SEQ_DECL_SIZE]; };
struct tyTuple__48iPM3yLBKU5nyEuYwJvuQ {
	NI32 Field0;
	tySet_tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw Field1;
};
struct tySequence__ezS5mGPcRfBURJyMgqYVzA_Content { NI cap; tyTuple__48iPM3yLBKU5nyEuYwJvuQ data[SEQ_DECL_SIZE]; };
struct tyTuple__R3ddFrA0G9buJY57Qhf9cTpg {
	NI32 Field0;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field1;
};
struct tySequence__wW7xkohjuUKO9aMaB0nt9cqA_Content { NI cap; tyTuple__R3ddFrA0G9buJY57Qhf9cTpg data[SEQ_DECL_SIZE]; };
struct tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ {
	NU32 Field0;
	NI32 Field1;
};
struct tySequence__b89aLriiJnVTD186H6zNIgg_Content { NI cap; tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ data[SEQ_DECL_SIZE]; };
struct tyTuple__7rmdAMLZ8fDd79brQn2ixZA {
	NU32 Field0;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field1;
};
struct tySequence__hIPTk9aFdaMMVAOzEbnPyqg_Content { NI cap; tyTuple__7rmdAMLZ8fDd79brQn2ixZA data[SEQ_DECL_SIZE]; };
struct tyTuple__qPXRCRNQuZLLKto7CIIEzw {
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field0;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field1;
};
struct tySequence__YYy1721YAuPF0ajBYHd8Wg_Content { NI cap; tyTuple__qPXRCRNQuZLLKto7CIIEzw data[SEQ_DECL_SIZE]; };
struct tyObject_PackedInstantiation__C3FSePJFY8gUIMObsjT2dg {
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig key;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig sym;
	tySequence__qBes3XzcQQ9cyia9bRwnmbJw concreteTypes;
};
struct tySequence__UODJbvzmu39c3Ho9cqhSk9agQ_Content { NI cap; tyObject_PackedInstantiation__C3FSePJFY8gUIMObsjT2dg data[SEQ_DECL_SIZE]; };
typedef NU8 tyEnum_TTypeAttachedOp__RefHoBI5deIfxIZqo3dS5Q;
struct tyTuple__6kG8KAxm9aXPdLdlxcxqJJw {
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field0;
	tyEnum_TTypeAttachedOp__RefHoBI5deIfxIZqo3dS5Q Field1;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field2;
};
struct tySequence__F1qNdU7m0Czu7Y2q0eksXw_Content { NI cap; tyTuple__6kG8KAxm9aXPdLdlxcxqJJw data[SEQ_DECL_SIZE]; };
struct tyTuple__TRK7rrwoha9bbDAdPWsqJMw {
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field0;
	NI Field1;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field2;
};
struct tySequence__r3Kz9breImOXyFFoJ29aBM8Q_Content { NI cap; tyTuple__TRK7rrwoha9bbDAdPWsqJMw data[SEQ_DECL_SIZE]; };
struct tySequence__qBes3XzcQQ9cyia9bRwnmbJw_Content { NI cap; tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig data[SEQ_DECL_SIZE]; };
typedef NU8 tyEnum_TLibKind__BkKL8ReLoyYDI7of9aQPV0A;
struct tyObject_PackedLib__EpwVLk0Fuc5Q9agKLMWedbg {
	tyEnum_TLibKind__BkKL8ReLoyYDI7of9aQPV0A kind;
	NIM_BOOL generated;
	NIM_BOOL isOverridden;
	NU32 name;
	NI32 path;
};
struct tyObject_PackedSym__KKnx6w8Cc9aaVsaPOpaqxbw {
	NI32 id;
	tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q kind;
	NU32 name;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig typ;
	tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg flags;
	tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg magic;
	NU32 info;
	NI32 ast;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig owner;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig guard;
	NI bitsize;
	NI alignment;
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ options;
	NI position;
	NI32 offset;
	NI32 disamb;
	NU32 externalName;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg locFlags;
	tyObject_PackedLib__EpwVLk0Fuc5Q9agKLMWedbg annex;
	NI32 constraint;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig instantiatedFrom;
};
struct tyTuple__V1VWX9bHapuzCjpMfFfys5Q {
	NI Field0;
	NI Field1;
	NI32 Field2;
	tyObject_PackedSym__KKnx6w8Cc9aaVsaPOpaqxbw Field3;
};
struct tySequence__Vl1abU3gfp0RqCb1KKfmDA_Content { NI cap; tyTuple__V1VWX9bHapuzCjpMfFfys5Q data[SEQ_DECL_SIZE]; };
struct tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ {
	NI32 id;
	tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg kind;
	tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ callConv;
	tySet_tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A flags;
	tySequence__qBes3XzcQQ9cyia9bRwnmbJw types;
	NI32 n;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig sym;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig owner;
	NI64 size;
	NI16 align;
	NI16 paddingAtEnd;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig typeInst;
	NI32 nonUniqueId;
};
struct tyTuple__anemVmHCFglLFt6LiEhFvg {
	NI Field0;
	NI Field1;
	NI32 Field2;
	tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ Field3;
};
struct tySequence__qyyNkmlc4fzOzelC8spUkQ_Content { NI cap; tyTuple__anemVmHCFglLFt6LiEhFvg data[SEQ_DECL_SIZE]; };
struct tySequence__IHUFRsFxZNv7YydiUO2esQ_Content { NI cap; NI64 data[SEQ_DECL_SIZE]; };
struct tyTuple__MaWaKZwaGUqCXKsSK12rVg {
	NU32 Field0;
	NI32 Field1;
	NI32 Field2;
};
struct tySequence__orxtl6CusdjXleqrxi67gw_Content { NI cap; tyTuple__MaWaKZwaGUqCXKsSK12rVg data[SEQ_DECL_SIZE]; };
struct tyTuple__nL9cBxaIV4ZA9b9ceY79coA5eA {
	NI Field0;
	NI Field1;
	NI32 Field2;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* Field3;
};
struct tySequence__K0j67V58u5FW0dCC534FQw_Content { NI cap; tyTuple__nL9cBxaIV4ZA9b9ceY79coA5eA data[SEQ_DECL_SIZE]; };
struct tyTuple__1xWeGeoNoZxaLhTUDDWYyA {
	NI Field0;
	NI Field1;
	NI32 Field2;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* Field3;
};
struct tySequence__UE4b6iUkm1b3zTPamTTkDw_Content { NI cap; tyTuple__1xWeGeoNoZxaLhTUDDWYyA data[SEQ_DECL_SIZE]; };
struct tyTuple__MZVSn3SE3XUBJOaMu7ofRQ {
	NI Field0;
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* Field1;
	tySequence__qBes3XzcQQ9cyia9bRwnmbJw Field2;
};
struct tySequence__FmsTQiIcS9arxHxs3QY48vA_Content { NI cap; tyTuple__MZVSn3SE3XUBJOaMu7ofRQ data[SEQ_DECL_SIZE]; };
struct tyTuple__UvldbCB6B9ayi9bGYW7vJNLA {
	NI Field0;
	NI32 Field1;
	NU32 Field2;
};
struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ_Content { NI cap; tyTuple__UvldbCB6B9ayi9bGYW7vJNLA data[SEQ_DECL_SIZE]; };
struct tyObject_LazyType__dsEGDq9cOhnzsRvTUTwwwuA {
	tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ id;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ;
};
struct tySequence__vb3AGHvMJTxdOSSwMmBmTQ_Content { NI cap; tyObject_LazyType__dsEGDq9cOhnzsRvTUTwwwuA data[SEQ_DECL_SIZE]; };
struct tySequence__YxH9cgSorHRI8ZPzHf47NNQ {
  NI len; tySequence__YxH9cgSorHRI8ZPzHf47NNQ_Content* p;
};
struct tyObject_LazyInstantiation__n72c7MnOoHWBy9c9akgwGqEA {
	NI module;
	tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ sym;
	tySequence__YxH9cgSorHRI8ZPzHf47NNQ concreteTypes;
	tyObject_TInstantiation__jr8MibvPn2sQBnO7XCoZRQ* inst;
};
struct tySequence__apM9bRAO19cVjhWlxqd1PGeA_Content { NI cap; tyObject_LazyInstantiation__n72c7MnOoHWBy9c9akgwGqEA data[SEQ_DECL_SIZE]; };
struct tyTuple__lGHLhAAUpxgfrnQkIzNrMw {
	NI Field0;
	tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA Field1;
};
struct tySequence__9bW2eTK9b7vXE70Sx5VPH1mw_Content { NI cap; tyTuple__lGHLhAAUpxgfrnQkIzNrMw data[SEQ_DECL_SIZE]; };
struct tyObject_TinyLineInfo__qW2GTIPjeOQ42q9c2MPWLLA {
	NU16 line;
	NI16 col;
};
struct tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg_Content { NI cap; tyObject_TinyLineInfo__qW2GTIPjeOQ42q9c2MPWLLA data[SEQ_DECL_SIZE]; };
struct tySequence__yUWoZehF86MIc40opFgacw_Content { NI cap; tySequence__d8ZV4IMgHt9biik9cS9a0hrmg data[SEQ_DECL_SIZE]; };
struct tySequence__nSO1ltijM4vhc0UrrXKEqA_Content { NI cap; tyObject_SuggestcolonObjectType___UyASNXAqAMRY5zJmcRD9ccA* data[SEQ_DECL_SIZE]; };
struct tyTuple__V6P73hvHy70PBBwharKjig {
	NI Field0;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* Field1;
};
struct tySequence__juxPMVNF1FoR2ltzeQu8NQ_Content { NI cap; tyTuple__V6P73hvHy70PBBwharKjig data[SEQ_DECL_SIZE]; };
struct tySequence__YxH9cgSorHRI8ZPzHf47NNQ_Content { NI cap; tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ data[SEQ_DECL_SIZE]; };
static N_INLINE(void, nimZeroMem)(void* p_p0, NI size_p1);
static N_INLINE(void, nimSetMem__system_u2172)(void* a_p0, int v_p1, NI size_p2);
N_LIB_PRIVATE N_NOINLINE(void, liMessage__msgs_u1227)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA msg_p2, NimStringV2 arg_p3, tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w eh_p4, tyTuple__kN8up2W6YKc5YA9avn5mV5w info2_p5, NIM_BOOL isRaw_p6, NIM_BOOL ignoreError_p7);
static N_INLINE(NI, signatureLen__ast_u5610)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p0);
static N_INLINE(NI, safeLen__ast_u3197)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0);
static N_INLINE(NI, len__ast_u3190)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0);
static N_INLINE(NIM_BOOL*, nimErrorFlag)(void);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nsuFormatOpenArray)(NimStringV2 formatstr_p0, NimStringV2* a_p1, NI a_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, renderTree__renderer_u59)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0, tySet_tyEnum_TRenderFlag__Il2q467fyuki59ci9aspexFg renderFlags_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___systemZdollars_u9)(NI xX60gensym0__p0);
static N_INLINE(NI, paramsLen__ast_u5616)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___system_u2691)(NimStringV2 dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, setupGlobalCtx__vm_u14200)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module_p0, tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p1, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p2);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___ast_u4955)(RootObj** dest_p0, RootObj* src_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew*, newCtx__vmdef_u383)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module_p0, tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* cache_p1, tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p2, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p3);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___vmdef_u2206)(tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, registerAdditionalOps__vm_u13280)(tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew* c_p0);
N_LIB_PRIVATE N_NIMCALL(void*, nimNewObj)(NI size_p0, NI alignment_p1);
N_LIB_PRIVATE N_NIMCALL(void, rttiDestroy__vm_u14575)(void* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___vm_u14507)(tyObject_Env_vmopsdotnim_registerAdditionalOps___VDnIL6fWGTCjJE9c9cTQGKGw* dest_p0);
static N_INLINE(NIM_BOOL, nimDecRefIsLastCyclicDyn)(void* p_p0);
static N_INLINE(NI, minuspercent___system_u805)(NI x_p0, NI y_p1);
N_LIB_PRIVATE N_NOINLINE(void, rememberCycle__system_u3495)(NIM_BOOL isDestroyAction_p0, tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* s_p1, TNimTypeV2* desc_p2);
N_LIB_PRIVATE N_NIMCALL(void, nimDestroyAndDispose)(void* p_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqtrace___vm_u14519)(tyObject_Env_vmopsdotnim_registerAdditionalOps___VDnIL6fWGTCjJE9c9cTQGKGw* dest_p0, void* env_p1);
static N_INLINE(void, nimTraceRefDyn)(void* q_p0, void* env_p1);
static N_INLINE(void, add__system_u3016)(tyObject_CellSeq__gW9aeWLFbrNaeUKXqxYBXhg* s_p0, void** c_p1, TNimTypeV2* t_p2);
N_LIB_PRIVATE N_NIMCALL(void, resize__system_u3024)(tyObject_CellSeq__gW9aeWLFbrNaeUKXqxYBXhg* s_p0);
static N_INLINE(NI, pluspercent___system_u785)(NI x_p0, NI y_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___vmdef_u2209)(tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew** dest_p0, tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew* src_p1, NIM_BOOL cyclic_p2);
N_LIB_PRIVATE N_NIMCALL(NI, registerCallback__vmdef_u2258)(tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew* c_p0, NimStringV2 name_p1, tyProc__c9bXGQkBnyyGGVw063jrwZw callback_p2);
N_LIB_PRIVATE N_NIMCALL(void, sqrtWrapper__vm_u13311)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0);
N_LIB_PRIVATE N_NIMCALL(NI, numArgs__vm_u279)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0);
N_LIB_PRIVATE N_NIMCALL(void, failedAssertImpl__stdZassertions_u79)(NimStringV2 msg_p0);
N_LIB_PRIVATE N_NIMCALL(void, setResult__vm_u242)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, NF v_p1);
static N_INLINE(void, ensureKind__vm_u122)(tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A* n_p0, tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA k_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___vmdef_u1715)(tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A* dest_p0, tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A src_p1);
N_LIB_PRIVATE N_NIMCALL(NF, getFloat__vm_u331)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, NI i_p1);
static N_INLINE(void, appendString)(NimStringV2* dest_p0, NimStringV2 src_p1);
static N_INLINE(void, copyMem__system_u1742)(void* dest_p0, void* source_p1, NI size_p2);
static N_INLINE(void, nimCopyMem)(void* dest_p0, void* source_p1, NI size_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___vmdef_u304)(tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA e_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, rawNewString)(NI space_p0);
N_LIB_PRIVATE N_NIMCALL(void, cbrtWrapper__vm_u13318)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0);
N_LIB_PRIVATE N_NIMCALL(void, lnWrapper__vm_u13325)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0);
N_LIB_PRIVATE N_NIMCALL(void, log10Wrapper__vm_u13332)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0);
N_LIB_PRIVATE N_NIMCALL(void, log2Wrapper__vm_u13339)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0);
N_LIB_PRIVATE N_NIMCALL(void, expWrapper__vm_u13346)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0);
N_LIB_PRIVATE N_NIMCALL(void, arccosWrapper__vm_u13353)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0);
N_LIB_PRIVATE N_NIMCALL(void, arcsinWrapper__vm_u13360)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0);
N_LIB_PRIVATE N_NIMCALL(void, arctanWrapper__vm_u13367)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0);
N_LIB_PRIVATE N_NIMCALL(void, arcsinhWrapper__vm_u13374)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0);
N_LIB_PRIVATE N_NIMCALL(void, arccoshWrapper__vm_u13381)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0);
N_LIB_PRIVATE N_NIMCALL(void, arctanhWrapper__vm_u13388)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0);
N_LIB_PRIVATE N_NIMCALL(void, arctan2Wrapper__vm_u13395)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0);
N_LIB_PRIVATE N_NIMCALL(void, cosWrapper__vm_u13397)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0);
N_LIB_PRIVATE N_NIMCALL(void, coshWrapper__vm_u13404)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0);
N_LIB_PRIVATE N_NIMCALL(void, hypotWrapper__vm_u13411)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0);
N_LIB_PRIVATE N_NIMCALL(void, sinhWrapper__vm_u13413)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0);
N_LIB_PRIVATE N_NIMCALL(void, sinWrapper__vm_u13420)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0);
N_LIB_PRIVATE N_NIMCALL(void, tanWrapper__vm_u13427)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0);
N_LIB_PRIVATE N_NIMCALL(void, tanhWrapper__vm_u13434)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0);
N_LIB_PRIVATE N_NIMCALL(void, powWrapper__vm_u13441)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0);
N_LIB_PRIVATE N_NIMCALL(void, truncWrapper__vm_u13443)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0);
N_LIB_PRIVATE N_NIMCALL(void, floorWrapper__vm_u13450)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0);
N_LIB_PRIVATE N_NIMCALL(void, ceilWrapper__vm_u13457)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0);
N_LIB_PRIVATE N_NIMCALL(void, erfWrapper__vm_u13464)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0);
N_LIB_PRIVATE N_NIMCALL(void, erfcWrapper__vm_u13471)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0);
N_LIB_PRIVATE N_NIMCALL(void, gammaWrapper__vm_u13478)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0);
N_LIB_PRIVATE N_NIMCALL(void, lgammaWrapper__vm_u13485)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0);
N_LIB_PRIVATE N_NIMCALL(void, divmodWrapper__vm_u13492)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0);
N_LIB_PRIVATE N_NIMCALL(void, setResult__vm_u269)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, tyTuple__igdSbLMeeUm9brp9bUKtC70w v_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, newNode__ast_u4069)(tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw kind_p0);
N_LIB_PRIVATE N_NIMCALL(void, add__ast_u3215)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* father_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* son_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, newIntNode__ast_u5200)(tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw kind_p0, NI64 intVal_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___ast_u3261)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** dest_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* src_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u3252)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* dest_p0);
static N_INLINE(tyTuple__igdSbLMeeUm9brp9bUKtC70w, divmod__vm_u13494)(NI64 x_p0, NI64 y_p1);
N_LIB_PRIVATE N_NIMCALL(NI64, getInt__vm_u282)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, NI i_p1);
N_LIB_PRIVATE N_NIMCALL(void, copySignWrapper__vm_u13540)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0);
static N_INLINE(NF, copySign__vm_u13542)(NF x_p0, NF y_p1);
N_LIB_PRIVATE N_NIMCALL(void, signbitWrapper__vm_u13556)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0);
N_LIB_PRIVATE N_NIMCALL(void, setResult__vm_u245)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, NIM_BOOL v_p1);
static N_INLINE(NIM_BOOL, signbit__astyaml_u680)(NF x_p0);
N_LIB_PRIVATE N_NIMCALL(void, colonanonymous___vm_u13566)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0);
N_LIB_PRIVATE N_NIMCALL(NF, round__vm_u13569)(NF x_p0, NI places_p1);
N_LIB_PRIVATE N_NOINLINE(void, raiseAssert__stdZassertions_u15)(NimStringV2 msg_p0);
N_LIB_PRIVATE N_NIMCALL(void, modWrapper__vm_u13575)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0);
N_LIB_PRIVATE N_NIMCALL(void, getEnvWrapper__vm_u13577)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0);
N_LIB_PRIVATE N_NIMCALL(void, setResult__vm_u252)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, NimStringV2 v_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___system_u2694)(NimStringV2* dest_p0, NimStringV2 src_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getEnv__stdZenvvars_u16)(NimStringV2 key_p0, NimStringV2 default_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getString__vm_u381)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, NI i_p1);
N_LIB_PRIVATE N_NIMCALL(void, existsEnvWrapper__vm_u13579)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, existsEnv__stdZenvvars_u21)(NimStringV2 key_p0);
N_LIB_PRIVATE N_NIMCALL(void, putEnvWrapper__vm_u13581)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0);
N_LIB_PRIVATE N_NIMCALL(void, putEnv__stdZenvvars_u24)(NimStringV2 key_p0, NimStringV2 val_p1);
N_LIB_PRIVATE N_NIMCALL(void, delEnvWrapper__vm_u13583)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0);
N_LIB_PRIVATE N_NIMCALL(void, delEnv__stdZenvvars_u30)(NimStringV2 key_p0);
N_LIB_PRIVATE N_NIMCALL(void, dirExistsWrapper__vm_u13585)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, nosdirExists)(NimStringV2 dir_p0);
N_LIB_PRIVATE N_NIMCALL(void, fileExistsWrapper__vm_u13587)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, nosfileExists)(NimStringV2 filename_p0);
N_LIB_PRIVATE N_NIMCALL(void, writeFileWrapper__vm_u13597)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0);
N_LIB_PRIVATE N_NIMCALL(void, writeFileWrapper__vm_u13599)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0);
N_LIB_PRIVATE N_NIMCALL(void, writeFile__stdZsyncio_u532)(NimStringV2 filename_p0, NimStringV2 content_p1);
N_LIB_PRIVATE N_NIMCALL(void, createDirWrapper__vm_u13609)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0);
N_LIB_PRIVATE N_NIMCALL(void, createDirWrapper__vm_u13611)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0);
N_LIB_PRIVATE N_NIMCALL(void, noscreateDir)(NimStringV2 dir_p0);
N_LIB_PRIVATE N_NIMCALL(void, readFileWrapper__vm_u13613)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, readFile__stdZsyncio_u527)(NimStringV2 filename_p0);
N_LIB_PRIVATE N_NIMCALL(void, readLinesWrapper__vm_u13615)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0);
N_LIB_PRIVATE N_NIMCALL(void, setResult__vm_u261)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, tySequence__sM4lkSb7zS6F7OVMvW9cffQ v_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, newStrNode__ast_u5422)(tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw kind_p0, NimStringV2 strVal_p1);
N_LIB_PRIVATE N_NIMCALL(tySequence__sM4lkSb7zS6F7OVMvW9cffQ, readLines__stdZsyncio_u550)(NimStringV2 filename_p0, NI n_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___system_u5533)(tySequence__sM4lkSb7zS6F7OVMvW9cffQ dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, getCurrentExceptionMsgWrapper__vm_u13115)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, skipColon__ast_u7347)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0);
N_LIB_PRIVATE N_NIMCALL(void, getCurrentExceptionWrapper__vm_u13120)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0);
N_LIB_PRIVATE N_NIMCALL(void, setResult__vm_u255)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___ast_u3255)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** dest_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* src_p1);
N_LIB_PRIVATE N_NIMCALL(void, raiseDefectWrapper__vm_u13122)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0);
N_LIB_PRIVATE N_NIMCALL(void, colonanonymous___vm_u13617)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, staticWalkDirImpl__vm_u13124)(NimStringV2 path_p0, NIM_BOOL relative_p1);
static N_INLINE(NCSTRING, nimToCStringConv)(NimStringV2 s_p0);
N_LIB_PRIVATE N_NOINLINE(void, raiseOSError__stdZoserrors_u119)(NI32 errorCode_p0, NimStringV2 additionalInfo_p1);
N_LIB_PRIVATE N_NIMCALL(NI32, osLastError__stdZoserrors_u122)(void);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, cstrToNimstr)(NCSTRING str_p0);
static N_INLINE(NIM_BOOL, eqStrings)(NimStringV2 a_p0, NimStringV2 b_p1);
static N_INLINE(NIM_BOOL, equalMem__system_u1750)(void* a_p0, void* b_p1, NI size_p2);
static N_INLINE(int, nimCmpMem)(void* a_p0, void* b_p1, NI size_p2);
static N_INLINE(NimStringV2, slash___stdZprivateZospaths2_u91)(NimStringV2 head_p0, NimStringV2 tail_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nosjoinPath)(NimStringV2 head_p0, NimStringV2 tail_p1);
N_LIB_PRIVATE N_NIMCALL(tyTuple__wjbnfGBIEcH6aaevyJWrgw, getSymlinkFileKind__stdZprivateZoscommon_u20)(NimStringV2 path_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___system_u2700)(NimStringV2* dest_p0, NimStringV2 src_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___system_u2688)(NimStringV2* dest_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, toLit__vm_u13130)(tyTuple__RQuzKb7YBI25p4z9cTFFLeQ a_p0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, getBool__vm_u327)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, NI i_p1);
N_LIB_PRIVATE N_NIMCALL(void, colonanonymous___vm_u13619)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0);
N_LIB_PRIVATE N_NIMCALL(void, colonanonymous___vm_u13621)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___vm_u13623)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, querySettingImpl__vm_u13153)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NI64 switch_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, eqdup___system_u2697)(NimStringV2 src_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getNimcacheDir__options_u3737)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___options_u144)(tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw e_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___options_u213)(tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg e_p0);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___vm_u13625)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(tySequence__sM4lkSb7zS6F7OVMvW9cffQ, querySettingSeqImpl__vm_u13185)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NI64 switch_p1);
N_LIB_PRIVATE N_NIMCALL(void*, newSeqPayload)(NI cap_p0, NI elemSize_p1, NI elemAlign_p2);
N_LIB_PRIVATE N_NIMCALL(void, add__stdZenumutils_u71)(tySequence__sM4lkSb7zS6F7OVMvW9cffQ* x_p0, NimStringV2 y_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___system_u5536)(tySequence__sM4lkSb7zS6F7OVMvW9cffQ* dest_p0, tySequence__sM4lkSb7zS6F7OVMvW9cffQ src_p1);
N_LIB_PRIVATE N_CLOSURE(void, gorgeExWrapper__vm_u13286)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(tyTuple__XOVT24GHXwqiEj5GCsEGCA, opGorge__gorgeimpl_u14)(NimStringV2 cmd_p0, NimStringV2 input_p1, NimStringV2 cache_p2, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p3, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p4);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, toLit__vm_u13289)(tyTuple__XOVT24GHXwqiEj5GCsEGCA a_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___pureZosproc_u1951)(tyTuple__XOVT24GHXwqiEj5GCsEGCA dest_p0);
N_LIB_PRIVATE N_CLOSURE(void, getProjectPathWrapper__vm_u13309)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(void, colonanonymous___vm_u13631)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nosgetAppFilename)(void);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___vm_u13633)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, getNode__vm_u356)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, NI i_p1);
N_LIB_PRIVATE N_NIMCALL(void, stackTrace2__vm_u13276)(tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew* c_p0, NimStringV2 msg_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p2);
N_LIB_PRIVATE N_NOINLINE(void, stackTraceImpl__vm_u73)(tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew* c_p0, tyObject_TStackFrame__a20zU43j9cYHpYOOr1c2hZQ* tos_p1, NI pc_p2, NimStringV2 msg_p3, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA lineInfo_p4, tyTuple__kN8up2W6YKc5YA9avn5mV5w infoOrigin_p5);
N_LIB_PRIVATE N_NIMCALL(void, msgWriteln__msgs_u737)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 s_p1, tySet_tyEnum_MsgFlag__uOe9ahJyFezfCR4dA8VRyQw flags_p2);
N_LIB_PRIVATE N_NIMCALL(void, stackTraceAux__vm_u32)(tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew* c_p0, tyObject_TStackFrame__a20zU43j9cYHpYOOr1c2hZQ* x_p1, NI pc_p2, NI recursionLimit_p3);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___vmprofiler_u22)(tyObject_TStackFrame__a20zU43j9cYHpYOOr1c2hZQ** dest_p0, tyObject_TStackFrame__a20zU43j9cYHpYOOr1c2hZQ* src_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___vmprofiler_u19)(tyObject_TStackFrame__a20zU43j9cYHpYOOr1c2hZQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, toFullPath__msgs_u624)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NI32 fileIdx_p1);
static N_INLINE(NI, toLinenumber__msgs_u695)(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p0);
static N_INLINE(NI, toColumn__msgs_u698)(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p0);
static N_INLINE(void, nimAddCharV1)(NimStringV2* s_p0, NIM_CHAR c_p1);
N_LIB_PRIVATE N_NIMCALL(void, prepareAdd)(NimStringV2* s_p0, NI addLen_p1);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, eqeq___msgs_u1103)(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA a_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA b_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, eqdup___ast_u4580)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* src_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___renderer_u2166)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___nodekinds_u168)(tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw e_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___modulegraphs_u10732)(tyArray__dnD8kjh6rJ1Yy5jHvid0Ow u_p0);
N_LIB_PRIVATE N_NIMCALL(void, symBodyDigest__sighashes_u534)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_p1, tyArray__dnD8kjh6rJ1Yy5jHvid0Ow Result);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___vm_u13643)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, void* ClE_0);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___vm_u13657)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, contains__vm_u8108)(tyObject_Table__1HJsK7ponJ4Vb1lJgVFVTQ t_p0, NimStringV2 key_p1);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, contains__vm_u9814)(tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw b_p0, NimStringV2 key_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw*, X5BX5D___vm_u9673)(tyObject_Table__1HJsK7ponJ4Vb1lJgVFVTQ* t_p0, NimStringV2 key_p1);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___vm_u13837)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, void* ClE_0);
N_LIB_PRIVATE N_CLOSURE(void, hashVmImpl__vm_u13839)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(NI, hash__pureZhashes_u593)(NimStringV2 sBuf_p0, NI sPos_p1, NI ePos_p2);
N_LIB_PRIVATE N_NIMCALL(void, setResult__vm_u239)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, NI64 v_p1);
N_LIB_PRIVATE N_CLOSURE(void, hashVmImplByte__vm_u13846)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(tySequence__6H5Oh5UUvVCLiakt9aTwtUQ, newSeq__vm_u13879)(NI len_p0);
N_LIB_PRIVATE N_NIMCALL(NI, hash__vm_u13894)(NU8* aBuf_p0, NI aBuf_p0Len_0, NI sPos_p1, NI ePos_p2);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___pureZtimes_u2620)(tySequence__6H5Oh5UUvVCLiakt9aTwtUQ dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, colonanonymous___vm_u13910)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0);
static N_INLINE(NI, cmpStrings)(NimStringV2 a_p0, NimStringV2 b_p1);
N_LIB_PRIVATE N_NIMCALL(void, colonanonymous___vm_u13912)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0);
N_LIB_PRIVATE N_NIMCALL(void, cpuTimeWrapper__vm_u13922)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0);
N_LIB_PRIVATE N_NIMCALL(NF, cpuTime__pureZtimes_u5215)(void);
N_LIB_PRIVATE N_NIMCALL(void, cpuTimeWrapper__vm_u13926)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0);
N_LIB_PRIVATE N_NIMCALL(NF, cpuTime__vm_u13924)(void);
N_LIB_PRIVATE N_NIMCALL(void, colonanonymous___vm_u13932)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nosgetCurrentDir)(void);
N_LIB_PRIVATE N_NIMCALL(void, colonanonymous___vm_u13934)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0);
N_LIB_PRIVATE N_NIMCALL(tySet_tyEnum_ProcessOption__f8zQPCJAq3Y51oMx2CR9cxw, fromLit__vm_u13936)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, toLit__vm_u14000)(tyTuple__XOVT24GHXwqiEj5GCsEGCA a_p0);
N_LIB_PRIVATE N_NIMCALL(tyTuple__XOVT24GHXwqiEj5GCsEGCA, execCmdEx__pureZosproc_u1907)(NimStringV2 command_p0, tySet_tyEnum_ProcessOption__f8zQPCJAq3Y51oMx2CR9cxw options_p1, tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* env_p2, NimStringV2 workingDir_p3, NimStringV2 input_p4);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___vm_u14016)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, toTimeLit__vmconv_u29)(tyObject_Time__f9czJU2iP3D49bUN3jzSsOfA a_p0, tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew* c_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* obj_p2, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p3);
N_LIB_PRIVATE N_NIMCALL(tyObject_Time__f9czJU2iP3D49bUN3jzSsOfA, getTime__pureZtimes_u1291)(void);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___vm_u14038)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(void, getEffectList__vm_u14019)(tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew* c_p0, tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p1, NI effectIndex_p2);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, newNodeI__ast_u4091)(tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw kind_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, opMapTypeInstToAst__vmdeps_u302)(tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* cache_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p1, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p2, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p3, NIM_BOOL skipAlias_p4);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, skipTypes__ast_u5379)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p0, tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg kinds_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u3378)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, newIdentNode__ast_u5164)(tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* ident_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA*, getIdent__idents_u206)(tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* ic_p0, NimStringV2 identifier_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___idents_u155)(tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* dest_p0);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___vm_u14040)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, void* ClE_0);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___vm_u14042)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(void, colonanonymous___vm_u14044)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0);
N_LIB_PRIVATE N_NIMCALL(void, colonanonymous___vm_u14055)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0);
N_LIB_PRIVATE N_NIMCALL(void, colonanonymous___vm_u14074)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0);
N_LIB_PRIVATE N_NIMCALL(void, colonanonymous___vm_u14089)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, getVar__vm_u406)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, NI i_p1);
N_LIB_PRIVATE N_NIMCALL(void, addFloatRoundtrip__system_u4737)(NimStringV2* result_p0, NF x_p1);
N_LIB_PRIVATE N_NIMCALL(void, colonanonymous___vm_u14097)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0);
N_LIB_PRIVATE N_NIMCALL(void, addFloatSprintf__stdZformatfloat_u119)(NimStringV2* result_p0, NF x_p1);
N_LIB_PRIVATE N_NIMCALL(void, colonanonymous___vm_u14101)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nsuformatBiggestFloat)(NF f_p0, tyEnum_FloatFormatMode__CTUpdhZ6zDNw9cC9acViKeYg format_p1, NI precision_p2, NIM_CHAR decimalSep_p3);
N_LIB_PRIVATE N_NIMCALL(void, colonanonymous___vm_u14104)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* aX60gensym2316__p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, toLit__vm_u14137)(tySequence__4eQHGndY6XBYpFOH09apV8Q a_p0);
static N_INLINE(NIM_BOOL, eqeq___system_u8603)(NCSTRING x_p0, NCSTRING y_p1);
static N_INLINE(NI, find__pureZparseutils_u636)(NimStringV2 a_p0, NIM_CHAR item_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___stdZprivateZospaths2_u315)(tyTuple__UV3llMMYFckfui8YMBuUZA* dest_p0, tyTuple__UV3llMMYFckfui8YMBuUZA src_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, substr__system_u8659)(NimStringV2 s_p0, NI first_p1, NI last_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, substr__system_u8672)(NimStringV2 s_p0, NI first_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___stdZprivateZospaths2_u303)(tyTuple__UV3llMMYFckfui8YMBuUZA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, add__vm_u14117)(tySequence__4eQHGndY6XBYpFOH09apV8Q* x_p0, tyTuple__UV3llMMYFckfui8YMBuUZA y_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___stdZprivateZospaths2_u306)(tyTuple__UV3llMMYFckfui8YMBuUZA dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___stdZenvvars_u82)(tySequence__4eQHGndY6XBYpFOH09apV8Q dest_p0);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___vm_u14165)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___ast_u3381)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg** dest_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* src_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, loadAny__vmmarshal_u1900)(NimStringV2 s_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p1, tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* cache_p2, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p3, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p4);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___vm_u14168)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(void, storeAny__vmmarshal_u154)(NimStringV2* s_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_p2, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p3);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, regToNode__vm_u542)(tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A x_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___vm_u14535)(tyObject_Env_vmopsdotnim_registerAdditionalOps___VDnIL6fWGTCjJE9c9cTQGKGw* dest_p0);
static N_INLINE(NIM_BOOL, nimDecRefIsLastCyclicStatic)(void* p_p0, TNimTypeV2* desc_p1);
N_LIB_PRIVATE N_NIMCALL(void, nimRawDispose)(void* p_p0, NI alignment_p1);
N_LIB_PRIVATE N_NIMCALL(void, refresh__vmdef_u2227)(tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew* c_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module_p1, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p2);
N_LIB_PRIVATE N_NIMCALL(RootObj*, eqdup___ast_u4951)(RootObj* src_p0, NIM_BOOL cyclic_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___vm_u14411)(NI** dest_p0, NI* src_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_VmProcInfo__Jux30icZSrOlvcFTG81Ljg, genProc__vmgen_u3092)(tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew* c_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, errorNode__vm_u12981)(tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* owner_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p2);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___ast_u3387)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg** dest_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* src_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, newType__ast_u5900)(tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg kind_p0, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* owner_p2, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* son_p3);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___vmdef_u1706)(tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__vm_u2972)(tySequence__9c9aWmheGsuf9aHtY7gTnUcPA* s_p0, NI len_p1);
N_LIB_PRIVATE N_NIMCALL(void, setupMacroParam__vm_u14337)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* x_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p1, tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A* Result);
N_LIB_PRIVATE N_NIMCALL(void, putIntoReg__vm_u523)(tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A* dest_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, eqdup___ast_u3258)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* src_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, prepareVMValue__vm_u14304)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* arg_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, copyNode__ast_u6736)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* src_p0);
N_LIB_PRIVATE N_NIMCALL(void, rawExecute__vm_u879)(tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew* c_p0, NI start_p1, tyObject_TStackFrame__a20zU43j9cYHpYOOr1c2hZQ* tos_p2, tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A* Result);
N_LIB_PRIVATE N_NIMCALL(void, rttiDestroy__vm_u15113)(void* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___vm_u14789)(tyObject_Env_vmdotnim_rawExecute___hNEyCf8VhTK2S3ZJXhlD9cg* dest_p0);
static N_INLINE(NIM_BOOL, nimDecRefIsLastDyn)(void* p_p0);
N_LIB_PRIVATE N_NIMCALL(void, unregisterCycle__system_u3125)(tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* s_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___vmdef_u1600)(tyObject_TStackFrame__a20zU43j9cYHpYOOr1c2hZQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqtrace___vm_u14801)(tyObject_Env_vmdotnim_rawExecute___hNEyCf8VhTK2S3ZJXhlD9cg* dest_p0, void* env_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___msgs_u714)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___vmdef_u267)(tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA e_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, sourceLine__msgs_u1210)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA i_p1);
N_LIB_PRIVATE N_NIMCALL(void, echoBinSafe)(NimStringV2* args_p0, NI args_p0Len_0);
static N_INLINE(void, enter__vmprofiler_u8)(tyObject_Profiler__YI4zs2CaXXndlYireD0I8A* prof_p0, tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew* c_p1, tyObject_TStackFrame__a20zU43j9cYHpYOOr1c2hZQ* tos_p2);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___vmdef_u1709)(tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A* dest_p0, tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A src_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___vm_u14829)(tyObject_Env_vmdotnim_rawExecute___hNEyCf8VhTK2S3ZJXhlD9cg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(NI, cleanUpOnReturn__vm_u683)(tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew* c_p0, tyObject_TStackFrame__a20zU43j9cYHpYOOr1c2hZQ* f_p1);
static N_INLINE(NI*, X5BX5D___vm_u695)(NI* s_p0, NI s_p0Len_0, NI i_p1);
static N_INLINE(NI, pop__injectdestructors_u256)(tySequence__qwqHTkRvwhrRyENtudHQ7g* s_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___system_u8096)(NI* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, shrink__pureZosproc_u399)(tySequence__qwqHTkRvwhrRyENtudHQ7g* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___vmdef_u1703)(tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A* dest_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, newNodeIT__ast_u4112)(tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw kind_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___ast_u182)(tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg e_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___ast_u3249)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, asgnComplex__vm_u510)(tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A* x_p0, tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A y_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, copyValue__vm_u486)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* src_p0);
N_LIB_PRIVATE N_NIMCALL(void, commenteq___ast_u1334)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0, NimStringV2 a_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, comment__ast_u836)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___ast_u4577)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg** dest_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* src_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___idents_u158)(tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA** dest_p0, tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* src_p1);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__ast_u4100)(tySequence__9ahcSjIErJohSBBFLwuF56Q* s_p0, NI len_p1);
N_LIB_PRIVATE N_NIMCALL(void, fastAsgnComplex__vm_u513)(tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A* x_p0, tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A y_p1);
N_LIB_PRIVATE N_NIMCALL(void, moveConst__vm_u480)(tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A* x_p0, tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A y_p1);
N_LIB_PRIVATE N_CLOSURE(void, rangeCheck__vm_u1072)(NI64 left_p0, NI64 right_p1, NI64 safeLen_p2, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___systemZdollars_u29)(NI64 xX60gensym4__p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, newTree__ast_u4170)(tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw kind_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** children_p1, NI children_p1Len_0);
static N_INLINE(NI, safeArrLen__ast_u3204)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0);
static N_INLINE(NIM_BOOL, contains__vm_u1214)(tyObject_HSlice__QbYBq0DTmYHIHa8KuurQ6Q s_p0, NI value_p1);
static N_INLINE(tyObject_HSlice__QbYBq0DTmYHIHa8KuurQ6Q, dotdot___vm_u1109)(NI a_p0, NI64 b_p1);
static N_INLINE(NIM_BOOL, ltpercent___system_u1092)(NI x_p0, NI y_p1);
N_LIB_PRIVATE N_NIMCALL(void, takeCharAddress__vm_u864)(tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* src_p1, NI64 index_p2, NI pc_p3, tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A* Result);
static N_INLINE(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, owner__ast_u6254)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p0);
N_LIB_PRIVATE N_NIMCALL(void, add__ast_u3881)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* father_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* son_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, getSysType__magicsys_u55)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg kind_p2);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u4574)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, GC_ref__vm_u1333)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* x_p0);
static N_INLINE(void, nimPrepareStrMutationV2)(NimStringV2* s_p0);
N_LIB_PRIVATE N_NIMCALL(void, nimPrepareStrMutationImpl__system_u2430)(NimStringV2* s_p0);
N_LIB_PRIVATE N_NIMCALL(void, writeField__vm_u516)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** n_p0, tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A x_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___ast_u3279)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* dest_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* src_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___vm_u1541)(tyTuple__NF6bgG5XEXlP7DfqszlNdg* x_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, typeToString__types_u54)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p0, tyEnum_TPreferedDesc__ddj0M89bv09cBYthgD4XTq3Q prefer_p1);
static N_INLINE(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, elementType__ast_u5331)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* n_p0);
static N_INLINE(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg**, X5BX5D___ast_u5281)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg** s_p0, NI s_p0Len_0, NI i_p1);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, derefPtrToReg__vm_u144)(NI64 address_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p1, tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A* r_p2, NIM_BOOL isAssign_p3);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___vm_u1803)(tyTuple__dsvP9bgd7x7RN0ykJDjb3Sg x_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___ast_u3273)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* dest_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* src_p1);
static N_INLINE(NI64, pluspercent___system_u801)(NI64 x_p0, NI64 y_p1);
static N_INLINE(NI64, minuspercent___system_u821)(NI64 x_p0, NI64 y_p1);
static N_INLINE(NI, nimCStrLen)(NCSTRING a_p0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, inSet__nimsets_u8)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* s_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* elem_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, copyTree__ast_u6891)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* src_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, diffSets__nimsets_u138)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* b_p2);
N_LIB_PRIVATE N_NIMCALL(void, discardSons__ast_u3188)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* father_p0);
N_LIB_PRIVATE N_NIMCALL(NI64, cardSet__nimsets_u191)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_p1);
static N_INLINE(NI64, starpercent___system_u841)(NI64 x_p0, NI64 y_p1);
static N_INLINE(NF, toBiggestFloat__system_u1698)(NI64 i_p0);
static N_INLINE(NF, abs__system_u5136)(NF x_p0);
static N_INLINE(NI64, slashpercent___system_u861)(NI64 x_p0, NI64 y_p1);
static N_INLINE(NI64, percentpercent___system_u881)(NI64 x_p0, NI64 y_p1);
static N_INLINE(NIM_BOOL, lteqpercent___system_u1088)(NI64 x_p0, NI64 y_p1);
static N_INLINE(NIM_BOOL, ltpercent___system_u1108)(NI64 x_p0, NI64 y_p1);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, ptrEquality__vm_u2392)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** n1_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n2_p1);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, sameConstant__vmgen_u1074)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* b_p1);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, exprStructuralEquivalent__trees_u63)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* b_p1, NIM_BOOL strictSymEquality_p2);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, sameTypeOrNil__types_u1837)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* a_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* b_p1, tySet_tyEnum_TTypeCmpFlag__1219bojhd9apB6FQkQGJbzzQ flags_p2);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, containsSets__nimsets_u159)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* b_p2);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, equalSets__nimsets_u166)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* b_p2);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___ast_u3705)(tySequence__9ahcSjIErJohSBBFLwuF56Q* dest_p0, tySequence__9ahcSjIErJohSBBFLwuF56Q src_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, intersectSets__nimsets_u145)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* b_p2);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___ast_u3693)(tySequence__9ahcSjIErJohSBBFLwuF56Q* dest_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, unionSets__nimsets_u131)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* b_p2);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, symdiffSets__nimsets_u152)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* b_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nimCharToStr)(NIM_CHAR x_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, shallowCopy__ast_u6876)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* src_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, transformBody__transf_u26)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* prc_p2, tySet_tyEnum_TransformFlag__CzUOfRCXpoYcP43GAlt9cnA flags_p3);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, newSymNode__ast_u5168)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, skipGenericOwner__ast_u7111)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p0);
N_NIMCALL(NI, nimParseBiggestFloat)(NIM_CHAR* s_p0, NI s_p0Len_0, NF* number_p1);
N_NIMCALL(NimStringV2, rawNewString)(NI cap_p0);
N_LIB_PRIVATE N_NIMCALL(NI, parseBiggestFloat__pureZparseutils_u1009)(NimStringV2 s_p0, NF* number_p1, NI start_p2);
N_LIB_PRIVATE N_NIMCALL(void, internalErrorImpl__msgs_u1598)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, NimStringV2 errMsg_p2, tyTuple__kN8up2W6YKc5YA9avn5mV5w info2_p3);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, leValueConv__semfold_u621)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* b_p1);
static N_INLINE(NIM_BOOL, importcCond__vmgen_u2499)(tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew* c_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isEmptyBody__vmgen_u2487)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0);
static N_INLINE(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, getBody__modulegraphs_u17880)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, loadProcBody__icZic_u21187)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* config_p0, tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* cache_p1, tyObject_PackedModuleGraph__vzv9a6xTiz616FotDgUeo9bg* g_p2, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p3);
N_LIB_PRIVATE N_NIMCALL(tyObject_VmProcInfo__Jux30icZSrOlvcFTG81Ljg, compile__vm_u803)(tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew* c_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nsuFormatSingleElem)(NimStringV2 formatstr_p0, NimStringV2 a_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TStackFrame__a20zU43j9cYHpYOOr1c2hZQ*, eqdup___vmprofiler_u25)(tyObject_TStackFrame__a20zU43j9cYHpYOOr1c2hZQ* src_p0);
static N_INLINE(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, returnType__ast_u5354)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* n_p0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, fitsRegister__vmgen_u1796)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p0);
static N_INLINE(NIM_BOOL, isEmptyType__ast_u7234)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, getNullValue__vmgen_u2515)(tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew* c_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p1, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p2, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p3);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___vmprofiler_u28)(tyObject_TStackFrame__a20zU43j9cYHpYOOr1c2hZQ** dest_p0, tyObject_TStackFrame__a20zU43j9cYHpYOOr1c2hZQ* src_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___vmprofiler_u16)(tyObject_TStackFrame__a20zU43j9cYHpYOOr1c2hZQ** dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, annotateType__semmacrosanity_u136)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p1, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p2, NIM_BOOL* producedClosure_p3);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, evalTemplate__evaltempl_u344)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* tmpl_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* genSymOwner_p2, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p3, tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* ic_p4, NI* instID_p5, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p6, NIM_BOOL fromHlo_p7);
N_LIB_PRIVATE N_NIMCALL(void, recSetFlagIsRef__vm_u808)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* arg_p0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, overlap__nimsets_u32)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* b_p1);
N_LIB_PRIVATE N_NIMCALL(void, pushSafePoint__vm_u547)(tyObject_TStackFrame__a20zU43j9cYHpYOOr1c2hZQ* f_p0, NI pc_p1);
N_LIB_PRIVATE N_NIMCALL(void, add__varpartitions_u1538)(tySequence__qwqHTkRvwhrRyENtudHQ7g* x_p0, NI y_p1);
N_LIB_PRIVATE N_NIMCALL(void, popSafePoint__vm_u554)(tyObject_TStackFrame__a20zU43j9cYHpYOOr1c2hZQ* f_p0);
N_LIB_PRIVATE N_NIMCALL(tyTuple__BQblRMJ3qVZJdz8oXhBMaQ, findExceptionHandler__vm_u566)(tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew* c_p0, tyObject_TStackFrame__a20zU43j9cYHpYOOr1c2hZQ* f_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* exc_p2);
N_LIB_PRIVATE N_NIMCALL(NI, inheritanceDiff__types_u2785)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* a_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* b_p1);
N_LIB_PRIVATE N_NIMCALL(void, bailOut__vm_u119)(tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew* c_p0, tyObject_TStackFrame__a20zU43j9cYHpYOOr1c2hZQ* tos_p1);
N_NIMCALL(NimStringV2, mnewString)(NI len_p0);
N_LIB_PRIVATE N_NIMCALL(void, reset__vmdef_u1670)(tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, msgQuit__msgs_u479)(NI8 x_p0);
N_LIB_PRIVATE N_NIMCALL(NI, toInt__int128_u257)(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg arg_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg, getOrdValue__types_u171)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0, tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg onError_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg, toInt128__types_u1207)(NI arg_p0);
N_LIB_PRIVATE N_NIMCALL(void, setLengthStrV2)(NimStringV2* s_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, sameType__types_u1812)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* a_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* b_p1, tySet_tyEnum_TTypeCmpFlag__1219bojhd9apB6FQkQGJbzzQ flags_p2);
N_LIB_PRIVATE N_NIMCALL(void, setLenSeq__vm_u823)(tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* node_p1, NI newLen_p2, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p3);
N_LIB_PRIVATE N_NIMCALL(void, setLen__ast_u3718)(tySequence__9ahcSjIErJohSBBFLwuF56Q* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___vmdef_u1388)(tyProc__c9bXGQkBnyyGGVw063jrwZw* dest_p0, tyProc__c9bXGQkBnyyGGVw063jrwZw src_p1, NIM_BOOL cyclic_p2);
N_LIB_PRIVATE N_NIMCALL(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA, eqdup___lineinfos_u2037)(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA src_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___vm_u12910)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___vmdef_u1385)(tyProc__c9bXGQkBnyyGGVw063jrwZw dest_p0);
static N_INLINE(NIM_BOOL, lteqpercent___system_u1072)(NI x_p0, NI y_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, opMapTypeToAst__vmdeps_u296)(tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* cache_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p1, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p2, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p3);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, opMapTypeImplToAst__vmdeps_u309)(tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* cache_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p1, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p2, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p3);
N_LIB_PRIVATE N_NIMCALL(NI64, getSize__types_u3397)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p1);
N_LIB_PRIVATE N_NIMCALL(NI64, getAlign__types_u3393)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p1);
N_LIB_PRIVATE N_NIMCALL(void, sigHash__sighashes_u522)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p0, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p1, tyArray__dnD8kjh6rJ1Yy5jHvid0Ow Result);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, opSlurp__vmdeps_u10)(NimStringV2 file_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module_p2, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p3);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, parseString__parser_u1772)(NimStringV2 s_p0, tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* cache_p1, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* config_p2, NimStringV2 filename_p3, NI line_p4, tyProc__urLEtt9bmeGdJpEukhLR9a1A errorHandler_p5);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___vm_u3895)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA msg_p2, NimStringV2 arg_p3, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, formatMsg__msgs_u1220)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA msg_p2, NimStringV2 arg_p3);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___vm_u3916)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA msg_p2, NimStringV2 arg_p3, void* ClE_0);
static N_INLINE(NimStringV2, toFileLineCol__msgs_u701)(tyTuple__kN8up2W6YKc5YA9avn5mV5w info_p0);
static N_INLINE(void, addInt__stdZprivateZdigitsutils_u204)(NimStringV2* result_p0, NI x_p1);
N_LIB_PRIVATE N_NIMCALL(void, addInt__stdZprivateZdigitsutils_u187)(NimStringV2* result_p0, NI64 x_p1);
N_LIB_PRIVATE N_NIMCALL(NI32, fileInfoIdx__msgs_u414)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 filename_p1);
N_LIB_PRIVATE N_NIMCALL(NI, cmpIgnoreStyle__idents_u18)(NCSTRING a_p0, NCSTRING b_p1, NI blen_p2);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___idents_u164)(tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA** dest_p0, tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* src_p1);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, opConv__vm_u731)(tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew* c_p0, tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A* dest_p1, tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A src_p2, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* desttyp_p3, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* srctyp_p4);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___systemZdollars_u54)(NU64 xX60gensym9__p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___system_u4728)(NF x_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___ast_u3699)(tySequence__9ahcSjIErJohSBBFLwuF56Q* dest_p0, tySequence__9ahcSjIErJohSBBFLwuF56Q src_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u3696)(tySequence__9ahcSjIErJohSBBFLwuF56Q dest_p0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, lt___int128_u404)(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg a_p0, tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg b_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg, toInt128__int128_u937)(NI64 arg_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg, firstOrd__types_u1182)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg, lastOrd__types_u1298)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p1);
N_LIB_PRIVATE N_NIMCALL(void, delSon__ast_u6724)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* father_p0, NI idx_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, newSym__ast_u4205)(tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q symKind_p0, tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* name_p1, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p2, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* owner_p3, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p4, tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ options_p5);
N_LIB_PRIVATE N_NIMCALL(NI64, getOrDefault__vm_u4335)(tyObject_Table__MsPmCuYz1KcEw6lr7P9cGkw t_p0, NimStringV2 key_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___modulegraphs_u14756)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw** dest_p0, tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* src_p1);
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___vm_u4773)(tyObject_Table__MsPmCuYz1KcEw6lr7P9cGkw* t_p0, NimStringV2 key_p1, NI64 val_p2);
N_LIB_PRIVATE N_NIMCALL(void, recordInc__macrocacheimpl_u27)(tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew* c_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, NimStringV2 key_p2, NI64 by_p3);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u14753)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* dest_p0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, contains__vm_u5937)(tyObject_Table__pI3mJh4Ap2XujSCfcSeUvQ t_p0, NimStringV2 key_p1);
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___vm_u6248)(tyObject_Table__pI3mJh4Ap2XujSCfcSeUvQ* t_p0, NimStringV2 key_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* val_p2);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ**, X5BX5D___vm_u7388)(tyObject_Table__pI3mJh4Ap2XujSCfcSeUvQ* t_p0, NimStringV2 key_p1);
N_LIB_PRIVATE N_NIMCALL(void, recordAdd__macrocacheimpl_u40)(tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew* c_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, NimStringV2 key_p2, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* val_p3);
N_LIB_PRIVATE N_NIMCALL(void, recordIncl__macrocacheimpl_u46)(tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew* c_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, NimStringV2 key_p2, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* val_p3);
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___vm_u8529)(tyObject_Table__1HJsK7ponJ4Vb1lJgVFVTQ* t_p0, NimStringV2 key_p1, tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw val_p2);
N_LIB_PRIVATE N_NIMCALL(void, initBTree__vm_u8410)(tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw* Result);
N_LIB_PRIVATE N_NIMCALL(void, add__vm_u10092)(tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw* b_p0, NimStringV2 key_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* val_p2);
N_LIB_PRIVATE N_NIMCALL(void, recordPut__macrocacheimpl_u33)(tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew* c_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, NimStringV2 key_p2, NimStringV2 k_p3, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* val_p4);
static N_INLINE(NI, len__vm_u11692)(tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw b_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, getOrDefault__vm_u12014)(tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw b_p0, NimStringV2 key_p1);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasNext__vm_u12373)(tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw b_p0, NI index_p1);
N_LIB_PRIVATE N_NIMCALL(void, next__vm_u12522)(tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw b_p0, NI index_p1, tyTuple__4wIKrvA4KpCWPy4McN64Pg* Result);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, newStrNode__ast_u5426)(NimStringV2 strVal_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___vm_u12834)(tyTuple__4wIKrvA4KpCWPy4McN64Pg dest_p0);
static N_INLINE(NIM_BOOL, hasElementType__ast_u5660)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p0);
static N_INLINE(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, skipModifier__ast_u5338)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* n_p0);
static N_INLINE(void, leave__vmprofiler_u1887)(tyObject_Profiler__YI4zs2CaXXndlYireD0I8A* prof_p0, tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew* c_p1);
N_LIB_PRIVATE N_NOINLINE(void, leaveImpl__vmprofiler_u41)(tyObject_Profiler__YI4zs2CaXXndlYireD0I8A* prof_p0, tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew* c_p1);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, cyclicTree__trees_u51)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, evalConstExprAux__vm_u14217)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module_p0, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p1, tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p2, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* prc_p3, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p4, tyEnum_TEvalMode__sQljSFf0fjnsNV1fpgXakg mode_p5);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, transformExpr__transf_u3516)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module_p2, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p3, tySet_tyEnum_TransformFlag__CzUOfRCXpoYcP43GAlt9cnA flags_p4);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___pureZcollectionsZintsets_u250)(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* dest_p0, tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* src_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___pureZcollectionsZintsets_u236)(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* dest_p0, tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* src_p1);
static N_INLINE(void, initIntSet__pureZcollectionsZintsets_u598)(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* Result);
N_LIB_PRIVATE N_NIMCALL(void, initPackedSet__pureZcollectionsZintsets_u37)(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* Result);
N_LIB_PRIVATE N_NIMCALL(NI, genExpr__vmgen_u3448)(tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, NIM_BOOL requiresValue_p2);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___pureZcollectionsZintsets_u227)(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___pureZcollectionsZintsets_u230)(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ*, eqdup___cgen_u30982)(tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ* src_p0, NIM_BOOL cyclic_p1);
N_LIB_PRIVATE N_NIMCALL(void, evalStmt__vm_u12990)(tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
N_LIB_PRIVATE N_NIMCALL(NI, genStmt__vmgen_u3440)(tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, execute__vm_u12939)(tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew* c_p0, NI start_p1);
static const struct {
  NI cap; NIM_CHAR data[30+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_2 = { 30 | NIM_STRLIT_FLAG, "macro instantiation too nested" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_3 = {30, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_2};
static const struct {
  NI cap; NIM_CHAR data[57+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_5 = { 57 | NIM_STRLIT_FLAG, "/home/runner/work/nightlies/nightlies/nim/compiler/vm.nim" };
static const struct {
  NI cap; NIM_CHAR data[48+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_6 = { 48 | NIM_STRLIT_FLAG, "in call \'$#\' got $#, but expected $# argument(s)" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_7 = {48, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_6};
N_LIB_PRIVATE TNimTypeV2 NTIv2__VDnIL6fWGTCjJE9c9cTQGKGw_;
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_10 = { 16 | NIM_STRLIT_FLAG, "stdlib.math.sqrt" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_11 = {16, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_10};
static const struct {
  NI cap; NIM_CHAR data[34+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_12 = { 34 | NIM_STRLIT_FLAG, "vmops.nim(75, 5) `a.numArgs == 1` " };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_13 = {34, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_12};
static const struct {
  NI cap; NIM_CHAR data[34+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_14 = { 34 | NIM_STRLIT_FLAG, "vmhooks.nim(50, 3) `i < a.rc - 1` " };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_15 = {34, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_14};
static const struct {
  NI cap; NIM_CHAR data[39+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_16 = { 39 | NIM_STRLIT_FLAG, "vmhooks.nim(55, 3) `p.kind == rkFloat` " };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_17 = {39, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_16};
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_19 = { 16 | NIM_STRLIT_FLAG, "stdlib.math.cbrt" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_20 = {16, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_19};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_21 = {34, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_12};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_23 = { 14 | NIM_STRLIT_FLAG, "stdlib.math.ln" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_24 = {14, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_23};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_25 = {34, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_12};
static const struct {
  NI cap; NIM_CHAR data[17+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_27 = { 17 | NIM_STRLIT_FLAG, "stdlib.math.log10" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_28 = {17, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_27};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_29 = {34, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_12};
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_31 = { 16 | NIM_STRLIT_FLAG, "stdlib.math.log2" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_32 = {16, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_31};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_33 = {34, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_12};
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_35 = { 15 | NIM_STRLIT_FLAG, "stdlib.math.exp" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_36 = {15, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_35};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_37 = {34, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_12};
static const struct {
  NI cap; NIM_CHAR data[18+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_39 = { 18 | NIM_STRLIT_FLAG, "stdlib.math.arccos" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_40 = {18, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_39};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_41 = {34, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_12};
static const struct {
  NI cap; NIM_CHAR data[18+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_43 = { 18 | NIM_STRLIT_FLAG, "stdlib.math.arcsin" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_44 = {18, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_43};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_45 = {34, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_12};
static const struct {
  NI cap; NIM_CHAR data[18+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_47 = { 18 | NIM_STRLIT_FLAG, "stdlib.math.arctan" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_48 = {18, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_47};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_49 = {34, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_12};
static const struct {
  NI cap; NIM_CHAR data[19+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_51 = { 19 | NIM_STRLIT_FLAG, "stdlib.math.arcsinh" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_52 = {19, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_51};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_53 = {34, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_12};
static const struct {
  NI cap; NIM_CHAR data[19+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_55 = { 19 | NIM_STRLIT_FLAG, "stdlib.math.arccosh" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_56 = {19, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_55};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_57 = {34, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_12};
static const struct {
  NI cap; NIM_CHAR data[19+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_59 = { 19 | NIM_STRLIT_FLAG, "stdlib.math.arctanh" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_60 = {19, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_59};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_61 = {34, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_12};
static const struct {
  NI cap; NIM_CHAR data[19+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_63 = { 19 | NIM_STRLIT_FLAG, "stdlib.math.arctan2" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_64 = {19, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_63};
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_66 = { 15 | NIM_STRLIT_FLAG, "stdlib.math.cos" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_67 = {15, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_66};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_68 = {34, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_12};
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_70 = { 16 | NIM_STRLIT_FLAG, "stdlib.math.cosh" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_71 = {16, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_70};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_72 = {34, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_12};
static const struct {
  NI cap; NIM_CHAR data[17+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_74 = { 17 | NIM_STRLIT_FLAG, "stdlib.math.hypot" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_75 = {17, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_74};
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_77 = { 16 | NIM_STRLIT_FLAG, "stdlib.math.sinh" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_78 = {16, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_77};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_79 = {34, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_12};
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_81 = { 15 | NIM_STRLIT_FLAG, "stdlib.math.sin" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_82 = {15, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_81};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_83 = {34, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_12};
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_85 = { 15 | NIM_STRLIT_FLAG, "stdlib.math.tan" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_86 = {15, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_85};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_87 = {34, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_12};
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_89 = { 16 | NIM_STRLIT_FLAG, "stdlib.math.tanh" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_90 = {16, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_89};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_91 = {34, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_12};
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_93 = { 15 | NIM_STRLIT_FLAG, "stdlib.math.pow" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_94 = {15, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_93};
static const struct {
  NI cap; NIM_CHAR data[17+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_96 = { 17 | NIM_STRLIT_FLAG, "stdlib.math.trunc" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_97 = {17, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_96};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_98 = {34, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_12};
static const struct {
  NI cap; NIM_CHAR data[17+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_100 = { 17 | NIM_STRLIT_FLAG, "stdlib.math.floor" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_101 = {17, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_100};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_102 = {34, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_12};
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_104 = { 16 | NIM_STRLIT_FLAG, "stdlib.math.ceil" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_105 = {16, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_104};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_106 = {34, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_12};
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_108 = { 15 | NIM_STRLIT_FLAG, "stdlib.math.erf" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_109 = {15, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_108};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_110 = {34, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_12};
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_112 = { 16 | NIM_STRLIT_FLAG, "stdlib.math.erfc" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_113 = {16, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_112};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_114 = {34, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_12};
static const struct {
  NI cap; NIM_CHAR data[17+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_116 = { 17 | NIM_STRLIT_FLAG, "stdlib.math.gamma" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_117 = {17, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_116};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_118 = {34, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_12};
static const struct {
  NI cap; NIM_CHAR data[18+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_120 = { 18 | NIM_STRLIT_FLAG, "stdlib.math.lgamma" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_121 = {18, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_120};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_122 = {34, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_12};
static const struct {
  NI cap; NIM_CHAR data[18+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_124 = { 18 | NIM_STRLIT_FLAG, "stdlib.math.divmod" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_125 = {18, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_124};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_126 = {34, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_14};
static const struct {
  NI cap; NIM_CHAR data[37+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_127 = { 37 | NIM_STRLIT_FLAG, "vmhooks.nim(55, 3) `p.kind == rkInt` " };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_128 = {37, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_127};
static const struct {
  NI cap; NIM_CHAR data[20+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_130 = { 20 | NIM_STRLIT_FLAG, "stdlib.math.copySign" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_131 = {20, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_130};
static const struct {
  NI cap; NIM_CHAR data[19+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_133 = { 19 | NIM_STRLIT_FLAG, "stdlib.math.signbit" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_134 = {19, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_133};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_135 = {34, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_12};
static const struct {
  NI cap; NIM_CHAR data[17+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_137 = { 17 | NIM_STRLIT_FLAG, "stdlib.math.round" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_138 = {17, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_137};
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_140 = { 15 | NIM_STRLIT_FLAG, "stdlib.math.mod" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_141 = {15, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_140};
static const struct {
  NI cap; NIM_CHAR data[21+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_143 = { 21 | NIM_STRLIT_FLAG, "stdlib.envvars.getEnv" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_144 = {21, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_143};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_145 = {34, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_14};
static const struct {
  NI cap; NIM_CHAR data[38+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_146 = { 38 | NIM_STRLIT_FLAG, "vmhooks.nim(55, 3) `p.kind == rkNode` " };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_147 = {38, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_146};
static const struct {
  NI cap; NIM_CHAR data[24+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_149 = { 24 | NIM_STRLIT_FLAG, "stdlib.envvars.existsEnv" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_150 = {24, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_149};
static const struct {
  NI cap; NIM_CHAR data[21+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_152 = { 21 | NIM_STRLIT_FLAG, "stdlib.envvars.putEnv" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_153 = {21, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_152};
static const struct {
  NI cap; NIM_CHAR data[21+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_155 = { 21 | NIM_STRLIT_FLAG, "stdlib.envvars.delEnv" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_156 = {21, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_155};
static const struct {
  NI cap; NIM_CHAR data[25+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_158 = { 25 | NIM_STRLIT_FLAG, "stdlib.oscommon.dirExists" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_159 = {25, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_158};
static const struct {
  NI cap; NIM_CHAR data[26+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_161 = { 26 | NIM_STRLIT_FLAG, "stdlib.oscommon.fileExists" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_162 = {26, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_161};
static const struct {
  NI cap; NIM_CHAR data[23+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_164 = { 23 | NIM_STRLIT_FLAG, "stdlib.syncio.writeFile" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_165 = {23, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_164};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_167 = {23, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_164};
static const struct {
  NI cap; NIM_CHAR data[23+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_169 = { 23 | NIM_STRLIT_FLAG, "stdlib.osdirs.createDir" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_170 = {23, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_169};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_172 = {23, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_169};
static const struct {
  NI cap; NIM_CHAR data[22+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_174 = { 22 | NIM_STRLIT_FLAG, "stdlib.syncio.readFile" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_175 = {22, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_174};
static const struct {
  NI cap; NIM_CHAR data[23+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_177 = { 23 | NIM_STRLIT_FLAG, "stdlib.syncio.readLines" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_178 = {23, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_177};
static const struct {
  NI cap; NIM_CHAR data[36+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_180 = { 36 | NIM_STRLIT_FLAG, "stdlib.system.getCurrentExceptionMsg" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_181 = {36, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_180};
static const struct {
  NI cap; NIM_CHAR data[0+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_182 = { 0 | NIM_STRLIT_FLAG, "" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_183 = {0, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_182};
static const struct {
  NI cap; NIM_CHAR data[33+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_185 = { 33 | NIM_STRLIT_FLAG, "stdlib.system.getCurrentException" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_186 = {33, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_185};
static const struct {
  NI cap; NIM_CHAR data[25+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_188 = { 25 | NIM_STRLIT_FLAG, "stdlib.system.raiseDefect" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_189 = {25, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_188};
static const struct {
  NI cap; NIM_CHAR data[29+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_191 = { 29 | NIM_STRLIT_FLAG, "stdlib.staticos.staticWalkDir" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_192 = {29, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_191};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_193 = { 1 | NIM_STRLIT_FLAG, "." };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_194 = {1, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_193};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_195 = { 2 | NIM_STRLIT_FLAG, ".." };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_196 = {2, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_195};
static const struct {
  NI cap; NIM_CHAR data[31+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_198 = { 31 | NIM_STRLIT_FLAG, "stdlib.staticos.staticDirExists" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_199 = {31, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_198};
static const struct {
  NI cap; NIM_CHAR data[32+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_201 = { 32 | NIM_STRLIT_FLAG, "stdlib.staticos.staticFileExists" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_202 = {32, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_201};
static const struct {
  NI cap; NIM_CHAR data[35+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_204 = { 35 | NIM_STRLIT_FLAG, "stdlib.compilesettings.querySetting" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_205 = {35, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_204};
static const struct {
  NI cap; NIM_CHAR data[38+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_206 = { 38 | NIM_STRLIT_FLAG, "stdlib.compilesettings.querySettingSeq" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_207 = {38, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_206};
static const struct {
  NI cap; NIM_CHAR data[21+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_208 = { 21 | NIM_STRLIT_FLAG, "stdlib.system.gorgeEx" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_209 = {21, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_208};
static const struct {
  NI cap; NIM_CHAR data[28+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_210 = { 28 | NIM_STRLIT_FLAG, "stdlib.macros.getProjectPath" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_211 = {28, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_210};
static const struct {
  NI cap; NIM_CHAR data[31+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_212 = { 31 | NIM_STRLIT_FLAG, "stdlib.os.getCurrentCompilerExe" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_213 = {31, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_212};
static const struct {
  NI cap; NIM_CHAR data[25+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_215 = { 25 | NIM_STRLIT_FLAG, "stdlib.macros.symBodyHash" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_216 = {25, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_215};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_217 = {34, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_14};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_218 = {38, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_146};
static const struct {
  NI cap; NIM_CHAR data[36+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_219 = { 36 | NIM_STRLIT_FLAG, "stack trace: (most recent call last)" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_220 = {36, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_219};
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_221 = { 15 | NIM_STRLIT_FLAG, " calls omitted\012" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_222 = {15, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_221};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_223 = {0, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_182};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_224 = { 12 | NIM_STRLIT_FLAG, "command line" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_225 = {12, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_224};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_226 = { 3 | NIM_STRLIT_FLAG, "\?\?\?" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_227 = {3, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_226};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_228 = { 2 | NIM_STRLIT_FLAG, ", " };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_229 = {2, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_228};
static const struct {
  NI cap; NIM_CHAR data[53+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_231 = { 53 | NIM_STRLIT_FLAG, "symBodyHash() requires a symbol. \'$#\' is of kind \'$#\'" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_232 = {53, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_231};
static const struct {
  NI cap; NIM_CHAR data[24+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_233 = { 24 | NIM_STRLIT_FLAG, "stdlib.macros.isExported" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_234 = {24, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_233};
static const struct {
  NI cap; NIM_CHAR data[52+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_235 = { 52 | NIM_STRLIT_FLAG, "isExported() requires a symbol. \'$#\' is of kind \'$#\'" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_236 = {52, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_235};
static const struct {
  NI cap; NIM_CHAR data[24+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_237 = { 24 | NIM_STRLIT_FLAG, "stdlib.macrocache.hasKey" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_238 = {24, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_237};
static const struct {
  NI cap; NIM_CHAR data[22+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_239 = { 22 | NIM_STRLIT_FLAG, "stdlib.vmutils.vmTrace" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_240 = {22, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_239};
static const struct {
  NI cap; NIM_CHAR data[24+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_241 = { 24 | NIM_STRLIT_FLAG, "stdlib.hashes.hashVmImpl" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_242 = {24, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_241};
static const struct {
  NI cap; NIM_CHAR data[28+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_243 = { 28 | NIM_STRLIT_FLAG, "stdlib.hashes.hashVmImplByte" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_244 = {28, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_243};
static const struct {
  NI cap; NIM_CHAR data[28+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_245 = { 28 | NIM_STRLIT_FLAG, "stdlib.hashes.hashVmImplChar" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_246 = {28, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_245};
static const struct {
  NI cap; NIM_CHAR data[25+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_247 = { 25 | NIM_STRLIT_FLAG, "stdlib.system.ltCStringVm" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_248 = {25, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_247};
static const struct {
  NI cap; NIM_CHAR data[25+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_250 = { 25 | NIM_STRLIT_FLAG, "stdlib.system.leCStringVm" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_251 = {25, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_250};
static const struct {
  NI cap; NIM_CHAR data[20+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_253 = { 20 | NIM_STRLIT_FLAG, "stdlib.times.cpuTime" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_254 = {20, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_253};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_256 = {20, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_253};
static const struct {
  NI cap; NIM_CHAR data[29+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_258 = { 29 | NIM_STRLIT_FLAG, "stdlib.ospaths2.getCurrentDir" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_259 = {29, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_258};
static const struct {
  NI cap; NIM_CHAR data[23+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_261 = { 23 | NIM_STRLIT_FLAG, "stdlib.osproc.execCmdEx" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_262 = {23, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_261};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_263 = {0, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_182};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_264 = {0, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_182};
static const struct {
  NI cap; NIM_CHAR data[24+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_266 = { 24 | NIM_STRLIT_FLAG, "stdlib.times.getTimeImpl" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_267 = {24, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_266};
static const struct {
  NI cap; NIM_CHAR data[37+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_268 = { 37 | NIM_STRLIT_FLAG, "stdlib.effecttraits.getRaisesListImpl" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_269 = {37, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_268};
static NIM_CONST tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg TM__pyAIA9cUF0h9c4j2HfNQPfYw_270 = {
0x00, 0x00, 0x40, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00}
;
static const struct {
  NI cap; NIM_CHAR data[17+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_271 = { 17 | NIM_STRLIT_FLAG, "UncomputedEffects" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_272 = {17, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_271};
static const struct {
  NI cap; NIM_CHAR data[35+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_273 = { 35 | NIM_STRLIT_FLAG, "stdlib.effecttraits.getTagsListImpl" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_274 = {35, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_273};
static const struct {
  NI cap; NIM_CHAR data[38+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_275 = { 38 | NIM_STRLIT_FLAG, "stdlib.effecttraits.getForbidsListImpl" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_276 = {38, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_275};
static const struct {
  NI cap; NIM_CHAR data[32+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_277 = { 32 | NIM_STRLIT_FLAG, "stdlib.effecttraits.isGcSafeImpl" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_278 = {32, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_277};
static const struct {
  NI cap; NIM_CHAR data[40+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_280 = { 40 | NIM_STRLIT_FLAG, "stdlib.effecttraits.hasNoSideEffectsImpl" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_281 = {40, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_280};
static const struct {
  NI cap; NIM_CHAR data[32+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_283 = { 32 | NIM_STRLIT_FLAG, "stdlib.typetraits.hasClosureImpl" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_284 = {32, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_283};
static const struct {
  NI cap; NIM_CHAR data[36+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_286 = { 36 | NIM_STRLIT_FLAG, "stdlib.formatfloat.addFloatRoundtrip" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_287 = {36, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_286};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_288 = {34, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_14};
static const struct {
  NI cap; NIM_CHAR data[34+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_290 = { 34 | NIM_STRLIT_FLAG, "stdlib.formatfloat.addFloatSprintf" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_291 = {34, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_290};
static const struct {
  NI cap; NIM_CHAR data[34+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_293 = { 34 | NIM_STRLIT_FLAG, "stdlib.strutils.formatBiggestFloat" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_294 = {34, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_293};
static const struct {
  NI cap; NIM_CHAR data[30+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_296 = { 30 | NIM_STRLIT_FLAG, "stdlib.envvars.envPairsImplSeq" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_297 = {30, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_296};
static const struct {
  NI cap; NIM_CHAR data[19+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_299 = { 19 | NIM_STRLIT_FLAG, "stdlib.marshal.toVM" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_300 = {19, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_299};
static const struct {
  NI cap; NIM_CHAR data[21+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_301 = { 21 | NIM_STRLIT_FLAG, "stdlib.marshal.loadVM" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_302 = {21, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_301};
static const struct {
  NI cap; NIM_CHAR data[34+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_303 = { 34 | NIM_STRLIT_FLAG, "vmhooks.nim(50, 3) `1 < a.rc - 1` " };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_304 = {34, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_303};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_305 = {0, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_182};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_306 = { 9 | NIM_STRLIT_FLAG, "expected " };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_307 = {9, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_306};
static const struct {
  NI cap; NIM_CHAR data[21+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_308 = { 21 | NIM_STRLIT_FLAG, " generic parameter(s)" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_309 = {21, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_308};
N_LIB_PRIVATE TNimTypeV2 NTIv2__hNEyCf8VhTK2S3ZJXhlD9cg_;
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_312 = { 10 | NIM_STRLIT_FLAG, "$# [$#] $#" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_313 = {10, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_312};
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_314 = { 16 | NIM_STRLIT_FLAG, "opcAsgnInt: got " };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_315 = {16, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_314};
static const struct {
  NI cap; NIM_CHAR data[21+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_316 = { 21 | NIM_STRLIT_FLAG, "opcCastPtrToInt: got " };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_317 = {21, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_316};
static const struct {
  NI cap; NIM_CHAR data[36+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_318 = { 36 | NIM_STRLIT_FLAG, "opcCastIntToPtr: regs[rb].node.typ: " };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_319 = {36, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_318};
static const struct {
  NI cap; NIM_CHAR data[32+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_320 = { 32 | NIM_STRLIT_FLAG, "opcCastIntToPtr: regs[rb].kind: " };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_321 = {32, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_320};
static const struct {
  NI cap; NIM_CHAR data[31+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_322 = { 31 | NIM_STRLIT_FLAG, "attempt to access a nil address" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_323 = {31, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_322};
static const struct {
  NI cap; NIM_CHAR data[43+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_324 = { 43 | NIM_STRLIT_FLAG, "index out of bounds, the container is empty" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_325 = {43, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_324};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_326 = { 6 | NIM_STRLIT_FLAG, "index " };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_327 = {6, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_326};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_328 = { 13 | NIM_STRLIT_FLAG, " not in 0 .. " };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_329 = {13, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_328};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_330 = {43, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_324};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_331 = {6, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_326};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_332 = {13, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_328};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_335 = {43, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_324};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_336 = {6, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_326};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_337 = {13, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_328};
static const struct {
  NI cap; NIM_CHAR data[23+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_338 = { 23 | NIM_STRLIT_FLAG, "opcLdArr internal error" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_339 = {23, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_338};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_340 = {43, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_324};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_341 = {6, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_326};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_342 = {13, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_328};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_343 = {43, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_324};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_344 = {6, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_326};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_345 = {13, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_328};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_346 = {43, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_324};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_347 = {6, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_326};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_348 = {13, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_328};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_349 = {43, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_324};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_350 = {6, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_326};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_351 = {13, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_328};
static const struct {
  NI cap; NIM_CHAR data[27+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_352 = { 27 | NIM_STRLIT_FLAG, "opcLdArrAddr internal error" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_353 = {27, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_352};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_354 = {43, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_324};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_355 = {6, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_326};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_356 = {13, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_328};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_357 = {43, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_324};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_358 = {6, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_326};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_359 = {13, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_328};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_360 = {43, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_324};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_361 = {6, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_326};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_362 = {13, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_328};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_363 = {43, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_324};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_364 = {6, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_326};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_365 = {13, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_328};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_366 = {43, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_324};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_367 = {6, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_326};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_368 = {13, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_328};
static const struct {
  NI cap; NIM_CHAR data[23+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_369 = { 23 | NIM_STRLIT_FLAG, "opcWrArr internal error" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_370 = {23, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_369};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_371 = {43, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_324};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_372 = {6, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_326};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_373 = {13, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_328};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_374 = {43, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_324};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_375 = {6, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_326};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_376 = {13, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_328};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_377 = {43, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_324};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_378 = {6, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_326};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_379 = {13, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_328};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_380 = {31, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_322};
static const struct {
  NI cap; NIM_CHAR data[32+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_381 = { 32 | NIM_STRLIT_FLAG, "attempt to access a nil address " };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_382 = {32, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_381};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_383 = { 4 | NIM_STRLIT_FLAG, "kind" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_384 = {4, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_383};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_385 = { 3 | NIM_STRLIT_FLAG, "typ" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_386 = {3, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_385};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_387 = { 2 | NIM_STRLIT_FLAG, "rc" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_388 = {2, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_387};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_389 = {31, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_322};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_390 = {31, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_322};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_391 = {43, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_324};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_392 = {6, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_326};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_393 = {13, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_328};
static const struct {
  NI cap; NIM_CHAR data[41+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_394 = { 41 | NIM_STRLIT_FLAG, "limited VM support for \'addr\', got kind: " };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_395 = {41, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_394};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_396 = {31, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_322};
static const struct {
  NI cap; NIM_CHAR data[28+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_398 = { 28 | NIM_STRLIT_FLAG, "deref unsupported ptr type: " };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_399 = {28, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_398};
static const struct {
  NI cap; NIM_CHAR data[38+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_400 = { 38 | NIM_STRLIT_FLAG, "attempt to access a nil address kind: " };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_401 = {38, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_400};
static const struct {
  NI cap; NIM_CHAR data[25+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_402 = { 25 | NIM_STRLIT_FLAG, "opcWrDeref internal error" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_403 = {25, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_402};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_404 = {31, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_322};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_406 = {28, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_398};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_407 = {31, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_322};
static const struct {
  NI cap; NIM_CHAR data[18+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_408 = { 18 | NIM_STRLIT_FLAG, "over- or underflow" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_409 = {18, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_408};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_410 = {18, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_408};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_411 = {18, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_408};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_412 = {18, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_408};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_413 = {18, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_408};
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_414 = { 16 | NIM_STRLIT_FLAG, "division by zero" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_415 = {16, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_414};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_416 = {16, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_414};
static NIM_CONST tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg TM__pyAIA9cUF0h9c4j2HfNQPfYw_417 = {
0x10, 0xa9, 0x00, 0x00, 0x00, 0x60, 0x80, 0x00,
0x00}
;
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_418 = {18, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_408};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_419 = {31, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_322};
static const struct {
  NI cap; NIM_CHAR data[20+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_420 = { 20 | NIM_STRLIT_FLAG, "node is not a symbol" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_421 = {20, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_420};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_422 = {20, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_420};
static const struct {
  NI cap; NIM_CHAR data[25+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_423 = { 25 | NIM_STRLIT_FLAG, "node is not a proc symbol" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_424 = {25, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_423};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_425 = {0, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_182};
static const struct {
  NI cap; NIM_CHAR data[44+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_426 = { 44 | NIM_STRLIT_FLAG, "opcParseFloat: Incorrectly created openarray" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_427 = {44, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_426};
static const struct {
  NI cap; NIM_CHAR data[36+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_429 = { 36 | NIM_STRLIT_FLAG, "illegal conversion from \'$1\' to \'$2\'" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_430 = {36, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_429};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_431 = { 1 | NIM_STRLIT_FLAG, "[" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_432 = {1, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_431};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_433 = {2, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_195};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_434 = { 1 | NIM_STRLIT_FLAG, "]" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_435 = {1, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_434};
static const struct {
  NI cap; NIM_CHAR data[27+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_436 = { 27 | NIM_STRLIT_FLAG, "attempt to call nil closure" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_437 = {27, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_436};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_438 = {27, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_436};
static const struct {
  NI cap; NIM_CHAR data[46+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_440 = { 46 | NIM_STRLIT_FLAG, "VM not allowed to do FFI, see `compiletimeFFI`" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_441 = {46, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_440};
static const struct {
  NI cap; NIM_CHAR data[29+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_443 = { 29 | NIM_STRLIT_FLAG, "VM not built with FFI support" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_444 = {29, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_443};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_446 = {36, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_219};
static const struct {
  NI cap; NIM_CHAR data[156+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_447 = { 156 | NIM_STRLIT_FLAG, "interpretation requires too many iterations; if you are sure this is not a bug in your code, compile with `--maxLoopIterationsVM:number` (current value: $1)" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_448 = {156, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_447};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_450 = {36, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_219};
static const struct {
  NI cap; NIM_CHAR data[146+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_451 = { 146 | NIM_STRLIT_FLAG, "maximum call depth for the VM exceeded; if you are sure this is not a bug in your code, compile with `--maxCallDepthVM:number` (current value: $1)" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_452 = {146, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_451};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_454 = {36, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_219};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_455 = {156, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_447};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_456 = { 11 | NIM_STRLIT_FLAG, "unreachable" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_457 = {11, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_456};
static const struct {
  NI cap; NIM_CHAR data[31+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_458 = { 31 | NIM_STRLIT_FLAG, "vm.nim(1541, 15) `savedPC < 0` " };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_459 = {31, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_458};
static NIM_CONST tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg TM__pyAIA9cUF0h9c4j2HfNQPfYw_460 = {
0x10, 0xa9, 0xe0, 0x00, 0x00, 0xe0, 0x80, 0x00,
0x00}
;
static const struct {
  NI cap; NIM_CHAR data[21+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_461 = { 21 | NIM_STRLIT_FLAG, "unhandled exception: " };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_462 = {21, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_461};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_463 = { 2 | NIM_STRLIT_FLAG, " [" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_464 = {2, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_463};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_465 = {1, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_434};
static NIM_CONST tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg TM__pyAIA9cUF0h9c4j2HfNQPfYw_466 = {
0x10, 0xa8, 0x10, 0x00, 0x00, 0x60, 0x80, 0x00,
0x00}
;
static const struct {
  NI cap; NIM_CHAR data[40+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_467 = { 40 | NIM_STRLIT_FLAG, "vm.nim(1664, 7) `node.kind == nkIntLit` " };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_468 = {40, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_467};
static const struct {
  NI cap; NIM_CHAR data[29+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_469 = { 29 | NIM_STRLIT_FLAG, "opcLdDeref unsupported type: " };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_470 = {29, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_469};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_471 = {0, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_182};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_473 = { 1 | NIM_STRLIT_FLAG, "\'" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_474 = {1, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_473};
static NIM_CONST tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg TM__pyAIA9cUF0h9c4j2HfNQPfYw_475 = {
0x00, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00}
;
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_476 = {31, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_322};
static const struct {
  NI cap; NIM_CHAR data[39+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_477 = { 39 | NIM_STRLIT_FLAG, "unhandled exception: value out of range" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_478 = {39, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_477};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_479 = {39, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_477};
static const struct {
  NI cap; NIM_CHAR data[32+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_481 = { 32 | NIM_STRLIT_FLAG, "cannot get child of node kind: n" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_482 = {32, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_481};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_483 = {43, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_324};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_484 = {6, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_326};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_485 = {13, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_328};
static const struct {
  NI cap; NIM_CHAR data[37+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_486 = { 37 | NIM_STRLIT_FLAG, "typechecked nodes may not be modified" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_487 = {37, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_486};
static const struct {
  NI cap; NIM_CHAR data[32+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_488 = { 32 | NIM_STRLIT_FLAG, "cannot set child of node kind: n" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_489 = {32, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_488};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_490 = {43, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_324};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_491 = {6, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_326};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_492 = {13, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_328};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_493 = {37, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_486};
static const struct {
  NI cap; NIM_CHAR data[26+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_494 = { 26 | NIM_STRLIT_FLAG, "cannot add to node kind: n" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_495 = {26, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_494};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_496 = {37, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_486};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_497 = {26, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_494};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_498 = {20, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_420};
static const struct {
  NI cap; NIM_CHAR data[24+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_499 = { 24 | NIM_STRLIT_FLAG, "node lacks field: intVal" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_500 = {24, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_499};
static const struct {
  NI cap; NIM_CHAR data[26+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_501 = { 26 | NIM_STRLIT_FLAG, "node lacks field: floatVal" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_502 = {26, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_501};
static const struct {
  NI cap; NIM_CHAR data[24+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_503 = { 24 | NIM_STRLIT_FLAG, "node lacks field: symbol" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_504 = {24, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_503};
static const struct {
  NI cap; NIM_CHAR data[23+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_505 = { 23 | NIM_STRLIT_FLAG, "node lacks field: ident" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_506 = {23, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_505};
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_507 = { 16 | NIM_STRLIT_FLAG, "node has no type" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_508 = {16, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_507};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_509 = {16, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_507};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_510 = {16, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_507};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_511 = {16, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_507};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_512 = {16, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_507};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_513 = {16, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_507};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_514 = {20, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_420};
static const struct {
  NI cap; NIM_CHAR data[32+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_515 = { 32 | NIM_STRLIT_FLAG, "symbol is not a field (nskField)" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_516 = {32, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_515};
static const struct {
  NI cap; NIM_CHAR data[24+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_517 = { 24 | NIM_STRLIT_FLAG, "node lacks field: strVal" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_518 = {24, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_517};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_519 = {20, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_420};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_520 = {0, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_182};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_523 = {0, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_182};
static const struct {
  NI cap; NIM_CHAR data[48+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_524 = { 48 | NIM_STRLIT_FLAG, "expected expression, but got multiple statements" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_525 = {48, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_524};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_526 = {0, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_182};
static const struct {
  NI cap; NIM_CHAR data[26+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_527 = { 26 | NIM_STRLIT_FLAG, "node lacks field: callsite" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_528 = {26, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_527};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_529 = {0, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_182};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_530 = { 1 | NIM_STRLIT_FLAG, "(" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_531 = {1, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_530};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_532 = {2, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_228};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_533 = { 1 | NIM_STRLIT_FLAG, ")" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_534 = {1, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_533};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_536 = {24, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_517};
static NIM_CONST tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg TM__pyAIA9cUF0h9c4j2HfNQPfYw_537 = {
0x10, 0xa9, 0x10, 0x00, 0x00, 0x60, 0x80, 0x00,
0x00}
;
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_538 = { 15 | NIM_STRLIT_FLAG, "opConv for enum" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_539 = {15, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_538};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_541 = { 1 | NIM_STRLIT_FLAG, " " };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_542 = {1, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_541};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_543 = { 5 | NIM_STRLIT_FLAG, "false" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_544 = {5, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_543};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_545 = { 4 | NIM_STRLIT_FLAG, "true" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_546 = {4, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_545};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_547 = {0, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_182};
static const struct {
  NI cap; NIM_CHAR data[25+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_548 = { 25 | NIM_STRLIT_FLAG, "cannot convert to string " };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_549 = {25, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_548};
static NIM_CONST tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg TM__pyAIA9cUF0h9c4j2HfNQPfYw_551 = {
0x10, 0xa9, 0x90, 0x00, 0x00, 0x60, 0x80, 0x00,
0x00}
;
static const struct {
  NI cap; NIM_CHAR data[35+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_552 = { 35 | NIM_STRLIT_FLAG, "invalid object-to-object conversion" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_553 = {35, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_552};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_555 = {36, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_429};
static const struct {
  NI cap; NIM_CHAR data[20+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_556 = { 20 | NIM_STRLIT_FLAG, "cannot evaluate cast" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_557 = {20, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_556};
static const struct {
  NI cap; NIM_CHAR data[46+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_559 = { 46 | NIM_STRLIT_FLAG, "`intVal` cannot be changed for an enum symbol." };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_560 = {46, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_559};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_561 = {24, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_499};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_562 = {26, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_501};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_563 = {24, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_503};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_564 = {23, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_505};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_565 = {24, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_517};
static const struct {
  NI cap; NIM_CHAR data[43+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_566 = { 43 | NIM_STRLIT_FLAG, "request to create a NimNode of invalid kind" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_567 = {43, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_566};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_569 = { 4 | NIM_STRLIT_FLAG, ":tmp" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_570 = {4, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_569};
static const struct {
  NI cap; NIM_CHAR data[40+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_571 = { 40 | NIM_STRLIT_FLAG, "request to create symbol of invalid kind" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_572 = {40, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_571};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_574 = {43, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_324};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_575 = {6, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_326};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_576 = {13, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_328};
static const struct {
  NI cap; NIM_CHAR data[20+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_577 = { 20 | NIM_STRLIT_FLAG, "key already exists: " };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_578 = {20, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_577};
static const struct {
  NI cap; NIM_CHAR data[20+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_579 = { 20 | NIM_STRLIT_FLAG, "key does not exist: " };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_580 = {20, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_579};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_581 = {20, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_579};
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_582 = {20, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_579};
static const struct {
  NI cap; NIM_CHAR data[28+1];
} TM__pyAIA9cUF0h9c4j2HfNQPfYw_584 = { 28 | NIM_STRLIT_FLAG, "macro produced a cyclic tree" };
static const NimStringV2 TM__pyAIA9cUF0h9c4j2HfNQPfYw_585 = {28, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_584};
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__pyAIA9cUF0h9c4j2HfNQPfYw_4 = {{57, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_5},
((NI)2539),
((NI)15)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__pyAIA9cUF0h9c4j2HfNQPfYw_8 = {{57, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_5},
((NI)2545),
((NI)15)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__pyAIA9cUF0h9c4j2HfNQPfYw_230 = {{3, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_226},
((NI)0),
((NI)-1)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__pyAIA9cUF0h9c4j2HfNQPfYw_310 = {{57, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_5},
((NI)2584),
((NI)16)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__pyAIA9cUF0h9c4j2HfNQPfYw_397 = {{57, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_5},
((NI)951),
((NI)31)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__pyAIA9cUF0h9c4j2HfNQPfYw_405 = {{57, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_5},
((NI)975),
((NI)29)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__pyAIA9cUF0h9c4j2HfNQPfYw_428 = {{57, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_5},
((NI)1388),
((NI)23)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__pyAIA9cUF0h9c4j2HfNQPfYw_442 = {{57, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_5},
((NI)1420),
((NI)21)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__pyAIA9cUF0h9c4j2HfNQPfYw_445 = {{57, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_5},
((NI)1439),
((NI)21)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__pyAIA9cUF0h9c4j2HfNQPfYw_449 = {{57, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_5},
((NI)495),
((NI)17)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__pyAIA9cUF0h9c4j2HfNQPfYw_453 = {{57, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_5},
((NI)1468),
((NI)23)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__pyAIA9cUF0h9c4j2HfNQPfYw_472 = {{57, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_5},
((NI)1693),
((NI)15)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__pyAIA9cUF0h9c4j2HfNQPfYw_521 = {{57, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_5},
((NI)1984),
((NI)15)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__pyAIA9cUF0h9c4j2HfNQPfYw_522 = {{57, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_5},
((NI)1986),
((NI)15)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__pyAIA9cUF0h9c4j2HfNQPfYw_535 = {{57, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_5},
((NI)2036),
((NI)8)}
;
extern NIM_CONST tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA unknownLineInfo__lineinfos_u364;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__pyAIA9cUF0h9c4j2HfNQPfYw_540 = {{57, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_5},
((NI)397),
((NI)46)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__pyAIA9cUF0h9c4j2HfNQPfYw_550 = {{57, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_5},
((NI)427),
((NI)19)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__pyAIA9cUF0h9c4j2HfNQPfYw_554 = {{57, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_5},
((NI)477),
((NI)21)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__pyAIA9cUF0h9c4j2HfNQPfYw_558 = {{57, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_5},
((NI)2143),
((NI)19)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__pyAIA9cUF0h9c4j2HfNQPfYw_568 = {{57, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_5},
((NI)2190),
((NI)21)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__pyAIA9cUF0h9c4j2HfNQPfYw_573 = {{57, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_5},
((NI)2224),
((NI)21)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__pyAIA9cUF0h9c4j2HfNQPfYw_583 = {{57, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_5},
((NI)2336),
((NI)6)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__pyAIA9cUF0h9c4j2HfNQPfYw_586 = {{57, (NimStrPayload*)&TM__pyAIA9cUF0h9c4j2HfNQPfYw_5},
((NI)2590),
((NI)36)}
;
extern NIM_BOOL nimInErrorMode__system_u4141;
static NIM_CONST NU32 TM__pyAIA9cUF0h9c4j2HfNQPfYw_9[2] = {3701606400, 969420544};
N_LIB_PRIVATE TNimTypeV2 NTIv2__VDnIL6fWGTCjJE9c9cTQGKGw_ = {.destructor = (void*)rttiDestroy__vm_u14575, .size = sizeof(tyObject_Env_vmopsdotnim_registerAdditionalOps___VDnIL6fWGTCjJE9c9cTQGKGw), .align = (NI16) NIM_ALIGNOF(tyObject_Env_vmopsdotnim_registerAdditionalOps___VDnIL6fWGTCjJE9c9cTQGKGw), .depth = 1, .display = TM__pyAIA9cUF0h9c4j2HfNQPfYw_9, .traceImpl = (void*)eqtrace___vm_u14519, .flags = 0};
extern NCSTRING* environ;
static NIM_CONST NU32 TM__pyAIA9cUF0h9c4j2HfNQPfYw_311[2] = {3701606400, 3509717248};
N_LIB_PRIVATE TNimTypeV2 NTIv2__hNEyCf8VhTK2S3ZJXhlD9cg_ = {.destructor = (void*)rttiDestroy__vm_u15113, .size = sizeof(tyObject_Env_vmdotnim_rawExecute___hNEyCf8VhTK2S3ZJXhlD9cg), .align = (NI16) NIM_ALIGNOF(tyObject_Env_vmdotnim_rawExecute___hNEyCf8VhTK2S3ZJXhlD9cg), .depth = 1, .display = TM__pyAIA9cUF0h9c4j2HfNQPfYw_311, .traceImpl = (void*)eqtrace___vm_u14801, .flags = 0};
static N_INLINE(void, nimSetMem__system_u2172)(void* a_p0, int v_p1, NI size_p2) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a_p0, v_p1, ((size_t) (size_p2)));
}
static N_INLINE(void, nimZeroMem)(void* p_p0, NI size_p1) {
	nimSetMem__system_u2172(p_p0, ((int)0), size_p1);
}
static N_INLINE(NI, signatureLen__ast_u5610)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p0) {
	NI result;
	NI T1_;
	T1_ = (*t_p0).sons.len;
	result = T1_;
	return result;
}
static N_INLINE(NI, len__ast_u3190)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0) {
	NI result;
	NI T1_;
	T1_ = (*n_p0)._kind_6.sons.len;
	result = T1_;
	return result;
}
static N_INLINE(NIM_BOOL*, nimErrorFlag)(void) {
	NIM_BOOL* result;
	result = (&nimInErrorMode__system_u4141);
	return result;
}
static N_INLINE(NI, safeLen__ast_u3197)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0) {
	NI result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	{
		if (!((*n_p0).kind >= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)0) && (*n_p0).kind <= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)23))) goto LA3_;
		result = ((NI)0);
	}
	goto LA1_;
LA3_: ;
	{
		result = len__ast_u3190(n_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI, paramsLen__ast_u5616)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p0) {
	NI result;
	NI T1_;
	T1_ = (*t_p0).sons.len;
	result = (NI)(T1_ - ((NI)1));
	return result;
}
static N_INLINE(NI, minuspercent___system_u805)(NI x_p0, NI y_p1) {
	NI result;
	result = ((NI) ((NU)((NU32)(((NU) (x_p0))) - (NU32)(((NU) (y_p1))))));
	return result;
}
static N_INLINE(NIM_BOOL, nimDecRefIsLastCyclicDyn)(void* p_p0) {
	NIM_BOOL result;
	result = NIM_FALSE;
	{
		tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* cell_1;
		NI T5_;
		if (!!((p_p0 == NIM_NIL))) goto LA3_;
		T5_ = (NI)0;
		T5_ = minuspercent___system_u805(((NI) (ptrdiff_t) (p_p0)), ((NI)8));
		cell_1 = ((tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A*) (T5_));
		{
			if (!((NI)((*cell_1).rc & ((NI)-16)) == ((NI)0))) goto LA8_;
			result = NIM_TRUE;
		}
		goto LA6_;
LA8_: ;
		{
			(*cell_1).rc = minuspercent___system_u805((*cell_1).rc, ((NI)16));
		}
LA6_: ;
		rememberCycle__system_u3495(result, cell_1, (*((TNimTypeV2**) (p_p0))));
	}
LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___vm_u14507)(tyObject_Env_vmopsdotnim_registerAdditionalOps___VDnIL6fWGTCjJE9c9cTQGKGw* dest_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastCyclicDyn((*dest_p0).c0);
		if (!T3_) goto LA4_;
		nimDestroyAndDispose((*dest_p0).c0);
	}
LA4_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, rttiDestroy__vm_u14575)(void* dest_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqdestroy___vm_u14507((&(*((tyObject_Env_vmopsdotnim_registerAdditionalOps___VDnIL6fWGTCjJE9c9cTQGKGw*) (dest_p0)))));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(NI, pluspercent___system_u785)(NI x_p0, NI y_p1) {
	NI result;
	result = ((NI) ((NU)((NU32)(((NU) (x_p0))) + (NU32)(((NU) (y_p1))))));
	return result;
}
static N_INLINE(void, add__system_u3016)(tyObject_CellSeq__gW9aeWLFbrNaeUKXqxYBXhg* s_p0, void** c_p1, TNimTypeV2* t_p2) {
	void** colontmp_;
	TNimTypeV2* colontmp__2;
	{
		if (!((*s_p0).cap <= (*s_p0).len)) goto LA3_;
		resize__system_u3024(s_p0);
	}
LA3_: ;
	colontmp_ = c_p1;
	colontmp__2 = t_p2;
	(*s_p0).d[(*s_p0).len].Field0 = colontmp_;
	(*s_p0).d[(*s_p0).len].Field1 = colontmp__2;
	(*s_p0).len = pluspercent___system_u785((*s_p0).len, ((NI)1));
}
static N_INLINE(void, nimTraceRefDyn)(void* q_p0, void* env_p1) {
	void** p_1;
	p_1 = ((void**) (q_p0));
	{
		tyObject_GcEnv__HccVszwojlCZRN46BE9cG8w* j_1;
		if (!!(((*p_1) == NIM_NIL))) goto LA3_;
		j_1 = ((tyObject_GcEnv__HccVszwojlCZRN46BE9cG8w*) (env_p1));
		add__system_u3016((&(*j_1).traceStack), p_1, (*((TNimTypeV2**) ((*p_1)))));
	}
LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqtrace___vm_u14519)(tyObject_Env_vmopsdotnim_registerAdditionalOps___VDnIL6fWGTCjJE9c9cTQGKGw* dest_p0, void* env_p1) {
	nimTraceRefDyn(&(*dest_p0).c0, env_p1);
}
N_LIB_PRIVATE N_NIMCALL(NI, numArgs__vm_u279)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0) {
	NI result;
	result = (NI)((*a_p0).rc - ((NI)1));
	return result;
}
static N_INLINE(void, ensureKind__vm_u122)(tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A* n_p0, tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA k_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A T5_;
		if (!!(((*n_p0).kind == k_p1))) goto LA3_;
		nimZeroMem((void*)(&T5_), sizeof(tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A));
		nimZeroMem((void*)(&T5_), sizeof(tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A));
		T5_.kind = k_p1;
		eqsink___vmdef_u1715((&(*n_p0)), T5_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA3_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, setResult__vm_u242)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, NF v_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	ensureKind__vm_u122((&(*a_p0).slots[(*a_p0).ra]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)3));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*a_p0).slots[(*a_p0).ra].floatVal = v_p1;
	}BeforeRet_: ;
}
static N_INLINE(void, nimCopyMem)(void* dest_p0, void* source_p1, NI size_p2) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest_p0, source_p1, ((size_t) (size_p2)));
}
static N_INLINE(void, copyMem__system_u1742)(void* dest_p0, void* source_p1, NI size_p2) {
	nimCopyMem(dest_p0, source_p1, size_p2);
}
static N_INLINE(void, appendString)(NimStringV2* dest_p0, NimStringV2 src_p1) {
	{
		if (!(((NI)0) < src_p1.len)) goto LA3_;
		copyMem__system_u1742(((void*) ((&(*(*dest_p0).p).data[(*dest_p0).len]))), ((void*) ((&(*src_p1.p).data[((NI)0)]))), (src_p1.len));
		(*dest_p0).len += src_p1.len;
		(*(*dest_p0).p).data[(*dest_p0).len] = 0;
	}
LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(NF, getFloat__vm_u331)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, NI i_p1) {
	NF result;
	tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A* p_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NF)0;
	{
		if (!!((i_p1 < (NI)((*a_p0).rc - ((NI)1))))) goto LA3_;
		failedAssertImpl__stdZassertions_u79(TM__pyAIA9cUF0h9c4j2HfNQPfYw_15);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA3_: ;
	p_1 = (&(*a_p0).slots[(NI)((NI)(i_p1 + (*a_p0).rb) + ((NI)1))]);
	{
		NimStringV2 colontmpD_;
		NimStringV2 colontmpD__2;
		NimStringV2 T9_;
		if (!!(((*p_1).kind == ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)3)))) goto LA7_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		T9_.len = 0; T9_.p = NIM_NIL;
		colontmpD_ = dollar___vmdef_u304((*p_1).kind);
		T9_ = rawNewString(colontmpD_.len + 39);
appendString((&T9_), TM__pyAIA9cUF0h9c4j2HfNQPfYw_17);
appendString((&T9_), colontmpD_);
		colontmpD__2 = T9_;
		failedAssertImpl__stdZassertions_u79(colontmpD__2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(colontmpD_);
	}
LA7_: ;
	result = (*p_1).floatVal;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, sqrtWrapper__vm_u13311)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0) {
	NF T6_;
	NF T7_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NI T3_;
		T3_ = (NI)0;
		T3_ = numArgs__vm_u279(a_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T3_ == ((NI)1)))) goto LA4_;
		failedAssertImpl__stdZassertions_u79(TM__pyAIA9cUF0h9c4j2HfNQPfYw_13);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA4_: ;
	T6_ = (NF)0;
	T6_ = getFloat__vm_u331(a_p0, ((NI)0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T7_ = (NF)0;
	T7_ = sqrt(T6_);
	setResult__vm_u242(a_p0, T7_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, cbrtWrapper__vm_u13318)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0) {
	NF T6_;
	NF T7_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NI T3_;
		T3_ = (NI)0;
		T3_ = numArgs__vm_u279(a_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T3_ == ((NI)1)))) goto LA4_;
		failedAssertImpl__stdZassertions_u79(TM__pyAIA9cUF0h9c4j2HfNQPfYw_21);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA4_: ;
	T6_ = (NF)0;
	T6_ = getFloat__vm_u331(a_p0, ((NI)0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T7_ = (NF)0;
	T7_ = cbrt(T6_);
	setResult__vm_u242(a_p0, T7_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, lnWrapper__vm_u13325)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0) {
	NF T6_;
	NF T7_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NI T3_;
		T3_ = (NI)0;
		T3_ = numArgs__vm_u279(a_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T3_ == ((NI)1)))) goto LA4_;
		failedAssertImpl__stdZassertions_u79(TM__pyAIA9cUF0h9c4j2HfNQPfYw_25);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA4_: ;
	T6_ = (NF)0;
	T6_ = getFloat__vm_u331(a_p0, ((NI)0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T7_ = (NF)0;
	T7_ = log(T6_);
	setResult__vm_u242(a_p0, T7_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, log10Wrapper__vm_u13332)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0) {
	NF T6_;
	NF T7_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NI T3_;
		T3_ = (NI)0;
		T3_ = numArgs__vm_u279(a_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T3_ == ((NI)1)))) goto LA4_;
		failedAssertImpl__stdZassertions_u79(TM__pyAIA9cUF0h9c4j2HfNQPfYw_29);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA4_: ;
	T6_ = (NF)0;
	T6_ = getFloat__vm_u331(a_p0, ((NI)0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T7_ = (NF)0;
	T7_ = log10(T6_);
	setResult__vm_u242(a_p0, T7_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, log2Wrapper__vm_u13339)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0) {
	NF T6_;
	NF T7_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NI T3_;
		T3_ = (NI)0;
		T3_ = numArgs__vm_u279(a_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T3_ == ((NI)1)))) goto LA4_;
		failedAssertImpl__stdZassertions_u79(TM__pyAIA9cUF0h9c4j2HfNQPfYw_33);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA4_: ;
	T6_ = (NF)0;
	T6_ = getFloat__vm_u331(a_p0, ((NI)0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T7_ = (NF)0;
	T7_ = log2(T6_);
	setResult__vm_u242(a_p0, T7_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, expWrapper__vm_u13346)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0) {
	NF T6_;
	NF T7_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NI T3_;
		T3_ = (NI)0;
		T3_ = numArgs__vm_u279(a_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T3_ == ((NI)1)))) goto LA4_;
		failedAssertImpl__stdZassertions_u79(TM__pyAIA9cUF0h9c4j2HfNQPfYw_37);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA4_: ;
	T6_ = (NF)0;
	T6_ = getFloat__vm_u331(a_p0, ((NI)0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T7_ = (NF)0;
	T7_ = exp(T6_);
	setResult__vm_u242(a_p0, T7_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, arccosWrapper__vm_u13353)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0) {
	NF T6_;
	NF T7_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NI T3_;
		T3_ = (NI)0;
		T3_ = numArgs__vm_u279(a_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T3_ == ((NI)1)))) goto LA4_;
		failedAssertImpl__stdZassertions_u79(TM__pyAIA9cUF0h9c4j2HfNQPfYw_41);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA4_: ;
	T6_ = (NF)0;
	T6_ = getFloat__vm_u331(a_p0, ((NI)0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T7_ = (NF)0;
	T7_ = acos(T6_);
	setResult__vm_u242(a_p0, T7_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, arcsinWrapper__vm_u13360)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0) {
	NF T6_;
	NF T7_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NI T3_;
		T3_ = (NI)0;
		T3_ = numArgs__vm_u279(a_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T3_ == ((NI)1)))) goto LA4_;
		failedAssertImpl__stdZassertions_u79(TM__pyAIA9cUF0h9c4j2HfNQPfYw_45);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA4_: ;
	T6_ = (NF)0;
	T6_ = getFloat__vm_u331(a_p0, ((NI)0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T7_ = (NF)0;
	T7_ = asin(T6_);
	setResult__vm_u242(a_p0, T7_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, arctanWrapper__vm_u13367)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0) {
	NF T6_;
	NF T7_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NI T3_;
		T3_ = (NI)0;
		T3_ = numArgs__vm_u279(a_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T3_ == ((NI)1)))) goto LA4_;
		failedAssertImpl__stdZassertions_u79(TM__pyAIA9cUF0h9c4j2HfNQPfYw_49);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA4_: ;
	T6_ = (NF)0;
	T6_ = getFloat__vm_u331(a_p0, ((NI)0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T7_ = (NF)0;
	T7_ = atan(T6_);
	setResult__vm_u242(a_p0, T7_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, arcsinhWrapper__vm_u13374)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0) {
	NF T6_;
	NF T7_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NI T3_;
		T3_ = (NI)0;
		T3_ = numArgs__vm_u279(a_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T3_ == ((NI)1)))) goto LA4_;
		failedAssertImpl__stdZassertions_u79(TM__pyAIA9cUF0h9c4j2HfNQPfYw_53);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA4_: ;
	T6_ = (NF)0;
	T6_ = getFloat__vm_u331(a_p0, ((NI)0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T7_ = (NF)0;
	T7_ = asinh(T6_);
	setResult__vm_u242(a_p0, T7_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, arccoshWrapper__vm_u13381)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0) {
	NF T6_;
	NF T7_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NI T3_;
		T3_ = (NI)0;
		T3_ = numArgs__vm_u279(a_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T3_ == ((NI)1)))) goto LA4_;
		failedAssertImpl__stdZassertions_u79(TM__pyAIA9cUF0h9c4j2HfNQPfYw_57);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA4_: ;
	T6_ = (NF)0;
	T6_ = getFloat__vm_u331(a_p0, ((NI)0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T7_ = (NF)0;
	T7_ = acosh(T6_);
	setResult__vm_u242(a_p0, T7_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, arctanhWrapper__vm_u13388)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0) {
	NF T6_;
	NF T7_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NI T3_;
		T3_ = (NI)0;
		T3_ = numArgs__vm_u279(a_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T3_ == ((NI)1)))) goto LA4_;
		failedAssertImpl__stdZassertions_u79(TM__pyAIA9cUF0h9c4j2HfNQPfYw_61);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA4_: ;
	T6_ = (NF)0;
	T6_ = getFloat__vm_u331(a_p0, ((NI)0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T7_ = (NF)0;
	T7_ = atanh(T6_);
	setResult__vm_u242(a_p0, T7_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, arctan2Wrapper__vm_u13395)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0) {
	NF T1_;
	NF T2_;
	NF T3_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	T1_ = (NF)0;
	T1_ = getFloat__vm_u331(a_p0, ((NI)0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T2_ = (NF)0;
	T2_ = getFloat__vm_u331(a_p0, ((NI)1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T3_ = (NF)0;
	T3_ = atan2(T1_, T2_);
	setResult__vm_u242(a_p0, T3_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, cosWrapper__vm_u13397)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0) {
	NF T6_;
	NF T7_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NI T3_;
		T3_ = (NI)0;
		T3_ = numArgs__vm_u279(a_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T3_ == ((NI)1)))) goto LA4_;
		failedAssertImpl__stdZassertions_u79(TM__pyAIA9cUF0h9c4j2HfNQPfYw_68);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA4_: ;
	T6_ = (NF)0;
	T6_ = getFloat__vm_u331(a_p0, ((NI)0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T7_ = (NF)0;
	T7_ = cos(T6_);
	setResult__vm_u242(a_p0, T7_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, coshWrapper__vm_u13404)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0) {
	NF T6_;
	NF T7_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NI T3_;
		T3_ = (NI)0;
		T3_ = numArgs__vm_u279(a_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T3_ == ((NI)1)))) goto LA4_;
		failedAssertImpl__stdZassertions_u79(TM__pyAIA9cUF0h9c4j2HfNQPfYw_72);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA4_: ;
	T6_ = (NF)0;
	T6_ = getFloat__vm_u331(a_p0, ((NI)0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T7_ = (NF)0;
	T7_ = cosh(T6_);
	setResult__vm_u242(a_p0, T7_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, hypotWrapper__vm_u13411)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0) {
	NF T1_;
	NF T2_;
	NF T3_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	T1_ = (NF)0;
	T1_ = getFloat__vm_u331(a_p0, ((NI)0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T2_ = (NF)0;
	T2_ = getFloat__vm_u331(a_p0, ((NI)1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T3_ = (NF)0;
	T3_ = hypot(T1_, T2_);
	setResult__vm_u242(a_p0, T3_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, sinhWrapper__vm_u13413)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0) {
	NF T6_;
	NF T7_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NI T3_;
		T3_ = (NI)0;
		T3_ = numArgs__vm_u279(a_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T3_ == ((NI)1)))) goto LA4_;
		failedAssertImpl__stdZassertions_u79(TM__pyAIA9cUF0h9c4j2HfNQPfYw_79);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA4_: ;
	T6_ = (NF)0;
	T6_ = getFloat__vm_u331(a_p0, ((NI)0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T7_ = (NF)0;
	T7_ = sinh(T6_);
	setResult__vm_u242(a_p0, T7_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, sinWrapper__vm_u13420)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0) {
	NF T6_;
	NF T7_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NI T3_;
		T3_ = (NI)0;
		T3_ = numArgs__vm_u279(a_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T3_ == ((NI)1)))) goto LA4_;
		failedAssertImpl__stdZassertions_u79(TM__pyAIA9cUF0h9c4j2HfNQPfYw_83);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA4_: ;
	T6_ = (NF)0;
	T6_ = getFloat__vm_u331(a_p0, ((NI)0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T7_ = (NF)0;
	T7_ = sin(T6_);
	setResult__vm_u242(a_p0, T7_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, tanWrapper__vm_u13427)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0) {
	NF T6_;
	NF T7_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NI T3_;
		T3_ = (NI)0;
		T3_ = numArgs__vm_u279(a_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T3_ == ((NI)1)))) goto LA4_;
		failedAssertImpl__stdZassertions_u79(TM__pyAIA9cUF0h9c4j2HfNQPfYw_87);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA4_: ;
	T6_ = (NF)0;
	T6_ = getFloat__vm_u331(a_p0, ((NI)0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T7_ = (NF)0;
	T7_ = tan(T6_);
	setResult__vm_u242(a_p0, T7_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, tanhWrapper__vm_u13434)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0) {
	NF T6_;
	NF T7_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NI T3_;
		T3_ = (NI)0;
		T3_ = numArgs__vm_u279(a_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T3_ == ((NI)1)))) goto LA4_;
		failedAssertImpl__stdZassertions_u79(TM__pyAIA9cUF0h9c4j2HfNQPfYw_91);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA4_: ;
	T6_ = (NF)0;
	T6_ = getFloat__vm_u331(a_p0, ((NI)0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T7_ = (NF)0;
	T7_ = tanh(T6_);
	setResult__vm_u242(a_p0, T7_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, powWrapper__vm_u13441)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0) {
	NF T1_;
	NF T2_;
	NF T3_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	T1_ = (NF)0;
	T1_ = getFloat__vm_u331(a_p0, ((NI)0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T2_ = (NF)0;
	T2_ = getFloat__vm_u331(a_p0, ((NI)1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T3_ = (NF)0;
	T3_ = pow(T1_, T2_);
	setResult__vm_u242(a_p0, T3_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, truncWrapper__vm_u13443)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0) {
	NF T6_;
	NF T7_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NI T3_;
		T3_ = (NI)0;
		T3_ = numArgs__vm_u279(a_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T3_ == ((NI)1)))) goto LA4_;
		failedAssertImpl__stdZassertions_u79(TM__pyAIA9cUF0h9c4j2HfNQPfYw_98);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA4_: ;
	T6_ = (NF)0;
	T6_ = getFloat__vm_u331(a_p0, ((NI)0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T7_ = (NF)0;
	T7_ = trunc(T6_);
	setResult__vm_u242(a_p0, T7_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, floorWrapper__vm_u13450)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0) {
	NF T6_;
	NF T7_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NI T3_;
		T3_ = (NI)0;
		T3_ = numArgs__vm_u279(a_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T3_ == ((NI)1)))) goto LA4_;
		failedAssertImpl__stdZassertions_u79(TM__pyAIA9cUF0h9c4j2HfNQPfYw_102);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA4_: ;
	T6_ = (NF)0;
	T6_ = getFloat__vm_u331(a_p0, ((NI)0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T7_ = (NF)0;
	T7_ = floor(T6_);
	setResult__vm_u242(a_p0, T7_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, ceilWrapper__vm_u13457)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0) {
	NF T6_;
	NF T7_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NI T3_;
		T3_ = (NI)0;
		T3_ = numArgs__vm_u279(a_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T3_ == ((NI)1)))) goto LA4_;
		failedAssertImpl__stdZassertions_u79(TM__pyAIA9cUF0h9c4j2HfNQPfYw_106);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA4_: ;
	T6_ = (NF)0;
	T6_ = getFloat__vm_u331(a_p0, ((NI)0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T7_ = (NF)0;
	T7_ = ceil(T6_);
	setResult__vm_u242(a_p0, T7_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, erfWrapper__vm_u13464)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0) {
	NF T6_;
	NF T7_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NI T3_;
		T3_ = (NI)0;
		T3_ = numArgs__vm_u279(a_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T3_ == ((NI)1)))) goto LA4_;
		failedAssertImpl__stdZassertions_u79(TM__pyAIA9cUF0h9c4j2HfNQPfYw_110);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA4_: ;
	T6_ = (NF)0;
	T6_ = getFloat__vm_u331(a_p0, ((NI)0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T7_ = (NF)0;
	T7_ = erf(T6_);
	setResult__vm_u242(a_p0, T7_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, erfcWrapper__vm_u13471)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0) {
	NF T6_;
	NF T7_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NI T3_;
		T3_ = (NI)0;
		T3_ = numArgs__vm_u279(a_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T3_ == ((NI)1)))) goto LA4_;
		failedAssertImpl__stdZassertions_u79(TM__pyAIA9cUF0h9c4j2HfNQPfYw_114);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA4_: ;
	T6_ = (NF)0;
	T6_ = getFloat__vm_u331(a_p0, ((NI)0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T7_ = (NF)0;
	T7_ = erfc(T6_);
	setResult__vm_u242(a_p0, T7_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, gammaWrapper__vm_u13478)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0) {
	NF T6_;
	NF T7_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NI T3_;
		T3_ = (NI)0;
		T3_ = numArgs__vm_u279(a_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T3_ == ((NI)1)))) goto LA4_;
		failedAssertImpl__stdZassertions_u79(TM__pyAIA9cUF0h9c4j2HfNQPfYw_118);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA4_: ;
	T6_ = (NF)0;
	T6_ = getFloat__vm_u331(a_p0, ((NI)0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T7_ = (NF)0;
	T7_ = tgamma(T6_);
	setResult__vm_u242(a_p0, T7_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, lgammaWrapper__vm_u13485)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0) {
	NF T6_;
	NF T7_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NI T3_;
		T3_ = (NI)0;
		T3_ = numArgs__vm_u279(a_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T3_ == ((NI)1)))) goto LA4_;
		failedAssertImpl__stdZassertions_u79(TM__pyAIA9cUF0h9c4j2HfNQPfYw_122);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA4_: ;
	T6_ = (NF)0;
	T6_ = getFloat__vm_u331(a_p0, ((NI)0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T7_ = (NF)0;
	T7_ = lgamma(T6_);
	setResult__vm_u242(a_p0, T7_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, setResult__vm_u269)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, tyTuple__igdSbLMeeUm9brp9bUKtC70w v_p1) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* tuplen_1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD_;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__2;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	tuplen_1 = NIM_NIL;
	colontmpD_ = NIM_NIL;
	colontmpD__2 = NIM_NIL;
	ensureKind__vm_u122((&(*a_p0).slots[(*a_p0).ra]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	tuplen_1 = newNode__ast_u4069(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)160));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	colontmpD_ = newIntNode__ast_u5200(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)6), v_p1.Field0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	add__ast_u3215(tuplen_1, colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	colontmpD__2 = newIntNode__ast_u5200(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)6), v_p1.Field1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	add__ast_u3215(tuplen_1, colontmpD__2);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqsink___ast_u3261(&(*a_p0).slots[(*a_p0).ra].node, tuplen_1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqdestroy___ast_u3252(colontmpD__2);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqdestroy___ast_u3252(colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(tyTuple__igdSbLMeeUm9brp9bUKtC70w, divmod__vm_u13494)(NI64 x_p0, NI64 y_p1) {
	tyTuple__igdSbLMeeUm9brp9bUKtC70w result;
	lldiv_t res_1;
	nimZeroMem((void*)(&result), sizeof(tyTuple__igdSbLMeeUm9brp9bUKtC70w));
	res_1 = lldiv(x_p0, y_p1);
	result.Field0 = res_1.quot;
	result.Field1 = res_1.rem;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI64, getInt__vm_u282)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, NI i_p1) {
	NI64 result;
	tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A* p_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI64)0;
	{
		if (!!((i_p1 < (NI)((*a_p0).rc - ((NI)1))))) goto LA3_;
		failedAssertImpl__stdZassertions_u79(TM__pyAIA9cUF0h9c4j2HfNQPfYw_126);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA3_: ;
	p_1 = (&(*a_p0).slots[(NI)((NI)(i_p1 + (*a_p0).rb) + ((NI)1))]);
	{
		NimStringV2 colontmpD_;
		NimStringV2 colontmpD__2;
		NimStringV2 T9_;
		if (!!(((*p_1).kind == ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2)))) goto LA7_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		T9_.len = 0; T9_.p = NIM_NIL;
		colontmpD_ = dollar___vmdef_u304((*p_1).kind);
		T9_ = rawNewString(colontmpD_.len + 37);
appendString((&T9_), TM__pyAIA9cUF0h9c4j2HfNQPfYw_128);
appendString((&T9_), colontmpD_);
		colontmpD__2 = T9_;
		failedAssertImpl__stdZassertions_u79(colontmpD__2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(colontmpD_);
	}
LA7_: ;
	result = (*p_1).intVal;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, divmodWrapper__vm_u13492)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0) {
	NI64 T1_;
	NI64 T2_;
	tyTuple__igdSbLMeeUm9brp9bUKtC70w T3_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	T1_ = (NI64)0;
	T1_ = getInt__vm_u282(a_p0, ((NI)0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T2_ = (NI64)0;
	T2_ = getInt__vm_u282(a_p0, ((NI)1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T3_ = divmod__vm_u13494(T1_, T2_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	setResult__vm_u269(a_p0, T3_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(NF, copySign__vm_u13542)(NF x_p0, NF y_p1) {
	NF result;
	result = (NF)0;
	result = copysign(x_p0, y_p1);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, copySignWrapper__vm_u13540)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0) {
	NF T1_;
	NF T2_;
	NF T3_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	T1_ = (NF)0;
	T1_ = getFloat__vm_u331(a_p0, ((NI)0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T2_ = (NF)0;
	T2_ = getFloat__vm_u331(a_p0, ((NI)1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T3_ = (NF)0;
	T3_ = copySign__vm_u13542(T1_, T2_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	setResult__vm_u242(a_p0, T3_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, setResult__vm_u245)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, NIM_BOOL v_p1) {
	NI v_2;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	v_2 = v_p1;
	ensureKind__vm_u122((&(*a_p0).slots[(*a_p0).ra]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*a_p0).slots[(*a_p0).ra].intVal = ((NI64) (v_2));
	}BeforeRet_: ;
}
static N_INLINE(NIM_BOOL, signbit__astyaml_u680)(NF x_p0) {
	NIM_BOOL result;
	int T1_;
	T1_ = (int)0;
	T1_ = signbit(x_p0);
	result = !((T1_ == ((NI32)0)));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, signbitWrapper__vm_u13556)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0) {
	NF T6_;
	NIM_BOOL T7_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NI T3_;
		T3_ = (NI)0;
		T3_ = numArgs__vm_u279(a_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T3_ == ((NI)1)))) goto LA4_;
		failedAssertImpl__stdZassertions_u79(TM__pyAIA9cUF0h9c4j2HfNQPfYw_135);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA4_: ;
	T6_ = (NF)0;
	T6_ = getFloat__vm_u331(a_p0, ((NI)0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T7_ = (NIM_BOOL)0;
	T7_ = signbit__astyaml_u680(T6_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	setResult__vm_u245(a_p0, T7_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, colonanonymous___vm_u13566)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0) {
	NI n_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	n_1 = numArgs__vm_u279(a_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	switch (n_1) {
	case ((NI)1):
	{
		NF T2_;
		NF T3_;
		T2_ = (NF)0;
		T2_ = getFloat__vm_u331(a_p0, ((NI)0));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T3_ = (NF)0;
		T3_ = round(T2_);
		setResult__vm_u242(a_p0, T3_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((NI)2):
	{
		NF T5_;
		NI64 T6_;
		NF T7_;
		T5_ = (NF)0;
		T5_ = getFloat__vm_u331(a_p0, ((NI)0));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T6_ = (NI64)0;
		T6_ = getInt__vm_u282(a_p0, ((NI)1));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T7_ = (NF)0;
		T7_ = round__vm_u13569(T5_, ((NI) (T6_)));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		setResult__vm_u242(a_p0, T7_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	default:
	{
		NimStringV2 colontmpD_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		colontmpD_ = dollar___systemZdollars_u9(n_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		raiseAssert__stdZassertions_u15(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___system_u2691(colontmpD_);
	}
	break;
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, modWrapper__vm_u13575)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0) {
	NF T1_;
	NF T2_;
	NF T3_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	T1_ = (NF)0;
	T1_ = getFloat__vm_u331(a_p0, ((NI)0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T2_ = (NF)0;
	T2_ = getFloat__vm_u331(a_p0, ((NI)1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T3_ = (NF)0;
	T3_ = fmod(T1_, T2_);
	setResult__vm_u242(a_p0, T3_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, setResult__vm_u252)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, NimStringV2 v_p1) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	ensureKind__vm_u122((&(*a_p0).slots[(*a_p0).ra]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_ = NIM_NIL;
	T1_ = newNode__ast_u4069(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)20));
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T1_); goto BeforeRet_;}
	eqsink___ast_u3261(&(*a_p0).slots[(*a_p0).ra].node, T1_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqcopy___system_u2694((&(*(*a_p0).slots[(*a_p0).ra].node)._kind_3.strVal), v_p1);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getString__vm_u381)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, NI i_p1) {
	NimStringV2 result;
	tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A* p_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	{
		if (!!((i_p1 < (NI)((*a_p0).rc - ((NI)1))))) goto LA3_;
		failedAssertImpl__stdZassertions_u79(TM__pyAIA9cUF0h9c4j2HfNQPfYw_145);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA3_: ;
	p_1 = (&(*a_p0).slots[(NI)((NI)(i_p1 + (*a_p0).rb) + ((NI)1))]);
	{
		NimStringV2 colontmpD_;
		NimStringV2 colontmpD__2;
		NimStringV2 T9_;
		if (!!(((*p_1).kind == ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1)))) goto LA7_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		T9_.len = 0; T9_.p = NIM_NIL;
		colontmpD_ = dollar___vmdef_u304((*p_1).kind);
		T9_ = rawNewString(colontmpD_.len + 38);
appendString((&T9_), TM__pyAIA9cUF0h9c4j2HfNQPfYw_147);
appendString((&T9_), colontmpD_);
		colontmpD__2 = T9_;
		failedAssertImpl__stdZassertions_u79(colontmpD__2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(colontmpD_);
	}
LA7_: ;
	eqcopy___system_u2694((&result), (*(*p_1).node)._kind_3.strVal);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, getEnvWrapper__vm_u13577)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0) {
	NimStringV2 colontmpD_;
	NimStringV2 colontmpD__2;
	NimStringV2 colontmpD__3;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
	colontmpD_ = getString__vm_u381(a_p0, ((NI)0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	colontmpD__2 = getString__vm_u381(a_p0, ((NI)1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	colontmpD__3 = getEnv__stdZenvvars_u16(colontmpD_, colontmpD__2);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	setResult__vm_u252(a_p0, colontmpD__3);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqdestroy___system_u2691(colontmpD__3);
	eqdestroy___system_u2691(colontmpD__2);
	eqdestroy___system_u2691(colontmpD_);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, existsEnvWrapper__vm_u13579)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0) {
	NimStringV2 colontmpD_;
	NIM_BOOL T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD_ = getString__vm_u381(a_p0, ((NI)0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_ = (NIM_BOOL)0;
	T1_ = existsEnv__stdZenvvars_u21(colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	setResult__vm_u245(a_p0, T1_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqdestroy___system_u2691(colontmpD_);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, putEnvWrapper__vm_u13581)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0) {
	NimStringV2 colontmpD_;
	NimStringV2 colontmpD__2;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	colontmpD_ = getString__vm_u381(a_p0, ((NI)0));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__2 = getString__vm_u381(a_p0, ((NI)1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	putEnv__stdZenvvars_u24(colontmpD_, colontmpD__2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(colontmpD_);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, delEnvWrapper__vm_u13583)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0) {
	NimStringV2 colontmpD_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD_ = getString__vm_u381(a_p0, ((NI)0));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	delEnv__stdZenvvars_u30(colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD_);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, dirExistsWrapper__vm_u13585)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0) {
	NimStringV2 colontmpD_;
	NIM_BOOL T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD_ = getString__vm_u381(a_p0, ((NI)0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_ = (NIM_BOOL)0;
	T1_ = nosdirExists(colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	setResult__vm_u245(a_p0, T1_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqdestroy___system_u2691(colontmpD_);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, fileExistsWrapper__vm_u13587)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0) {
	NimStringV2 colontmpD_;
	NIM_BOOL T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD_ = getString__vm_u381(a_p0, ((NI)0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_ = (NIM_BOOL)0;
	T1_ = nosfileExists(colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	setResult__vm_u245(a_p0, T1_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqdestroy___system_u2691(colontmpD_);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, writeFileWrapper__vm_u13597)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0) {
}
N_LIB_PRIVATE N_NIMCALL(void, writeFileWrapper__vm_u13599)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0) {
	NimStringV2 colontmpD_;
	NimStringV2 colontmpD__2;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	colontmpD_ = getString__vm_u381(a_p0, ((NI)0));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__2 = getString__vm_u381(a_p0, ((NI)1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	writeFile__stdZsyncio_u532(colontmpD_, colontmpD__2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(colontmpD_);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, createDirWrapper__vm_u13609)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0) {
}
N_LIB_PRIVATE N_NIMCALL(void, createDirWrapper__vm_u13611)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0) {
	NimStringV2 colontmpD_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD_ = getString__vm_u381(a_p0, ((NI)0));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	noscreateDir(colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD_);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, readFileWrapper__vm_u13613)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0) {
	NimStringV2 colontmpD_;
	NimStringV2 colontmpD__2;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	colontmpD_ = getString__vm_u381(a_p0, ((NI)0));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__2 = readFile__stdZsyncio_u527(colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	setResult__vm_u252(a_p0, colontmpD__2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(colontmpD_);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, setResult__vm_u261)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, tySequence__sM4lkSb7zS6F7OVMvW9cffQ v_p1) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	n_1 = NIM_NIL;
	ensureKind__vm_u122((&(*a_p0).slots[(*a_p0).ra]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	n_1 = newNode__ast_u4069(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)41));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		NimStringV2* x_1;
		NI i_1;
		NI L_1;
		NI T2_;
		x_1 = (NimStringV2*)0;
		i_1 = ((NI)0);
		T2_ = v_p1.len;
		L_1 = T2_;
		{
			while (1) {
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD_;
				if (!(i_1 < L_1)) goto LA4;
				colontmpD_ = NIM_NIL;
				x_1 = (&v_p1.p->data[i_1]);
				colontmpD_ = newStrNode__ast_u5422(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)20), (*x_1));
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				add__ast_u3215(n_1, colontmpD_);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				i_1 += ((NI)1);
				eqdestroy___ast_u3252(colontmpD_);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			} LA4: ;
		}
	}
	eqsink___ast_u3261(&(*a_p0).slots[(*a_p0).ra].node, n_1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, readLinesWrapper__vm_u13615)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0) {
	NimStringV2 colontmpD_;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ colontmpD__2;
	NI64 T2_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	colontmpD_ = getString__vm_u381(a_p0, ((NI)0));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T2_ = (NI64)0;
	T2_ = getInt__vm_u282(a_p0, ((NI)1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__2 = readLines__stdZsyncio_u550(colontmpD_, ((NI) (T2_)));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	setResult__vm_u261(a_p0, colontmpD__2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u5533(colontmpD__2);
		eqdestroy___system_u2691(colontmpD_);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, getCurrentExceptionMsgWrapper__vm_u13115)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0) {
	NimStringV2 colontmpD_;
	NimStringV2 colontmpD__2;
	NimStringV2 T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	T1_.len = 0; T1_.p = NIM_NIL;
	{
		if (!((*a_p0).currentException == 0)) goto LA4_;
		colontmpD_ = TM__pyAIA9cUF0h9c4j2HfNQPfYw_183;
		T1_ = colontmpD_;
	}
	goto LA2_;
LA4_: ;
	{
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__3;
		colontmpD__3 = NIM_NIL;
		colontmpD__3 = skipColon__ast_u7347((*(*a_p0).currentException)._kind_6.sons.p->data[((NI)3)]);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqcopy___system_u2694((&colontmpD__2), (*colontmpD__3)._kind_3.strVal);
		eqdestroy___ast_u3252(colontmpD__3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T1_ = colontmpD__2;
	}
LA2_: ;
	setResult__vm_u252(a_p0, T1_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqdestroy___system_u2691(colontmpD__2);
	eqdestroy___system_u2691(colontmpD_);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, setResult__vm_u255)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	ensureKind__vm_u122((&(*a_p0).slots[(*a_p0).ra]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqcopy___ast_u3255(&(*a_p0).slots[(*a_p0).ra].node, n_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, getCurrentExceptionWrapper__vm_u13120)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	setResult__vm_u255(a_p0, (*a_p0).currentException);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, raiseDefectWrapper__vm_u13122)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0) {
}
static N_INLINE(NCSTRING, nimToCStringConv)(NimStringV2 s_p0) {
	NCSTRING result;
	{
		if (!(s_p0.len == ((NI)0))) goto LA3_;
		result = "";
	}
	goto LA1_;
LA3_: ;
	{
		result = ((NCSTRING) ((*s_p0.p).data));
	}
LA1_: ;
	return result;
}
static N_INLINE(int, nimCmpMem)(void* a_p0, void* b_p1, NI size_p2) {
	int result;
	result = memcmp(a_p0, b_p1, ((size_t) (size_p2)));
	return result;
}
static N_INLINE(NIM_BOOL, equalMem__system_u1750)(void* a_p0, void* b_p1, NI size_p2) {
	NIM_BOOL result;
	int T1_;
	T1_ = (int)0;
	T1_ = nimCmpMem(a_p0, b_p1, size_p2);
	result = (T1_ == ((NI32)0));
	return result;
}
static N_INLINE(NIM_BOOL, eqStrings)(NimStringV2 a_p0, NimStringV2 b_p1) {
	NIM_BOOL result;
	NI alen_1;
	NI blen_1;
{	result = NIM_FALSE;
	alen_1 = a_p0.len;
	blen_1 = b_p1.len;
	{
		if (!(alen_1 == blen_1)) goto LA3_;
		{
			if (!(alen_1 == ((NI)0))) goto LA7_;
			result = NIM_TRUE;
			goto BeforeRet_;
		}
LA7_: ;
		result = equalMem__system_u1750(((void*) ((&a_p0.p->data[((NI)0)]))), ((void*) ((&b_p1.p->data[((NI)0)]))), (alen_1));
		goto BeforeRet_;
	}
LA3_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NimStringV2, slash___stdZprivateZospaths2_u91)(NimStringV2 head_p0, NimStringV2 tail_p1) {
	NimStringV2 result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	result = nosjoinPath(head_p0, tail_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, staticWalkDirImpl__vm_u13124)(NimStringV2 path_p0, NIM_BOOL relative_p1) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
NIM_BOOL oldNimErrFin28_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	result = newNode__ast_u4069(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)41));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		NimStringV2 f_1;
		tyEnum_PathComponent__daMOTwam9cW3AQtl6fxq4sQ k_1;
		DIR* d_1;
		f_1.len = 0; f_1.p = NIM_NIL;
		k_1 = (tyEnum_PathComponent__daMOTwam9cW3AQtl6fxq4sQ)0;
		d_1 = opendir(nimToCStringConv(path_p0));
		{
			if (!(d_1 == ((DIR*) NIM_NIL))) goto LA5_;
			{
				NI32 T11_;
				if (!NIM_FALSE) goto LA9_;
				T11_ = (NI32)0;
				T11_ = osLastError__stdZoserrors_u122();
				if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
				raiseOSError__stdZoserrors_u119(T11_, path_p0);
				if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
			}
LA9_: ;
		}
		goto LA3_;
LA5_: ;
		{
			{
				while (1) {
					{
						NimStringV2 y_1;
						struct dirent* x_1;
						y_1.len = 0; y_1.p = NIM_NIL;
						x_1 = readdir(d_1);
						{
							if (!(x_1 == ((struct dirent*) NIM_NIL))) goto LA20_;
							eqdestroy___system_u2691(y_1);
							goto LA14;
						}
LA20_: ;
						y_1 = cstrToNimstr(((NCSTRING) ((*x_1).d_name)));
						{
							NIM_BOOL T24_;
							NimStringV2 path_2;
							tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD_;
							struct stat s_1;
							tyEnum_PathComponent__daMOTwam9cW3AQtl6fxq4sQ k_2;
							tyTuple__RQuzKb7YBI25p4z9cTFFLeQ T75_;
							T24_ = (NIM_BOOL)0;
							T24_ = !(eqStrings(y_1, TM__pyAIA9cUF0h9c4j2HfNQPfYw_194));
							if (!(T24_)) goto LA25_;
							T24_ = !(eqStrings(y_1, TM__pyAIA9cUF0h9c4j2HfNQPfYw_196));
LA25_: ;
							if (!T24_) goto LA26_;
							path_2.len = 0; path_2.p = NIM_NIL;
							colontmpD_ = NIM_NIL;
							nimZeroMem((void*)(&s_1), sizeof(struct stat));
							path_2 = slash___stdZprivateZospaths2_u91(path_p0, y_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA28_;
							{
								if (!!(relative_p1)) goto LA31_;
								eqcopy___system_u2694((&y_1), path_2);
							}
LA31_: ;
							k_2 = ((tyEnum_PathComponent__daMOTwam9cW3AQtl6fxq4sQ)0);
							switch ((*x_1).d_type) {
							case ((NI8)4):
							{
								k_2 = ((tyEnum_PathComponent__daMOTwam9cW3AQtl6fxq4sQ)2);
							}
							break;
							case ((NI8)10):
							{
								NIM_BOOL isSpecialX60gensym19__1;
								tyTuple__wjbnfGBIEcH6aaevyJWrgw tmpTupleAsgn;
								isSpecialX60gensym19__1 = (NIM_BOOL)0;
								tmpTupleAsgn = getSymlinkFileKind__stdZprivateZoscommon_u20(path_2);
								if (NIM_UNLIKELY(*nimErr_)) goto LA28_;
								k_2 = tmpTupleAsgn.Field0;
								isSpecialX60gensym19__1 = tmpTupleAsgn.Field1;
								{
									NIM_BOOL T37_;
									T37_ = (NIM_BOOL)0;
									T37_ = NIM_FALSE;
									if (!(T37_)) goto LA38_;
									T37_ = isSpecialX60gensym19__1;
LA38_: ;
									if (!T37_) goto LA39_;
									eqdestroy___ast_u3252(colontmpD_);
									if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
									eqdestroy___system_u2691(path_2);
									eqdestroy___system_u2691(y_1);
									goto LA16;
								}
LA39_: ;
							}
							break;
							case ((NI8)0):
							{
								{
									int T44_;
									T44_ = (int)0;
									T44_ = lstat(nimToCStringConv(path_2), (&s_1));
									if (!(T44_ < ((NI32)0))) goto LA45_;
									eqdestroy___ast_u3252(colontmpD_);
									if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
									eqdestroy___system_u2691(path_2);
									eqdestroy___system_u2691(y_1);
									goto LA16;
								}
								goto LA42_;
LA45_: ;
								{
									NIM_BOOL T48_;
									T48_ = (NIM_BOOL)0;
									T48_ = S_ISDIR(s_1.st_mode);
									if (!T48_) goto LA49_;
									k_2 = ((tyEnum_PathComponent__daMOTwam9cW3AQtl6fxq4sQ)2);
								}
								goto LA42_;
LA49_: ;
								{
									NIM_BOOL T52_;
									NIM_BOOL isSpecialX60gensym21__1;
									tyTuple__wjbnfGBIEcH6aaevyJWrgw tmpTupleAsgn_2;
									T52_ = (NIM_BOOL)0;
									T52_ = S_ISLNK(s_1.st_mode);
									if (!T52_) goto LA53_;
									isSpecialX60gensym21__1 = (NIM_BOOL)0;
									tmpTupleAsgn_2 = getSymlinkFileKind__stdZprivateZoscommon_u20(path_2);
									if (NIM_UNLIKELY(*nimErr_)) goto LA28_;
									k_2 = tmpTupleAsgn_2.Field0;
									isSpecialX60gensym21__1 = tmpTupleAsgn_2.Field1;
									{
										NIM_BOOL T57_;
										T57_ = (NIM_BOOL)0;
										T57_ = NIM_FALSE;
										if (!(T57_)) goto LA58_;
										T57_ = isSpecialX60gensym21__1;
LA58_: ;
										if (!T57_) goto LA59_;
										eqdestroy___ast_u3252(colontmpD_);
										if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
										eqdestroy___system_u2691(path_2);
										eqdestroy___system_u2691(y_1);
										goto LA16;
									}
LA59_: ;
								}
								goto LA42_;
LA53_: ;
								{
									NIM_BOOL T62_;
									NIM_BOOL T64_;
									T62_ = (NIM_BOOL)0;
									T62_ = NIM_FALSE;
									if (!(T62_)) goto LA63_;
									T64_ = (NIM_BOOL)0;
									T64_ = S_ISREG(s_1.st_mode);
									T62_ = !(T64_);
LA63_: ;
									if (!T62_) goto LA65_;
									eqdestroy___ast_u3252(colontmpD_);
									if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
									eqdestroy___system_u2691(path_2);
									eqdestroy___system_u2691(y_1);
									goto LA16;
								}
								goto LA42_;
LA65_: ;
LA42_: ;
							}
							break;
							default:
							{
								{
									NIM_BOOL T70_;
									T70_ = (NIM_BOOL)0;
									T70_ = NIM_FALSE;
									if (!(T70_)) goto LA71_;
									T70_ = !(((*x_1).d_type == ((NI8)8)));
LA71_: ;
									if (!T70_) goto LA72_;
									eqdestroy___ast_u3252(colontmpD_);
									if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
									eqdestroy___system_u2691(path_2);
									eqdestroy___system_u2691(y_1);
									goto LA16;
								}
								goto LA68_;
LA72_: ;
								{
								}
LA68_: ;
							}
							break;
							}
							k_1 = k_2;
							eqsink___system_u2700((&f_1), y_1);
							eqwasMoved___system_u2688((&y_1));
							T75_.Field0 = k_1;
							T75_.Field1 = f_1;
							colontmpD_ = toLit__vm_u13130(T75_);
							if (NIM_UNLIKELY(*nimErr_)) goto LA28_;
							add__ast_u3215(result, colontmpD_);
							if (NIM_UNLIKELY(*nimErr_)) goto LA28_;
							{
								LA28_:;
							}
							{
								oldNimErrFin28_ = *nimErr_; *nimErr_ = NIM_FALSE;
								eqdestroy___ast_u3252(colontmpD_);
								if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
								eqdestroy___system_u2691(path_2);
								*nimErr_ = oldNimErrFin28_;
							}
							if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
						}
LA26_: ;
						{
							LA17_:;
						}
						{
							eqdestroy___system_u2691(y_1);
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
					} LA16: ;
				}
			} LA14: ;
			{
				LA13_:;
			}
			{
				int T82_;
				T82_ = (int)0;
				T82_ = closedir(d_1);
				(void)(T82_);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
		}
LA3_: ;
		{
			LA2_:;
		}
		{
			eqdestroy___system_u2691(f_1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, getBool__vm_u327)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, NI i_p1) {
	NIM_BOOL result;
	NI64 T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	T1_ = (NI64)0;
	T1_ = getInt__vm_u282(a_p0, i_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	result = !((T1_ == IL64(0)));
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, colonanonymous___vm_u13617)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0) {
	NimStringV2 colontmpD_;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__2;
	NIM_BOOL T2_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD__2 = NIM_NIL;
	colontmpD_ = getString__vm_u381(a_p0, ((NI)0));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T2_ = (NIM_BOOL)0;
	T2_ = getBool__vm_u327(a_p0, ((NI)1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__2 = staticWalkDirImpl__vm_u13124(colontmpD_, T2_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	setResult__vm_u255(a_p0, colontmpD__2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3252(colontmpD__2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___system_u2691(colontmpD_);
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, colonanonymous___vm_u13619)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0) {
	NimStringV2 colontmpD_;
	NIM_BOOL T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD_ = getString__vm_u381(a_p0, ((NI)0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_ = (NIM_BOOL)0;
	T1_ = nosdirExists(colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	setResult__vm_u245(a_p0, T1_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqdestroy___system_u2691(colontmpD_);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, colonanonymous___vm_u13621)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0) {
	NimStringV2 colontmpD_;
	NIM_BOOL T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD_ = getString__vm_u381(a_p0, ((NI)0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_ = (NIM_BOOL)0;
	T1_ = nosfileExists(colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	setResult__vm_u245(a_p0, T1_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqdestroy___system_u2691(colontmpD_);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, querySettingImpl__vm_u13153)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NI64 switch_p1) {
	NimStringV2 result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	switch (((tyEnum_SingleValueSetting__HRmc2gxK9bXtRNyOdKDv9c3g) (switch_p1))) {
	case ((tyEnum_SingleValueSetting__HRmc2gxK9bXtRNyOdKDv9c3g)0):
	{
		eqcopy___system_u2694((&result), (*conf_p0).arguments);
	}
	break;
	case ((tyEnum_SingleValueSetting__HRmc2gxK9bXtRNyOdKDv9c3g)1):
	{
		NimStringV2 colontmpD_;
		colontmpD_ = eqdup___system_u2697((*conf_p0).outFile);
		result = colontmpD_;
	}
	break;
	case ((tyEnum_SingleValueSetting__HRmc2gxK9bXtRNyOdKDv9c3g)2):
	{
		NimStringV2 colontmpD__2;
		colontmpD__2 = eqdup___system_u2697((*conf_p0).outDir);
		result = colontmpD__2;
	}
	break;
	case ((tyEnum_SingleValueSetting__HRmc2gxK9bXtRNyOdKDv9c3g)3):
	{
		result = getNimcacheDir__options_u3737(conf_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_SingleValueSetting__HRmc2gxK9bXtRNyOdKDv9c3g)4):
	{
		eqcopy___system_u2694((&result), (*conf_p0).projectName);
	}
	break;
	case ((tyEnum_SingleValueSetting__HRmc2gxK9bXtRNyOdKDv9c3g)5):
	{
		NimStringV2 colontmpD__3;
		colontmpD__3 = eqdup___system_u2697((*conf_p0).projectPath);
		result = colontmpD__3;
	}
	break;
	case ((tyEnum_SingleValueSetting__HRmc2gxK9bXtRNyOdKDv9c3g)6):
	{
		NimStringV2 colontmpD__4;
		colontmpD__4 = eqdup___system_u2697((*conf_p0).projectFull);
		result = colontmpD__4;
	}
	break;
	case ((tyEnum_SingleValueSetting__HRmc2gxK9bXtRNyOdKDv9c3g)7):
	{
		eqcopy___system_u2694((&result), (*conf_p0).command);
	}
	break;
	case ((tyEnum_SingleValueSetting__HRmc2gxK9bXtRNyOdKDv9c3g)8):
	{
		eqcopy___system_u2694((&result), (*conf_p0).commandLine);
	}
	break;
	case ((tyEnum_SingleValueSetting__HRmc2gxK9bXtRNyOdKDv9c3g)9):
	{
		eqcopy___system_u2694((&result), (*conf_p0).linkOptions);
	}
	break;
	case ((tyEnum_SingleValueSetting__HRmc2gxK9bXtRNyOdKDv9c3g)10):
	{
		eqcopy___system_u2694((&result), (*conf_p0).compileOptions);
	}
	break;
	case ((tyEnum_SingleValueSetting__HRmc2gxK9bXtRNyOdKDv9c3g)11):
	{
		eqcopy___system_u2694((&result), (*conf_p0).cCompilerPath);
	}
	break;
	case ((tyEnum_SingleValueSetting__HRmc2gxK9bXtRNyOdKDv9c3g)12):
	{
		result = dollar___options_u144((*conf_p0).backend);
	}
	break;
	case ((tyEnum_SingleValueSetting__HRmc2gxK9bXtRNyOdKDv9c3g)13):
	{
		NimStringV2 colontmpD__5;
		colontmpD__5 = eqdup___system_u2697((*conf_p0).libpath);
		result = colontmpD__5;
	}
	break;
	case ((tyEnum_SingleValueSetting__HRmc2gxK9bXtRNyOdKDv9c3g)14):
	{
		result = dollar___options_u213((*conf_p0).selectedGC);
	}
	break;
	case ((tyEnum_SingleValueSetting__HRmc2gxK9bXtRNyOdKDv9c3g)15):
	{
		result = dollar___options_u213((*conf_p0).selectedGC);
	}
	break;
	default: __builtin_unreachable();
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___vm_u13623)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, void* ClE_0) {
	tyObject_Env_vmopsdotnim_registerAdditionalOps___VDnIL6fWGTCjJE9c9cTQGKGw* colonenvP__1;
	NimStringV2 colontmpD_;
	NI64 T2_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colonenvP__1 = (tyObject_Env_vmopsdotnim_registerAdditionalOps___VDnIL6fWGTCjJE9c9cTQGKGw*) ClE_0;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	T2_ = (NI64)0;
	T2_ = getInt__vm_u282(a_p0, ((NI)0));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD_ = querySettingImpl__vm_u13153((*(*colonenvP__1).c0).config, T2_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	setResult__vm_u252(a_p0, colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD_);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tySequence__sM4lkSb7zS6F7OVMvW9cffQ, querySettingSeqImpl__vm_u13185)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NI64 switch_p1) {
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ result;
	result.len = 0; result.p = NIM_NIL;
	switch (((tyEnum_MultipleValueSetting__9afzpxz1DiqdeW9a0ZsAq8Kg) (switch_p1))) {
	case ((tyEnum_MultipleValueSetting__9afzpxz1DiqdeW9a0ZsAq8Kg)0):
	{
		result.len = 0; result.p = (tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content*) newSeqPayload(0, sizeof(NimStringV2), NIM_ALIGNOF(NimStringV2));
		{
			NimStringV2* iX60gensym2126__1;
			NI i_1;
			NI L_1;
			NI T3_;
			iX60gensym2126__1 = (NimStringV2*)0;
			i_1 = ((NI)0);
			T3_ = (*conf_p0).nimblePaths.len;
			L_1 = T3_;
			{
				while (1) {
					NimStringV2 colontmpD_;
					if (!(i_1 < L_1)) goto LA5;
					iX60gensym2126__1 = (&(*conf_p0).nimblePaths.p->data[i_1]);
					colontmpD_ = eqdup___system_u2697((*iX60gensym2126__1));
					add__stdZenumutils_u71((&result), colontmpD_);
					i_1 += ((NI)1);
				} LA5: ;
			}
		}
	}
	break;
	case ((tyEnum_MultipleValueSetting__9afzpxz1DiqdeW9a0ZsAq8Kg)1):
	{
		result.len = 0; result.p = (tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content*) newSeqPayload(0, sizeof(NimStringV2), NIM_ALIGNOF(NimStringV2));
		{
			NimStringV2* iX60gensym2127__1;
			NI i_2;
			NI L_2;
			NI T8_;
			iX60gensym2127__1 = (NimStringV2*)0;
			i_2 = ((NI)0);
			T8_ = (*conf_p0).searchPaths.len;
			L_2 = T8_;
			{
				while (1) {
					NimStringV2 colontmpD__2;
					if (!(i_2 < L_2)) goto LA10;
					iX60gensym2127__1 = (&(*conf_p0).searchPaths.p->data[i_2]);
					colontmpD__2 = eqdup___system_u2697((*iX60gensym2127__1));
					add__stdZenumutils_u71((&result), colontmpD__2);
					i_2 += ((NI)1);
				} LA10: ;
			}
		}
	}
	break;
	case ((tyEnum_MultipleValueSetting__9afzpxz1DiqdeW9a0ZsAq8Kg)2):
	{
		result.len = 0; result.p = (tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content*) newSeqPayload(0, sizeof(NimStringV2), NIM_ALIGNOF(NimStringV2));
		{
			NimStringV2* iX60gensym2128__1;
			NI i_3;
			NI L_3;
			NI T13_;
			iX60gensym2128__1 = (NimStringV2*)0;
			i_3 = ((NI)0);
			T13_ = (*conf_p0).lazyPaths.len;
			L_3 = T13_;
			{
				while (1) {
					NimStringV2 colontmpD__3;
					if (!(i_3 < L_3)) goto LA15;
					iX60gensym2128__1 = (&(*conf_p0).lazyPaths.p->data[i_3]);
					colontmpD__3 = eqdup___system_u2697((*iX60gensym2128__1));
					add__stdZenumutils_u71((&result), colontmpD__3);
					i_3 += ((NI)1);
				} LA15: ;
			}
		}
	}
	break;
	case ((tyEnum_MultipleValueSetting__9afzpxz1DiqdeW9a0ZsAq8Kg)3):
	{
		eqcopy___system_u5536((&result), (*conf_p0).commandArgs);
	}
	break;
	case ((tyEnum_MultipleValueSetting__9afzpxz1DiqdeW9a0ZsAq8Kg)4):
	{
		result.len = 0; result.p = (tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content*) newSeqPayload(0, sizeof(NimStringV2), NIM_ALIGNOF(NimStringV2));
		{
			NimStringV2* iX60gensym2129__1;
			NI i_4;
			NI L_4;
			NI T19_;
			iX60gensym2129__1 = (NimStringV2*)0;
			i_4 = ((NI)0);
			T19_ = (*conf_p0).cIncludes.len;
			L_4 = T19_;
			{
				while (1) {
					NimStringV2 colontmpD__4;
					if (!(i_4 < L_4)) goto LA21;
					iX60gensym2129__1 = (&(*conf_p0).cIncludes.p->data[i_4]);
					colontmpD__4 = eqdup___system_u2697((*iX60gensym2129__1));
					add__stdZenumutils_u71((&result), colontmpD__4);
					i_4 += ((NI)1);
				} LA21: ;
			}
		}
	}
	break;
	case ((tyEnum_MultipleValueSetting__9afzpxz1DiqdeW9a0ZsAq8Kg)5):
	{
		result.len = 0; result.p = (tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content*) newSeqPayload(0, sizeof(NimStringV2), NIM_ALIGNOF(NimStringV2));
		{
			NimStringV2* iX60gensym2130__1;
			NI i_5;
			NI L_5;
			NI T24_;
			iX60gensym2130__1 = (NimStringV2*)0;
			i_5 = ((NI)0);
			T24_ = (*conf_p0).cLibs.len;
			L_5 = T24_;
			{
				while (1) {
					NimStringV2 colontmpD__5;
					if (!(i_5 < L_5)) goto LA26;
					iX60gensym2130__1 = (&(*conf_p0).cLibs.p->data[i_5]);
					colontmpD__5 = eqdup___system_u2697((*iX60gensym2130__1));
					add__stdZenumutils_u71((&result), colontmpD__5);
					i_5 += ((NI)1);
				} LA26: ;
			}
		}
	}
	break;
	default: __builtin_unreachable();
	}
	return result;
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___vm_u13625)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, void* ClE_0) {
	tyObject_Env_vmopsdotnim_registerAdditionalOps___VDnIL6fWGTCjJE9c9cTQGKGw* colonenvP__1;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ colontmpD_;
	NI64 T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colonenvP__1 = (tyObject_Env_vmopsdotnim_registerAdditionalOps___VDnIL6fWGTCjJE9c9cTQGKGw*) ClE_0;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	T1_ = (NI64)0;
	T1_ = getInt__vm_u282(a_p0, ((NI)0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	colontmpD_ = querySettingSeqImpl__vm_u13185((*(*colonenvP__1).c0).config, T1_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	setResult__vm_u261(a_p0, colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqdestroy___system_u5533(colontmpD_);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_CLOSURE(void, gorgeExWrapper__vm_u13286)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, void* ClE_0) {
	tyObject_Env_vmopsdotnim_registerAdditionalOps___VDnIL6fWGTCjJE9c9cTQGKGw* colonenvP__1;
	tyTuple__XOVT24GHXwqiEj5GCsEGCA ret_1;
	NimStringV2 colontmpD_;
	NimStringV2 colontmpD__2;
	NimStringV2 colontmpD__3;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__4;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colonenvP__1 = (tyObject_Env_vmopsdotnim_registerAdditionalOps___VDnIL6fWGTCjJE9c9cTQGKGw*) ClE_0;
	nimZeroMem((void*)(&ret_1), sizeof(tyTuple__XOVT24GHXwqiEj5GCsEGCA));
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
	colontmpD__4 = NIM_NIL;
	colontmpD_ = getString__vm_u381(a_p0, ((NI)0));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__2 = getString__vm_u381(a_p0, ((NI)1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__3 = getString__vm_u381(a_p0, ((NI)2));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	ret_1 = opGorge__gorgeimpl_u14(colontmpD_, colontmpD__2, colontmpD__3, (*a_p0).currentLineInfo, (*(*colonenvP__1).c0).config);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__4 = toLit__vm_u13289(ret_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	setResult__vm_u255(a_p0, colontmpD__4);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3252(colontmpD__4);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___system_u2691(colontmpD__3);
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___pureZosproc_u1951(ret_1);
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_CLOSURE(void, getProjectPathWrapper__vm_u13309)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, void* ClE_0) {
	tyObject_Env_vmopsdotnim_registerAdditionalOps___VDnIL6fWGTCjJE9c9cTQGKGw* colonenvP__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colonenvP__1 = (tyObject_Env_vmopsdotnim_registerAdditionalOps___VDnIL6fWGTCjJE9c9cTQGKGw*) ClE_0;
	setResult__vm_u252(a_p0, (*(*(*colonenvP__1).c0).config).projectPath);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, colonanonymous___vm_u13631)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0) {
	NimStringV2 colontmpD_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD_ = nosgetAppFilename();
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	setResult__vm_u252(a_p0, colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqdestroy___system_u2691(colontmpD_);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, getNode__vm_u356)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, NI i_p1) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
	tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A* p_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	{
		if (!!((i_p1 < (NI)((*a_p0).rc - ((NI)1))))) goto LA3_;
		failedAssertImpl__stdZassertions_u79(TM__pyAIA9cUF0h9c4j2HfNQPfYw_217);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA3_: ;
	p_1 = (&(*a_p0).slots[(NI)((NI)(i_p1 + (*a_p0).rb) + ((NI)1))]);
	{
		NimStringV2 colontmpD_;
		NimStringV2 colontmpD__2;
		NimStringV2 T9_;
		if (!!(((*p_1).kind == ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1)))) goto LA7_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		T9_.len = 0; T9_.p = NIM_NIL;
		colontmpD_ = dollar___vmdef_u304((*p_1).kind);
		T9_ = rawNewString(colontmpD_.len + 38);
appendString((&T9_), TM__pyAIA9cUF0h9c4j2HfNQPfYw_218);
appendString((&T9_), colontmpD_);
		colontmpD__2 = T9_;
		failedAssertImpl__stdZassertions_u79(colontmpD__2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(colontmpD_);
	}
LA7_: ;
	eqcopy___ast_u3255(&result, (*p_1).node);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI, toLinenumber__msgs_u695)(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p0) {
	NI result;
	result = ((NI) (info_p0.line));
	return result;
}
static N_INLINE(NI, toColumn__msgs_u698)(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p0) {
	NI result;
	result = ((NI) (info_p0.col));
	return result;
}
static N_INLINE(void, nimAddCharV1)(NimStringV2* s_p0, NIM_CHAR c_p1) {
	prepareAdd(s_p0, ((NI)1));
	(*(*s_p0).p).data[(*s_p0).len] = c_p1;
	(*s_p0).len += ((NI)1);
	(*(*s_p0).p).data[(*s_p0).len] = 0;
}
N_LIB_PRIVATE N_NIMCALL(void, stackTraceAux__vm_u32)(tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew* c_p0, tyObject_TStackFrame__a20zU43j9cYHpYOOr1c2hZQ* x_p1, NI pc_p2, NI recursionLimit_p3) {
NIM_BOOL oldNimErrFin10_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NimStringV2 s_1;
		tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_1;
		NI line_1;
		NI col_1;
		if (!!((x_p1 == ((tyObject_TStackFrame__a20zU43j9cYHpYOOr1c2hZQ*) NIM_NIL)))) goto LA3_;
		s_1.len = 0; s_1.p = NIM_NIL;
		{
			tyObject_TStackFrame__a20zU43j9cYHpYOOr1c2hZQ* x_2;
			NimStringV2 colontmpD_;
			NimStringV2 colontmpD__2;
			NI calls_1;
			NimStringV2 T13_;
			if (!(recursionLimit_p3 == ((NI)0))) goto LA8_;
			x_2 = NIM_NIL;
			colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
			colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
			calls_1 = ((NI)0);
			eqcopy___vmprofiler_u22(&x_2, x_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
			{
				while (1) {
					if (!!((x_2 == ((tyObject_TStackFrame__a20zU43j9cYHpYOOr1c2hZQ*) NIM_NIL)))) goto LA12;
					calls_1 += ((NI)1);
					eqcopy___vmprofiler_u22(&x_2, (*x_2).next);
					if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
				} LA12: ;
			}
			T13_.len = 0; T13_.p = NIM_NIL;
			colontmpD_ = dollar___systemZdollars_u9(calls_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
			T13_ = rawNewString(colontmpD_.len + 15);
appendString((&T13_), colontmpD_);
appendString((&T13_), TM__pyAIA9cUF0h9c4j2HfNQPfYw_222);
			colontmpD__2 = T13_;
			msgWriteln__msgs_u737((*c_p0).config, colontmpD__2, 4);
			if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
			eqdestroy___system_u2691(colontmpD__2);
			eqdestroy___system_u2691(colontmpD_);
			eqdestroy___vmprofiler_u19(x_2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
			eqdestroy___system_u2691(s_1);
			goto BeforeRet_;
			{
				LA10_:;
			}
			{
				oldNimErrFin10_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___system_u2691(colontmpD__2);
				eqdestroy___system_u2691(colontmpD_);
				eqdestroy___vmprofiler_u19(x_2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
				*nimErr_ = oldNimErrFin10_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		}
LA8_: ;
		stackTraceAux__vm_u32(c_p0, (*x_p1).next, (*x_p1).comesFrom, (NI)(recursionLimit_p3 - ((NI)1)));
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		info_1 = (*c_p0).debug.p->data[pc_p2];
		s_1 = TM__pyAIA9cUF0h9c4j2HfNQPfYw_223;
		{
			NimStringV2 T20_;
			if (!(((*(*c_p0).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)36)))&63U)))!=0)) goto LA18_;
			T20_.len = 0; T20_.p = NIM_NIL;
			T20_ = toFullPath__msgs_u624((*c_p0).config, info_1.fileIndex);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T20_); goto LA5_;}
			eqsink___system_u2700((&s_1), T20_);
		}
		goto LA16_;
LA18_: ;
		{
			NimStringV2 T22_;
			T22_.len = 0; T22_.p = NIM_NIL;
			{
				NIM_BOOL T25_;
				NimStringV2 T29_;
				T25_ = (NIM_BOOL)0;
				T25_ = (info_1.fileIndex < ((NI32)0));
				if (T25_) goto LA26_;
				T25_ = ((*c_p0).config == ((tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg*) NIM_NIL));
LA26_: ;
				if (!T25_) goto LA27_;
				T29_.len = 0; T29_.p = NIM_NIL;
				{
					if (!(info_1.fileIndex == ((NI32)-3))) goto LA32_;
					eqsink___system_u2700((&s_1), TM__pyAIA9cUF0h9c4j2HfNQPfYw_225);
				}
				goto LA30_;
LA32_: ;
				{
					eqsink___system_u2700((&s_1), TM__pyAIA9cUF0h9c4j2HfNQPfYw_227);
				}
LA30_: ;
			}
			goto LA23_;
LA27_: ;
			{
				eqcopy___system_u2694((&s_1), (*(*c_p0).config).m.fileInfos.p->data[info_1.fileIndex].shortName);
			}
LA23_: ;
		}
LA16_: ;
		line_1 = toLinenumber__msgs_u695(info_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		col_1 = toColumn__msgs_u698(info_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		{
			NimStringV2 colontmpD__3;
			NimStringV2 colontmpD__4;
			if (!(((NI)0) < line_1)) goto LA38_;
			colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
			colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
			nimAddCharV1((&s_1), 40);
			colontmpD__3 = dollar___systemZdollars_u9(line_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
			prepareAdd((&s_1), colontmpD__3.len + 0);
appendString((&s_1), colontmpD__3);
			prepareAdd((&s_1), 2);
appendString((&s_1), TM__pyAIA9cUF0h9c4j2HfNQPfYw_229);
			colontmpD__4 = dollar___systemZdollars_u9((NI)(col_1 + ((NI)1)));
			if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
			prepareAdd((&s_1), colontmpD__4.len + 0);
appendString((&s_1), colontmpD__4);
			nimAddCharV1((&s_1), 41);
			eqdestroy___system_u2691(colontmpD__4);
			eqdestroy___system_u2691(colontmpD__3);
		}
LA38_: ;
		{
			if (!!(((*x_p1).prc == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)))) goto LA42_;
			{
				NI k_1;
				NI colontmp_;
				NI res_1;
				k_1 = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = ((((NI)1) >= (NI)(((NI)25) - s_1.len)) ? ((NI)1) : (NI)(((NI)25) - s_1.len));
				res_1 = ((NI)1);
				{
					while (1) {
						if (!(res_1 <= colontmp_)) goto LA46;
						k_1 = ((NI) (res_1));
						nimAddCharV1((&s_1), 32);
						res_1 += ((NI)1);
					} LA46: ;
				}
			}
			prepareAdd((&s_1), (*(*(*x_p1).prc).name).s.len + 0);
appendString((&s_1), (*(*(*x_p1).prc).name).s);
		}
LA42_: ;
		msgWriteln__msgs_u737((*c_p0).config, s_1, 4);
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		{
			LA5_:;
		}
		{
			eqdestroy___system_u2691(s_1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA3_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NOINLINE(void, stackTraceImpl__vm_u73)(tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew* c_p0, tyObject_TStackFrame__a20zU43j9cYHpYOOr1c2hZQ* tos_p1, NI pc_p2, NimStringV2 msg_p3, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA lineInfo_p4, tyTuple__kN8up2W6YKc5YA9avn5mV5w infoOrigin_p5) {
	tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w colontmpD_;
	tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w colontmpD__2;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA colontmpD__3;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA colontmpD__4;
	tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w action_1;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA lineInfo_2;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_ = (tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0;
	colontmpD__2 = (tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0;
	nimZeroMem((void*)(&colontmpD__3), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
	nimZeroMem((void*)(&colontmpD__4), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
	msgWriteln__msgs_u737((*c_p0).config, TM__pyAIA9cUF0h9c4j2HfNQPfYw_220, 4);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	stackTraceAux__vm_u32(c_p0, tos_p1, pc_p2, ((NI)100));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!((*c_p0).mode == ((tyEnum_TEvalMode__sQljSFf0fjnsNV1fpgXakg)0))) goto LA3_;
		colontmpD_ = ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)2);
		action_1 = colontmpD_;
	}
	goto LA1_;
LA3_: ;
	{
		colontmpD__2 = ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0);
		action_1 = colontmpD__2;
	}
LA1_: ;
	{
		tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T8_;
		NIM_BOOL T9_;
		nimZeroMem((void*)(&T8_), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
		T9_ = (NIM_BOOL)0;
		T9_ = eqeq___msgs_u1103(lineInfo_p4, T8_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!T9_) goto LA10_;
		colontmpD__3 = (*c_p0).debug.p->data[pc_p2];
		lineInfo_2 = colontmpD__3;
	}
	goto LA6_;
LA10_: ;
	{
		colontmpD__4 = lineInfo_p4;
		lineInfo_2 = colontmpD__4;
	}
LA6_: ;
	liMessage__msgs_u1227((*c_p0).config, lineInfo_2, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), msg_p3, action_1, infoOrigin_p5, NIM_FALSE, NIM_FALSE);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, stackTrace2__vm_u13276)(tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew* c_p0, NimStringV2 msg_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p2) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD_;
	tyObject_TStackFrame__a20zU43j9cYHpYOOr1c2hZQ* colontmpD__2;
	tyObject_TStackFrame__a20zU43j9cYHpYOOr1c2hZQ* T2_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD__2 = NIM_NIL;
	T2_ = NIM_NIL;
	T2_ = (tyObject_TStackFrame__a20zU43j9cYHpYOOr1c2hZQ*) nimNewObj(sizeof(tyObject_TStackFrame__a20zU43j9cYHpYOOr1c2hZQ), NIM_ALIGNOF(tyObject_TStackFrame__a20zU43j9cYHpYOOr1c2hZQ));
	colontmpD_ = eqdup___ast_u4580((*(*c_p0).prc).sym);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	(*T2_).prc = colontmpD_;
	(*T2_).comesFrom = ((NI)0);
	(*T2_).next = ((tyObject_TStackFrame__a20zU43j9cYHpYOOr1c2hZQ*) NIM_NIL);
	colontmpD__2 = T2_;
	stackTraceImpl__vm_u73(c_p0, colontmpD__2, (*c_p0).exceptionInstr, msg_p1, (*n_p2).info, TM__pyAIA9cUF0h9c4j2HfNQPfYw_230);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	eqdestroy___vmprofiler_u19(colontmpD__2);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	goto BeforeRet_;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___vmprofiler_u19(colontmpD__2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___vm_u13633)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, void* ClE_0) {
	tyObject_Env_vmopsdotnim_registerAdditionalOps___VDnIL6fWGTCjJE9c9cTQGKGw* colonenvP__1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_1;
	NimStringV2 colontmpD_;
	tyArray__dnD8kjh6rJ1Yy5jHvid0Ow T10_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colonenvP__1 = (tyObject_Env_vmopsdotnim_registerAdditionalOps___VDnIL6fWGTCjJE9c9cTQGKGw*) ClE_0;
	n_1 = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	n_1 = getNode__vm_u356(a_p0, ((NI)0));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NimStringV2 colontmpD__2;
		NimStringV2 colontmpD__3;
		NimStringV2 colontmpD__4;
		tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T7_;
		if (!!(((*n_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3)))) goto LA4_;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
		colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
		colontmpD__2 = dollar___renderer_u2166(n_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		T7_[0] = colontmpD__2;
		colontmpD__3 = dollar___nodekinds_u168((*n_1).kind);
		T7_[1] = colontmpD__3;
		colontmpD__4 = nsuFormatOpenArray(TM__pyAIA9cUF0h9c4j2HfNQPfYw_232, T7_, 2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		stackTrace2__vm_u13276((*colonenvP__1).c0, colontmpD__4, n_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		{
			LA6_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__4);
			eqdestroy___system_u2691(colontmpD__3);
			eqdestroy___system_u2691(colontmpD__2);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA4_: ;
	nimZeroMem((void*)T10_, sizeof(tyArray__dnD8kjh6rJ1Yy5jHvid0Ow));
	symBodyDigest__sighashes_u534((*(*colonenvP__1).c0).graph, (*n_1)._kind_4.sym, T10_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD_ = dollar___modulegraphs_u10732(T10_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	setResult__vm_u252(a_p0, colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___ast_u3252(n_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___vm_u13643)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, void* ClE_0) {
	tyObject_Env_vmopsdotnim_registerAdditionalOps___VDnIL6fWGTCjJE9c9cTQGKGw* colonenvP__1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_1;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colonenvP__1 = (tyObject_Env_vmopsdotnim_registerAdditionalOps___VDnIL6fWGTCjJE9c9cTQGKGw*) ClE_0;
	n_1 = NIM_NIL;
	n_1 = getNode__vm_u356(a_p0, ((NI)0));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NimStringV2 colontmpD_;
		NimStringV2 colontmpD__2;
		NimStringV2 colontmpD__3;
		tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T7_;
		if (!!(((*n_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3)))) goto LA4_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
		colontmpD_ = dollar___renderer_u2166(n_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		T7_[0] = colontmpD_;
		colontmpD__2 = dollar___nodekinds_u168((*n_1).kind);
		T7_[1] = colontmpD__2;
		colontmpD__3 = nsuFormatOpenArray(TM__pyAIA9cUF0h9c4j2HfNQPfYw_236, T7_, 2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		stackTrace2__vm_u13276((*colonenvP__1).c0, colontmpD__3, n_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		{
			LA6_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__3);
			eqdestroy___system_u2691(colontmpD__2);
			eqdestroy___system_u2691(colontmpD_);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA4_: ;
	setResult__vm_u245(a_p0, (((*(*n_1)._kind_4.sym).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)1)))&63U)))!=0));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3252(n_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___vm_u13657)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, void* ClE_0) {
	tyObject_Env_vmopsdotnim_registerAdditionalOps___VDnIL6fWGTCjJE9c9cTQGKGw* colonenvP__1;
	NimStringV2 table_1;
	NimStringV2 key_1;
	NIM_BOOL T2_;
	tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw* T4_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colonenvP__1 = (tyObject_Env_vmopsdotnim_registerAdditionalOps___VDnIL6fWGTCjJE9c9cTQGKGw*) ClE_0;
	table_1.len = 0; table_1.p = NIM_NIL;
	key_1.len = 0; key_1.p = NIM_NIL;
	table_1 = getString__vm_u381(a_p0, ((NI)0));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	key_1 = getString__vm_u381(a_p0, ((NI)1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T2_ = (NIM_BOOL)0;
	T2_ = contains__vm_u8108((*(*(*colonenvP__1).c0).graph).cacheTables, table_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	if (!(T2_)) goto LA3_;
	T4_ = (tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw*)0;
	T4_ = X5BX5D___vm_u9673((&(*(*(*colonenvP__1).c0).graph).cacheTables), table_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T2_ = contains__vm_u9814((*T4_), key_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
LA3_: ;
	setResult__vm_u245(a_p0, T2_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(key_1);
		eqdestroy___system_u2691(table_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___vm_u13837)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, void* ClE_0) {
	tyObject_Env_vmopsdotnim_registerAdditionalOps___VDnIL6fWGTCjJE9c9cTQGKGw* colonenvP__1;
	NIM_BOOL T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colonenvP__1 = (tyObject_Env_vmopsdotnim_registerAdditionalOps___VDnIL6fWGTCjJE9c9cTQGKGw*) ClE_0;
	T1_ = (NIM_BOOL)0;
	T1_ = getBool__vm_u327(a_p0, ((NI)0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*(*(*colonenvP__1).c0).config).isVmTrace = T1_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, setResult__vm_u239)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, NI64 v_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	ensureKind__vm_u122((&(*a_p0).slots[(*a_p0).ra]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*a_p0).slots[(*a_p0).ra].intVal = v_p1;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_CLOSURE(void, hashVmImpl__vm_u13839)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, void* ClE_0) {
	tyObject_Env_vmopsdotnim_registerAdditionalOps___VDnIL6fWGTCjJE9c9cTQGKGw* colonenvP__1;
	NimStringV2 colontmpD_;
	NI res_1;
	NI64 T1_;
	NI64 T2_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colonenvP__1 = (tyObject_Env_vmopsdotnim_registerAdditionalOps___VDnIL6fWGTCjJE9c9cTQGKGw*) ClE_0;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD_ = getString__vm_u381(a_p0, ((NI)0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_ = (NI64)0;
	T1_ = getInt__vm_u282(a_p0, ((NI)1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T2_ = (NI64)0;
	T2_ = getInt__vm_u282(a_p0, ((NI)2));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	res_1 = hash__pureZhashes_u593(colontmpD_, ((NI) (T1_)), ((NI) (T2_)));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!((*(*(*colonenvP__1).c0).config).backend == ((tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)3))) goto LA5_;
		res_1 = ((NI) (((NI32) (res_1))));
	}
LA5_: ;
	setResult__vm_u239(a_p0, ((NI64) (res_1)));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqdestroy___system_u2691(colontmpD_);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_CLOSURE(void, hashVmImplByte__vm_u13846)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, void* ClE_0) {
	tyObject_Env_vmopsdotnim_registerAdditionalOps___VDnIL6fWGTCjJE9c9cTQGKGw* colonenvP__1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* arr_1;
	tySequence__6H5Oh5UUvVCLiakt9aTwtUQ bytes_1;
	NI sPos_1;
	NI64 T1_;
	NI ePos_1;
	NI64 T2_;
	NI T3_;
	NI res_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colonenvP__1 = (tyObject_Env_vmopsdotnim_registerAdditionalOps___VDnIL6fWGTCjJE9c9cTQGKGw*) ClE_0;
	arr_1 = NIM_NIL;
	bytes_1.len = 0; bytes_1.p = NIM_NIL;
	T1_ = (NI64)0;
	T1_ = getInt__vm_u282(a_p0, ((NI)1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	sPos_1 = ((NI) (T1_));
	T2_ = (NI64)0;
	T2_ = getInt__vm_u282(a_p0, ((NI)2));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	ePos_1 = ((NI) (T2_));
	arr_1 = getNode__vm_u356(a_p0, ((NI)0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T3_ = (NI)0;
	T3_ = len__ast_u3190(arr_1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	bytes_1 = newSeq__vm_u13879((T3_));
	{
		NI i_1;
		NI colontmp_;
		NI i_2;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_u3190(arr_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		i_2 = ((NI)0);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA6;
				i_1 = i_2;
				bytes_1.p->data[i_1] = ((NU8) ((NI64)((*(*arr_1)._kind_6.sons.p->data[i_1])._kind_1.intVal & IL64(255))));
				i_2 += ((NI)1);
			} LA6: ;
		}
	}
	res_1 = hash__vm_u13894(((bytes_1).p) ? (bytes_1.p->data) : NIM_NIL, bytes_1.len, sPos_1, ePos_1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!((*(*(*colonenvP__1).c0).config).backend == ((tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)3))) goto LA9_;
		res_1 = ((NI) (((NI32) (res_1))));
	}
LA9_: ;
	setResult__vm_u239(a_p0, ((NI64) (res_1)));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqdestroy___pureZtimes_u2620(bytes_1);
	eqdestroy___ast_u3252(arr_1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(NI, cmpStrings)(NimStringV2 a_p0, NimStringV2 b_p1) {
	NI result;
	NI alen_1;
	NI blen_1;
	NI minlen_1;
	alen_1 = a_p0.len;
	blen_1 = b_p1.len;
	minlen_1 = ((alen_1 <= blen_1) ? alen_1 : blen_1);
	{
		int T5_;
		if (!(((NI)0) < minlen_1)) goto LA3_;
		T5_ = (int)0;
		T5_ = memcmp(((void*) ((&a_p0.p->data[((NI)0)]))), ((void*) ((&b_p1.p->data[((NI)0)]))), ((size_t) (minlen_1)));
		result = ((NI) (T5_));
		{
			if (!(result == ((NI)0))) goto LA8_;
			result = (NI)(alen_1 - blen_1);
		}
LA8_: ;
	}
	goto LA1_;
LA3_: ;
	{
		result = (NI)(alen_1 - blen_1);
	}
LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, colonanonymous___vm_u13910)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0) {
	NimStringV2 colontmpD_;
	NimStringV2 colontmpD__2;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	colontmpD_ = getString__vm_u381(a_p0, ((NI)0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	colontmpD__2 = getString__vm_u381(a_p0, ((NI)1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	setResult__vm_u245(a_p0, (cmpStrings(colontmpD_, colontmpD__2) < 0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqdestroy___system_u2691(colontmpD__2);
	eqdestroy___system_u2691(colontmpD_);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, colonanonymous___vm_u13912)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0) {
	NimStringV2 colontmpD_;
	NimStringV2 colontmpD__2;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	colontmpD_ = getString__vm_u381(a_p0, ((NI)0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	colontmpD__2 = getString__vm_u381(a_p0, ((NI)1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	setResult__vm_u245(a_p0, (cmpStrings(colontmpD_, colontmpD__2) <= 0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqdestroy___system_u2691(colontmpD__2);
	eqdestroy___system_u2691(colontmpD_);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, cpuTimeWrapper__vm_u13922)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0) {
	NF T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	T1_ = (NF)0;
	T1_ = cpuTime__pureZtimes_u5215();
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	setResult__vm_u242(a_p0, T1_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NF, cpuTime__vm_u13924)(void) {
	NF result;
	result = 5.391245e-44;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, cpuTimeWrapper__vm_u13926)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0) {
	NF T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	T1_ = (NF)0;
	T1_ = cpuTime__vm_u13924();
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	setResult__vm_u242(a_p0, T1_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, colonanonymous___vm_u13932)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0) {
	NimStringV2 colontmpD_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD_ = nosgetCurrentDir();
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	setResult__vm_u252(a_p0, colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD_);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, colonanonymous___vm_u13934)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD_;
	NimStringV2 colontmpD__2;
	tyTuple__XOVT24GHXwqiEj5GCsEGCA colontmpD__3;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__4;
	tySet_tyEnum_ProcessOption__f8zQPCJAq3Y51oMx2CR9cxw options_1;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_ = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	nimZeroMem((void*)(&colontmpD__3), sizeof(tyTuple__XOVT24GHXwqiEj5GCsEGCA));
	colontmpD__4 = NIM_NIL;
	colontmpD_ = getNode__vm_u356(a_p0, ((NI)1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	options_1 = fromLit__vm_u13936(colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__2 = getString__vm_u381(a_p0, ((NI)0));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__3 = execCmdEx__pureZosproc_u1907(colontmpD__2, options_1, ((tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg*) NIM_NIL), TM__pyAIA9cUF0h9c4j2HfNQPfYw_263, TM__pyAIA9cUF0h9c4j2HfNQPfYw_264);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__4 = toLit__vm_u14000(colontmpD__3);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	setResult__vm_u255(a_p0, colontmpD__4);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3252(colontmpD__4);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___pureZosproc_u1951(colontmpD__3);
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___ast_u3252(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___vm_u14016)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, void* ClE_0) {
	tyObject_Env_vmopsdotnim_registerAdditionalOps___VDnIL6fWGTCjJE9c9cTQGKGw* colonenvP__1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* obj_1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD_;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__2;
	tyObject_Time__f9czJU2iP3D49bUN3jzSsOfA T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colonenvP__1 = (tyObject_Env_vmopsdotnim_registerAdditionalOps___VDnIL6fWGTCjJE9c9cTQGKGw*) ClE_0;
	obj_1 = NIM_NIL;
	colontmpD_ = NIM_NIL;
	colontmpD__2 = NIM_NIL;
	colontmpD_ = getNode__vm_u356(a_p0, ((NI)0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqcopy___ast_u3255(&obj_1, (*(*colontmpD_).typField).n);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_ = getTime__pureZtimes_u1291();
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	colontmpD__2 = toTimeLit__vmconv_u29(T1_, (*colonenvP__1).c0, obj_1, (*a_p0).currentLineInfo);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	setResult__vm_u255(a_p0, colontmpD__2);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqdestroy___ast_u3252(colontmpD__2);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqdestroy___ast_u3252(colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqdestroy___ast_u3252(obj_1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, getEffectList__vm_u14019)(tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew* c_p0, tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p1, NI effectIndex_p2) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* fn_1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* list_1;
NIM_BOOL oldNimErrFin18_;
NIM_BOOL oldNimErrFin14_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	fn_1 = NIM_NIL;
	list_1 = NIM_NIL;
	fn_1 = getNode__vm_u356(a_p1, ((NI)0));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	list_1 = newNodeI__ast_u4091(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)41), (*fn_1).info);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NIM_BOOL T4_;
		NIM_BOOL T5_;
		NIM_BOOL T6_;
		NI T9_;
		T4_ = (NIM_BOOL)0;
		T5_ = (NIM_BOOL)0;
		T6_ = (NIM_BOOL)0;
		T6_ = !(((*fn_1).typField == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL)));
		if (!(T6_)) goto LA7_;
		T6_ = !(((*(*fn_1).typField).n == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL)));
LA7_: ;
		T5_ = T6_;
		if (!(T5_)) goto LA8_;
		T9_ = (NI)0;
		T9_ = len__ast_u3190((*(*(*fn_1).typField).n)._kind_6.sons.p->data[((NI)0)]);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T5_ = (((NI)6) <= T9_);
LA8_: ;
		T4_ = T5_;
		if (!(T4_)) goto LA10_;
		T4_ = !(((*(*(*(*fn_1).typField).n)._kind_6.sons.p->data[((NI)0)])._kind_6.sons.p->data[effectIndex_p2] == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL)));
LA10_: ;
		if (!T4_) goto LA11_;
		{
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_1;
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** colontmp_;
			e_1 = NIM_NIL;
			colontmp_ = (tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ**)0;
			colontmp_ = &(*(*(*(*fn_1).typField).n)._kind_6.sons.p->data[((NI)0)])._kind_6.sons.p->data[effectIndex_p2];
			{
				NI i_1;
				NI colontmp__2;
				NI i_2;
				i_1 = (NI)0;
				colontmp__2 = (NI)0;
				colontmp__2 = safeLen__ast_u3197((*colontmp_));
				if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
				i_2 = ((NI)0);
				{
					while (1) {
						tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
						tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__2;
						if (!(i_2 < colontmp__2)) goto LA17;
						colontmpD_ = NIM_NIL;
						colontmpD__2 = NIM_NIL;
						i_1 = i_2;
						eqcopy___ast_u3255(&e_1, (*(*colontmp_))._kind_6.sons.p->data[i_1]);
						if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
						colontmpD_ = skipTypes__ast_u5379((*e_1).typField, TM__pyAIA9cUF0h9c4j2HfNQPfYw_270);
						if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
						colontmpD__2 = opMapTypeInstToAst__vmdeps_u302((*c_p0).cache, colontmpD_, (*e_1).info, (*c_p0).Sup.idgen, NIM_FALSE);
						if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
						add__ast_u3215(list_1, colontmpD__2);
						if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
						i_2 += ((NI)1);
						{
							LA18_:;
						}
						{
							oldNimErrFin18_ = *nimErr_; *nimErr_ = NIM_FALSE;
							eqdestroy___ast_u3252(colontmpD__2);
							if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
							eqdestroy___ast_u3378(colontmpD_);
							if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
							*nimErr_ = oldNimErrFin18_;
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
					} LA17: ;
				}
			}
			{
				LA14_:;
			}
			{
				oldNimErrFin14_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u3252(e_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				*nimErr_ = oldNimErrFin14_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
	}
	goto LA2_;
LA11_: ;
	{
		tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* colontmpD__3;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__4;
		colontmpD__3 = NIM_NIL;
		colontmpD__4 = NIM_NIL;
		colontmpD__3 = getIdent__idents_u206((*c_p0).cache, TM__pyAIA9cUF0h9c4j2HfNQPfYw_272);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		colontmpD__4 = newIdentNode__ast_u5164(colontmpD__3, (*fn_1).info);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		add__ast_u3215(list_1, colontmpD__4);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		eqdestroy___ast_u3252(colontmpD__4);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		eqdestroy___idents_u155(colontmpD__3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA2_: ;
	setResult__vm_u255(a_p1, list_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3252(list_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3252(fn_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___vm_u14038)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, void* ClE_0) {
	tyObject_Env_vmopsdotnim_registerAdditionalOps___VDnIL6fWGTCjJE9c9cTQGKGw* colonenvP__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colonenvP__1 = (tyObject_Env_vmopsdotnim_registerAdditionalOps___VDnIL6fWGTCjJE9c9cTQGKGw*) ClE_0;
	getEffectList__vm_u14019((*colonenvP__1).c0, a_p0, ((NI)0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___vm_u14040)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, void* ClE_0) {
	tyObject_Env_vmopsdotnim_registerAdditionalOps___VDnIL6fWGTCjJE9c9cTQGKGw* colonenvP__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colonenvP__1 = (tyObject_Env_vmopsdotnim_registerAdditionalOps___VDnIL6fWGTCjJE9c9cTQGKGw*) ClE_0;
	getEffectList__vm_u14019((*colonenvP__1).c0, a_p0, ((NI)3));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___vm_u14042)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, void* ClE_0) {
	tyObject_Env_vmopsdotnim_registerAdditionalOps___VDnIL6fWGTCjJE9c9cTQGKGw* colonenvP__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colonenvP__1 = (tyObject_Env_vmopsdotnim_registerAdditionalOps___VDnIL6fWGTCjJE9c9cTQGKGw*) ClE_0;
	getEffectList__vm_u14019((*colonenvP__1).c0, a_p0, ((NI)5));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, colonanonymous___vm_u14044)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* fn_1;
	NIM_BOOL T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	fn_1 = NIM_NIL;
	fn_1 = getNode__vm_u356(a_p0, ((NI)0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_ = (NIM_BOOL)0;
	T1_ = !(((*fn_1).typField == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL)));
	if (!(T1_)) goto LA2_;
	T1_ = (((*(*fn_1).typField).flags &((NU64)1<<((NU)((((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)7)))&63U)))!=0);
LA2_: ;
	setResult__vm_u245(a_p0, T1_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqdestroy___ast_u3252(fn_1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, colonanonymous___vm_u14055)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* fn_1;
	NIM_BOOL T1_;
	NIM_BOOL T2_;
	NIM_BOOL T5_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	fn_1 = NIM_NIL;
	fn_1 = getNode__vm_u356(a_p0, ((NI)0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_ = (NIM_BOOL)0;
	T2_ = (NIM_BOOL)0;
	T2_ = !(((*fn_1).typField == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL)));
	if (!(T2_)) goto LA3_;
	T2_ = (((*(*fn_1).typField).flags &((NU64)1<<((NU)((((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)1)))&63U)))!=0);
LA3_: ;
	T1_ = T2_;
	if (T1_) goto LA4_;
	T5_ = (NIM_BOOL)0;
	T5_ = ((*fn_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3));
	if (!(T5_)) goto LA6_;
	T5_ = ((*(*fn_1)._kind_4.sym).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)13));
LA6_: ;
	T1_ = T5_;
LA4_: ;
	setResult__vm_u245(a_p0, T1_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqdestroy___ast_u3252(fn_1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, colonanonymous___vm_u14074)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* fn_1;
	NIM_BOOL T1_;
	NIM_BOOL T3_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	fn_1 = NIM_NIL;
	fn_1 = getNode__vm_u356(a_p0, ((NI)0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_ = (NIM_BOOL)0;
	T1_ = ((*fn_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)155));
	if (T1_) goto LA2_;
	T3_ = (NIM_BOOL)0;
	T3_ = !(((*fn_1).typField == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL)));
	if (!(T3_)) goto LA4_;
	T3_ = ((*(*fn_1).typField).callConv == ((tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ)9));
LA4_: ;
	T1_ = T3_;
LA2_: ;
	setResult__vm_u245(a_p0, T1_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqdestroy___ast_u3252(fn_1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, getVar__vm_u406)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, NI i_p1) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
	tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A* p_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	{
		if (!!((i_p1 < (NI)((*a_p0).rc - ((NI)1))))) goto LA3_;
		failedAssertImpl__stdZassertions_u79(TM__pyAIA9cUF0h9c4j2HfNQPfYw_288);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA3_: ;
	p_1 = (&(*a_p0).slots[(NI)((NI)(i_p1 + (*a_p0).rb) + ((NI)1))]);
	switch ((*p_1).kind) {
	case ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)4):
	{
		eqcopy___ast_u3255(&result, (*(*p_1).regAddr).node);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)5):
	{
		eqcopy___ast_u3255(&result, (*(*p_1).nodeAddr));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	default:
	{
		NimStringV2 colontmpD_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		colontmpD_ = dollar___vmdef_u304((*p_1).kind);
		raiseAssert__stdZassertions_u15(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___system_u2691(colontmpD_);
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, colonanonymous___vm_u14089)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* p_1;
	NF x_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	p_1 = NIM_NIL;
	p_1 = getVar__vm_u406(a_p0, ((NI)0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	x_1 = getFloat__vm_u331(a_p0, ((NI)1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	addFloatRoundtrip__system_u4737((&(*p_1)._kind_3.strVal), x_1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqdestroy___ast_u3252(p_1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, colonanonymous___vm_u14097)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* p_1;
	NF x_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	p_1 = NIM_NIL;
	p_1 = getVar__vm_u406(a_p0, ((NI)0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	x_1 = getFloat__vm_u331(a_p0, ((NI)1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	addFloatSprintf__stdZformatfloat_u119((&(*p_1)._kind_3.strVal), x_1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqdestroy___ast_u3252(p_1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, colonanonymous___vm_u14101)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0) {
	NimStringV2 colontmpD_;
	NF T1_;
	NI64 T2_;
	NI64 T3_;
	NI64 T4_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	T1_ = (NF)0;
	T1_ = getFloat__vm_u331(a_p0, ((NI)0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T2_ = (NI64)0;
	T2_ = getInt__vm_u282(a_p0, ((NI)1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T3_ = (NI64)0;
	T3_ = getInt__vm_u282(a_p0, ((NI)2));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T4_ = (NI64)0;
	T4_ = getInt__vm_u282(a_p0, ((NI)3));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	colontmpD_ = nsuformatBiggestFloat(T1_, ((tyEnum_FloatFormatMode__CTUpdhZ6zDNw9cC9acViKeYg) (T2_)), ((NI) (T3_)), ((NIM_CHAR) (((NI) (T4_)))));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	setResult__vm_u252(a_p0, colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqdestroy___system_u2691(colontmpD_);
	}BeforeRet_: ;
}
static N_INLINE(NIM_BOOL, eqeq___system_u8603)(NCSTRING x_p0, NCSTRING y_p1) {
	NIM_BOOL result;
	{
		if (!(((void*) (x_p0)) == ((void*) (y_p1)))) goto LA3_;
		result = NIM_TRUE;
	}
	goto LA1_;
LA3_: ;
	{
		NIM_BOOL T6_;
		T6_ = (NIM_BOOL)0;
		T6_ = (((void*) (x_p0)) == NIM_NIL);
		if (T6_) goto LA7_;
		T6_ = (((void*) (y_p1)) == NIM_NIL);
LA7_: ;
		if (!T6_) goto LA8_;
		result = NIM_FALSE;
	}
	goto LA1_;
LA8_: ;
	{
		int T11_;
		T11_ = (int)0;
		T11_ = strcmp(x_p0, y_p1);
		result = (T11_ == ((NI32)0));
	}
LA1_: ;
	return result;
}
static N_INLINE(NI, find__pureZparseutils_u636)(NimStringV2 a_p0, NIM_CHAR item_p1) {
	NI result;
{	result = ((NI)0);
	{
		NIM_CHAR i_1;
		NI i_2;
		NI L_1;
		i_1 = (NIM_CHAR)0;
		i_2 = ((NI)0);
		L_1 = a_p0.len;
		{
			while (1) {
				if (!(i_2 < L_1)) goto LA3;
				i_1 = a_p0.p->data[i_2];
				{
					if (!((NU8)(i_1) == (NU8)(item_p1))) goto LA6_;
					goto BeforeRet_;
				}
LA6_: ;
				result += ((NI)1);
				i_2 += ((NI)1);
			} LA3: ;
		}
	}
	result = ((NI)-1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, colonanonymous___vm_u14104)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* aX60gensym2316__p0) {
	tySequence__4eQHGndY6XBYpFOH09apV8Q resultX60gensym2317__1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	resultX60gensym2317__1.len = 0; resultX60gensym2317__1.p = NIM_NIL;
	colontmpD_ = NIM_NIL;
	resultX60gensym2317__1.len = 0; resultX60gensym2317__1.p = (tySequence__4eQHGndY6XBYpFOH09apV8Q_Content*) newSeqPayload(0, sizeof(tyTuple__UV3llMMYFckfui8YMBuUZA), NIM_ALIGNOF(tyTuple__UV3llMMYFckfui8YMBuUZA));
	{
		tyTuple__UV3llMMYFckfui8YMBuUZA xX60gensym2317__1;
		nimZeroMem((void*)(&xX60gensym2317__1), sizeof(tyTuple__UV3llMMYFckfui8YMBuUZA));
		{
			tyTuple__UV3llMMYFckfui8YMBuUZA ai_1;
			NI i_1;
			nimZeroMem((void*)(&ai_1), sizeof(tyTuple__UV3llMMYFckfui8YMBuUZA));
			i_1 = ((NI)0);
			{
				while (1) {
					NIM_BOOL T5_;
					NimStringV2 kv_1;
					NI p_1;
					tyTuple__UV3llMMYFckfui8YMBuUZA T6_;
					tyTuple__UV3llMMYFckfui8YMBuUZA blitTmp_1;
					T5_ = (NIM_BOOL)0;
					T5_ = eqeq___system_u8603(environ[i_1], ((NCSTRING) NIM_NIL));
					if (!!(T5_)) goto LA4;
					kv_1.len = 0; kv_1.p = NIM_NIL;
					kv_1 = cstrToNimstr(environ[i_1]);
					i_1 += ((NI)1);
					p_1 = find__pureZparseutils_u636(kv_1, 61);
					T6_.Field0 = substr__system_u8659(kv_1, ((NI)0), (NI)(p_1 - ((NI)1)));
					T6_.Field1 = substr__system_u8672(kv_1, (NI)(p_1 + ((NI)1)));
					eqsink___stdZprivateZospaths2_u315((&ai_1), T6_);
					eqsink___stdZprivateZospaths2_u315((&xX60gensym2317__1), ai_1);
					eqwasMoved___stdZprivateZospaths2_u303((&ai_1));
					blitTmp_1 = xX60gensym2317__1;
					eqwasMoved___stdZprivateZospaths2_u303((&xX60gensym2317__1));
					add__vm_u14117((&resultX60gensym2317__1), blitTmp_1);
					eqdestroy___system_u2691(kv_1);
				} LA4: ;
			}
			eqdestroy___stdZprivateZospaths2_u306(ai_1);
		}
		eqdestroy___stdZprivateZospaths2_u306(xX60gensym2317__1);
	}
	colontmpD_ = toLit__vm_u14137(resultX60gensym2317__1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	setResult__vm_u255(aX60gensym2316__p0, colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqdestroy___ast_u3252(colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqdestroy___stdZenvvars_u82(resultX60gensym2317__1);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___vm_u14165)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, void* ClE_0) {
	tyObject_Env_vmopsdotnim_registerAdditionalOps___VDnIL6fWGTCjJE9c9cTQGKGw* colonenvP__1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD_;
NIM_BOOL oldNimErrFin3_;
NIM_BOOL oldNimErrFin7_;
NIM_BOOL oldNimErrFin11_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colonenvP__1 = (tyObject_Env_vmopsdotnim_registerAdditionalOps___VDnIL6fWGTCjJE9c9cTQGKGw*) ClE_0;
	typ_1 = NIM_NIL;
	colontmpD_ = NIM_NIL;
	colontmpD_ = getNode__vm_u356(a_p0, ((NI)0));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	eqcopy___ast_u3381(&typ_1, (*colontmpD_).typField);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	switch ((*typ_1).kind) {
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)31) ... ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)35):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)40) ... ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)44):
	{
		NimStringV2 colontmpD__2;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__3;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		colontmpD__3 = NIM_NIL;
		colontmpD__2 = getString__vm_u381(a_p0, ((NI)1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
		colontmpD__3 = loadAny__vmmarshal_u1900(colontmpD__2, typ_1, (*(*colonenvP__1).c0).cache, (*(*colonenvP__1).c0).config, (*(*colonenvP__1).c0).Sup.idgen);
		if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
		setResult__vm_u239(a_p0, (*colontmpD__3)._kind_1.intVal);
		if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
		{
			LA3_:;
		}
		{
			oldNimErrFin3_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3252(colontmpD__3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___system_u2691(colontmpD__2);
			*nimErr_ = oldNimErrFin3_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)36) ... ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)39):
	{
		NimStringV2 colontmpD__4;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__5;
		colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
		colontmpD__5 = NIM_NIL;
		colontmpD__4 = getString__vm_u381(a_p0, ((NI)1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		colontmpD__5 = loadAny__vmmarshal_u1900(colontmpD__4, typ_1, (*(*colonenvP__1).c0).cache, (*(*colonenvP__1).c0).config, (*(*colonenvP__1).c0).Sup.idgen);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		setResult__vm_u242(a_p0, (*colontmpD__5)._kind_2.floatVal);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		{
			LA7_:;
		}
		{
			oldNimErrFin7_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3252(colontmpD__5);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___system_u2691(colontmpD__4);
			*nimErr_ = oldNimErrFin7_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	default:
	{
		NimStringV2 colontmpD__6;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__7;
		colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
		colontmpD__7 = NIM_NIL;
		colontmpD__6 = getString__vm_u381(a_p0, ((NI)1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
		colontmpD__7 = loadAny__vmmarshal_u1900(colontmpD__6, typ_1, (*(*colonenvP__1).c0).cache, (*(*colonenvP__1).c0).config, (*(*colonenvP__1).c0).Sup.idgen);
		if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
		setResult__vm_u255(a_p0, colontmpD__7);
		if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
		{
			LA11_:;
		}
		{
			oldNimErrFin11_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3252(colontmpD__7);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___system_u2691(colontmpD__6);
			*nimErr_ = oldNimErrFin11_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	}
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3252(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(typ_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, regToNode__vm_u542)(tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A x_p0) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	switch (x_p0.kind) {
	case ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)0):
	{
		result = newNode__ast_u4069(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)1));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2):
	{
		result = newNode__ast_u4069(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)6));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*result)._kind_1.intVal = x_p0.intVal;
	}
	break;
	case ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)3):
	{
		result = newNode__ast_u4069(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)16));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*result)._kind_2.floatVal = x_p0.floatVal;
	}
	break;
	case ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1):
	{
		eqcopy___ast_u3255(&result, x_p0.node);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)4):
	{
		result = regToNode__vm_u542((*x_p0.regAddr));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)5):
	{
		eqcopy___ast_u3255(&result, (*x_p0.nodeAddr));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	default: __builtin_unreachable();
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___vm_u14168)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, void* ClE_0) {
	tyObject_Env_vmopsdotnim_registerAdditionalOps___VDnIL6fWGTCjJE9c9cTQGKGw* colonenvP__1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD_;
	NimStringV2 res_1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__2;
	tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A* p_1;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colonenvP__1 = (tyObject_Env_vmopsdotnim_registerAdditionalOps___VDnIL6fWGTCjJE9c9cTQGKGw*) ClE_0;
	typ_1 = NIM_NIL;
	colontmpD_ = NIM_NIL;
	res_1.len = 0; res_1.p = NIM_NIL;
	colontmpD__2 = NIM_NIL;
	colontmpD_ = getNode__vm_u356(a_p0, ((NI)0));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	eqcopy___ast_u3381(&typ_1, (*colontmpD_).typField);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		if (!!((((NI)1) < (NI)((*a_p0).rc - ((NI)1))))) goto LA4_;
		failedAssertImpl__stdZassertions_u79(TM__pyAIA9cUF0h9c4j2HfNQPfYw_304);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA4_: ;
	p_1 = (&(*a_p0).slots[(NI)((NI)(((NI)1) + (*a_p0).rb) + ((NI)1))]);
	res_1 = TM__pyAIA9cUF0h9c4j2HfNQPfYw_305;
	colontmpD__2 = regToNode__vm_u542((*p_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	storeAny__vmmarshal_u154((&res_1), typ_1, colontmpD__2, (*(*colonenvP__1).c0).config);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	setResult__vm_u252(a_p0, res_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3252(colontmpD__2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___system_u2691(res_1);
		eqdestroy___ast_u3252(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(typ_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(NIM_BOOL, nimDecRefIsLastCyclicStatic)(void* p_p0, TNimTypeV2* desc_p1) {
	NIM_BOOL result;
	result = NIM_FALSE;
	{
		tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* cell_1;
		NI T5_;
		if (!!((p_p0 == NIM_NIL))) goto LA3_;
		T5_ = (NI)0;
		T5_ = minuspercent___system_u805(((NI) (ptrdiff_t) (p_p0)), ((NI)8));
		cell_1 = ((tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A*) (T5_));
		{
			if (!((NI)((*cell_1).rc & ((NI)-16)) == ((NI)0))) goto LA8_;
			result = NIM_TRUE;
		}
		goto LA6_;
LA8_: ;
		{
			(*cell_1).rc = minuspercent___system_u805((*cell_1).rc, ((NI)16));
		}
LA6_: ;
		rememberCycle__system_u3495(result, cell_1, desc_p1);
	}
LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___vm_u14535)(tyObject_Env_vmopsdotnim_registerAdditionalOps___VDnIL6fWGTCjJE9c9cTQGKGw* dest_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastCyclicStatic(dest_p0, ((TNimTypeV2*) ((&NTIv2__VDnIL6fWGTCjJE9c9cTQGKGw_))));
		if (!T3_) goto LA4_;
		eqdestroy___vm_u14507((&(*dest_p0)));
		nimRawDispose(dest_p0, ((NI)4));
	}
LA4_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, registerAdditionalOps__vm_u13280)(tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew* c_p0) {
	tyObject_Env_vmopsdotnim_registerAdditionalOps___VDnIL6fWGTCjJE9c9cTQGKGw* colonenv__1;
	NI colontmpD_;
	NI colontmpD__2;
	NI colontmpD__3;
	NI colontmpD__4;
	NI colontmpD__5;
	NI colontmpD__6;
	tyObject_Env_vmopsdotnim_registerAdditionalOps___VDnIL6fWGTCjJE9c9cTQGKGw* T1_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T2_;
	NI T3_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T4_;
	NI T5_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T6_;
	NI T7_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T8_;
	NI T9_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T10_;
	NI T11_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T12_;
	NI T13_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T14_;
	NI T15_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T16_;
	NI T17_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T18_;
	NI T19_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T20_;
	NI T21_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T22_;
	NI T23_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T24_;
	NI T25_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T26_;
	NI T27_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T28_;
	NI T29_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T30_;
	NI T31_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T32_;
	NI T33_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T34_;
	NI T35_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T36_;
	NI T37_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T38_;
	NI T39_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T40_;
	NI T41_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T42_;
	NI T43_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T44_;
	NI T45_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T46_;
	NI T47_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T48_;
	NI T49_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T50_;
	NI T51_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T52_;
	NI T53_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T54_;
	NI T55_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T56_;
	NI T57_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T58_;
	NI T59_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T60_;
	NI T61_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T62_;
	NI T63_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T64_;
	NI T65_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T66_;
	NI T67_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T68_;
	NI T69_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T70_;
	NI T71_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T72_;
	NI T73_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T74_;
	NI T75_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T76_;
	NI T77_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T78_;
	NI T79_;
	NI T80_;
	NI T92_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T104_;
	NI T105_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T106_;
	NI T107_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T108_;
	NI T109_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T110_;
	NI T111_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T112_;
	NI T113_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T114_;
	NI T115_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T116_;
	NI T117_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T118_;
	NI T119_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T120_;
	NI T121_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T122_;
	NI T123_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T133_;
	NI T134_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T135_;
	NI T136_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T137_;
	NI T138_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T139_;
	NI T140_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T141_;
	NI T142_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T143_;
	NI T144_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T145_;
	NI T146_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T147_;
	NI T148_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T149_;
	NI T150_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T151_;
	NI T152_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T153_;
	NI T154_;
	NI T155_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T175_;
	NI T176_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T177_;
	NI T178_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T179_;
	NI T180_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T181_;
	NI T182_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T183_;
	NI T184_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T185_;
	NI T186_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T187_;
	NI T188_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T189_;
	NI T190_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T191_;
	NI T192_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T193_;
	NI T194_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T195_;
	NI T196_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T197_;
	NI T198_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colonenv__1 = NIM_NIL;
	colontmpD_ = (NI)0;
	colontmpD__2 = (NI)0;
	colontmpD__3 = (NI)0;
	colontmpD__4 = (NI)0;
	colontmpD__5 = (NI)0;
	colontmpD__6 = (NI)0;
	T1_ = NIM_NIL;
	T1_ = (tyObject_Env_vmopsdotnim_registerAdditionalOps___VDnIL6fWGTCjJE9c9cTQGKGw*) nimNewObj(sizeof(tyObject_Env_vmopsdotnim_registerAdditionalOps___VDnIL6fWGTCjJE9c9cTQGKGw), NIM_ALIGNOF(tyObject_Env_vmopsdotnim_registerAdditionalOps___VDnIL6fWGTCjJE9c9cTQGKGw));
	(*T1_).Sup.m_type = (&NTIv2__VDnIL6fWGTCjJE9c9cTQGKGw_);
	colonenv__1 = T1_;
	eqcopy___vmdef_u2209(&(*colonenv__1).c0, c_p0, NIM_TRUE);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T2_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T2_.ClP_0 = ((TM__pyAIA9cUF0h9c4j2HfNQPfYw_18) (sqrtWrapper__vm_u13311)); T2_.ClE_0 = NIM_NIL;
	T3_ = (NI)0;
	T3_ = registerCallback__vmdef_u2258((*colonenv__1).c0, TM__pyAIA9cUF0h9c4j2HfNQPfYw_11, T2_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T4_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T4_.ClP_0 = ((TM__pyAIA9cUF0h9c4j2HfNQPfYw_22) (cbrtWrapper__vm_u13318)); T4_.ClE_0 = NIM_NIL;
	T5_ = (NI)0;
	T5_ = registerCallback__vmdef_u2258((*colonenv__1).c0, TM__pyAIA9cUF0h9c4j2HfNQPfYw_20, T4_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T6_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T6_.ClP_0 = ((TM__pyAIA9cUF0h9c4j2HfNQPfYw_26) (lnWrapper__vm_u13325)); T6_.ClE_0 = NIM_NIL;
	T7_ = (NI)0;
	T7_ = registerCallback__vmdef_u2258((*colonenv__1).c0, TM__pyAIA9cUF0h9c4j2HfNQPfYw_24, T6_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T8_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T8_.ClP_0 = ((TM__pyAIA9cUF0h9c4j2HfNQPfYw_30) (log10Wrapper__vm_u13332)); T8_.ClE_0 = NIM_NIL;
	T9_ = (NI)0;
	T9_ = registerCallback__vmdef_u2258((*colonenv__1).c0, TM__pyAIA9cUF0h9c4j2HfNQPfYw_28, T8_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T10_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T10_.ClP_0 = ((TM__pyAIA9cUF0h9c4j2HfNQPfYw_34) (log2Wrapper__vm_u13339)); T10_.ClE_0 = NIM_NIL;
	T11_ = (NI)0;
	T11_ = registerCallback__vmdef_u2258((*colonenv__1).c0, TM__pyAIA9cUF0h9c4j2HfNQPfYw_32, T10_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T12_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T12_.ClP_0 = ((TM__pyAIA9cUF0h9c4j2HfNQPfYw_38) (expWrapper__vm_u13346)); T12_.ClE_0 = NIM_NIL;
	T13_ = (NI)0;
	T13_ = registerCallback__vmdef_u2258((*colonenv__1).c0, TM__pyAIA9cUF0h9c4j2HfNQPfYw_36, T12_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T14_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T14_.ClP_0 = ((TM__pyAIA9cUF0h9c4j2HfNQPfYw_42) (arccosWrapper__vm_u13353)); T14_.ClE_0 = NIM_NIL;
	T15_ = (NI)0;
	T15_ = registerCallback__vmdef_u2258((*colonenv__1).c0, TM__pyAIA9cUF0h9c4j2HfNQPfYw_40, T14_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T16_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T16_.ClP_0 = ((TM__pyAIA9cUF0h9c4j2HfNQPfYw_46) (arcsinWrapper__vm_u13360)); T16_.ClE_0 = NIM_NIL;
	T17_ = (NI)0;
	T17_ = registerCallback__vmdef_u2258((*colonenv__1).c0, TM__pyAIA9cUF0h9c4j2HfNQPfYw_44, T16_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T18_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T18_.ClP_0 = ((TM__pyAIA9cUF0h9c4j2HfNQPfYw_50) (arctanWrapper__vm_u13367)); T18_.ClE_0 = NIM_NIL;
	T19_ = (NI)0;
	T19_ = registerCallback__vmdef_u2258((*colonenv__1).c0, TM__pyAIA9cUF0h9c4j2HfNQPfYw_48, T18_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T20_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T20_.ClP_0 = ((TM__pyAIA9cUF0h9c4j2HfNQPfYw_54) (arcsinhWrapper__vm_u13374)); T20_.ClE_0 = NIM_NIL;
	T21_ = (NI)0;
	T21_ = registerCallback__vmdef_u2258((*colonenv__1).c0, TM__pyAIA9cUF0h9c4j2HfNQPfYw_52, T20_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T22_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T22_.ClP_0 = ((TM__pyAIA9cUF0h9c4j2HfNQPfYw_58) (arccoshWrapper__vm_u13381)); T22_.ClE_0 = NIM_NIL;
	T23_ = (NI)0;
	T23_ = registerCallback__vmdef_u2258((*colonenv__1).c0, TM__pyAIA9cUF0h9c4j2HfNQPfYw_56, T22_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T24_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T24_.ClP_0 = ((TM__pyAIA9cUF0h9c4j2HfNQPfYw_62) (arctanhWrapper__vm_u13388)); T24_.ClE_0 = NIM_NIL;
	T25_ = (NI)0;
	T25_ = registerCallback__vmdef_u2258((*colonenv__1).c0, TM__pyAIA9cUF0h9c4j2HfNQPfYw_60, T24_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T26_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T26_.ClP_0 = ((TM__pyAIA9cUF0h9c4j2HfNQPfYw_65) (arctan2Wrapper__vm_u13395)); T26_.ClE_0 = NIM_NIL;
	T27_ = (NI)0;
	T27_ = registerCallback__vmdef_u2258((*colonenv__1).c0, TM__pyAIA9cUF0h9c4j2HfNQPfYw_64, T26_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T28_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T28_.ClP_0 = ((TM__pyAIA9cUF0h9c4j2HfNQPfYw_69) (cosWrapper__vm_u13397)); T28_.ClE_0 = NIM_NIL;
	T29_ = (NI)0;
	T29_ = registerCallback__vmdef_u2258((*colonenv__1).c0, TM__pyAIA9cUF0h9c4j2HfNQPfYw_67, T28_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T30_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T30_.ClP_0 = ((TM__pyAIA9cUF0h9c4j2HfNQPfYw_73) (coshWrapper__vm_u13404)); T30_.ClE_0 = NIM_NIL;
	T31_ = (NI)0;
	T31_ = registerCallback__vmdef_u2258((*colonenv__1).c0, TM__pyAIA9cUF0h9c4j2HfNQPfYw_71, T30_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T32_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T32_.ClP_0 = ((TM__pyAIA9cUF0h9c4j2HfNQPfYw_76) (hypotWrapper__vm_u13411)); T32_.ClE_0 = NIM_NIL;
	T33_ = (NI)0;
	T33_ = registerCallback__vmdef_u2258((*colonenv__1).c0, TM__pyAIA9cUF0h9c4j2HfNQPfYw_75, T32_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T34_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T34_.ClP_0 = ((TM__pyAIA9cUF0h9c4j2HfNQPfYw_80) (sinhWrapper__vm_u13413)); T34_.ClE_0 = NIM_NIL;
	T35_ = (NI)0;
	T35_ = registerCallback__vmdef_u2258((*colonenv__1).c0, TM__pyAIA9cUF0h9c4j2HfNQPfYw_78, T34_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T36_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T36_.ClP_0 = ((TM__pyAIA9cUF0h9c4j2HfNQPfYw_84) (sinWrapper__vm_u13420)); T36_.ClE_0 = NIM_NIL;
	T37_ = (NI)0;
	T37_ = registerCallback__vmdef_u2258((*colonenv__1).c0, TM__pyAIA9cUF0h9c4j2HfNQPfYw_82, T36_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T38_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T38_.ClP_0 = ((TM__pyAIA9cUF0h9c4j2HfNQPfYw_88) (tanWrapper__vm_u13427)); T38_.ClE_0 = NIM_NIL;
	T39_ = (NI)0;
	T39_ = registerCallback__vmdef_u2258((*colonenv__1).c0, TM__pyAIA9cUF0h9c4j2HfNQPfYw_86, T38_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T40_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T40_.ClP_0 = ((TM__pyAIA9cUF0h9c4j2HfNQPfYw_92) (tanhWrapper__vm_u13434)); T40_.ClE_0 = NIM_NIL;
	T41_ = (NI)0;
	T41_ = registerCallback__vmdef_u2258((*colonenv__1).c0, TM__pyAIA9cUF0h9c4j2HfNQPfYw_90, T40_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T42_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T42_.ClP_0 = ((TM__pyAIA9cUF0h9c4j2HfNQPfYw_95) (powWrapper__vm_u13441)); T42_.ClE_0 = NIM_NIL;
	T43_ = (NI)0;
	T43_ = registerCallback__vmdef_u2258((*colonenv__1).c0, TM__pyAIA9cUF0h9c4j2HfNQPfYw_94, T42_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T44_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T44_.ClP_0 = ((TM__pyAIA9cUF0h9c4j2HfNQPfYw_99) (truncWrapper__vm_u13443)); T44_.ClE_0 = NIM_NIL;
	T45_ = (NI)0;
	T45_ = registerCallback__vmdef_u2258((*colonenv__1).c0, TM__pyAIA9cUF0h9c4j2HfNQPfYw_97, T44_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T46_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T46_.ClP_0 = ((TM__pyAIA9cUF0h9c4j2HfNQPfYw_103) (floorWrapper__vm_u13450)); T46_.ClE_0 = NIM_NIL;
	T47_ = (NI)0;
	T47_ = registerCallback__vmdef_u2258((*colonenv__1).c0, TM__pyAIA9cUF0h9c4j2HfNQPfYw_101, T46_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T48_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T48_.ClP_0 = ((TM__pyAIA9cUF0h9c4j2HfNQPfYw_107) (ceilWrapper__vm_u13457)); T48_.ClE_0 = NIM_NIL;
	T49_ = (NI)0;
	T49_ = registerCallback__vmdef_u2258((*colonenv__1).c0, TM__pyAIA9cUF0h9c4j2HfNQPfYw_105, T48_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T50_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T50_.ClP_0 = ((TM__pyAIA9cUF0h9c4j2HfNQPfYw_111) (erfWrapper__vm_u13464)); T50_.ClE_0 = NIM_NIL;
	T51_ = (NI)0;
	T51_ = registerCallback__vmdef_u2258((*colonenv__1).c0, TM__pyAIA9cUF0h9c4j2HfNQPfYw_109, T50_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T52_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T52_.ClP_0 = ((TM__pyAIA9cUF0h9c4j2HfNQPfYw_115) (erfcWrapper__vm_u13471)); T52_.ClE_0 = NIM_NIL;
	T53_ = (NI)0;
	T53_ = registerCallback__vmdef_u2258((*colonenv__1).c0, TM__pyAIA9cUF0h9c4j2HfNQPfYw_113, T52_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T54_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T54_.ClP_0 = ((TM__pyAIA9cUF0h9c4j2HfNQPfYw_119) (gammaWrapper__vm_u13478)); T54_.ClE_0 = NIM_NIL;
	T55_ = (NI)0;
	T55_ = registerCallback__vmdef_u2258((*colonenv__1).c0, TM__pyAIA9cUF0h9c4j2HfNQPfYw_117, T54_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T56_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T56_.ClP_0 = ((TM__pyAIA9cUF0h9c4j2HfNQPfYw_123) (lgammaWrapper__vm_u13485)); T56_.ClE_0 = NIM_NIL;
	T57_ = (NI)0;
	T57_ = registerCallback__vmdef_u2258((*colonenv__1).c0, TM__pyAIA9cUF0h9c4j2HfNQPfYw_121, T56_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T58_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T58_.ClP_0 = ((TM__pyAIA9cUF0h9c4j2HfNQPfYw_129) (divmodWrapper__vm_u13492)); T58_.ClE_0 = NIM_NIL;
	T59_ = (NI)0;
	T59_ = registerCallback__vmdef_u2258((*colonenv__1).c0, TM__pyAIA9cUF0h9c4j2HfNQPfYw_125, T58_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T60_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T60_.ClP_0 = ((TM__pyAIA9cUF0h9c4j2HfNQPfYw_132) (copySignWrapper__vm_u13540)); T60_.ClE_0 = NIM_NIL;
	T61_ = (NI)0;
	T61_ = registerCallback__vmdef_u2258((*colonenv__1).c0, TM__pyAIA9cUF0h9c4j2HfNQPfYw_131, T60_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T62_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T62_.ClP_0 = ((TM__pyAIA9cUF0h9c4j2HfNQPfYw_136) (signbitWrapper__vm_u13556)); T62_.ClE_0 = NIM_NIL;
	T63_ = (NI)0;
	T63_ = registerCallback__vmdef_u2258((*colonenv__1).c0, TM__pyAIA9cUF0h9c4j2HfNQPfYw_134, T62_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T64_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T64_.ClP_0 = ((TM__pyAIA9cUF0h9c4j2HfNQPfYw_139) (colonanonymous___vm_u13566)); T64_.ClE_0 = NIM_NIL;
	T65_ = (NI)0;
	T65_ = registerCallback__vmdef_u2258((*colonenv__1).c0, TM__pyAIA9cUF0h9c4j2HfNQPfYw_138, T64_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T66_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T66_.ClP_0 = ((TM__pyAIA9cUF0h9c4j2HfNQPfYw_142) (modWrapper__vm_u13575)); T66_.ClE_0 = NIM_NIL;
	T67_ = (NI)0;
	T67_ = registerCallback__vmdef_u2258((*colonenv__1).c0, TM__pyAIA9cUF0h9c4j2HfNQPfYw_141, T66_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T68_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T68_.ClP_0 = ((TM__pyAIA9cUF0h9c4j2HfNQPfYw_148) (getEnvWrapper__vm_u13577)); T68_.ClE_0 = NIM_NIL;
	T69_ = (NI)0;
	T69_ = registerCallback__vmdef_u2258((*colonenv__1).c0, TM__pyAIA9cUF0h9c4j2HfNQPfYw_144, T68_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T70_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T70_.ClP_0 = ((TM__pyAIA9cUF0h9c4j2HfNQPfYw_151) (existsEnvWrapper__vm_u13579)); T70_.ClE_0 = NIM_NIL;
	T71_ = (NI)0;
	T71_ = registerCallback__vmdef_u2258((*colonenv__1).c0, TM__pyAIA9cUF0h9c4j2HfNQPfYw_150, T70_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T72_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T72_.ClP_0 = ((TM__pyAIA9cUF0h9c4j2HfNQPfYw_154) (putEnvWrapper__vm_u13581)); T72_.ClE_0 = NIM_NIL;
	T73_ = (NI)0;
	T73_ = registerCallback__vmdef_u2258((*colonenv__1).c0, TM__pyAIA9cUF0h9c4j2HfNQPfYw_153, T72_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T74_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T74_.ClP_0 = ((TM__pyAIA9cUF0h9c4j2HfNQPfYw_157) (delEnvWrapper__vm_u13583)); T74_.ClE_0 = NIM_NIL;
	T75_ = (NI)0;
	T75_ = registerCallback__vmdef_u2258((*colonenv__1).c0, TM__pyAIA9cUF0h9c4j2HfNQPfYw_156, T74_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T76_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T76_.ClP_0 = ((TM__pyAIA9cUF0h9c4j2HfNQPfYw_160) (dirExistsWrapper__vm_u13585)); T76_.ClE_0 = NIM_NIL;
	T77_ = (NI)0;
	T77_ = registerCallback__vmdef_u2258((*colonenv__1).c0, TM__pyAIA9cUF0h9c4j2HfNQPfYw_159, T76_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T78_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T78_.ClP_0 = ((TM__pyAIA9cUF0h9c4j2HfNQPfYw_163) (fileExistsWrapper__vm_u13587)); T78_.ClE_0 = NIM_NIL;
	T79_ = (NI)0;
	T79_ = registerCallback__vmdef_u2258((*colonenv__1).c0, TM__pyAIA9cUF0h9c4j2HfNQPfYw_162, T78_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T80_ = (NI)0;
	{
		NIM_BOOL T83_;
		NIM_BOOL T85_;
		tyProc__c9bXGQkBnyyGGVw063jrwZw T89_;
		T83_ = (NIM_BOOL)0;
		T83_ = !((((*(*(*colonenv__1).c0).config).features &((NU32)1<<((NU)((((tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ)10)))&31U)))!=0));
		if (!(T83_)) goto LA84_;
		T85_ = (NIM_BOOL)0;
		T85_ = NIM_FALSE;
		if (T85_) goto LA86_;
		T85_ = ((*(*(*colonenv__1).c0).config).cmd == ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)8));
LA86_: ;
		T83_ = T85_;
LA84_: ;
		if (!T83_) goto LA87_;
		nimZeroMem((void*)(&T89_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
		T89_.ClP_0 = ((TM__pyAIA9cUF0h9c4j2HfNQPfYw_166) (writeFileWrapper__vm_u13597)); T89_.ClE_0 = NIM_NIL;
		colontmpD_ = registerCallback__vmdef_u2258((*colonenv__1).c0, TM__pyAIA9cUF0h9c4j2HfNQPfYw_165, T89_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T80_ = colontmpD_;
	}
	goto LA81_;
LA87_: ;
	{
		tyProc__c9bXGQkBnyyGGVw063jrwZw T91_;
		nimZeroMem((void*)(&T91_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
		T91_.ClP_0 = ((TM__pyAIA9cUF0h9c4j2HfNQPfYw_168) (writeFileWrapper__vm_u13599)); T91_.ClE_0 = NIM_NIL;
		colontmpD__2 = registerCallback__vmdef_u2258((*colonenv__1).c0, TM__pyAIA9cUF0h9c4j2HfNQPfYw_167, T91_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T80_ = colontmpD__2;
	}
LA81_: ;
	T92_ = (NI)0;
	{
		NIM_BOOL T95_;
		NIM_BOOL T97_;
		tyProc__c9bXGQkBnyyGGVw063jrwZw T101_;
		T95_ = (NIM_BOOL)0;
		T95_ = !((((*(*(*colonenv__1).c0).config).features &((NU32)1<<((NU)((((tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ)10)))&31U)))!=0));
		if (!(T95_)) goto LA96_;
		T97_ = (NIM_BOOL)0;
		T97_ = NIM_FALSE;
		if (T97_) goto LA98_;
		T97_ = ((*(*(*colonenv__1).c0).config).cmd == ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)8));
LA98_: ;
		T95_ = T97_;
LA96_: ;
		if (!T95_) goto LA99_;
		nimZeroMem((void*)(&T101_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
		T101_.ClP_0 = ((TM__pyAIA9cUF0h9c4j2HfNQPfYw_171) (createDirWrapper__vm_u13609)); T101_.ClE_0 = NIM_NIL;
		colontmpD__3 = registerCallback__vmdef_u2258((*colonenv__1).c0, TM__pyAIA9cUF0h9c4j2HfNQPfYw_170, T101_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T92_ = colontmpD__3;
	}
	goto LA93_;
LA99_: ;
	{
		tyProc__c9bXGQkBnyyGGVw063jrwZw T103_;
		nimZeroMem((void*)(&T103_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
		T103_.ClP_0 = ((TM__pyAIA9cUF0h9c4j2HfNQPfYw_173) (createDirWrapper__vm_u13611)); T103_.ClE_0 = NIM_NIL;
		colontmpD__4 = registerCallback__vmdef_u2258((*colonenv__1).c0, TM__pyAIA9cUF0h9c4j2HfNQPfYw_172, T103_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T92_ = colontmpD__4;
	}
LA93_: ;
	nimZeroMem((void*)(&T104_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T104_.ClP_0 = ((TM__pyAIA9cUF0h9c4j2HfNQPfYw_176) (readFileWrapper__vm_u13613)); T104_.ClE_0 = NIM_NIL;
	T105_ = (NI)0;
	T105_ = registerCallback__vmdef_u2258((*colonenv__1).c0, TM__pyAIA9cUF0h9c4j2HfNQPfYw_175, T104_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T106_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T106_.ClP_0 = ((TM__pyAIA9cUF0h9c4j2HfNQPfYw_179) (readLinesWrapper__vm_u13615)); T106_.ClE_0 = NIM_NIL;
	T107_ = (NI)0;
	T107_ = registerCallback__vmdef_u2258((*colonenv__1).c0, TM__pyAIA9cUF0h9c4j2HfNQPfYw_178, T106_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T108_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T108_.ClP_0 = ((TM__pyAIA9cUF0h9c4j2HfNQPfYw_184) (getCurrentExceptionMsgWrapper__vm_u13115)); T108_.ClE_0 = NIM_NIL;
	T109_ = (NI)0;
	T109_ = registerCallback__vmdef_u2258((*colonenv__1).c0, TM__pyAIA9cUF0h9c4j2HfNQPfYw_181, T108_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T110_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T110_.ClP_0 = ((TM__pyAIA9cUF0h9c4j2HfNQPfYw_187) (getCurrentExceptionWrapper__vm_u13120)); T110_.ClE_0 = NIM_NIL;
	T111_ = (NI)0;
	T111_ = registerCallback__vmdef_u2258((*colonenv__1).c0, TM__pyAIA9cUF0h9c4j2HfNQPfYw_186, T110_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T112_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T112_.ClP_0 = ((TM__pyAIA9cUF0h9c4j2HfNQPfYw_190) (raiseDefectWrapper__vm_u13122)); T112_.ClE_0 = NIM_NIL;
	T113_ = (NI)0;
	T113_ = registerCallback__vmdef_u2258((*colonenv__1).c0, TM__pyAIA9cUF0h9c4j2HfNQPfYw_189, T112_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T114_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T114_.ClP_0 = ((TM__pyAIA9cUF0h9c4j2HfNQPfYw_197) (colonanonymous___vm_u13617)); T114_.ClE_0 = NIM_NIL;
	T115_ = (NI)0;
	T115_ = registerCallback__vmdef_u2258((*colonenv__1).c0, TM__pyAIA9cUF0h9c4j2HfNQPfYw_192, T114_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T116_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T116_.ClP_0 = ((TM__pyAIA9cUF0h9c4j2HfNQPfYw_200) (colonanonymous___vm_u13619)); T116_.ClE_0 = NIM_NIL;
	T117_ = (NI)0;
	T117_ = registerCallback__vmdef_u2258((*colonenv__1).c0, TM__pyAIA9cUF0h9c4j2HfNQPfYw_199, T116_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T118_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T118_.ClP_0 = ((TM__pyAIA9cUF0h9c4j2HfNQPfYw_203) (colonanonymous___vm_u13621)); T118_.ClE_0 = NIM_NIL;
	T119_ = (NI)0;
	T119_ = registerCallback__vmdef_u2258((*colonenv__1).c0, TM__pyAIA9cUF0h9c4j2HfNQPfYw_202, T118_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T120_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T120_.ClP_0 = colonanonymous___vm_u13623; T120_.ClE_0 = colonenv__1;
	T121_ = (NI)0;
	T121_ = registerCallback__vmdef_u2258((*colonenv__1).c0, TM__pyAIA9cUF0h9c4j2HfNQPfYw_205, T120_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T122_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T122_.ClP_0 = colonanonymous___vm_u13625; T122_.ClE_0 = colonenv__1;
	T123_ = (NI)0;
	T123_ = registerCallback__vmdef_u2258((*colonenv__1).c0, TM__pyAIA9cUF0h9c4j2HfNQPfYw_207, T122_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		NIM_BOOL T126_;
		T126_ = (NIM_BOOL)0;
		T126_ = NIM_FALSE;
		if (T126_) goto LA127_;
		T126_ = ((*(*(*colonenv__1).c0).config).cmd == ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)8));
LA127_: ;
		if (!T126_) goto LA128_;
	}
	goto LA124_;
LA128_: ;
	{
		tyProc__c9bXGQkBnyyGGVw063jrwZw T131_;
		NI T132_;
		nimZeroMem((void*)(&T131_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
		T131_.ClP_0 = gorgeExWrapper__vm_u13286; T131_.ClE_0 = colonenv__1;
		T132_ = (NI)0;
		T132_ = registerCallback__vmdef_u2258((*colonenv__1).c0, TM__pyAIA9cUF0h9c4j2HfNQPfYw_209, T131_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA124_: ;
	nimZeroMem((void*)(&T133_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T133_.ClP_0 = getProjectPathWrapper__vm_u13309; T133_.ClE_0 = colonenv__1;
	T134_ = (NI)0;
	T134_ = registerCallback__vmdef_u2258((*colonenv__1).c0, TM__pyAIA9cUF0h9c4j2HfNQPfYw_211, T133_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T135_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T135_.ClP_0 = ((TM__pyAIA9cUF0h9c4j2HfNQPfYw_214) (colonanonymous___vm_u13631)); T135_.ClE_0 = NIM_NIL;
	T136_ = (NI)0;
	T136_ = registerCallback__vmdef_u2258((*colonenv__1).c0, TM__pyAIA9cUF0h9c4j2HfNQPfYw_213, T135_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T137_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T137_.ClP_0 = colonanonymous___vm_u13633; T137_.ClE_0 = colonenv__1;
	T138_ = (NI)0;
	T138_ = registerCallback__vmdef_u2258((*colonenv__1).c0, TM__pyAIA9cUF0h9c4j2HfNQPfYw_216, T137_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T139_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T139_.ClP_0 = colonanonymous___vm_u13643; T139_.ClE_0 = colonenv__1;
	T140_ = (NI)0;
	T140_ = registerCallback__vmdef_u2258((*colonenv__1).c0, TM__pyAIA9cUF0h9c4j2HfNQPfYw_234, T139_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T141_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T141_.ClP_0 = colonanonymous___vm_u13657; T141_.ClE_0 = colonenv__1;
	T142_ = (NI)0;
	T142_ = registerCallback__vmdef_u2258((*colonenv__1).c0, TM__pyAIA9cUF0h9c4j2HfNQPfYw_238, T141_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T143_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T143_.ClP_0 = colonanonymous___vm_u13837; T143_.ClE_0 = colonenv__1;
	T144_ = (NI)0;
	T144_ = registerCallback__vmdef_u2258((*colonenv__1).c0, TM__pyAIA9cUF0h9c4j2HfNQPfYw_240, T143_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T145_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T145_.ClP_0 = hashVmImpl__vm_u13839; T145_.ClE_0 = colonenv__1;
	T146_ = (NI)0;
	T146_ = registerCallback__vmdef_u2258((*colonenv__1).c0, TM__pyAIA9cUF0h9c4j2HfNQPfYw_242, T145_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T147_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T147_.ClP_0 = hashVmImplByte__vm_u13846; T147_.ClE_0 = colonenv__1;
	T148_ = (NI)0;
	T148_ = registerCallback__vmdef_u2258((*colonenv__1).c0, TM__pyAIA9cUF0h9c4j2HfNQPfYw_244, T147_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T149_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T149_.ClP_0 = hashVmImplByte__vm_u13846; T149_.ClE_0 = colonenv__1;
	T150_ = (NI)0;
	T150_ = registerCallback__vmdef_u2258((*colonenv__1).c0, TM__pyAIA9cUF0h9c4j2HfNQPfYw_246, T149_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T151_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T151_.ClP_0 = ((TM__pyAIA9cUF0h9c4j2HfNQPfYw_249) (colonanonymous___vm_u13910)); T151_.ClE_0 = NIM_NIL;
	T152_ = (NI)0;
	T152_ = registerCallback__vmdef_u2258((*colonenv__1).c0, TM__pyAIA9cUF0h9c4j2HfNQPfYw_248, T151_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T153_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T153_.ClP_0 = ((TM__pyAIA9cUF0h9c4j2HfNQPfYw_252) (colonanonymous___vm_u13912)); T153_.ClE_0 = NIM_NIL;
	T154_ = (NI)0;
	T154_ = registerCallback__vmdef_u2258((*colonenv__1).c0, TM__pyAIA9cUF0h9c4j2HfNQPfYw_251, T153_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T155_ = (NI)0;
	{
		NIM_BOOL T158_;
		tyProc__c9bXGQkBnyyGGVw063jrwZw T162_;
		T158_ = (NIM_BOOL)0;
		T158_ = (((*(*(*colonenv__1).c0).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)49)))&63U)))!=0);
		if (T158_) goto LA159_;
		T158_ = (((*(*(*colonenv__1).c0).config).features &((NU32)1<<((NU)((((tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ)10)))&31U)))!=0);
LA159_: ;
		if (!T158_) goto LA160_;
		nimZeroMem((void*)(&T162_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
		T162_.ClP_0 = ((TM__pyAIA9cUF0h9c4j2HfNQPfYw_255) (cpuTimeWrapper__vm_u13922)); T162_.ClE_0 = NIM_NIL;
		colontmpD__5 = registerCallback__vmdef_u2258((*colonenv__1).c0, TM__pyAIA9cUF0h9c4j2HfNQPfYw_254, T162_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T155_ = colontmpD__5;
	}
	goto LA156_;
LA160_: ;
	{
		tyProc__c9bXGQkBnyyGGVw063jrwZw T164_;
		nimZeroMem((void*)(&T164_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
		T164_.ClP_0 = ((TM__pyAIA9cUF0h9c4j2HfNQPfYw_257) (cpuTimeWrapper__vm_u13926)); T164_.ClE_0 = NIM_NIL;
		colontmpD__6 = registerCallback__vmdef_u2258((*colonenv__1).c0, TM__pyAIA9cUF0h9c4j2HfNQPfYw_256, T164_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T155_ = colontmpD__6;
	}
LA156_: ;
	{
		tyProc__c9bXGQkBnyyGGVw063jrwZw T169_;
		NI T170_;
		tyProc__c9bXGQkBnyyGGVw063jrwZw T171_;
		NI T172_;
		tyProc__c9bXGQkBnyyGGVw063jrwZw T173_;
		NI T174_;
		if (!(((*(*(*colonenv__1).c0).config).features &((NU32)1<<((NU)((((tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ)10)))&31U)))!=0)) goto LA167_;
		nimZeroMem((void*)(&T169_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
		T169_.ClP_0 = ((TM__pyAIA9cUF0h9c4j2HfNQPfYw_260) (colonanonymous___vm_u13932)); T169_.ClE_0 = NIM_NIL;
		T170_ = (NI)0;
		T170_ = registerCallback__vmdef_u2258((*colonenv__1).c0, TM__pyAIA9cUF0h9c4j2HfNQPfYw_259, T169_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		nimZeroMem((void*)(&T171_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
		T171_.ClP_0 = ((TM__pyAIA9cUF0h9c4j2HfNQPfYw_265) (colonanonymous___vm_u13934)); T171_.ClE_0 = NIM_NIL;
		T172_ = (NI)0;
		T172_ = registerCallback__vmdef_u2258((*colonenv__1).c0, TM__pyAIA9cUF0h9c4j2HfNQPfYw_262, T171_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		nimZeroMem((void*)(&T173_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
		T173_.ClP_0 = colonanonymous___vm_u14016; T173_.ClE_0 = colonenv__1;
		T174_ = (NI)0;
		T174_ = registerCallback__vmdef_u2258((*colonenv__1).c0, TM__pyAIA9cUF0h9c4j2HfNQPfYw_267, T173_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA167_: ;
	nimZeroMem((void*)(&T175_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T175_.ClP_0 = colonanonymous___vm_u14038; T175_.ClE_0 = colonenv__1;
	T176_ = (NI)0;
	T176_ = registerCallback__vmdef_u2258((*colonenv__1).c0, TM__pyAIA9cUF0h9c4j2HfNQPfYw_269, T175_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T177_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T177_.ClP_0 = colonanonymous___vm_u14040; T177_.ClE_0 = colonenv__1;
	T178_ = (NI)0;
	T178_ = registerCallback__vmdef_u2258((*colonenv__1).c0, TM__pyAIA9cUF0h9c4j2HfNQPfYw_274, T177_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T179_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T179_.ClP_0 = colonanonymous___vm_u14042; T179_.ClE_0 = colonenv__1;
	T180_ = (NI)0;
	T180_ = registerCallback__vmdef_u2258((*colonenv__1).c0, TM__pyAIA9cUF0h9c4j2HfNQPfYw_276, T179_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T181_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T181_.ClP_0 = ((TM__pyAIA9cUF0h9c4j2HfNQPfYw_279) (colonanonymous___vm_u14044)); T181_.ClE_0 = NIM_NIL;
	T182_ = (NI)0;
	T182_ = registerCallback__vmdef_u2258((*colonenv__1).c0, TM__pyAIA9cUF0h9c4j2HfNQPfYw_278, T181_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T183_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T183_.ClP_0 = ((TM__pyAIA9cUF0h9c4j2HfNQPfYw_282) (colonanonymous___vm_u14055)); T183_.ClE_0 = NIM_NIL;
	T184_ = (NI)0;
	T184_ = registerCallback__vmdef_u2258((*colonenv__1).c0, TM__pyAIA9cUF0h9c4j2HfNQPfYw_281, T183_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T185_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T185_.ClP_0 = ((TM__pyAIA9cUF0h9c4j2HfNQPfYw_285) (colonanonymous___vm_u14074)); T185_.ClE_0 = NIM_NIL;
	T186_ = (NI)0;
	T186_ = registerCallback__vmdef_u2258((*colonenv__1).c0, TM__pyAIA9cUF0h9c4j2HfNQPfYw_284, T185_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T187_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T187_.ClP_0 = ((TM__pyAIA9cUF0h9c4j2HfNQPfYw_289) (colonanonymous___vm_u14089)); T187_.ClE_0 = NIM_NIL;
	T188_ = (NI)0;
	T188_ = registerCallback__vmdef_u2258((*colonenv__1).c0, TM__pyAIA9cUF0h9c4j2HfNQPfYw_287, T187_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T189_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T189_.ClP_0 = ((TM__pyAIA9cUF0h9c4j2HfNQPfYw_292) (colonanonymous___vm_u14097)); T189_.ClE_0 = NIM_NIL;
	T190_ = (NI)0;
	T190_ = registerCallback__vmdef_u2258((*colonenv__1).c0, TM__pyAIA9cUF0h9c4j2HfNQPfYw_291, T189_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T191_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T191_.ClP_0 = ((TM__pyAIA9cUF0h9c4j2HfNQPfYw_295) (colonanonymous___vm_u14101)); T191_.ClE_0 = NIM_NIL;
	T192_ = (NI)0;
	T192_ = registerCallback__vmdef_u2258((*colonenv__1).c0, TM__pyAIA9cUF0h9c4j2HfNQPfYw_294, T191_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T193_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T193_.ClP_0 = ((TM__pyAIA9cUF0h9c4j2HfNQPfYw_298) (colonanonymous___vm_u14104)); T193_.ClE_0 = NIM_NIL;
	T194_ = (NI)0;
	T194_ = registerCallback__vmdef_u2258((*colonenv__1).c0, TM__pyAIA9cUF0h9c4j2HfNQPfYw_297, T193_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T195_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T195_.ClP_0 = colonanonymous___vm_u14165; T195_.ClE_0 = colonenv__1;
	T196_ = (NI)0;
	T196_ = registerCallback__vmdef_u2258((*colonenv__1).c0, TM__pyAIA9cUF0h9c4j2HfNQPfYw_300, T195_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T197_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T197_.ClP_0 = colonanonymous___vm_u14168; T197_.ClE_0 = colonenv__1;
	T198_ = (NI)0;
	T198_ = registerCallback__vmdef_u2258((*colonenv__1).c0, TM__pyAIA9cUF0h9c4j2HfNQPfYw_302, T197_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqdestroy___vm_u14535(colonenv__1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, setupGlobalCtx__vm_u14200)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module_p0, tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p1, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p2) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew* T5_;
		if (!((*graph_p1).vm == 0)) goto LA3_;
		T5_ = NIM_NIL;
		T5_ = newCtx__vmdef_u383(module_p0, (*graph_p1).cache, graph_p1, idgen_p2);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___vmdef_u2206(T5_); goto BeforeRet_;}
		eqsink___ast_u4955(&(*graph_p1).vm, &T5_->Sup.Sup);
		registerAdditionalOps__vm_u13280((*((tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew**) (&((*graph_p1).vm)))));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA3_: ;
	{
		refresh__vmdef_u2227((*((tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew**) (&((*graph_p1).vm)))), module_p0, idgen_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, errorNode__vm_u12981)(tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* owner_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p2) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	result = newNodeI__ast_u4091(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)1), (*n_p2).info);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_ = NIM_NIL;
	T1_ = newType__ast_u5900(((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)50), idgen_p0, owner_p1, ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL));
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3378(T1_); goto BeforeRet_;}
	eqsink___ast_u3387(&(*result).typField, T1_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*(*result).typField).flags |= ((NU64)1)<<(((((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)38))) & 63);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, putIntoReg__vm_u523)(tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A* dest_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	switch ((*n_p1).kind) {
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)20) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)22):
	{
		tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A T2_;
		nimZeroMem((void*)(&T2_), sizeof(tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A));
		T2_.kind = ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1);
		T2_.node = newStrNode__ast_u5422(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)20), (*n_p1)._kind_3.strVal);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqsink___vmdef_u1715((&(*dest_p0)), T2_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)6):
	{
		{
			if (!((*dest_p0).kind == ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1))) goto LA6_;
			eqcopy___ast_u3255(&(*dest_p0).node, n_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		goto LA4_;
LA6_: ;
		{
			NIM_BOOL T9_;
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD_;
			tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A T13_;
			T9_ = (NIM_BOOL)0;
			T9_ = !(((*n_p1).typField == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL)));
			if (!(T9_)) goto LA10_;
			T9_ = ((*(*n_p1).typField).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)26) || (*(*n_p1).typField).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)21));
LA10_: ;
			if (!T9_) goto LA11_;
			nimZeroMem((void*)(&T13_), sizeof(tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A));
			T13_.kind = ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1);
			colontmpD_ = eqdup___ast_u3258(n_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			T13_.node = colontmpD_;
			eqsink___vmdef_u1715((&(*dest_p0)), T13_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		goto LA4_;
LA11_: ;
		{
			tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A T15_;
			nimZeroMem((void*)(&T15_), sizeof(tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A));
			T15_.kind = ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2);
			T15_.intVal = (*n_p1)._kind_1.intVal;
			eqsink___vmdef_u1715((&(*dest_p0)), T15_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA4_: ;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)5):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)7) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)15):
	{
		tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A T17_;
		nimZeroMem((void*)(&T17_), sizeof(tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A));
		T17_.kind = ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2);
		T17_.intVal = (*n_p1)._kind_1.intVal;
		eqsink___vmdef_u1715((&(*dest_p0)), T17_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)16) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)19):
	{
		tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A T19_;
		nimZeroMem((void*)(&T19_), sizeof(tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A));
		T19_.kind = ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)3);
		T19_.floatVal = (*n_p1)._kind_2.floatVal;
		eqsink___vmdef_u1715((&(*dest_p0)), T19_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	default:
	{
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__2;
		tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A T21_;
		nimZeroMem((void*)(&T21_), sizeof(tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A));
		T21_.kind = ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1);
		colontmpD__2 = eqdup___ast_u3258(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T21_.node = colontmpD__2;
		eqsink___vmdef_u1715((&(*dest_p0)), T21_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, prepareVMValue__vm_u14304)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* arg_p0) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
NIM_BOOL oldNimErrFin28_;
NIM_BOOL oldNimErrFin32_;
NIM_BOOL oldNimErrFin20_;
NIM_BOOL oldNimErrFin43_;
NIM_BOOL oldNimErrFin39_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	{
		if (!((*arg_p0).kind >= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)5) && (*arg_p0).kind <= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)22))) goto LA3_;
		eqcopy___ast_u3255(&result, arg_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		goto BeforeRet_;
	}
LA3_: ;
	{
		NIM_BOOL T7_;
		NIM_BOOL T8_;
		NIM_BOOL T9_;
		T7_ = (NIM_BOOL)0;
		T8_ = (NIM_BOOL)0;
		T9_ = (NIM_BOOL)0;
		T9_ = ((*arg_p0).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)34));
		if (!(T9_)) goto LA10_;
		T9_ = !(((*(*arg_p0)._kind_6.sons.p->data[((NI)0)]).typField == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL)));
LA10_: ;
		T8_ = T9_;
		if (!(T8_)) goto LA11_;
		T8_ = !(((*(*(*arg_p0)._kind_6.sons.p->data[((NI)0)]).typField).sym == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)));
LA11_: ;
		T7_ = T8_;
		if (!(T7_)) goto LA12_;
		T7_ = ((*(*(*(*arg_p0)._kind_6.sons.p->data[((NI)0)]).typField).sym).magic == ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)198));
LA12_: ;
		if (!T7_) goto LA13_;
		eqcopy___ast_u3255(&result, arg_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		goto BeforeRet_;
	}
LA13_: ;
	result = copyNode__ast_u6736(arg_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!((*arg_p0).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)160))) goto LA17_;
		{
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* child_1;
			child_1 = NIM_NIL;
			{
				NI i_1;
				NI colontmp_;
				NI i_2;
				i_1 = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = safeLen__ast_u3197(arg_p0);
				if (NIM_UNLIKELY(*nimErr_)) goto LA20_;
				i_2 = ((NI)0);
				{
					while (1) {
						if (!(i_2 < colontmp_)) goto LA23;
						i_1 = i_2;
						eqcopy___ast_u3255(&child_1, (*arg_p0)._kind_6.sons.p->data[i_1]);
						if (NIM_UNLIKELY(*nimErr_)) goto LA20_;
						{
							tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD_;
							if (!((*child_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)34))) goto LA26_;
							colontmpD_ = NIM_NIL;
							colontmpD_ = prepareVMValue__vm_u14304((*child_1)._kind_6.sons.p->data[((NI)1)]);
							if (NIM_UNLIKELY(*nimErr_)) goto LA28_;
							add__ast_u3215(result, colontmpD_);
							if (NIM_UNLIKELY(*nimErr_)) goto LA28_;
							{
								LA28_:;
							}
							{
								oldNimErrFin28_ = *nimErr_; *nimErr_ = NIM_FALSE;
								eqdestroy___ast_u3252(colontmpD_);
								if (NIM_UNLIKELY(*nimErr_)) goto LA20_;
								*nimErr_ = oldNimErrFin28_;
							}
							if (NIM_UNLIKELY(*nimErr_)) goto LA20_;
						}
						goto LA24_;
LA26_: ;
						{
							tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__2;
							colontmpD__2 = NIM_NIL;
							colontmpD__2 = prepareVMValue__vm_u14304(child_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA32_;
							add__ast_u3215(result, colontmpD__2);
							if (NIM_UNLIKELY(*nimErr_)) goto LA32_;
							{
								LA32_:;
							}
							{
								oldNimErrFin32_ = *nimErr_; *nimErr_ = NIM_FALSE;
								eqdestroy___ast_u3252(colontmpD__2);
								if (NIM_UNLIKELY(*nimErr_)) goto LA20_;
								*nimErr_ = oldNimErrFin32_;
							}
							if (NIM_UNLIKELY(*nimErr_)) goto LA20_;
						}
LA24_: ;
						i_2 += ((NI)1);
					} LA23: ;
				}
			}
			{
				LA20_:;
			}
			{
				oldNimErrFin20_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u3252(child_1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				*nimErr_ = oldNimErrFin20_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
	}
	goto LA15_;
LA17_: ;
	{
		{
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* child_2;
			child_2 = NIM_NIL;
			{
				NI i_3;
				NI colontmp__2;
				NI i_4;
				i_3 = (NI)0;
				colontmp__2 = (NI)0;
				colontmp__2 = safeLen__ast_u3197(arg_p0);
				if (NIM_UNLIKELY(*nimErr_)) goto LA39_;
				i_4 = ((NI)0);
				{
					while (1) {
						tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__3;
						if (!(i_4 < colontmp__2)) goto LA42;
						colontmpD__3 = NIM_NIL;
						i_3 = i_4;
						eqcopy___ast_u3255(&child_2, (*arg_p0)._kind_6.sons.p->data[i_3]);
						if (NIM_UNLIKELY(*nimErr_)) goto LA43_;
						colontmpD__3 = prepareVMValue__vm_u14304(child_2);
						if (NIM_UNLIKELY(*nimErr_)) goto LA43_;
						add__ast_u3215(result, colontmpD__3);
						if (NIM_UNLIKELY(*nimErr_)) goto LA43_;
						i_4 += ((NI)1);
						{
							LA43_:;
						}
						{
							oldNimErrFin43_ = *nimErr_; *nimErr_ = NIM_FALSE;
							eqdestroy___ast_u3252(colontmpD__3);
							if (NIM_UNLIKELY(*nimErr_)) goto LA39_;
							*nimErr_ = oldNimErrFin43_;
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA39_;
					} LA42: ;
				}
			}
			{
				LA39_:;
			}
			{
				oldNimErrFin39_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u3252(child_2);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				*nimErr_ = oldNimErrFin39_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
	}
LA15_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, setupMacroParam__vm_u14337)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* x_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p1, tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A* Result) {
NIM_BOOL oldNimErrFin2_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)Result, sizeof(tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A));
	switch ((*typ_p1).kind) {
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)60):
	{
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD_;
		colontmpD_ = NIM_NIL;
		nimZeroMem((void*)Result, sizeof(tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A));
		(*Result).kind = ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)0);
		colontmpD_ = prepareVMValue__vm_u14304(x_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
		putIntoReg__vm_u523(Result, colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
		{
			LA2_:;
		}
		{
			oldNimErrFin2_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3252(colontmpD_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin2_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	default:
	{
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_1;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* blitTmp_1;
		n_1 = NIM_NIL;
		eqcopy___ast_u3255(&n_1, x_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		{
			if (!((*n_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)59) || (*n_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)58))) goto LA8_;
			eqcopy___ast_u3255(&n_1, (*n_1)._kind_6.sons.p->data[((NI)1)]);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA8_: ;
		(*n_1).flags |= ((NU32)1)<<(((((tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw)13))) & 31);
		eqcopy___ast_u3381(&(*n_1).typField, (*x_p0).typField);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*Result).kind = ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1);
		blitTmp_1 = n_1;
		(*Result).node = blitTmp_1;
	}
	break;
	}
	}BeforeRet_: ;
}
static N_INLINE(NIM_BOOL, nimDecRefIsLastDyn)(void* p_p0) {
	NIM_BOOL result;
	result = NIM_FALSE;
	{
		tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* cell_1;
		NI T5_;
		if (!!((p_p0 == NIM_NIL))) goto LA3_;
		T5_ = (NI)0;
		T5_ = minuspercent___system_u805(((NI) (ptrdiff_t) (p_p0)), ((NI)8));
		cell_1 = ((tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A*) (T5_));
		{
			if (!((NI)((*cell_1).rc & ((NI)-16)) == ((NI)0))) goto LA8_;
			result = NIM_TRUE;
		}
		goto LA6_;
LA8_: ;
		{
			(*cell_1).rc = minuspercent___system_u805((*cell_1).rc, ((NI)16));
		}
LA6_: ;
		{
			if (!result) goto LA13_;
			{
				if (!(((NI)0) < (*cell_1).rootIdx)) goto LA17_;
				unregisterCycle__system_u3125(cell_1);
			}
LA17_: ;
		}
LA13_: ;
	}
LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___vm_u14789)(tyObject_Env_vmdotnim_rawExecute___hNEyCf8VhTK2S3ZJXhlD9cg* dest_p0) {
	eqdestroy___system_u2691((*dest_p0).error4);
	eqdestroy___system_u2691((*dest_p0).error3);
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastDyn((*dest_p0).tos1);
		if (!T3_) goto LA4_;
		eqdestroy___vmdef_u1600((&(*(*dest_p0).tos1)));
		nimRawDispose((*dest_p0).tos1, ((NI)4));
	}
LA4_: ;
	{
		NIM_BOOL T8_;
		T8_ = (NIM_BOOL)0;
		T8_ = nimDecRefIsLastCyclicDyn((*dest_p0).c0);
		if (!T8_) goto LA9_;
		nimDestroyAndDispose((*dest_p0).c0);
	}
LA9_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, rttiDestroy__vm_u15113)(void* dest_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqdestroy___vm_u14789((&(*((tyObject_Env_vmdotnim_rawExecute___hNEyCf8VhTK2S3ZJXhlD9cg*) (dest_p0)))));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqtrace___vm_u14801)(tyObject_Env_vmdotnim_rawExecute___hNEyCf8VhTK2S3ZJXhlD9cg* dest_p0, void* env_p1) {
	nimTraceRefDyn(&(*dest_p0).c0, env_p1);
}
static N_INLINE(void, enter__vmprofiler_u8)(tyObject_Profiler__YI4zs2CaXXndlYireD0I8A* prof_p0, tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew* c_p1, tyObject_TStackFrame__a20zU43j9cYHpYOOr1c2hZQ* tos_p2) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NF T5_;
		if (!(((*(*c_p1).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)53)))&63U)))!=0)) goto LA3_;
		T5_ = (NF)0;
		T5_ = cpuTime__pureZtimes_u5215();
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*prof_p0).tEnter = T5_;
		eqcopy___vmprofiler_u22(&(*prof_p0).tos, tos_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA3_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___vm_u14829)(tyObject_Env_vmdotnim_rawExecute___hNEyCf8VhTK2S3ZJXhlD9cg* dest_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastCyclicStatic(dest_p0, ((TNimTypeV2*) ((&NTIv2__hNEyCf8VhTK2S3ZJXhlD9cg_))));
		if (!T3_) goto LA4_;
		eqdestroy___vm_u14789((&(*dest_p0)));
		nimRawDispose(dest_p0, ((NI)4));
	}
LA4_: ;
}
static N_INLINE(NI*, X5BX5D___vm_u695)(NI* s_p0, NI s_p0Len_0, NI i_p1) {
	NI* result;
	result = (&s_p0[(NI)(s_p0Len_0 - i_p1)]);
	return result;
}
static N_INLINE(NI, pop__injectdestructors_u256)(tySequence__qwqHTkRvwhrRyENtudHQ7g* s_p0) {
	NI result;
	NI L_1;
	NI T1_;
	T1_ = (*s_p0).len;
	L_1 = (NI)(T1_ - ((NI)1));
	result = (*s_p0).p->data[L_1];
	eqwasMoved___system_u8096((&(*s_p0).p->data[L_1]));
	shrink__pureZosproc_u399(s_p0, (L_1));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, cleanUpOnReturn__vm_u683)(tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew* c_p0, tyObject_TStackFrame__a20zU43j9cYHpYOOr1c2hZQ* f_p1) {
	NI result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = ((NI)-1);
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*f_p1).safePoints.len;
		colontmp_ = T2_;
		res_1 = ((NI)1);
		{
			while (1) {
				NI pc_1;
				NI* T5_;
				if (!(res_1 <= colontmp_)) goto LA4;
				i_1 = ((NI) (res_1));
				T5_ = (NI*)0;
				T5_ = X5BX5D___vm_u695((((*f_p1).safePoints).p) ? ((*f_p1).safePoints.p->data) : NIM_NIL, (*f_p1).safePoints.len, i_1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				pc_1 = (*T5_);
				{
					while (1) {
						if (!(((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA) ((NU64)((NU64)((NU64)((*c_p0).code.p->data[pc_1]) >> (NU64)(0ULL & (64 - 1))) & 255ULL))) == ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)172))) goto LA7;
						pc_1 += (NI)(((NI) ((NU64)((NU64)((NU64)((*c_p0).code.p->data[pc_1]) >> (NU64)(24ULL & (64 - 1))) & 16777215ULL))) - ((NI)8388608));
					} LA7: ;
				}
				{
					NI T12_;
					if (!(((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA) ((NU64)((NU64)((NU64)((*c_p0).code.p->data[pc_1]) >> (NU64)(0ULL & (64 - 1))) & 255ULL))) == ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)173))) goto LA10_;
					T12_ = (NI)0;
					T12_ = pop__injectdestructors_u256((&(*f_p1).safePoints));
					(void)(T12_);
					result = (NI)(pc_1 + ((NI)1));
					goto BeforeRet_;
				}
LA10_: ;
				res_1 += ((NI)1);
			} LA4: ;
		}
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, copyValue__vm_u486)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* src_p0) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
	NimStringV2 colontmpD_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	{
		NIM_BOOL T4_;
		T4_ = (NIM_BOOL)0;
		T4_ = (src_p0 == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = (((*src_p0).flags &((NU32)1<<((NU)((((tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw)13)))&31U)))!=0);
LA5_: ;
		if (!T4_) goto LA6_;
		eqcopy___ast_u3255(&result, src_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		eqdestroy___system_u2691(colontmpD_);
		goto BeforeRet_;
	}
LA6_: ;
	result = newNode__ast_u4069((*src_p0).kind);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	(*result).info = (*src_p0).info;
	eqcopy___ast_u3381(&(*result).typField, (*src_p0).typField);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	(*result).flags = ((*src_p0).flags & 58386190);
	colontmpD_ = comment__ast_u836(src_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	commenteq___ast_u1334(result, colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	switch ((*src_p0).kind) {
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)5) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)15):
	{
		(*result)._kind_1.intVal = (*src_p0)._kind_1.intVal;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)16) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)19):
	{
		(*result)._kind_2.floatVal = (*src_p0)._kind_2.floatVal;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3):
	{
		eqcopy___ast_u4577(&(*result)._kind_4.sym, (*src_p0)._kind_4.sym);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)2):
	{
		eqcopy___idents_u158(&(*result)._kind_5.ident, (*src_p0)._kind_5.ident);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)20) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)22):
	{
		eqcopy___system_u2694((&(*result)._kind_3.strVal), (*src_p0)._kind_3.strVal);
	}
	break;
	default:
	{
		NI T14_;
		T14_ = (NI)0;
		T14_ = len__ast_u3190(src_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		newSeq__ast_u4100((&(*result)._kind_6.sons), (T14_));
		{
			NI i_1;
			NI colontmp_;
			NI i_2;
			i_1 = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__ast_u3190(src_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			i_2 = ((NI)0);
			{
				while (1) {
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T18_;
					if (!(i_2 < colontmp_)) goto LA17;
					i_1 = i_2;
					T18_ = NIM_NIL;
					T18_ = copyValue__vm_u486((*src_p0)._kind_6.sons.p->data[i_1]);
					if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T18_); goto LA1_;}
					eqsink___ast_u3261(&(*result)._kind_6.sons.p->data[i_1], T18_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					i_2 += ((NI)1);
				} LA17: ;
			}
		}
	}
	break;
	}
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD_);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, asgnComplex__vm_u510)(tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A* x_p0, tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A y_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	ensureKind__vm_u122(x_p0, y_p1.kind);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	switch ((*x_p0).kind) {
	case ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)0):
	{
	}
	break;
	case ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2):
	{
		(*x_p0).intVal = y_p1.intVal;
	}
	break;
	case ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)3):
	{
		(*x_p0).floatVal = y_p1.floatVal;
	}
	break;
	case ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1):
	{
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T5_;
		T5_ = NIM_NIL;
		T5_ = copyValue__vm_u486(y_p1.node);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T5_); goto BeforeRet_;}
		eqsink___ast_u3261(&(*x_p0).node, T5_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)4):
	{
		(*x_p0).regAddr = y_p1.regAddr;
	}
	break;
	case ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)5):
	{
		(*x_p0).nodeAddr = y_p1.nodeAddr;
	}
	break;
	default: __builtin_unreachable();
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, fastAsgnComplex__vm_u513)(tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A* x_p0, tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A y_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	ensureKind__vm_u122(x_p0, y_p1.kind);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	switch ((*x_p0).kind) {
	case ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)0):
	{
	}
	break;
	case ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2):
	{
		(*x_p0).intVal = y_p1.intVal;
	}
	break;
	case ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)3):
	{
		(*x_p0).floatVal = y_p1.floatVal;
	}
	break;
	case ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1):
	{
		eqcopy___ast_u3255(&(*x_p0).node, y_p1.node);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)4):
	{
		(*x_p0).regAddr = y_p1.regAddr;
	}
	break;
	case ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)5):
	{
		(*x_p0).nodeAddr = y_p1.nodeAddr;
	}
	break;
	default: __builtin_unreachable();
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, moveConst__vm_u480)(tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A* x_p0, tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A y_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	ensureKind__vm_u122(x_p0, y_p1.kind);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	switch ((*x_p0).kind) {
	case ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)0):
	{
	}
	break;
	case ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2):
	{
		(*x_p0).intVal = y_p1.intVal;
	}
	break;
	case ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)3):
	{
		(*x_p0).floatVal = y_p1.floatVal;
	}
	break;
	case ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1):
	{
		eqcopy___ast_u3255(&(*x_p0).node, y_p1.node);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)4):
	{
		(*x_p0).regAddr = y_p1.regAddr;
	}
	break;
	case ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)5):
	{
		(*x_p0).nodeAddr = y_p1.nodeAddr;
	}
	break;
	default: __builtin_unreachable();
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_CLOSURE(void, rangeCheck__vm_u1072)(NI64 left_p0, NI64 right_p1, NI64 safeLen_p2, void* ClE_0) {
	tyObject_Env_vmdotnim_rawExecute___hNEyCf8VhTK2S3ZJXhlD9cg* colonenvP__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colonenvP__1 = (tyObject_Env_vmdotnim_rawExecute___hNEyCf8VhTK2S3ZJXhlD9cg*) ClE_0;
	{
		NimStringV2 colontmpD_;
		NimStringV2 colontmpD__2;
		NimStringV2 T6_;
		tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T13_;
		if (!(left_p0 < IL64(0))) goto LA3_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		T6_.len = 0; T6_.p = NIM_NIL;
		{
			if (!(safeLen_p2 < IL64(0))) goto LA9_;
			colontmpD_ = TM__pyAIA9cUF0h9c4j2HfNQPfYw_325;
			T6_ = colontmpD_;
		}
		goto LA7_;
LA9_: ;
		{
			NimStringV2 colontmpD__3;
			NimStringV2 colontmpD__4;
			NimStringV2 T12_;
			colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
			colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
			T12_.len = 0; T12_.p = NIM_NIL;
			colontmpD__3 = dollar___systemZdollars_u29(left_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
			colontmpD__4 = dollar___systemZdollars_u29(safeLen_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
			T12_ = rawNewString(colontmpD__3.len + colontmpD__4.len + 19);
appendString((&T12_), TM__pyAIA9cUF0h9c4j2HfNQPfYw_327);
appendString((&T12_), colontmpD__3);
appendString((&T12_), TM__pyAIA9cUF0h9c4j2HfNQPfYw_329);
appendString((&T12_), colontmpD__4);
			colontmpD__2 = T12_;
			eqdestroy___system_u2691(colontmpD__4);
			eqdestroy___system_u2691(colontmpD__3);
			T6_ = colontmpD__2;
		}
LA7_: ;
		nimZeroMem((void*)(&T13_), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
		stackTraceImpl__vm_u73((*colonenvP__1).c0, (*colonenvP__1).tos1, (*colonenvP__1).pc2, T6_, T13_, TM__pyAIA9cUF0h9c4j2HfNQPfYw_230);
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(colontmpD_);
		goto BeforeRet_;
		{
			LA5_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__2);
			eqdestroy___system_u2691(colontmpD_);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA3_: ;
	{
		NimStringV2 colontmpD__5;
		NimStringV2 colontmpD__6;
		NimStringV2 T21_;
		tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T28_;
		if (!(safeLen_p2 < right_p1)) goto LA18_;
		colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
		colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
		T21_.len = 0; T21_.p = NIM_NIL;
		{
			if (!(safeLen_p2 < IL64(0))) goto LA24_;
			colontmpD__5 = TM__pyAIA9cUF0h9c4j2HfNQPfYw_330;
			T21_ = colontmpD__5;
		}
		goto LA22_;
LA24_: ;
		{
			NimStringV2 colontmpD__7;
			NimStringV2 colontmpD__8;
			NimStringV2 T27_;
			colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
			colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
			T27_.len = 0; T27_.p = NIM_NIL;
			colontmpD__7 = dollar___systemZdollars_u29(right_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA20_;
			colontmpD__8 = dollar___systemZdollars_u29(safeLen_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA20_;
			T27_ = rawNewString(colontmpD__7.len + colontmpD__8.len + 19);
appendString((&T27_), TM__pyAIA9cUF0h9c4j2HfNQPfYw_331);
appendString((&T27_), colontmpD__7);
appendString((&T27_), TM__pyAIA9cUF0h9c4j2HfNQPfYw_332);
appendString((&T27_), colontmpD__8);
			colontmpD__6 = T27_;
			eqdestroy___system_u2691(colontmpD__8);
			eqdestroy___system_u2691(colontmpD__7);
			T21_ = colontmpD__6;
		}
LA22_: ;
		nimZeroMem((void*)(&T28_), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
		stackTraceImpl__vm_u73((*colonenvP__1).c0, (*colonenvP__1).tos1, (*colonenvP__1).pc2, T21_, T28_, TM__pyAIA9cUF0h9c4j2HfNQPfYw_230);
		if (NIM_UNLIKELY(*nimErr_)) goto LA20_;
		eqdestroy___system_u2691(colontmpD__6);
		eqdestroy___system_u2691(colontmpD__5);
		goto BeforeRet_;
		{
			LA20_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__6);
			eqdestroy___system_u2691(colontmpD__5);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA18_: ;
	}BeforeRet_: ;
}
static N_INLINE(NI, safeArrLen__ast_u3204)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0) {
	NI result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	{
		if (!((*n_p0).kind >= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)20) && (*n_p0).kind <= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)22))) goto LA3_;
		result = (*n_p0)._kind_3.strVal.len;
	}
	goto LA1_;
LA3_: ;
	{
		if (!((*n_p0).kind >= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)0) && (*n_p0).kind <= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)19))) goto LA6_;
		result = ((NI)0);
	}
	goto LA1_;
LA6_: ;
	{
		result = len__ast_u3190(n_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, contains__vm_u1214)(tyObject_HSlice__QbYBq0DTmYHIHa8KuurQ6Q s_p0, NI value_p1) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	T1_ = (NIM_BOOL)0;
	T1_ = (s_p0.a <= value_p1);
	if (!(T1_)) goto LA2_;
	T1_ = (((NI64) (value_p1)) <= s_p0.b);
LA2_: ;
	result = T1_;
	return result;
}
static N_INLINE(tyObject_HSlice__QbYBq0DTmYHIHa8KuurQ6Q, dotdot___vm_u1109)(NI a_p0, NI64 b_p1) {
	tyObject_HSlice__QbYBq0DTmYHIHa8KuurQ6Q result;
	result.a = a_p0;
	result.b = b_p1;
	return result;
}
static N_INLINE(NIM_BOOL, ltpercent___system_u1092)(NI x_p0, NI y_p1) {
	NIM_BOOL result;
	result = ((NU32)(((NU) (x_p0))) < (NU32)(((NU) (y_p1))));
	return result;
}
static N_INLINE(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, owner__ast_u6254)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p0) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	eqcopy___ast_u4577(&result, (*s_p0).ownerField);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, takeCharAddress__vm_u864)(tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* src_p1, NI64 index_p2, NI pc_p3, tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A* Result) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_1;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD_;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__2;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* node_1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* blitTmp_1;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)Result, sizeof(tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A));
	typ_1 = NIM_NIL;
	colontmpD_ = NIM_NIL;
	colontmpD__2 = NIM_NIL;
	node_1 = NIM_NIL;
	colontmpD_ = owner__ast_u6254((*c_p0).module);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	typ_1 = newType__ast_u5900(((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)21), (*c_p0).Sup.idgen, colontmpD_, ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__2 = getSysType__magicsys_u55((*c_p0).graph, (*c_p0).debug.p->data[pc_p3], ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)2));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	add__ast_u3881(typ_1, colontmpD__2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	node_1 = newNodeIT__ast_u4112(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)6), (*c_p0).debug.p->data[pc_p3], typ_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	(*node_1)._kind_1.intVal = ((NI64) (((NI) (ptrdiff_t) ((&(*src_p1)._kind_3.strVal.p->data[index_p2])))));
	(*node_1).flags |= ((NU32)1)<<(((((tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw)14))) & 31);
	(*Result).kind = ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1);
	blitTmp_1 = node_1;
	eqwasMoved___ast_u3249(&node_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	(*Result).node = blitTmp_1;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3252(node_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(colontmpD__2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u4574(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(typ_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(void, nimPrepareStrMutationV2)(NimStringV2* s_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = !(((*s_p0).p == ((NimStrPayload*) NIM_NIL)));
		if (!(T3_)) goto LA4_;
		T3_ = ((NI)((*(*s_p0).p).cap & ((NI)1073741824)) == ((NI)1073741824));
LA4_: ;
		if (!T3_) goto LA5_;
		nimPrepareStrMutationImpl__system_u2430(s_p0);
	}
LA5_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, writeField__vm_u516)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** n_p0, tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A x_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	switch (x_p1.kind) {
	case ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)0):
	{
	}
	break;
	case ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2):
	{
		{
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ T7_;
			if (!((*(*n_p0)).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)23))) goto LA5_;
			nimZeroMem((void*)(&T7_), sizeof(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ));
			nimZeroMem((void*)(&T7_), sizeof(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ));
			T7_.kind = ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)6);
			T7_._kind_1.intVal = 0;
			eqsink___ast_u3279((&(*(*n_p0))), (&T7_));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA5_: ;
		(*(*n_p0))._kind_1.intVal = x_p1.intVal;
	}
	break;
	case ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)3):
	{
		(*(*n_p0))._kind_2.floatVal = x_p1.floatVal;
	}
	break;
	case ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1):
	{
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T10_;
		T10_ = NIM_NIL;
		T10_ = copyValue__vm_u486(x_p1.node);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T10_); goto BeforeRet_;}
		eqsink___ast_u3261(&(*n_p0), T10_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)4):
	{
		writeField__vm_u516(n_p0, (*x_p1.regAddr));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)5):
	{
		eqcopy___ast_u3255(&(*n_p0), (*x_p1.nodeAddr));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	default: __builtin_unreachable();
	}
	}BeforeRet_: ;
}
static N_INLINE(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg**, X5BX5D___ast_u5281)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg** s_p0, NI s_p0Len_0, NI i_p1) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg** result;
	result = &s_p0[(NI)(s_p0Len_0 - i_p1)];
	return result;
}
static N_INLINE(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, elementType__ast_u5331)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* n_p0) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* result;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg** T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	T1_ = (tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg**)0;
	T1_ = X5BX5D___ast_u5281((((*n_p0).sons).p) ? ((*n_p0).sons.p->data) : NIM_NIL, (*n_p0).sons.len, ((NI)1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqcopy___ast_u3381(&result, (*T1_));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, derefPtrToReg__vm_u144)(NI64 address_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p1, tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A* r_p2, NIM_BOOL isAssign_p3) {
	NIM_BOOL result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	switch ((*typ_p1).kind) {
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)2):
	{
		{
			if (!isAssign_p3) goto LA4_;
			(*((NIM_CHAR*) (address_p0))) = ((NIM_CHAR) ((*r_p2).intVal));
		}
		goto LA2_;
LA4_: ;
		{
			NIM_CHAR valX60gensym12__1;
			ensureKind__vm_u122(r_p2, ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			valX60gensym12__1 = (*((NIM_CHAR*) (address_p0)));
			(*r_p2).intVal = ((NI64) (((NU8)(valX60gensym12__1))));
		}
LA2_: ;
		result = NIM_TRUE;
		goto BeforeRet_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)31):
	{
		{
			if (!isAssign_p3) goto LA10_;
			(*((NI*) (address_p0))) = ((NI) ((*r_p2).intVal));
		}
		goto LA8_;
LA10_: ;
		{
			NI valX60gensym13__1;
			ensureKind__vm_u122(r_p2, ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			valX60gensym13__1 = (*((NI*) (address_p0)));
			(*r_p2).intVal = ((NI64) (valX60gensym13__1));
		}
LA8_: ;
		result = NIM_TRUE;
		goto BeforeRet_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)32):
	{
		{
			if (!isAssign_p3) goto LA16_;
			(*((NI8*) (address_p0))) = ((NI8) ((*r_p2).intVal));
		}
		goto LA14_;
LA16_: ;
		{
			NI8 valX60gensym14__1;
			ensureKind__vm_u122(r_p2, ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			valX60gensym14__1 = (*((NI8*) (address_p0)));
			(*r_p2).intVal = ((NI64) (valX60gensym14__1));
		}
LA14_: ;
		result = NIM_TRUE;
		goto BeforeRet_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)33):
	{
		{
			if (!isAssign_p3) goto LA22_;
			(*((NI16*) (address_p0))) = ((NI16) ((*r_p2).intVal));
		}
		goto LA20_;
LA22_: ;
		{
			NI16 valX60gensym15__1;
			ensureKind__vm_u122(r_p2, ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			valX60gensym15__1 = (*((NI16*) (address_p0)));
			(*r_p2).intVal = ((NI64) (valX60gensym15__1));
		}
LA20_: ;
		result = NIM_TRUE;
		goto BeforeRet_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)34):
	{
		{
			if (!isAssign_p3) goto LA28_;
			(*((NI32*) (address_p0))) = ((NI32) ((*r_p2).intVal));
		}
		goto LA26_;
LA28_: ;
		{
			NI32 valX60gensym16__1;
			ensureKind__vm_u122(r_p2, ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			valX60gensym16__1 = (*((NI32*) (address_p0)));
			(*r_p2).intVal = ((NI64) (valX60gensym16__1));
		}
LA26_: ;
		result = NIM_TRUE;
		goto BeforeRet_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)35):
	{
		{
			if (!isAssign_p3) goto LA34_;
			(*((NI64*) (address_p0))) = (*r_p2).intVal;
		}
		goto LA32_;
LA34_: ;
		{
			NI64 valX60gensym17__1;
			ensureKind__vm_u122(r_p2, ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			valX60gensym17__1 = (*((NI64*) (address_p0)));
			(*r_p2).intVal = valX60gensym17__1;
		}
LA32_: ;
		result = NIM_TRUE;
		goto BeforeRet_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)40):
	{
		{
			if (!isAssign_p3) goto LA40_;
			(*((NU*) (address_p0))) = ((NU) ((*r_p2).intVal));
		}
		goto LA38_;
LA40_: ;
		{
			NU valX60gensym18__1;
			ensureKind__vm_u122(r_p2, ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			valX60gensym18__1 = (*((NU*) (address_p0)));
			(*r_p2).intVal = ((NI64) (valX60gensym18__1));
		}
LA38_: ;
		result = NIM_TRUE;
		goto BeforeRet_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)41):
	{
		{
			if (!isAssign_p3) goto LA46_;
			(*((NU8*) (address_p0))) = ((NU8) ((*r_p2).intVal));
		}
		goto LA44_;
LA46_: ;
		{
			NU8 valX60gensym19__1;
			ensureKind__vm_u122(r_p2, ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			valX60gensym19__1 = (*((NU8*) (address_p0)));
			(*r_p2).intVal = ((NI64) (valX60gensym19__1));
		}
LA44_: ;
		result = NIM_TRUE;
		goto BeforeRet_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)42):
	{
		{
			if (!isAssign_p3) goto LA52_;
			(*((NU16*) (address_p0))) = ((NU16) ((*r_p2).intVal));
		}
		goto LA50_;
LA52_: ;
		{
			NU16 valX60gensym20__1;
			ensureKind__vm_u122(r_p2, ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			valX60gensym20__1 = (*((NU16*) (address_p0)));
			(*r_p2).intVal = ((NI64) (valX60gensym20__1));
		}
LA50_: ;
		result = NIM_TRUE;
		goto BeforeRet_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)43):
	{
		{
			if (!isAssign_p3) goto LA58_;
			(*((NU32*) (address_p0))) = ((NU32) ((*r_p2).intVal));
		}
		goto LA56_;
LA58_: ;
		{
			NU32 valX60gensym21__1;
			ensureKind__vm_u122(r_p2, ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			valX60gensym21__1 = (*((NU32*) (address_p0)));
			(*r_p2).intVal = ((NI64) (valX60gensym21__1));
		}
LA56_: ;
		result = NIM_TRUE;
		goto BeforeRet_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)44):
	{
		{
			if (!isAssign_p3) goto LA64_;
			(*((NU64*) (address_p0))) = ((NU64) ((*r_p2).intVal));
		}
		goto LA62_;
LA64_: ;
		{
			NU64 valX60gensym22__1;
			ensureKind__vm_u122(r_p2, ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			valX60gensym22__1 = (*((NU64*) (address_p0)));
			(*r_p2).intVal = ((NI64) (valX60gensym22__1));
		}
LA62_: ;
		result = NIM_TRUE;
		goto BeforeRet_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)36):
	{
		{
			if (!isAssign_p3) goto LA70_;
			(*((NF*) (address_p0))) = (*r_p2).floatVal;
		}
		goto LA68_;
LA70_: ;
		{
			NF valX60gensym23__1;
			ensureKind__vm_u122(r_p2, ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)3));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			valX60gensym23__1 = (*((NF*) (address_p0)));
			(*r_p2).floatVal = valX60gensym23__1;
		}
LA68_: ;
		result = NIM_TRUE;
		goto BeforeRet_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)37):
	{
		{
			if (!isAssign_p3) goto LA76_;
			(*((NF32*) (address_p0))) = ((NF32) ((*r_p2).floatVal));
		}
		goto LA74_;
LA76_: ;
		{
			NF32 valX60gensym24__1;
			ensureKind__vm_u122(r_p2, ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)3));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			valX60gensym24__1 = (*((NF32*) (address_p0)));
			(*r_p2).floatVal = ((NF) (valX60gensym24__1));
		}
LA74_: ;
		result = NIM_TRUE;
		goto BeforeRet_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)38):
	{
		{
			if (!isAssign_p3) goto LA82_;
			(*((NF*) (address_p0))) = (*r_p2).floatVal;
		}
		goto LA80_;
LA82_: ;
		{
			NF valX60gensym25__1;
			ensureKind__vm_u122(r_p2, ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)3));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			valX60gensym25__1 = (*((NF*) (address_p0)));
			(*r_p2).floatVal = valX60gensym25__1;
		}
LA80_: ;
		result = NIM_TRUE;
		goto BeforeRet_;
	}
	break;
	default:
	{
		result = NIM_FALSE;
		goto BeforeRet_;
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI64, pluspercent___system_u801)(NI64 x_p0, NI64 y_p1) {
	NI64 result;
	result = ((NI64) ((NU64)((NU64)(((NU64) (x_p0))) + (NU64)(((NU64) (y_p1))))));
	return result;
}
static N_INLINE(NI64, minuspercent___system_u821)(NI64 x_p0, NI64 y_p1) {
	NI64 result;
	result = ((NI64) ((NU64)((NU64)(((NU64) (x_p0))) - (NU64)(((NU64) (y_p1))))));
	return result;
}
static N_INLINE(NI, nimCStrLen)(NCSTRING a_p0) {
	NI result;
	size_t T5_;
{	{
		if (!(a_p0 == 0)) goto LA3_;
		result = ((NI)0);
		goto BeforeRet_;
	}
LA3_: ;
	T5_ = (size_t)0;
	T5_ = strlen(a_p0);
	result = ((NI) (T5_));
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI64, starpercent___system_u841)(NI64 x_p0, NI64 y_p1) {
	NI64 result;
	result = ((NI64) ((NU64)((NU64)(((NU64) (x_p0))) * (NU64)(((NU64) (y_p1))))));
	return result;
}
static N_INLINE(NF, toBiggestFloat__system_u1698)(NI64 i_p0) {
	NF result;
	result = ((NF) (i_p0));
	return result;
}
static N_INLINE(NF, abs__system_u5136)(NF x_p0) {
	NF result;
	result = (NF)0;
	result = fabs(x_p0);
	return result;
}
static N_INLINE(NI64, slashpercent___system_u861)(NI64 x_p0, NI64 y_p1) {
	NI64 result;
	result = ((NI64) ((NU64)((NU64)(((NU64) (x_p0))) / (NU64)(((NU64) (y_p1))))));
	return result;
}
static N_INLINE(NI64, percentpercent___system_u881)(NI64 x_p0, NI64 y_p1) {
	NI64 result;
	result = ((NI64) ((NU64)((NU64)(((NU64) (x_p0))) % (NU64)(((NU64) (y_p1))))));
	return result;
}
static N_INLINE(NIM_BOOL, lteqpercent___system_u1088)(NI64 x_p0, NI64 y_p1) {
	NIM_BOOL result;
	result = ((NU64)(((NU64) (x_p0))) <= (NU64)(((NU64) (y_p1))));
	return result;
}
static N_INLINE(NIM_BOOL, ltpercent___system_u1108)(NI64 x_p0, NI64 y_p1) {
	NIM_BOOL result;
	result = ((NU64)(((NU64) (x_p0))) < (NU64)(((NU64) (y_p1))));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, ptrEquality__vm_u2392)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** n1_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n2_p1) {
	NIM_BOOL result;
	NI p1_1;
NIM_BOOL oldNimErrFin3_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	p1_1 = ((NI) (ptrdiff_t) (n1_p0));
	switch ((*n2_p1).kind) {
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)23):
	{
		result = (p1_1 == ((NI)0));
		goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)6):
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t2_1;
		NIM_BOOL T4_;
		t2_1 = NIM_NIL;
		t2_1 = skipTypes__ast_u5379((*n2_p1).typField, TM__pyAIA9cUF0h9c4j2HfNQPfYw_417);
		if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*t2_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)26) || (*t2_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)21));
		if (!(T4_)) goto LA5_;
		T4_ = ((*n2_p1)._kind_1.intVal == ((NI64) (p1_1)));
LA5_: ;
		result = T4_;
		eqdestroy___ast_u3378(t2_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		goto BeforeRet_;
		{
			LA3_:;
		}
		{
			oldNimErrFin3_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3378(t2_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin3_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	default:
	{
		result = NIM_FALSE;
		goto BeforeRet_;
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
static N_INLINE(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, getBody__modulegraphs_u17880)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	eqcopy___ast_u3255(&result, (*(*s_p1).ast)._kind_6.sons.p->data[((NI)6)]);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		NIM_BOOL T3_;
		tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* T7_;
		tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* T8_;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T9_;
		T3_ = (NIM_BOOL)0;
		T3_ = (result == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL));
		if (!(T3_)) goto LA4_;
		T3_ = ((*(*g_p0).config).symbolFiles == ((tyEnum_SymbolFilesOption__2eyIIreuRXhYT9buPPZbBYA)2) || (*(*g_p0).config).symbolFiles == ((tyEnum_SymbolFilesOption__2eyIIreuRXhYT9buPPZbBYA)3) || (*(*g_p0).config).symbolFiles == ((tyEnum_SymbolFilesOption__2eyIIreuRXhYT9buPPZbBYA)4));
LA4_: ;
		if (!T3_) goto LA5_;
		T7_ = NIM_NIL;
		T7_ = (*g_p0).config;
		T8_ = NIM_NIL;
		T8_ = (*g_p0).cache;
		T9_ = NIM_NIL;
		T9_ = loadProcBody__icZic_u21187(T7_, T8_, (&(*g_p0).packed_0), s_p1);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T9_); goto BeforeRet_;}
		eqsink___ast_u3261(&result, T9_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqcopy___ast_u3255(&(*(*s_p1).ast)._kind_6.sons.p->data[((NI)6)], result);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA5_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, importcCond__vmgen_u2499)(tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew* c_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1) {
	NIM_BOOL result;
NIM_BOOL oldNimErrFin9_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_FALSE;
	{
		if (!(((*s_p1).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)6)))&63U)))!=0)) goto LA3_;
		{
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD_;
			if (!((*s_p1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)12) || (*s_p1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)13) || (*s_p1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)14) || (*s_p1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)15) || (*s_p1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)16) || (*s_p1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)17) || (*s_p1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)18))) goto LA7_;
			colontmpD_ = NIM_NIL;
			colontmpD_ = getBody__modulegraphs_u17880((*c_p0).graph, s_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
			result = isEmptyBody__vmgen_u2487(colontmpD_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
			eqdestroy___ast_u3252(colontmpD_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			goto BeforeRet_;
			{
				LA9_:;
			}
			{
				oldNimErrFin9_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u3252(colontmpD_);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				*nimErr_ = oldNimErrFin9_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA7_: ;
	}
LA3_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_VmProcInfo__Jux30icZSrOlvcFTG81Ljg, compile__vm_u803)(tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew* c_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1) {
	tyObject_VmProcInfo__Jux30icZSrOlvcFTG81Ljg result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&result), sizeof(tyObject_VmProcInfo__Jux30icZSrOlvcFTG81Ljg));
	result = genProc__vmgen_u3092(c_p0, s_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, returnType__ast_u5354)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* n_p0) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	eqcopy___ast_u3381(&result, (*n_p0).sons.p->data[((NI)0)]);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, isEmptyType__ast_u7234)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p0) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	T1_ = (NIM_BOOL)0;
	T1_ = (t_p0 == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL));
	if (T1_) goto LA2_;
	T1_ = ((*t_p0).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)63) || (*t_p0).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)7));
LA2_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, recSetFlagIsRef__vm_u808)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* arg_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!(((*arg_p0).kind >= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)20) && (*arg_p0).kind <= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)22)))) goto LA3_;
		(*arg_p0).flags |= ((NU32)1)<<(((((tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw)13))) & 31);
	}
LA3_: ;
	{
		NI i_1;
		NI colontmp_;
		NI i_2;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = safeLen__ast_u3197(arg_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		i_2 = ((NI)0);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA7;
				i_1 = i_2;
				recSetFlagIsRef__vm_u808((*arg_p0)._kind_6.sons.p->data[i_1]);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				i_2 += ((NI)1);
			} LA7: ;
		}
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, pushSafePoint__vm_u547)(tyObject_TStackFrame__a20zU43j9cYHpYOOr1c2hZQ* f_p0, NI pc_p1) {
	add__varpartitions_u1538((&(*f_p0).safePoints), pc_p1);
}
N_LIB_PRIVATE N_NIMCALL(void, popSafePoint__vm_u554)(tyObject_TStackFrame__a20zU43j9cYHpYOOr1c2hZQ* f_p0) {
	NI T1_;
	T1_ = (NI)0;
	T1_ = pop__injectdestructors_u256((&(*f_p0).safePoints));
	(void)(T1_);
}
N_LIB_PRIVATE N_NIMCALL(tyTuple__BQblRMJ3qVZJdz8oXhBMaQ, findExceptionHandler__vm_u566)(tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew* c_p0, tyObject_TStackFrame__a20zU43j9cYHpYOOr1c2hZQ* f_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* exc_p2) {
	tyTuple__BQblRMJ3qVZJdz8oXhBMaQ result;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* raisedType_1;
NIM_BOOL oldNimErrFin9_;
	tyEnum_ExceptionGoto__UXGPMKK1kMiyMPS9b1jNcmg colontmp__5;
	NI colontmp__6;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&result), sizeof(tyTuple__BQblRMJ3qVZJdz8oXhBMaQ));
	raisedType_1 = NIM_NIL;
	raisedType_1 = skipTypes__ast_u5379((*exc_p2).typField, TM__pyAIA9cUF0h9c4j2HfNQPfYw_460);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		while (1) {
			NI T4_;
			NI pc_1;
			NIM_BOOL matched_1;
			NI pcEndExcept_1;
			NI pcBody_1;
			T4_ = (*f_p1).safePoints.len;
			if (!(((NI)0) < T4_)) goto LA3;
			pc_1 = pop__injectdestructors_u256((&(*f_p1).safePoints));
			matched_1 = NIM_FALSE;
			pcEndExcept_1 = pc_1;
			{
				while (1) {
					if (!(((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA) ((NU64)((NU64)((NU64)((*c_p0).code.p->data[pc_1]) >> (NU64)(0ULL & (64 - 1))) & 255ULL))) == ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)172))) goto LA6;
					pcEndExcept_1 = (NI)((NI)(pc_1 + ((NI) ((NU64)((NU64)((NU64)((*c_p0).code.p->data[pc_1]) >> (NU64)(24ULL & (64 - 1))) & 16777215ULL)))) - ((NI)8388608));
					pc_1 += ((NI)1);
					{
						while (1) {
							tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* exceptType_1;
							NI excIndex_1;
							tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* T10_;
							if (!(((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA) ((NU64)((NU64)((NU64)((*c_p0).code.p->data[pc_1]) >> (NU64)(0ULL & (64 - 1))) & 255ULL))) == ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)172))) goto LA8;
							exceptType_1 = NIM_NIL;
							excIndex_1 = (NI)(((NI) ((NU64)((NU64)((NU64)((*c_p0).code.p->data[pc_1]) >> (NU64)(24ULL & (64 - 1))) & 16777215ULL))) - ((NI)8388608));
							T10_ = NIM_NIL;
							{
								if (!(((NI)0) < excIndex_1)) goto LA13_;
								exceptType_1 = skipTypes__ast_u5379((*c_p0).types.p->data[excIndex_1], TM__pyAIA9cUF0h9c4j2HfNQPfYw_460);
								if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
							}
							goto LA11_;
LA13_: ;
							{
								exceptType_1 = ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL);
							}
LA11_: ;
							{
								NIM_BOOL T18_;
								NI T20_;
								T18_ = (NIM_BOOL)0;
								T18_ = (exceptType_1 == 0);
								if (T18_) goto LA19_;
								T20_ = (NI)0;
								T20_ = inheritanceDiff__types_u2785(raisedType_1, exceptType_1);
								if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
								T18_ = (T20_ <= ((NI)0));
LA19_: ;
								if (!T18_) goto LA21_;
								matched_1 = NIM_TRUE;
								eqdestroy___ast_u3378(exceptType_1);
								if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
								goto LA7;
							}
LA21_: ;
							pc_1 += ((NI)1);
							{
								LA9_:;
							}
							{
								oldNimErrFin9_ = *nimErr_; *nimErr_ = NIM_FALSE;
								eqdestroy___ast_u3378(exceptType_1);
								if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
								*nimErr_ = oldNimErrFin9_;
							}
							if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						} LA8: ;
					} LA7: ;
					{
						while (1) {
							if (!(((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA) ((NU64)((NU64)((NU64)((*c_p0).code.p->data[pc_1]) >> (NU64)(0ULL & (64 - 1))) & 255ULL))) == ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)172))) goto LA26;
							pc_1 += ((NI)1);
						} LA26: ;
					}
					{
						if (!matched_1) goto LA29_;
						goto LA5;
					}
LA29_: ;
					pc_1 = pcEndExcept_1;
				} LA6: ;
			} LA5: ;
			pcBody_1 = pc_1;
			{
				tyEnum_ExceptionGoto__UXGPMKK1kMiyMPS9b1jNcmg colontmp_;
				NI colontmp__2;
				if (!matched_1) goto LA33_;
				colontmp_ = ((tyEnum_ExceptionGoto__UXGPMKK1kMiyMPS9b1jNcmg)0);
				colontmp__2 = pcBody_1;
				result.Field0 = colontmp_;
				result.Field1 = colontmp__2;
				eqdestroy___ast_u3378(raisedType_1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				goto BeforeRet_;
			}
			goto LA31_;
LA33_: ;
			{
				tyEnum_ExceptionGoto__UXGPMKK1kMiyMPS9b1jNcmg colontmp__3;
				NI colontmp__4;
				if (!(((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA) ((NU64)((NU64)((NU64)((*c_p0).code.p->data[pc_1]) >> (NU64)(0ULL & (64 - 1))) & 255ULL))) == ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)173))) goto LA36_;
				colontmp__3 = ((tyEnum_ExceptionGoto__UXGPMKK1kMiyMPS9b1jNcmg)1);
				colontmp__4 = (NI)(pc_1 + ((NI)1));
				result.Field0 = colontmp__3;
				result.Field1 = colontmp__4;
				eqdestroy___ast_u3378(raisedType_1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				goto BeforeRet_;
			}
			goto LA31_;
LA36_: ;
LA31_: ;
		} LA3: ;
	}
	colontmp__5 = ((tyEnum_ExceptionGoto__UXGPMKK1kMiyMPS9b1jNcmg)2);
	colontmp__6 = ((NI)0);
	result.Field0 = colontmp__5;
	result.Field1 = colontmp__6;
	eqdestroy___ast_u3378(raisedType_1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	goto BeforeRet_;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(raisedType_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, bailOut__vm_u119)(tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew* c_p0, tyObject_TStackFrame__a20zU43j9cYHpYOOr1c2hZQ* tos_p1) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD_;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__2;
	NimStringV2 colontmpD__3;
	NimStringV2 T2_;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T3_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_ = NIM_NIL;
	colontmpD__2 = NIM_NIL;
	colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
	T2_.len = 0; T2_.p = NIM_NIL;
	colontmpD_ = skipColon__ast_u7347((*(*c_p0).currentExceptionA)._kind_6.sons.p->data[((NI)3)]);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__2 = skipColon__ast_u7347((*(*c_p0).currentExceptionA)._kind_6.sons.p->data[((NI)2)]);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T2_ = rawNewString((*colontmpD_)._kind_3.strVal.len + (*colontmpD__2)._kind_3.strVal.len + 24);
appendString((&T2_), TM__pyAIA9cUF0h9c4j2HfNQPfYw_462);
appendString((&T2_), (*colontmpD_)._kind_3.strVal);
appendString((&T2_), TM__pyAIA9cUF0h9c4j2HfNQPfYw_464);
appendString((&T2_), (*colontmpD__2)._kind_3.strVal);
appendString((&T2_), TM__pyAIA9cUF0h9c4j2HfNQPfYw_465);
	colontmpD__3 = T2_;
	nimZeroMem((void*)(&T3_), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
	stackTraceImpl__vm_u73(c_p0, tos_p1, (*c_p0).exceptionInstr, colontmpD__3, T3_, TM__pyAIA9cUF0h9c4j2HfNQPfYw_230);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	eqdestroy___system_u2691(colontmpD__3);
	eqdestroy___ast_u3252(colontmpD__2);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqdestroy___ast_u3252(colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	goto BeforeRet_;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___system_u2691(colontmpD__3);
		eqdestroy___ast_u3252(colontmpD__2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3252(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, setLenSeq__vm_u823)(tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* node_p1, NI newLen_p2, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p3) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_1;
	NI oldLen_1;
NIM_BOOL oldNimErrFin9_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	typ_1 = NIM_NIL;
	typ_1 = skipTypes__ast_u5379((*node_p1).typField, TM__pyAIA9cUF0h9c4j2HfNQPfYw_466);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	oldLen_1 = len__ast_u3190(node_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	setLen__ast_u3718((&(*node_p1)._kind_6.sons), (newLen_p2));
	{
		if (!(oldLen_1 < newLen_p2)) goto LA4_;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T10_;
					if (!(i_2 < newLen_p2)) goto LA8;
					colontmpD_ = NIM_NIL;
					i_1 = i_2;
					colontmpD_ = elementType__ast_u5331(typ_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
					T10_ = NIM_NIL;
					T10_ = getNullValue__vmgen_u2515(c_p0, colontmpD_, info_p3, (*c_p0).config);
					if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T10_); goto LA9_;}
					eqsink___ast_u3261(&(*node_p1)._kind_6.sons.p->data[i_1], T10_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
					i_2 += ((NI)1);
					{
						LA9_:;
					}
					{
						oldNimErrFin9_ = *nimErr_; *nimErr_ = NIM_FALSE;
						eqdestroy___ast_u3378(colontmpD_);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						*nimErr_ = oldNimErrFin9_;
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				} LA8: ;
			}
		}
	}
LA4_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(typ_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(NIM_BOOL, lteqpercent___system_u1072)(NI x_p0, NI y_p1) {
	NIM_BOOL result;
	result = ((NU32)(((NU) (x_p0))) <= (NU32)(((NU) (y_p1))));
	return result;
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___vm_u3895)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA msg_p2, NimStringV2 arg_p3, void* ClE_0) {
	tyObject_Env_vmdotnim_rawExecute___hNEyCf8VhTK2S3ZJXhlD9cg* colonenvP__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colonenvP__1 = (tyObject_Env_vmdotnim_rawExecute___hNEyCf8VhTK2S3ZJXhlD9cg*) ClE_0;
	{
		NIM_BOOL T3_;
		NimStringV2 T7_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*colonenvP__1).error3.len == ((NI)0));
		if (!(T3_)) goto LA4_;
		T3_ = (msg_p2 <= ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)19));
LA4_: ;
		if (!T3_) goto LA5_;
		T7_.len = 0; T7_.p = NIM_NIL;
		T7_ = formatMsg__msgs_u1220(conf_p0, info_p1, msg_p2, arg_p3);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T7_); goto BeforeRet_;}
		eqsink___system_u2700((&(*colonenvP__1).error3), T7_);
	}
LA5_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___vm_u3916)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA msg_p2, NimStringV2 arg_p3, void* ClE_0) {
	tyObject_Env_vmdotnim_rawExecute___hNEyCf8VhTK2S3ZJXhlD9cg* colonenvP__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colonenvP__1 = (tyObject_Env_vmdotnim_rawExecute___hNEyCf8VhTK2S3ZJXhlD9cg*) ClE_0;
	{
		NIM_BOOL T3_;
		NimStringV2 T7_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*colonenvP__1).error4.len == ((NI)0));
		if (!(T3_)) goto LA4_;
		T3_ = (msg_p2 <= ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)19));
LA4_: ;
		if (!T3_) goto LA5_;
		T7_.len = 0; T7_.p = NIM_NIL;
		T7_ = formatMsg__msgs_u1220(conf_p0, info_p1, msg_p2, arg_p3);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T7_); goto BeforeRet_;}
		eqsink___system_u2700((&(*colonenvP__1).error4), T7_);
	}
LA5_: ;
	}BeforeRet_: ;
}
static N_INLINE(void, addInt__stdZprivateZdigitsutils_u204)(NimStringV2* result_p0, NI x_p1) {
	addInt__stdZprivateZdigitsutils_u187(result_p0, ((NI64) (x_p1)));
}
static N_INLINE(NimStringV2, toFileLineCol__msgs_u701)(tyTuple__kN8up2W6YKc5YA9avn5mV5w info_p0) {
	NimStringV2 result;
	result = TM__pyAIA9cUF0h9c4j2HfNQPfYw_529;
	prepareAdd((&result), info_p0.Field0.len + 0);
appendString((&result), info_p0.Field0);
	{
		if (!(((NI)0) < info_p0.Field1)) goto LA3_;
		prepareAdd((&result), 1);
appendString((&result), TM__pyAIA9cUF0h9c4j2HfNQPfYw_531);
		addInt__stdZprivateZdigitsutils_u204((&result), info_p0.Field1);
		{
			if (!(((NI)0) < (NI)(info_p0.Field2 + ((NI)1)))) goto LA7_;
			prepareAdd((&result), 2);
appendString((&result), TM__pyAIA9cUF0h9c4j2HfNQPfYw_532);
			addInt__stdZprivateZdigitsutils_u204((&result), (NI)(info_p0.Field2 + ((NI)1)));
		}
LA7_: ;
		prepareAdd((&result), 1);
appendString((&result), TM__pyAIA9cUF0h9c4j2HfNQPfYw_534);
	}
LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, opConv__vm_u731)(tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew* c_p0, tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A* dest_p1, tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A src_p2, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* desttyp_p3, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* srctyp_p4) {
	NIM_BOOL result;
NIM_BOOL oldNimErrFin27_;
NIM_BOOL oldNimErrFin8_;
NIM_BOOL oldNimErrFin70_;
NIM_BOOL oldNimErrFin5_;
NIM_BOOL oldNimErrFin95_;
NIM_BOOL oldNimErrFin111_;
NIM_BOOL oldNimErrFin129_;
NIM_BOOL oldNimErrFin93_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_FALSE;
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* styp_1;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T6_;
		if (!((*desttyp_p3).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)28))) goto LA3_;
		styp_1 = NIM_NIL;
		ensureKind__vm_u122(dest_p1, ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		T6_ = NIM_NIL;
		T6_ = newNode__ast_u4069(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)20));
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T6_); goto LA5_;}
		eqsink___ast_u3261(&(*dest_p1).node, T6_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		styp_1 = skipTypes__ast_u5379(srctyp_p4, TM__pyAIA9cUF0h9c4j2HfNQPfYw_537);
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		switch ((*styp_1).kind) {
		case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)14):
		{
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_1;
			tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* f_1;
			NI x_1;
			n_1 = NIM_NIL;
			f_1 = NIM_NIL;
			eqcopy___ast_u3255(&n_1, (*styp_1).n);
			if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
			x_1 = ((NI) (src_p2.intVal));
			{
				NIM_BOOL T11_;
				NI T12_;
				NimStringV2 T16_;
				T11_ = (NIM_BOOL)0;
				T12_ = (NI)0;
				T12_ = len__ast_u3190(n_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
				T11_ = ltpercent___system_u1092(x_1, T12_);
				if (!(T11_)) goto LA13_;
				f_1 = (*(*n_1)._kind_6.sons.p->data[x_1])._kind_4.sym;
				T11_ = ((*f_1).position == x_1);
LA13_: ;
				if (!T11_) goto LA14_;
				T16_.len = 0; T16_.p = NIM_NIL;
				{
					if (!((*f_1).ast == 0)) goto LA19_;
					eqcopy___system_u2694((&(*(*dest_p1).node)._kind_3.strVal), (*(*f_1).name).s);
				}
				goto LA17_;
LA19_: ;
				{
					eqcopy___system_u2694((&(*(*dest_p1).node)._kind_3.strVal), (*(*f_1).ast)._kind_3.strVal);
				}
LA17_: ;
			}
			goto LA9_;
LA14_: ;
			{
				NimStringV2 colontmpD_;
				NimStringV2 T44_;
				colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
				{
					NI i_1;
					NI colontmp_;
					NI i_2;
					i_1 = (NI)0;
					colontmp_ = (NI)0;
					colontmp_ = len__ast_u3190(n_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
					i_2 = ((NI)0);
					{
						while (1) {
							tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* f_2;
							if (!(i_2 < colontmp_)) goto LA26;
							f_2 = NIM_NIL;
							i_1 = i_2;
							{
								if (!!(((*(*n_1)._kind_6.sons.p->data[i_1]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3)))) goto LA30_;
								internalErrorImpl__msgs_u1598((*c_p0).config, unknownLineInfo__lineinfos_u364, TM__pyAIA9cUF0h9c4j2HfNQPfYw_539, TM__pyAIA9cUF0h9c4j2HfNQPfYw_540);
								if (NIM_UNLIKELY(*nimErr_)) goto LA27_;
							}
LA30_: ;
							eqcopy___ast_u4577(&f_2, (*(*n_1)._kind_6.sons.p->data[i_1])._kind_4.sym);
							if (NIM_UNLIKELY(*nimErr_)) goto LA27_;
							{
								NimStringV2 T36_;
								if (!((*f_2).position == x_1)) goto LA34_;
								T36_.len = 0; T36_.p = NIM_NIL;
								{
									if (!((*f_2).ast == 0)) goto LA39_;
									eqcopy___system_u2694((&(*(*dest_p1).node)._kind_3.strVal), (*(*f_2).name).s);
								}
								goto LA37_;
LA39_: ;
								{
									eqcopy___system_u2694((&(*(*dest_p1).node)._kind_3.strVal), (*(*f_2).ast)._kind_3.strVal);
								}
LA37_: ;
								eqdestroy___ast_u4574(f_2);
								if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
								eqdestroy___system_u2691(colontmpD_);
								eqdestroy___ast_u3252(n_1);
								if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
								eqdestroy___ast_u3378(styp_1);
								if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
								goto BeforeRet_;
							}
LA34_: ;
							i_2 += ((NI)1);
							{
								LA27_:;
							}
							{
								oldNimErrFin27_ = *nimErr_; *nimErr_ = NIM_FALSE;
								eqdestroy___ast_u4574(f_2);
								if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
								*nimErr_ = oldNimErrFin27_;
							}
							if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
						} LA26: ;
					}
				}
				T44_.len = 0; T44_.p = NIM_NIL;
				colontmpD_ = dollar___systemZdollars_u9(x_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
				T44_ = rawNewString((*(*(*styp_1).sym).name).s.len + colontmpD_.len + 1);
appendString((&T44_), (*(*(*styp_1).sym).name).s);
appendString((&T44_), TM__pyAIA9cUF0h9c4j2HfNQPfYw_542);
appendString((&T44_), colontmpD_);
				eqsink___system_u2700((&(*(*dest_p1).node)._kind_3.strVal), T44_);
				{
					LA23_:;
				}
				{
					eqdestroy___system_u2691(colontmpD_);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
			}
LA9_: ;
			{
				LA8_:;
			}
			{
				oldNimErrFin8_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u3252(n_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
				*nimErr_ = oldNimErrFin8_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		}
		break;
		case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)31) ... ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)35):
		{
			NimStringV2 T50_;
			T50_.len = 0; T50_.p = NIM_NIL;
			T50_ = dollar___systemZdollars_u29(src_p2.intVal);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T50_); goto LA5_;}
			eqsink___system_u2700((&(*(*dest_p1).node)._kind_3.strVal), T50_);
		}
		break;
		case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)40) ... ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)44):
		{
			NimStringV2 T52_;
			T52_.len = 0; T52_.p = NIM_NIL;
			T52_ = dollar___systemZdollars_u54(((NU64) (src_p2.intVal)));
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T52_); goto LA5_;}
			eqsink___system_u2700((&(*(*dest_p1).node)._kind_3.strVal), T52_);
		}
		break;
		case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)1):
		{
			NimStringV2 T54_;
			T54_.len = 0; T54_.p = NIM_NIL;
			{
				if (!(src_p2.intVal == IL64(0))) goto LA57_;
				eqsink___system_u2700((&(*(*dest_p1).node)._kind_3.strVal), TM__pyAIA9cUF0h9c4j2HfNQPfYw_544);
			}
			goto LA55_;
LA57_: ;
			{
				eqsink___system_u2700((&(*(*dest_p1).node)._kind_3.strVal), TM__pyAIA9cUF0h9c4j2HfNQPfYw_546);
			}
LA55_: ;
		}
		break;
		case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)36) ... ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)39):
		{
			NimStringV2 T61_;
			T61_.len = 0; T61_.p = NIM_NIL;
			T61_ = dollar___system_u4728(src_p2.floatVal);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T61_); goto LA5_;}
			eqsink___system_u2700((&(*(*dest_p1).node)._kind_3.strVal), T61_);
		}
		break;
		case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)28):
		{
			eqcopy___system_u2694((&(*(*dest_p1).node)._kind_3.strVal), (*src_p2.node)._kind_3.strVal);
		}
		break;
		case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)29):
		{
			{
				NimStringV2 strVal_1;
				if (!((*src_p2.node).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)41))) goto LA66_;
				strVal_1.len = 0; strVal_1.p = NIM_NIL;
				strVal_1 = TM__pyAIA9cUF0h9c4j2HfNQPfYw_547;
				{
					tySequence__9ahcSjIErJohSBBFLwuF56Q colontmp__2;
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** son_1;
					NI i_3;
					NI L_1;
					NI T71_;
					colontmp__2.len = 0; colontmp__2.p = NIM_NIL;
					son_1 = (tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ**)0;
					eqcopy___ast_u3699((&colontmp__2), (*src_p2.node)._kind_6.sons);
					if (NIM_UNLIKELY(*nimErr_)) goto LA70_;
					i_3 = ((NI)0);
					T71_ = colontmp__2.len;
					L_1 = T71_;
					{
						while (1) {
							NIM_CHAR c_2;
							if (!(i_3 < L_1)) goto LA73;
							son_1 = &colontmp__2.p->data[i_3];
							c_2 = ((NIM_CHAR) ((*(*son_1))._kind_1.intVal));
							{
								if (!((NU8)(c_2) == (NU8)(0))) goto LA76_;
								eqdestroy___ast_u3696(colontmp__2);
								if (NIM_UNLIKELY(*nimErr_)) goto LA68_;
								goto LA69;
							}
LA76_: ;
							nimAddCharV1((&strVal_1), c_2);
							i_3 += ((NI)1);
						} LA73: ;
					}
					{
						LA70_:;
					}
					{
						oldNimErrFin70_ = *nimErr_; *nimErr_ = NIM_FALSE;
						eqdestroy___ast_u3696(colontmp__2);
						if (NIM_UNLIKELY(*nimErr_)) goto LA68_;
						*nimErr_ = oldNimErrFin70_;
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA68_;
				} LA69: ;
				eqsink___system_u2700((&(*(*dest_p1).node)._kind_3.strVal), strVal_1);
				{
					LA68_:;
				}
				{
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
			}
			goto LA64_;
LA66_: ;
			{
				eqcopy___system_u2694((&(*(*dest_p1).node)._kind_3.strVal), (*src_p2.node)._kind_3.strVal);
			}
LA64_: ;
		}
		break;
		case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)2):
		{
			NimStringV2 T84_;
			T84_.len = 0; T84_.p = NIM_NIL;
			T84_ = nimCharToStr(((NIM_CHAR) (((NI) (src_p2.intVal)))));
			eqsink___system_u2700((&(*(*dest_p1).node)._kind_3.strVal), T84_);
		}
		break;
		default:
		{
			NimStringV2 colontmpD__2;
			NimStringV2 colontmpD__3;
			NimStringV2 T87_;
			colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
			colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
			T87_.len = 0; T87_.p = NIM_NIL;
			colontmpD__2 = typeToString__types_u54(desttyp_p3, ((tyEnum_TPreferedDesc__ddj0M89bv09cBYthgD4XTq3Q)0));
			if (NIM_UNLIKELY(*nimErr_)) goto LA86_;
			T87_ = rawNewString(colontmpD__2.len + 25);
appendString((&T87_), TM__pyAIA9cUF0h9c4j2HfNQPfYw_549);
appendString((&T87_), colontmpD__2);
			colontmpD__3 = T87_;
			internalErrorImpl__msgs_u1598((*c_p0).config, unknownLineInfo__lineinfos_u364, colontmpD__3, TM__pyAIA9cUF0h9c4j2HfNQPfYw_550);
			if (NIM_UNLIKELY(*nimErr_)) goto LA86_;
			{
				LA86_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__3);
				eqdestroy___system_u2691(colontmpD__2);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		}
		break;
		}
		{
			LA5_:;
		}
		{
			oldNimErrFin5_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3378(styp_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin5_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA3_: ;
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* desttyp_2;
		desttyp_2 = NIM_NIL;
		desttyp_2 = skipTypes__ast_u5379(desttyp_p3, TM__pyAIA9cUF0h9c4j2HfNQPfYw_551);
		if (NIM_UNLIKELY(*nimErr_)) goto LA93_;
		switch ((*desttyp_2).kind) {
		case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)31) ... ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)35):
		{
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__4;
			colontmpD__4 = NIM_NIL;
			ensureKind__vm_u122(dest_p1, ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA95_;
			colontmpD__4 = skipTypes__ast_u5379(srctyp_p4, TM__pyAIA9cUF0h9c4j2HfNQPfYw_537);
			if (NIM_UNLIKELY(*nimErr_)) goto LA95_;
			switch ((*colontmpD__4).kind) {
			case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)36) ... ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)38):
			{
				(*dest_p1).intVal = ((NI64) ((((NI) (((NI64) (src_p2.floatVal)))))));
			}
			break;
			default:
			{
				(*dest_p1).intVal = src_p2.intVal;
			}
			break;
			}
			{
				NIM_BOOL T100_;
				tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T101_;
				tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T102_;
				tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T104_;
				tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T105_;
				T100_ = (NIM_BOOL)0;
				T101_ = toInt128__int128_u937((*dest_p1).intVal);
				if (NIM_UNLIKELY(*nimErr_)) goto LA95_;
				T102_ = firstOrd__types_u1182((*c_p0).config, desttyp_2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA95_;
				T100_ = lt___int128_u404(T101_, T102_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA95_;
				if (T100_) goto LA103_;
				T104_ = lastOrd__types_u1298((*c_p0).config, desttyp_2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA95_;
				T105_ = toInt128__int128_u937((*dest_p1).intVal);
				if (NIM_UNLIKELY(*nimErr_)) goto LA95_;
				T100_ = lt___int128_u404(T104_, T105_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA95_;
LA103_: ;
				if (!T100_) goto LA106_;
				result = NIM_TRUE;
				eqdestroy___ast_u3378(colontmpD__4);
				if (NIM_UNLIKELY(*nimErr_)) goto LA93_;
				eqdestroy___ast_u3378(desttyp_2);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				goto BeforeRet_;
			}
LA106_: ;
			{
				LA95_:;
			}
			{
				oldNimErrFin95_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u3378(colontmpD__4);
				if (NIM_UNLIKELY(*nimErr_)) goto LA93_;
				*nimErr_ = oldNimErrFin95_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA93_;
		}
		break;
		case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)40) ... ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)44):
		{
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* styp_2;
			styp_2 = NIM_NIL;
			ensureKind__vm_u122(dest_p1, ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA111_;
			styp_2 = skipTypes__ast_u5379(srctyp_p4, TM__pyAIA9cUF0h9c4j2HfNQPfYw_537);
			if (NIM_UNLIKELY(*nimErr_)) goto LA111_;
			switch ((*styp_2).kind) {
			case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)36) ... ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)38):
			{
				(*dest_p1).intVal = ((NI64) ((((NI) (((NI64) (src_p2.floatVal)))))));
			}
			break;
			default:
			{
				NI64 destSize_1;
				NI64 destDist_1;
				NU64 value_1;
				destSize_1 = getSize__types_u3397((*c_p0).config, desttyp_2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA111_;
				destDist_1 = (NI64)((NI64)(IL64(8) - destSize_1) * IL64(8));
				value_1 = ((NU64) (src_p2.intVal));
				value_1 = (NU64)((NU64)((NU64)((NU64)(value_1) << (NU64)(destDist_1 & (64 - 1)))) >> (NU64)(destDist_1 & (64 - 1)));
				(*dest_p1).intVal = ((NI64) (value_1));
			}
			break;
			}
			{
				LA111_:;
			}
			{
				oldNimErrFin111_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u3378(styp_2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA93_;
				*nimErr_ = oldNimErrFin111_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA93_;
		}
		break;
		case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)1):
		{
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__5;
			NI colontmpD__6;
			NI colontmpD__7;
			NI T117_;
			colontmpD__5 = NIM_NIL;
			colontmpD__6 = (NI)0;
			colontmpD__7 = (NI)0;
			ensureKind__vm_u122(dest_p1, ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA93_;
			T117_ = (NI)0;
			colontmpD__5 = skipTypes__ast_u5379(srctyp_p4, TM__pyAIA9cUF0h9c4j2HfNQPfYw_537);
			if (NIM_UNLIKELY(*nimErr_)) goto LA93_;
			switch ((*colontmpD__5).kind) {
			case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)36) ... ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)38):
			{
				colontmpD__6 = ((NI) (!((src_p2.floatVal == 0.0))));
				T117_ = colontmpD__6;
			}
			break;
			default:
			{
				colontmpD__7 = ((NI) (!((src_p2.intVal == IL64(0)))));
				T117_ = colontmpD__7;
			}
			break;
			}
			(*dest_p1).intVal = ((NI64) (T117_));
			eqdestroy___ast_u3378(colontmpD__5);
			if (NIM_UNLIKELY(*nimErr_)) goto LA93_;
		}
		break;
		case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)36) ... ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)38):
		{
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__8;
			tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg srcKind_1;
			colontmpD__8 = NIM_NIL;
			ensureKind__vm_u122(dest_p1, ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)3));
			if (NIM_UNLIKELY(*nimErr_)) goto LA93_;
			colontmpD__8 = skipTypes__ast_u5379(srctyp_p4, TM__pyAIA9cUF0h9c4j2HfNQPfYw_537);
			if (NIM_UNLIKELY(*nimErr_)) goto LA93_;
			srcKind_1 = (*colontmpD__8).kind;
			switch (srcKind_1) {
			case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)31) ... ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)35):
			case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)40) ... ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)44):
			case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)14):
			case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)1):
			case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)2):
			{
				(*dest_p1).floatVal = toBiggestFloat__system_u1698(src_p2.intVal);
			}
			break;
			default:
			{
				{
					if (!(src_p2.kind == ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2))) goto LA125_;
					(*dest_p1).floatVal = toBiggestFloat__system_u1698(src_p2.intVal);
				}
				goto LA123_;
LA125_: ;
				{
					(*dest_p1).floatVal = src_p2.floatVal;
				}
LA123_: ;
			}
			break;
			}
			eqdestroy___ast_u3378(colontmpD__8);
			if (NIM_UNLIKELY(*nimErr_)) goto LA93_;
		}
		break;
		case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)17):
		{
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__9;
			colontmpD__9 = NIM_NIL;
			{
				colontmpD__9 = skipTypes__ast_u5379(srctyp_p4, TM__pyAIA9cUF0h9c4j2HfNQPfYw_551);
				if (NIM_UNLIKELY(*nimErr_)) goto LA129_;
				if (!!(((*colontmpD__9).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)17)))) goto LA132_;
				internalErrorImpl__msgs_u1598((*c_p0).config, unknownLineInfo__lineinfos_u364, TM__pyAIA9cUF0h9c4j2HfNQPfYw_553, TM__pyAIA9cUF0h9c4j2HfNQPfYw_554);
				if (NIM_UNLIKELY(*nimErr_)) goto LA129_;
			}
LA132_: ;
			moveConst__vm_u480(dest_p1, src_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA129_;
			{
				LA129_:;
			}
			{
				oldNimErrFin129_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u3378(colontmpD__9);
				if (NIM_UNLIKELY(*nimErr_)) goto LA93_;
				*nimErr_ = oldNimErrFin129_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA93_;
		}
		break;
		default:
		{
			asgnComplex__vm_u510(dest_p1, src_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA93_;
		}
		break;
		}
		{
			LA93_:;
		}
		{
			oldNimErrFin93_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3378(desttyp_2);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin93_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI, len__vm_u11692)(tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw b_p0) {
	NI result;
	result = b_p0.entries;
	return result;
}
static N_INLINE(NIM_BOOL, hasElementType__ast_u5660)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p0) {
	NIM_BOOL result;
	NI T1_;
	T1_ = (*t_p0).sons.len;
	result = (((NI)0) < T1_);
	return result;
}
static N_INLINE(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, skipModifier__ast_u5338)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* n_p0) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* result;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg** T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	T1_ = (tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg**)0;
	T1_ = X5BX5D___ast_u5281((((*n_p0).sons).p) ? ((*n_p0).sons.p->data) : NIM_NIL, (*n_p0).sons.len, ((NI)1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqcopy___ast_u3381(&result, (*T1_));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(void, leave__vmprofiler_u1887)(tyObject_Profiler__YI4zs2CaXXndlYireD0I8A* prof_p0, tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew* c_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!(((*(*c_p1).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)53)))&63U)))!=0)) goto LA3_;
		leaveImpl__vmprofiler_u41(prof_p0, c_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA3_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, rawExecute__vm_u879)(tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew* c_p0, NI start_p1, tyObject_TStackFrame__a20zU43j9cYHpYOOr1c2hZQ* tos_p2, tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A* Result) {
	tyObject_Env_vmdotnim_rawExecute___hNEyCf8VhTK2S3ZJXhlD9cg* colonenv__1;
	tyObject_TStackFrame__a20zU43j9cYHpYOOr1c2hZQ* savedFrame_1;
	tyObject_Env_vmdotnim_rawExecute___hNEyCf8VhTK2S3ZJXhlD9cg* T2_;
	NI savedPC_1;
NIM_BOOL oldNimErrFin20_;
NIM_BOOL oldNimErrFin69_;
NIM_BOOL oldNimErrFin103_;
NIM_BOOL oldNimErrFin118_;
NIM_BOOL oldNimErrFin125_;
NIM_BOOL oldNimErrFin116_;
NIM_BOOL oldNimErrFin135_;
NIM_BOOL oldNimErrFin219_;
NIM_BOOL oldNimErrFin350_;
NIM_BOOL oldNimErrFin348_;
NIM_BOOL oldNimErrFin440_;
NIM_BOOL oldNimErrFin468_;
NIM_BOOL oldNimErrFin487_;
NIM_BOOL oldNimErrFin551_;
NIM_BOOL oldNimErrFin531_;
NIM_BOOL oldNimErrFin584_;
NIM_BOOL oldNimErrFin618_;
NIM_BOOL oldNimErrFin601_;
NIM_BOOL oldNimErrFin705_;
NIM_BOOL oldNimErrFin699_;
NIM_BOOL oldNimErrFin711_;
NIM_BOOL oldNimErrFin715_;
NIM_BOOL oldNimErrFin853_;
NIM_BOOL oldNimErrFin860_;
NIM_BOOL oldNimErrFin866_;
NIM_BOOL oldNimErrFin872_;
NIM_BOOL oldNimErrFin878_;
NIM_BOOL oldNimErrFin908_;
NIM_BOOL oldNimErrFin914_;
NIM_BOOL oldNimErrFin948_;
NIM_BOOL oldNimErrFin936_;
NIM_BOOL oldNimErrFin959_;
NIM_BOOL oldNimErrFin977_;
NIM_BOOL oldNimErrFin1013_;
NIM_BOOL oldNimErrFin1028_;
NIM_BOOL oldNimErrFin1018_;
NIM_BOOL oldNimErrFin1051_;
NIM_BOOL oldNimErrFin1044_;
NIM_BOOL oldNimErrFin1126_;
NIM_BOOL oldNimErrFin1095_;
NIM_BOOL oldNimErrFin1164_;
NIM_BOOL oldNimErrFin1152_;
NIM_BOOL oldNimErrFin1060_;
NIM_BOOL oldNimErrFin1212_;
NIM_BOOL oldNimErrFin1207_;
NIM_BOOL oldNimErrFin1243_;
NIM_BOOL oldNimErrFin1273_;
NIM_BOOL oldNimErrFin1283_;
NIM_BOOL oldNimErrFin1278_;
NIM_BOOL oldNimErrFin1294_;
NIM_BOOL oldNimErrFin1312_;
NIM_BOOL oldNimErrFin1338_;
NIM_BOOL oldNimErrFin1324_;
NIM_BOOL oldNimErrFin1349_;
NIM_BOOL oldNimErrFin1359_;
NIM_BOOL oldNimErrFin1367_;
NIM_BOOL oldNimErrFin1374_;
NIM_BOOL oldNimErrFin1379_;
NIM_BOOL oldNimErrFin1436_;
NIM_BOOL oldNimErrFin1468_;
NIM_BOOL oldNimErrFin1506_;
NIM_BOOL oldNimErrFin1526_;
NIM_BOOL oldNimErrFin1550_;
NIM_BOOL oldNimErrFin1560_;
NIM_BOOL oldNimErrFin1575_;
NIM_BOOL oldNimErrFin1582_;
NIM_BOOL oldNimErrFin1593_;
NIM_BOOL oldNimErrFin1692_;
NIM_BOOL oldNimErrFin1723_;
NIM_BOOL oldNimErrFin1760_;
NIM_BOOL oldNimErrFin1779_;
NIM_BOOL oldNimErrFin1795_;
NIM_BOOL oldNimErrFin1815_;
NIM_BOOL oldNimErrFin1890_;
NIM_BOOL oldNimErrFin1905_;
NIM_BOOL oldNimErrFin1909_;
NIM_BOOL oldNimErrFin1927_;
NIM_BOOL oldNimErrFin1939_;
NIM_BOOL oldNimErrFin1951_;
NIM_BOOL oldNimErrFin1963_;
NIM_BOOL oldNimErrFin1980_;
NIM_BOOL oldNimErrFin2017_;
NIM_BOOL oldNimErrFin2038_;
NIM_BOOL oldNimErrFin2062_;
NIM_BOOL oldNimErrFin2051_;
NIM_BOOL oldNimErrFin2077_;
NIM_BOOL oldNimErrFin2092_;
NIM_BOOL oldNimErrFin2124_;
NIM_BOOL oldNimErrFin2147_;
NIM_BOOL oldNimErrFin2162_;
NIM_BOOL oldNimErrFin2191_;
NIM_BOOL oldNimErrFin2213_;
NIM_BOOL oldNimErrFin2207_;
NIM_BOOL oldNimErrFin2228_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)Result, sizeof(tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A));
	colonenv__1 = NIM_NIL;
	savedFrame_1 = NIM_NIL;
	T2_ = NIM_NIL;
	T2_ = (tyObject_Env_vmdotnim_rawExecute___hNEyCf8VhTK2S3ZJXhlD9cg*) nimNewObj(sizeof(tyObject_Env_vmdotnim_rawExecute___hNEyCf8VhTK2S3ZJXhlD9cg), NIM_ALIGNOF(tyObject_Env_vmdotnim_rawExecute___hNEyCf8VhTK2S3ZJXhlD9cg));
	(*T2_).Sup.m_type = (&NTIv2__hNEyCf8VhTK2S3ZJXhlD9cg_);
	colonenv__1 = T2_;
	eqcopy___vmdef_u2209(&(*colonenv__1).c0, c_p0, NIM_TRUE);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	nimZeroMem((void*)Result, sizeof(tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A));
	(*Result).kind = ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)0);
	(*colonenv__1).pc2 = start_p1;
	eqcopy___vmprofiler_u22(&(*colonenv__1).tos1, tos_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	savedPC_1 = ((NI)-1);
	savedFrame_1 = ((tyObject_TStackFrame__a20zU43j9cYHpYOOr1c2hZQ*) NIM_NIL);
	{
		while (1) {
			NU64 instr_1;
			NI ra_1;
			instr_1 = (*(*colonenv__1).c0).code.p->data[(*colonenv__1).pc2];
			ra_1 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(8ULL & (64 - 1))) & 65535ULL)));
			{
				NimStringV2 colontmpD_;
				NimStringV2 colontmpD__2;
				NimStringV2 colontmpD__3;
				NimStringV2 colontmpD__4;
				tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_1;
				tyArray__YgExxhfgKcesA5EOUj1MOA T10_;
				tyArray__dyW7vpmfeTYw8kX3EXuaJA T11_;
				if (!(*(*(*colonenv__1).c0).config).isVmTrace) goto LA7_;
				colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
				colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
				colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
				colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
				info_1 = (*(*colonenv__1).c0).debug.p->data[(*colonenv__1).pc2];
				colontmpD_ = dollar___msgs_u714((*(*colonenv__1).c0).config, info_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
				T11_[0] = colontmpD_;
				colontmpD__2 = dollar___vmdef_u267(((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(0ULL & (64 - 1))) & 255ULL))));
				T11_[1] = colontmpD__2;
				colontmpD__3 = sourceLine__msgs_u1210((*(*colonenv__1).c0).config, info_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
				T11_[2] = colontmpD__3;
				colontmpD__4 = nsuFormatOpenArray(TM__pyAIA9cUF0h9c4j2HfNQPfYw_313, T11_, 3);
				if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
				T10_[0] = colontmpD__4;
				echoBinSafe(T10_, 1);
				{
					LA9_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__4);
					eqdestroy___system_u2691(colontmpD__3);
					eqdestroy___system_u2691(colontmpD__2);
					eqdestroy___system_u2691(colontmpD_);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
LA7_: ;
			enter__vmprofiler_u8((&(*(*colonenv__1).c0).profiler), (*colonenv__1).c0, (*colonenv__1).tos1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			switch (((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(0ULL & (64 - 1))) & 255ULL)))) {
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)0):
			{
				eqcopy___vmdef_u1709(Result, (*(*colonenv__1).tos1).slots.p->data[ra_1]);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				eqdestroy___vmprofiler_u19(savedFrame_1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				eqdestroy___vm_u14829(colonenv__1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				goto BeforeRet_;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)1):
			{
				NI newPc_1;
				newPc_1 = cleanUpOnReturn__vm_u683((*colonenv__1).c0, (*colonenv__1).tos1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				{
					tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A retVal_1;
					if (!(newPc_1 < ((NI)0))) goto LA18_;
					nimZeroMem((void*)(&retVal_1), sizeof(tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A));
					(*(*colonenv__1).c0).callDepth += ((NI)1);
					(*colonenv__1).pc2 = (*(*colonenv__1).tos1).comesFrom;
					eqcopy___vmdef_u1709((&retVal_1), (*(*colonenv__1).tos1).slots.p->data[((NI)0)]);
					if (NIM_UNLIKELY(*nimErr_)) goto LA20_;
					eqcopy___vmprofiler_u22(&(*colonenv__1).tos1, (*(*colonenv__1).tos1).next);
					if (NIM_UNLIKELY(*nimErr_)) goto LA20_;
					{
						if (!((*colonenv__1).tos1 == 0)) goto LA23_;
						(*Result) = retVal_1;
						eqwasMoved___vmdef_u1703((&retVal_1));
						if (NIM_UNLIKELY(*nimErr_)) goto LA20_;
						eqdestroy___vmdef_u1706(retVal_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						eqdestroy___vmprofiler_u19(savedFrame_1);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						eqdestroy___vm_u14829(colonenv__1);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						goto BeforeRet_;
					}
LA23_: ;
					{
						if (!(((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA) ((NU64)((NU64)((NU64)((*(*colonenv__1).c0).code.p->data[(*colonenv__1).pc2]) >> (NU64)(0ULL & (64 - 1))) & 255ULL))) == ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)160))) goto LA27_;
						eqsink___vmdef_u1715((&(*(*colonenv__1).tos1).slots.p->data[((NI) ((NU64)((NU64)((NU64)((*(*colonenv__1).c0).code.p->data[(*colonenv__1).pc2]) >> (NU64)(8ULL & (64 - 1))) & 65535ULL)))]), retVal_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA20_;
						eqwasMoved___vmdef_u1703((&retVal_1));
						if (NIM_UNLIKELY(*nimErr_)) goto LA20_;
					}
LA27_: ;
					{
						LA20_:;
					}
					{
						oldNimErrFin20_ = *nimErr_; *nimErr_ = NIM_FALSE;
						eqdestroy___vmdef_u1706(retVal_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						*nimErr_ = oldNimErrFin20_;
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				}
				goto LA16_;
LA18_: ;
				{
					savedPC_1 = (*colonenv__1).pc2;
					eqcopy___vmprofiler_u22(&savedFrame_1, (*colonenv__1).tos1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					(*colonenv__1).pc2 = (NI)(newPc_1 - ((NI)1));
				}
LA16_: ;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)2):
			{
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)3):
			{
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)4):
			{
				NI rb_1;
				rb_1 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				{
					if (!((*(*colonenv__1).tos1).slots.p->data[rb_1].kind == ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2))) goto LA37_;
					(*(*colonenv__1).tos1).slots.p->data[ra_1].intVal = (*(*colonenv__1).tos1).slots.p->data[rb_1].intVal;
				}
				goto LA35_;
LA37_: ;
				{
					NimStringV2 colontmpD__5;
					NimStringV2 colontmpD__6;
					NimStringV2 T41_;
					tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T42_;
					colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
					colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
					T41_.len = 0; T41_.p = NIM_NIL;
					colontmpD__5 = dollar___vmdef_u304((*(*colonenv__1).tos1).slots.p->data[rb_1].kind);
					T41_ = rawNewString(colontmpD__5.len + 16);
appendString((&T41_), TM__pyAIA9cUF0h9c4j2HfNQPfYw_315);
appendString((&T41_), colontmpD__5);
					colontmpD__6 = T41_;
					nimZeroMem((void*)(&T42_), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
					stackTraceImpl__vm_u73((*colonenv__1).c0, (*colonenv__1).tos1, (*colonenv__1).pc2, colontmpD__6, T42_, TM__pyAIA9cUF0h9c4j2HfNQPfYw_230);
					if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
					eqdestroy___system_u2691(colontmpD__6);
					eqdestroy___system_u2691(colontmpD__5);
					eqdestroy___vmprofiler_u19(savedFrame_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					eqdestroy___vm_u14829(colonenv__1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					goto BeforeRet_;
					{
						LA40_:;
					}
					{
						eqdestroy___system_u2691(colontmpD__6);
						eqdestroy___system_u2691(colontmpD__5);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				}
LA35_: ;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)5):
			{
				NI rb_2;
				rb_2 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)3));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				(*(*colonenv__1).tos1).slots.p->data[ra_1].floatVal = (*(*colonenv__1).tos1).slots.p->data[rb_2].floatVal;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)10):
			{
				NI rb_3;
				union { NF32 source; NI32 dest; } LOC47;
				rb_3 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				LOC47.source = ((NF32) ((*(*colonenv__1).tos1).slots.p->data[rb_3].floatVal));
				(*(*colonenv__1).tos1).slots.p->data[ra_1].intVal = ((NI64) (LOC47.dest));
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)11):
			{
				NI rb_4;
				union { NF source; NI64 dest; } LOC49;
				rb_4 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				LOC49.source = (*(*colonenv__1).tos1).slots.p->data[rb_4].floatVal;
				(*(*colonenv__1).tos1).slots.p->data[ra_1].intVal = LOC49.dest;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)8):
			{
				NI rb_5;
				union { NI64 source; NF32 dest; } LOC51;
				rb_5 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)3));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				LOC51.source = (*(*colonenv__1).tos1).slots.p->data[rb_5].intVal;
				(*(*colonenv__1).tos1).slots.p->data[ra_1].floatVal = ((NF) (LOC51.dest));
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)9):
			{
				NI rb_6;
				union { NI64 source; NF dest; } LOC53;
				rb_6 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)3));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				LOC53.source = (*(*colonenv__1).tos1).slots.p->data[rb_6].intVal;
				(*(*colonenv__1).tos1).slots.p->data[ra_1].floatVal = LOC53.dest;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)12):
			{
				NI rb_7;
				NI imm_1;
				rb_7 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				imm_1 = (NI)(((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(40ULL & (64 - 1))) & 65535ULL))) - ((NI)128));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				switch (imm_1) {
				case ((NI)1):
				{
					switch ((*(*colonenv__1).tos1).slots.p->data[rb_7].kind) {
					case ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1):
					{
						(*(*colonenv__1).tos1).slots.p->data[ra_1].intVal = ((NI64) (((NI) ((*(*(*colonenv__1).tos1).slots.p->data[rb_7].node)._kind_1.intVal))));
					}
					break;
					case ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)5):
					{
						(*(*colonenv__1).tos1).slots.p->data[ra_1].intVal = ((NI64) (((NI) (ptrdiff_t) ((*(*colonenv__1).tos1).slots.p->data[rb_7].nodeAddr))));
					}
					break;
					case ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)4):
					{
						(*(*colonenv__1).tos1).slots.p->data[ra_1].intVal = ((NI64) (((NI) (ptrdiff_t) ((*(*colonenv__1).tos1).slots.p->data[rb_7].regAddr))));
					}
					break;
					case ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2):
					{
						(*(*colonenv__1).tos1).slots.p->data[ra_1].intVal = (*(*colonenv__1).tos1).slots.p->data[rb_7].intVal;
					}
					break;
					default:
					{
						NimStringV2 colontmpD__7;
						NimStringV2 colontmpD__8;
						NimStringV2 T62_;
						tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T63_;
						colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
						colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
						T62_.len = 0; T62_.p = NIM_NIL;
						colontmpD__7 = dollar___vmdef_u304((*(*colonenv__1).tos1).slots.p->data[rb_7].kind);
						T62_ = rawNewString(colontmpD__7.len + 21);
appendString((&T62_), TM__pyAIA9cUF0h9c4j2HfNQPfYw_317);
appendString((&T62_), colontmpD__7);
						colontmpD__8 = T62_;
						nimZeroMem((void*)(&T63_), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
						stackTraceImpl__vm_u73((*colonenv__1).c0, (*colonenv__1).tos1, (*colonenv__1).pc2, colontmpD__8, T63_, TM__pyAIA9cUF0h9c4j2HfNQPfYw_230);
						if (NIM_UNLIKELY(*nimErr_)) goto LA61_;
						eqdestroy___system_u2691(colontmpD__8);
						eqdestroy___system_u2691(colontmpD__7);
						eqdestroy___vmprofiler_u19(savedFrame_1);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						eqdestroy___vm_u14829(colonenv__1);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						goto BeforeRet_;
						{
							LA61_:;
						}
						{
							eqdestroy___system_u2691(colontmpD__8);
							eqdestroy___system_u2691(colontmpD__7);
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					}
					break;
					}
				}
				break;
				case ((NI)2):
				{
					(*(*colonenv__1).tos1).slots.p->data[ra_1].intVal = ((NI64) (((NI) ((*(*colonenv__1).tos1).slots.p->data[rb_7].node))));
				}
				break;
				default:
				{
				}
				break;
				}
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)13):
			{
				tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_1;
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* node2_1;
				NI rb_8;
				typ_1 = NIM_NIL;
				node2_1 = NIM_NIL;
				rb_8 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				eqcopy___ast_u3381(&typ_1, (*(*(*colonenv__1).tos1).slots.p->data[ra_1].node).typField);
				if (NIM_UNLIKELY(*nimErr_)) goto LA69_;
				node2_1 = newNodeIT__ast_u4112(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)6), (*(*colonenv__1).c0).debug.p->data[(*colonenv__1).pc2], typ_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA69_;
				switch ((*(*colonenv__1).tos1).slots.p->data[rb_8].kind) {
				case ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2):
				{
					(*node2_1)._kind_1.intVal = (*(*colonenv__1).tos1).slots.p->data[rb_8].intVal;
				}
				break;
				case ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1):
				{
					{
						NimStringV2 colontmpD__9;
						NimStringV2 colontmpD__10;
						NimStringV2 T77_;
						tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T78_;
						if (!!(((*(*(*(*colonenv__1).tos1).slots.p->data[rb_8].node).typField).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)26) || (*(*(*(*colonenv__1).tos1).slots.p->data[rb_8].node).typField).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)21)))) goto LA74_;
						colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
						colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
						T77_.len = 0; T77_.p = NIM_NIL;
						colontmpD__9 = dollar___ast_u182((*(*(*(*colonenv__1).tos1).slots.p->data[rb_8].node).typField).kind);
						T77_ = rawNewString(colontmpD__9.len + 36);
appendString((&T77_), TM__pyAIA9cUF0h9c4j2HfNQPfYw_319);
appendString((&T77_), colontmpD__9);
						colontmpD__10 = T77_;
						nimZeroMem((void*)(&T78_), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
						stackTraceImpl__vm_u73((*colonenv__1).c0, (*colonenv__1).tos1, (*colonenv__1).pc2, colontmpD__10, T78_, TM__pyAIA9cUF0h9c4j2HfNQPfYw_230);
						if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
						eqdestroy___system_u2691(colontmpD__10);
						eqdestroy___system_u2691(colontmpD__9);
						eqdestroy___ast_u3252(node2_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						eqdestroy___ast_u3378(typ_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						eqdestroy___vmprofiler_u19(savedFrame_1);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						eqdestroy___vm_u14829(colonenv__1);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						goto BeforeRet_;
						{
							LA76_:;
						}
						{
							eqdestroy___system_u2691(colontmpD__10);
							eqdestroy___system_u2691(colontmpD__9);
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA69_;
					}
LA74_: ;
					{
						if (!((*(*(*colonenv__1).tos1).slots.p->data[rb_8].node).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)23))) goto LA83_;
						(*node2_1)._kind_1.intVal = IL64(0);
					}
					goto LA81_;
LA83_: ;
					{
						(*node2_1)._kind_1.intVal = (*(*(*colonenv__1).tos1).slots.p->data[rb_8].node)._kind_1.intVal;
					}
LA81_: ;
				}
				break;
				default:
				{
					NimStringV2 colontmpD__11;
					NimStringV2 colontmpD__12;
					NimStringV2 T88_;
					tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T89_;
					colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
					colontmpD__12.len = 0; colontmpD__12.p = NIM_NIL;
					T88_.len = 0; T88_.p = NIM_NIL;
					colontmpD__11 = dollar___vmdef_u304((*(*colonenv__1).tos1).slots.p->data[rb_8].kind);
					T88_ = rawNewString(colontmpD__11.len + 32);
appendString((&T88_), TM__pyAIA9cUF0h9c4j2HfNQPfYw_321);
appendString((&T88_), colontmpD__11);
					colontmpD__12 = T88_;
					nimZeroMem((void*)(&T89_), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
					stackTraceImpl__vm_u73((*colonenv__1).c0, (*colonenv__1).tos1, (*colonenv__1).pc2, colontmpD__12, T89_, TM__pyAIA9cUF0h9c4j2HfNQPfYw_230);
					if (NIM_UNLIKELY(*nimErr_)) goto LA87_;
					eqdestroy___system_u2691(colontmpD__12);
					eqdestroy___system_u2691(colontmpD__11);
					eqdestroy___ast_u3252(node2_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___ast_u3378(typ_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___vmprofiler_u19(savedFrame_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					eqdestroy___vm_u14829(colonenv__1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					goto BeforeRet_;
					{
						LA87_:;
					}
					{
						eqdestroy___system_u2691(colontmpD__12);
						eqdestroy___system_u2691(colontmpD__11);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA69_;
				}
				break;
				}
				eqsink___ast_u3261(&(*(*colonenv__1).tos1).slots.p->data[ra_1].node, node2_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA69_;
				eqwasMoved___ast_u3249(&node2_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA69_;
				{
					LA69_:;
				}
				{
					oldNimErrFin69_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3252(node2_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___ast_u3378(typ_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin69_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)7):
			{
				asgnComplex__vm_u510((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), (*(*colonenv__1).tos1).slots.p->data[((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)))]);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)14):
			{
				fastAsgnComplex__vm_u513((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), (*(*colonenv__1).tos1).slots.p->data[((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)))]);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)6):
			{
				moveConst__vm_u480((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), (*(*colonenv__1).tos1).slots.p->data[((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)))]);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)15):
			{
				NI ra_2;
				NI rb_9;
				ra_2 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(8ULL & (64 - 1))) & 65535ULL)));
				rb_9 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				{
					if (!!(((*(*colonenv__1).tos1).slots.p->data[rb_9].kind == ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1)))) goto LA100_;
					eqcopy___vmdef_u1709((&(*(*colonenv__1).tos1).slots.p->data[ra_2]), (*(*colonenv__1).tos1).slots.p->data[rb_9]);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				}
				goto LA98_;
LA100_: ;
				{
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* nb_1;
					nb_1 = NIM_NIL;
					eqcopy___ast_u3255(&nb_1, (*(*colonenv__1).tos1).slots.p->data[rb_9].node);
					if (NIM_UNLIKELY(*nimErr_)) goto LA103_;
					{
						tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T108_;
						if (!(nb_1 == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL))) goto LA106_;
						nimZeroMem((void*)(&T108_), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
						stackTraceImpl__vm_u73((*colonenv__1).c0, (*colonenv__1).tos1, (*colonenv__1).pc2, TM__pyAIA9cUF0h9c4j2HfNQPfYw_323, T108_, TM__pyAIA9cUF0h9c4j2HfNQPfYw_230);
						if (NIM_UNLIKELY(*nimErr_)) goto LA103_;
						eqdestroy___ast_u3252(nb_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						eqdestroy___vmprofiler_u19(savedFrame_1);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						eqdestroy___vm_u14829(colonenv__1);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						goto BeforeRet_;
					}
					goto LA104_;
LA106_: ;
					{
						switch ((*nb_1).kind) {
						case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)5) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)15):
						{
							ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_2]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2));
							if (NIM_UNLIKELY(*nimErr_)) goto LA103_;
							(*(*colonenv__1).tos1).slots.p->data[ra_2].intVal = (*nb_1)._kind_1.intVal;
						}
						break;
						case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)16) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)18):
						{
							ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_2]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)3));
							if (NIM_UNLIKELY(*nimErr_)) goto LA103_;
							(*(*colonenv__1).tos1).slots.p->data[ra_2].floatVal = (*nb_1)._kind_2.floatVal;
						}
						break;
						default:
						{
							ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_2]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1));
							if (NIM_UNLIKELY(*nimErr_)) goto LA103_;
							eqsink___ast_u3261(&(*(*colonenv__1).tos1).slots.p->data[ra_2].node, nb_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA103_;
							eqwasMoved___ast_u3249(&nb_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA103_;
						}
						break;
						}
					}
LA104_: ;
					{
						LA103_:;
					}
					{
						oldNimErrFin103_ = *nimErr_; *nimErr_ = NIM_FALSE;
						eqdestroy___ast_u3252(nb_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						*nimErr_ = oldNimErrFin103_;
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				}
LA98_: ;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)29):
			{
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* collection_1;
				NI rb_10;
				NI rc_1;
				NI64 leftInd_1;
				NI64 rightInd_1;
				collection_1 = NIM_NIL;
				rb_10 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				rc_1 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(40ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA116_;
				eqcopy___ast_u3255(&collection_1, (*(*colonenv__1).tos1).slots.p->data[ra_1].node);
				if (NIM_UNLIKELY(*nimErr_)) goto LA116_;
				leftInd_1 = (*(*colonenv__1).tos1).slots.p->data[rb_10].intVal;
				rightInd_1 = (*(*colonenv__1).tos1).slots.p->data[rc_1].intVal;
				switch ((*collection_1).kind) {
				case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)160):
				{
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__13;
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__14;
					NI64 safeLen_1;
					tyProc__TSOsjF4c9aXotPerq9cEE56A T119_;
					NI64 leftInd_2;
					NI64 rightInd_2;
					tyArray__JEzAlj49cAK8qpM6I2Q9bfcQ T120_;
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T121_;
					colontmpD__13 = NIM_NIL;
					colontmpD__14 = NIM_NIL;
					safeLen_1 = (NI64)((*(*collection_1)._kind_6.sons.p->data[((NI)2)])._kind_1.intVal - (*(*collection_1)._kind_6.sons.p->data[((NI)1)])._kind_1.intVal);
					nimZeroMem((void*)(&T119_), sizeof(tyProc__TSOsjF4c9aXotPerq9cEE56A));
					T119_.ClP_0 = rangeCheck__vm_u1072; T119_.ClE_0 = colonenv__1;
					T119_.ClE_0? T119_.ClP_0(leftInd_1, rightInd_1, safeLen_1, T119_.ClE_0):((TM__pyAIA9cUF0h9c4j2HfNQPfYw_333)(T119_.ClP_0))(leftInd_1, rightInd_1, safeLen_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA118_;
					leftInd_2 = (NI64)(leftInd_1 + (*(*collection_1)._kind_6.sons.p->data[((NI)1)])._kind_1.intVal);
					rightInd_2 = (NI64)(rightInd_1 + (*(*collection_1)._kind_6.sons.p->data[((NI)1)])._kind_1.intVal);
					nimZeroMem((void*)T120_, sizeof(tyArray__JEzAlj49cAK8qpM6I2Q9bfcQ));
					T120_[0] = (*collection_1)._kind_6.sons.p->data[((NI)0)];
					colontmpD__13 = newIntNode__ast_u5200(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)6), leftInd_2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA118_;
					T120_[1] = colontmpD__13;
					colontmpD__14 = newIntNode__ast_u5200(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)6), rightInd_2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA118_;
					T120_[2] = colontmpD__14;
					T121_ = NIM_NIL;
					T121_ = newTree__ast_u4170(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)160), T120_, 3);
					if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T121_); goto LA118_;}
					eqsink___ast_u3261(&(*(*colonenv__1).tos1).slots.p->data[ra_1].node, T121_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA118_;
					{
						LA118_:;
					}
					{
						oldNimErrFin118_ = *nimErr_; *nimErr_ = NIM_FALSE;
						eqdestroy___ast_u3252(colontmpD__14);
						if (NIM_UNLIKELY(*nimErr_)) goto LA116_;
						eqdestroy___ast_u3252(colontmpD__13);
						if (NIM_UNLIKELY(*nimErr_)) goto LA116_;
						*nimErr_ = oldNimErrFin118_;
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA116_;
				}
				break;
				default:
				{
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__15;
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__16;
					NI safeLen_2;
					NI T126_;
					tyProc__TSOsjF4c9aXotPerq9cEE56A T127_;
					tyArray__JEzAlj49cAK8qpM6I2Q9bfcQ T128_;
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T129_;
					colontmpD__15 = NIM_NIL;
					colontmpD__16 = NIM_NIL;
					T126_ = (NI)0;
					T126_ = safeArrLen__ast_u3204(collection_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA125_;
					safeLen_2 = (NI)(T126_ - ((NI)1));
					nimZeroMem((void*)(&T127_), sizeof(tyProc__TSOsjF4c9aXotPerq9cEE56A));
					T127_.ClP_0 = rangeCheck__vm_u1072; T127_.ClE_0 = colonenv__1;
					T127_.ClE_0? T127_.ClP_0(leftInd_1, rightInd_1, ((NI64) (safeLen_2)), T127_.ClE_0):((TM__pyAIA9cUF0h9c4j2HfNQPfYw_334)(T127_.ClP_0))(leftInd_1, rightInd_1, ((NI64) (safeLen_2)));
					if (NIM_UNLIKELY(*nimErr_)) goto LA125_;
					nimZeroMem((void*)T128_, sizeof(tyArray__JEzAlj49cAK8qpM6I2Q9bfcQ));
					T128_[0] = collection_1;
					colontmpD__15 = newIntNode__ast_u5200(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)6), leftInd_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA125_;
					T128_[1] = colontmpD__15;
					colontmpD__16 = newIntNode__ast_u5200(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)6), rightInd_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA125_;
					T128_[2] = colontmpD__16;
					T129_ = NIM_NIL;
					T129_ = newTree__ast_u4170(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)160), T128_, 3);
					if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T129_); goto LA125_;}
					eqsink___ast_u3261(&(*(*colonenv__1).tos1).slots.p->data[ra_1].node, T129_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA125_;
					{
						LA125_:;
					}
					{
						oldNimErrFin125_ = *nimErr_; *nimErr_ = NIM_FALSE;
						eqdestroy___ast_u3252(colontmpD__16);
						if (NIM_UNLIKELY(*nimErr_)) goto LA116_;
						eqdestroy___ast_u3252(colontmpD__15);
						if (NIM_UNLIKELY(*nimErr_)) goto LA116_;
						*nimErr_ = oldNimErrFin125_;
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA116_;
				}
				break;
				}
				{
					LA116_:;
				}
				{
					oldNimErrFin116_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3252(collection_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin116_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)16):
			{
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* src_1;
				NI rb_11;
				NI rc_2;
				NI idx_1;
				src_1 = NIM_NIL;
				rb_11 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				rc_2 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(40ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA135_;
				{
					NimStringV2 colontmpD__17;
					NimStringV2 colontmpD__18;
					NimStringV2 T141_;
					tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T148_;
					if (!(IL64(2147483647) < (*(*colonenv__1).tos1).slots.p->data[rc_2].intVal)) goto LA138_;
					colontmpD__17.len = 0; colontmpD__17.p = NIM_NIL;
					colontmpD__18.len = 0; colontmpD__18.p = NIM_NIL;
					T141_.len = 0; T141_.p = NIM_NIL;
					{
						if (!NIM_FALSE) goto LA144_;
						colontmpD__17 = TM__pyAIA9cUF0h9c4j2HfNQPfYw_335;
						T141_ = colontmpD__17;
					}
					goto LA142_;
LA144_: ;
					{
						NimStringV2 colontmpD__19;
						NimStringV2 colontmpD__20;
						NimStringV2 T147_;
						colontmpD__19.len = 0; colontmpD__19.p = NIM_NIL;
						colontmpD__20.len = 0; colontmpD__20.p = NIM_NIL;
						T147_.len = 0; T147_.p = NIM_NIL;
						colontmpD__19 = dollar___systemZdollars_u29((*(*colonenv__1).tos1).slots.p->data[rc_2].intVal);
						if (NIM_UNLIKELY(*nimErr_)) goto LA140_;
						colontmpD__20 = dollar___systemZdollars_u9(((NI)2147483647));
						if (NIM_UNLIKELY(*nimErr_)) goto LA140_;
						T147_ = rawNewString(colontmpD__19.len + colontmpD__20.len + 19);
appendString((&T147_), TM__pyAIA9cUF0h9c4j2HfNQPfYw_336);
appendString((&T147_), colontmpD__19);
appendString((&T147_), TM__pyAIA9cUF0h9c4j2HfNQPfYw_337);
appendString((&T147_), colontmpD__20);
						colontmpD__18 = T147_;
						eqdestroy___system_u2691(colontmpD__20);
						eqdestroy___system_u2691(colontmpD__19);
						T141_ = colontmpD__18;
					}
LA142_: ;
					nimZeroMem((void*)(&T148_), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
					stackTraceImpl__vm_u73((*colonenv__1).c0, (*colonenv__1).tos1, (*colonenv__1).pc2, T141_, T148_, TM__pyAIA9cUF0h9c4j2HfNQPfYw_230);
					if (NIM_UNLIKELY(*nimErr_)) goto LA140_;
					eqdestroy___system_u2691(colontmpD__18);
					eqdestroy___system_u2691(colontmpD__17);
					eqdestroy___ast_u3252(src_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___vmprofiler_u19(savedFrame_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					eqdestroy___vm_u14829(colonenv__1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					goto BeforeRet_;
					{
						LA140_:;
					}
					{
						eqdestroy___system_u2691(colontmpD__18);
						eqdestroy___system_u2691(colontmpD__17);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA135_;
				}
LA138_: ;
				idx_1 = ((NI) ((*(*colonenv__1).tos1).slots.p->data[rc_2].intVal));
				eqcopy___ast_u3255(&src_1, (*(*colonenv__1).tos1).slots.p->data[rb_11].node);
				if (NIM_UNLIKELY(*nimErr_)) goto LA135_;
				switch ((*src_1).kind) {
				case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)160):
				{
					NI64 left_1;
					NI64 right_1;
					NI64 realIndex_1;
					left_1 = (*(*src_1)._kind_6.sons.p->data[((NI)1)])._kind_1.intVal;
					right_1 = (*(*src_1)._kind_6.sons.p->data[((NI)2)])._kind_1.intVal;
					realIndex_1 = (NI64)(left_1 + ((NI64) (idx_1)));
					{
						tyObject_HSlice__QbYBq0DTmYHIHa8KuurQ6Q T154_;
						NIM_BOOL T155_;
						T154_ = dotdot___vm_u1109(((NI)0), (NI64)(right_1 - left_1));
						T155_ = (NIM_BOOL)0;
						T155_ = contains__vm_u1214(T154_, idx_1);
						if (!T155_) goto LA156_;
						switch ((*(*src_1)._kind_6.sons.p->data[((NI)0)]).kind) {
						case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)20) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)22):
						{
							tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T159_;
							T159_ = NIM_NIL;
							T159_ = newIntNode__ast_u5200(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)5), ((NI64) (((NU8)((*(*src_1)._kind_6.sons.p->data[((NI)0)])._kind_3.strVal.p->data[((NI) (realIndex_1))])))));
							if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T159_); goto LA135_;}
							eqsink___ast_u3261(&(*(*colonenv__1).tos1).slots.p->data[ra_1].node, T159_);
							if (NIM_UNLIKELY(*nimErr_)) goto LA135_;
						}
						break;
						case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)41):
						{
							eqcopy___ast_u3255(&(*(*colonenv__1).tos1).slots.p->data[ra_1].node, (*(*src_1)._kind_6.sons.p->data[((NI)0)])._kind_6.sons.p->data[((NI) (realIndex_1))]);
							if (NIM_UNLIKELY(*nimErr_)) goto LA135_;
						}
						break;
						default:
						{
							tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T162_;
							nimZeroMem((void*)(&T162_), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
							stackTraceImpl__vm_u73((*colonenv__1).c0, (*colonenv__1).tos1, (*colonenv__1).pc2, TM__pyAIA9cUF0h9c4j2HfNQPfYw_339, T162_, TM__pyAIA9cUF0h9c4j2HfNQPfYw_230);
							if (NIM_UNLIKELY(*nimErr_)) goto LA135_;
							eqdestroy___ast_u3252(src_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
							eqdestroy___vmprofiler_u19(savedFrame_1);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
							eqdestroy___vm_u14829(colonenv__1);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
							goto BeforeRet_;
						}
						break;
						}
					}
					goto LA152_;
LA156_: ;
					{
						NimStringV2 colontmpD__21;
						NimStringV2 colontmpD__22;
						NimStringV2 T165_;
						tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T172_;
						colontmpD__21.len = 0; colontmpD__21.p = NIM_NIL;
						colontmpD__22.len = 0; colontmpD__22.p = NIM_NIL;
						T165_.len = 0; T165_.p = NIM_NIL;
						{
							if (!(((NI) (right_1)) < ((NI)0))) goto LA168_;
							colontmpD__21 = TM__pyAIA9cUF0h9c4j2HfNQPfYw_340;
							T165_ = colontmpD__21;
						}
						goto LA166_;
LA168_: ;
						{
							NimStringV2 colontmpD__23;
							NimStringV2 colontmpD__24;
							NimStringV2 T171_;
							colontmpD__23.len = 0; colontmpD__23.p = NIM_NIL;
							colontmpD__24.len = 0; colontmpD__24.p = NIM_NIL;
							T171_.len = 0; T171_.p = NIM_NIL;
							colontmpD__23 = dollar___systemZdollars_u9(idx_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA164_;
							colontmpD__24 = dollar___systemZdollars_u9(((NI) (right_1)));
							if (NIM_UNLIKELY(*nimErr_)) goto LA164_;
							T171_ = rawNewString(colontmpD__23.len + colontmpD__24.len + 19);
appendString((&T171_), TM__pyAIA9cUF0h9c4j2HfNQPfYw_341);
appendString((&T171_), colontmpD__23);
appendString((&T171_), TM__pyAIA9cUF0h9c4j2HfNQPfYw_342);
appendString((&T171_), colontmpD__24);
							colontmpD__22 = T171_;
							eqdestroy___system_u2691(colontmpD__24);
							eqdestroy___system_u2691(colontmpD__23);
							T165_ = colontmpD__22;
						}
LA166_: ;
						nimZeroMem((void*)(&T172_), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
						stackTraceImpl__vm_u73((*colonenv__1).c0, (*colonenv__1).tos1, (*colonenv__1).pc2, T165_, T172_, TM__pyAIA9cUF0h9c4j2HfNQPfYw_230);
						if (NIM_UNLIKELY(*nimErr_)) goto LA164_;
						eqdestroy___system_u2691(colontmpD__22);
						eqdestroy___system_u2691(colontmpD__21);
						eqdestroy___ast_u3252(src_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						eqdestroy___vmprofiler_u19(savedFrame_1);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						eqdestroy___vm_u14829(colonenv__1);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						goto BeforeRet_;
						{
							LA164_:;
						}
						{
							eqdestroy___system_u2691(colontmpD__22);
							eqdestroy___system_u2691(colontmpD__21);
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA135_;
					}
LA152_: ;
				}
				break;
				case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)20) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)22):
				{
					{
						NIM_BOOL T178_;
						tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T181_;
						T178_ = (NIM_BOOL)0;
						T178_ = ltpercent___system_u1092(idx_1, (*src_1)._kind_3.strVal.len);
						if (!T178_) goto LA179_;
						T181_ = NIM_NIL;
						T181_ = newNodeI__ast_u4091(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)5), (*(*colonenv__1).c0).debug.p->data[(*colonenv__1).pc2]);
						if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T181_); goto LA135_;}
						eqsink___ast_u3261(&(*(*colonenv__1).tos1).slots.p->data[ra_1].node, T181_);
						if (NIM_UNLIKELY(*nimErr_)) goto LA135_;
						(*(*(*colonenv__1).tos1).slots.p->data[ra_1].node)._kind_1.intVal = ((NI64) (((NU8)((*src_1)._kind_3.strVal.p->data[idx_1]))));
					}
					goto LA176_;
LA179_: ;
					{
						NimStringV2 colontmpD__25;
						NimStringV2 colontmpD__26;
						NimStringV2 T184_;
						tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T191_;
						colontmpD__25.len = 0; colontmpD__25.p = NIM_NIL;
						colontmpD__26.len = 0; colontmpD__26.p = NIM_NIL;
						T184_.len = 0; T184_.p = NIM_NIL;
						{
							if (!((NI)((*src_1)._kind_3.strVal.len - ((NI)1)) < ((NI)0))) goto LA187_;
							colontmpD__25 = TM__pyAIA9cUF0h9c4j2HfNQPfYw_343;
							T184_ = colontmpD__25;
						}
						goto LA185_;
LA187_: ;
						{
							NimStringV2 colontmpD__27;
							NimStringV2 colontmpD__28;
							NimStringV2 T190_;
							colontmpD__27.len = 0; colontmpD__27.p = NIM_NIL;
							colontmpD__28.len = 0; colontmpD__28.p = NIM_NIL;
							T190_.len = 0; T190_.p = NIM_NIL;
							colontmpD__27 = dollar___systemZdollars_u9(idx_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA183_;
							colontmpD__28 = dollar___systemZdollars_u9((NI)((*src_1)._kind_3.strVal.len - ((NI)1)));
							if (NIM_UNLIKELY(*nimErr_)) goto LA183_;
							T190_ = rawNewString(colontmpD__27.len + colontmpD__28.len + 19);
appendString((&T190_), TM__pyAIA9cUF0h9c4j2HfNQPfYw_344);
appendString((&T190_), colontmpD__27);
appendString((&T190_), TM__pyAIA9cUF0h9c4j2HfNQPfYw_345);
appendString((&T190_), colontmpD__28);
							colontmpD__26 = T190_;
							eqdestroy___system_u2691(colontmpD__28);
							eqdestroy___system_u2691(colontmpD__27);
							T184_ = colontmpD__26;
						}
LA185_: ;
						nimZeroMem((void*)(&T191_), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
						stackTraceImpl__vm_u73((*colonenv__1).c0, (*colonenv__1).tos1, (*colonenv__1).pc2, T184_, T191_, TM__pyAIA9cUF0h9c4j2HfNQPfYw_230);
						if (NIM_UNLIKELY(*nimErr_)) goto LA183_;
						eqdestroy___system_u2691(colontmpD__26);
						eqdestroy___system_u2691(colontmpD__25);
						eqdestroy___ast_u3252(src_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						eqdestroy___vmprofiler_u19(savedFrame_1);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						eqdestroy___vm_u14829(colonenv__1);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						goto BeforeRet_;
						{
							LA183_:;
						}
						{
							eqdestroy___system_u2691(colontmpD__26);
							eqdestroy___system_u2691(colontmpD__25);
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA135_;
					}
LA176_: ;
				}
				break;
				default:
				{
					{
						NIM_BOOL T197_;
						NI T199_;
						T197_ = (NIM_BOOL)0;
						T197_ = !(((*src_1).kind >= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)1) && (*src_1).kind <= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)19)));
						if (!(T197_)) goto LA198_;
						T199_ = (NI)0;
						T199_ = len__ast_u3190(src_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA135_;
						T197_ = ltpercent___system_u1092(idx_1, T199_);
LA198_: ;
						if (!T197_) goto LA200_;
						eqcopy___ast_u3255(&(*(*colonenv__1).tos1).slots.p->data[ra_1].node, (*src_1)._kind_6.sons.p->data[idx_1]);
						if (NIM_UNLIKELY(*nimErr_)) goto LA135_;
					}
					goto LA195_;
LA200_: ;
					{
						NimStringV2 colontmpD__29;
						NimStringV2 colontmpD__30;
						NimStringV2 T204_;
						tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T213_;
						colontmpD__29.len = 0; colontmpD__29.p = NIM_NIL;
						colontmpD__30.len = 0; colontmpD__30.p = NIM_NIL;
						T204_.len = 0; T204_.p = NIM_NIL;
						{
							NI T207_;
							T207_ = (NI)0;
							T207_ = safeLen__ast_u3197(src_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA203_;
							if (!((NI)(T207_ - ((NI)1)) < ((NI)0))) goto LA208_;
							colontmpD__29 = TM__pyAIA9cUF0h9c4j2HfNQPfYw_346;
							T204_ = colontmpD__29;
						}
						goto LA205_;
LA208_: ;
						{
							NimStringV2 colontmpD__31;
							NimStringV2 colontmpD__32;
							NimStringV2 T211_;
							NI T212_;
							colontmpD__31.len = 0; colontmpD__31.p = NIM_NIL;
							colontmpD__32.len = 0; colontmpD__32.p = NIM_NIL;
							T211_.len = 0; T211_.p = NIM_NIL;
							colontmpD__31 = dollar___systemZdollars_u9(idx_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA203_;
							T212_ = (NI)0;
							T212_ = safeLen__ast_u3197(src_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA203_;
							colontmpD__32 = dollar___systemZdollars_u9((NI)(T212_ - ((NI)1)));
							if (NIM_UNLIKELY(*nimErr_)) goto LA203_;
							T211_ = rawNewString(colontmpD__31.len + colontmpD__32.len + 19);
appendString((&T211_), TM__pyAIA9cUF0h9c4j2HfNQPfYw_347);
appendString((&T211_), colontmpD__31);
appendString((&T211_), TM__pyAIA9cUF0h9c4j2HfNQPfYw_348);
appendString((&T211_), colontmpD__32);
							colontmpD__30 = T211_;
							eqdestroy___system_u2691(colontmpD__32);
							eqdestroy___system_u2691(colontmpD__31);
							T204_ = colontmpD__30;
						}
LA205_: ;
						nimZeroMem((void*)(&T213_), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
						stackTraceImpl__vm_u73((*colonenv__1).c0, (*colonenv__1).tos1, (*colonenv__1).pc2, T204_, T213_, TM__pyAIA9cUF0h9c4j2HfNQPfYw_230);
						if (NIM_UNLIKELY(*nimErr_)) goto LA203_;
						eqdestroy___system_u2691(colontmpD__30);
						eqdestroy___system_u2691(colontmpD__29);
						eqdestroy___ast_u3252(src_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						eqdestroy___vmprofiler_u19(savedFrame_1);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						eqdestroy___vm_u14829(colonenv__1);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						goto BeforeRet_;
						{
							LA203_:;
						}
						{
							eqdestroy___system_u2691(colontmpD__30);
							eqdestroy___system_u2691(colontmpD__29);
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA135_;
					}
LA195_: ;
				}
				break;
				}
				{
					LA135_:;
				}
				{
					oldNimErrFin135_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3252(src_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin135_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)17):
			{
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* src_2;
				NI rb_12;
				NI rc_3;
				NI idx_2;
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T235_;
				src_2 = NIM_NIL;
				rb_12 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				rc_3 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(40ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)5));
				if (NIM_UNLIKELY(*nimErr_)) goto LA219_;
				{
					NimStringV2 colontmpD__33;
					NimStringV2 colontmpD__34;
					NimStringV2 T225_;
					tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T232_;
					if (!(IL64(2147483647) < (*(*colonenv__1).tos1).slots.p->data[rc_3].intVal)) goto LA222_;
					colontmpD__33.len = 0; colontmpD__33.p = NIM_NIL;
					colontmpD__34.len = 0; colontmpD__34.p = NIM_NIL;
					T225_.len = 0; T225_.p = NIM_NIL;
					{
						if (!NIM_FALSE) goto LA228_;
						colontmpD__33 = TM__pyAIA9cUF0h9c4j2HfNQPfYw_349;
						T225_ = colontmpD__33;
					}
					goto LA226_;
LA228_: ;
					{
						NimStringV2 colontmpD__35;
						NimStringV2 colontmpD__36;
						NimStringV2 T231_;
						colontmpD__35.len = 0; colontmpD__35.p = NIM_NIL;
						colontmpD__36.len = 0; colontmpD__36.p = NIM_NIL;
						T231_.len = 0; T231_.p = NIM_NIL;
						colontmpD__35 = dollar___systemZdollars_u29((*(*colonenv__1).tos1).slots.p->data[rc_3].intVal);
						if (NIM_UNLIKELY(*nimErr_)) goto LA224_;
						colontmpD__36 = dollar___systemZdollars_u9(((NI)2147483647));
						if (NIM_UNLIKELY(*nimErr_)) goto LA224_;
						T231_ = rawNewString(colontmpD__35.len + colontmpD__36.len + 19);
appendString((&T231_), TM__pyAIA9cUF0h9c4j2HfNQPfYw_350);
appendString((&T231_), colontmpD__35);
appendString((&T231_), TM__pyAIA9cUF0h9c4j2HfNQPfYw_351);
appendString((&T231_), colontmpD__36);
						colontmpD__34 = T231_;
						eqdestroy___system_u2691(colontmpD__36);
						eqdestroy___system_u2691(colontmpD__35);
						T225_ = colontmpD__34;
					}
LA226_: ;
					nimZeroMem((void*)(&T232_), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
					stackTraceImpl__vm_u73((*colonenv__1).c0, (*colonenv__1).tos1, (*colonenv__1).pc2, T225_, T232_, TM__pyAIA9cUF0h9c4j2HfNQPfYw_230);
					if (NIM_UNLIKELY(*nimErr_)) goto LA224_;
					eqdestroy___system_u2691(colontmpD__34);
					eqdestroy___system_u2691(colontmpD__33);
					eqdestroy___ast_u3252(src_2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___vmprofiler_u19(savedFrame_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					eqdestroy___vm_u14829(colonenv__1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					goto BeforeRet_;
					{
						LA224_:;
					}
					{
						eqdestroy___system_u2691(colontmpD__34);
						eqdestroy___system_u2691(colontmpD__33);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA219_;
				}
LA222_: ;
				idx_2 = ((NI) ((*(*colonenv__1).tos1).slots.p->data[rc_3].intVal));
				T235_ = NIM_NIL;
				{
					if (!((*(*colonenv__1).tos1).slots.p->data[rb_12].kind == ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1))) goto LA238_;
					eqcopy___ast_u3255(&src_2, (*(*colonenv__1).tos1).slots.p->data[rb_12].node);
					if (NIM_UNLIKELY(*nimErr_)) goto LA219_;
				}
				goto LA236_;
LA238_: ;
				{
					eqcopy___ast_u3255(&src_2, (*(*(*colonenv__1).tos1).slots.p->data[rb_12].nodeAddr));
					if (NIM_UNLIKELY(*nimErr_)) goto LA219_;
				}
LA236_: ;
				switch ((*src_2).kind) {
				case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)160):
				{
					NI64 left_2;
					NI64 right_2;
					NI64 realIndex_2;
					left_2 = (*(*src_2)._kind_6.sons.p->data[((NI)1)])._kind_1.intVal;
					right_2 = (*(*src_2)._kind_6.sons.p->data[((NI)2)])._kind_1.intVal;
					realIndex_2 = (NI64)(left_2 + ((NI64) (idx_2)));
					{
						tyObject_HSlice__QbYBq0DTmYHIHa8KuurQ6Q T244_;
						NIM_BOOL T245_;
						T244_ = dotdot___vm_u1109(((NI)0), (NI64)(right_2 - left_2));
						T245_ = (NIM_BOOL)0;
						T245_ = contains__vm_u1214(T244_, idx_2);
						if (!T245_) goto LA246_;
						switch ((*(*src_2)._kind_6.sons.p->data[((NI)0)]).kind) {
						case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)20) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)22):
						{
							tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A T249_;
							nimZeroMem((void*)(&T249_), sizeof(tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A));
							takeCharAddress__vm_u864((*colonenv__1).c0, (*src_2)._kind_6.sons.p->data[((NI)0)], realIndex_2, (*colonenv__1).pc2, (&T249_));
							if (NIM_UNLIKELY(*nimErr_)) goto LA219_;
							eqsink___vmdef_u1715((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), T249_);
							if (NIM_UNLIKELY(*nimErr_)) goto LA219_;
						}
						break;
						case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)41):
						{
							(*(*colonenv__1).tos1).slots.p->data[ra_1].nodeAddr = &(*(*src_2)._kind_6.sons.p->data[((NI)0)])._kind_6.sons.p->data[realIndex_2];
							GC_ref__vm_u1333((*(*src_2)._kind_6.sons.p->data[((NI)0)])._kind_6.sons.p->data[realIndex_2]);
						}
						break;
						default:
						{
							tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T252_;
							nimZeroMem((void*)(&T252_), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
							stackTraceImpl__vm_u73((*colonenv__1).c0, (*colonenv__1).tos1, (*colonenv__1).pc2, TM__pyAIA9cUF0h9c4j2HfNQPfYw_353, T252_, TM__pyAIA9cUF0h9c4j2HfNQPfYw_230);
							if (NIM_UNLIKELY(*nimErr_)) goto LA219_;
							eqdestroy___ast_u3252(src_2);
							if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
							eqdestroy___vmprofiler_u19(savedFrame_1);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
							eqdestroy___vm_u14829(colonenv__1);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
							goto BeforeRet_;
						}
						break;
						}
					}
					goto LA242_;
LA246_: ;
					{
						NimStringV2 colontmpD__37;
						NimStringV2 colontmpD__38;
						NimStringV2 T255_;
						tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T262_;
						colontmpD__37.len = 0; colontmpD__37.p = NIM_NIL;
						colontmpD__38.len = 0; colontmpD__38.p = NIM_NIL;
						T255_.len = 0; T255_.p = NIM_NIL;
						{
							if (!(((NI) (right_2)) < ((NI)0))) goto LA258_;
							colontmpD__37 = TM__pyAIA9cUF0h9c4j2HfNQPfYw_354;
							T255_ = colontmpD__37;
						}
						goto LA256_;
LA258_: ;
						{
							NimStringV2 colontmpD__39;
							NimStringV2 colontmpD__40;
							NimStringV2 T261_;
							colontmpD__39.len = 0; colontmpD__39.p = NIM_NIL;
							colontmpD__40.len = 0; colontmpD__40.p = NIM_NIL;
							T261_.len = 0; T261_.p = NIM_NIL;
							colontmpD__39 = dollar___systemZdollars_u9(idx_2);
							if (NIM_UNLIKELY(*nimErr_)) goto LA254_;
							colontmpD__40 = dollar___systemZdollars_u9(((NI) (right_2)));
							if (NIM_UNLIKELY(*nimErr_)) goto LA254_;
							T261_ = rawNewString(colontmpD__39.len + colontmpD__40.len + 19);
appendString((&T261_), TM__pyAIA9cUF0h9c4j2HfNQPfYw_355);
appendString((&T261_), colontmpD__39);
appendString((&T261_), TM__pyAIA9cUF0h9c4j2HfNQPfYw_356);
appendString((&T261_), colontmpD__40);
							colontmpD__38 = T261_;
							eqdestroy___system_u2691(colontmpD__40);
							eqdestroy___system_u2691(colontmpD__39);
							T255_ = colontmpD__38;
						}
LA256_: ;
						nimZeroMem((void*)(&T262_), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
						stackTraceImpl__vm_u73((*colonenv__1).c0, (*colonenv__1).tos1, (*colonenv__1).pc2, T255_, T262_, TM__pyAIA9cUF0h9c4j2HfNQPfYw_230);
						if (NIM_UNLIKELY(*nimErr_)) goto LA254_;
						eqdestroy___system_u2691(colontmpD__38);
						eqdestroy___system_u2691(colontmpD__37);
						eqdestroy___ast_u3252(src_2);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						eqdestroy___vmprofiler_u19(savedFrame_1);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						eqdestroy___vm_u14829(colonenv__1);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						goto BeforeRet_;
						{
							LA254_:;
						}
						{
							eqdestroy___system_u2691(colontmpD__38);
							eqdestroy___system_u2691(colontmpD__37);
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA219_;
					}
LA242_: ;
				}
				break;
				default:
				{
					{
						NIM_BOOL T268_;
						NI T270_;
						T268_ = (NIM_BOOL)0;
						T268_ = !(((*src_2).kind >= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)1) && (*src_2).kind <= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)22)));
						if (!(T268_)) goto LA269_;
						T270_ = (NI)0;
						T270_ = len__ast_u3190(src_2);
						if (NIM_UNLIKELY(*nimErr_)) goto LA219_;
						T268_ = ltpercent___system_u1092(idx_2, T270_);
LA269_: ;
						if (!T268_) goto LA271_;
						(*(*colonenv__1).tos1).slots.p->data[ra_1].nodeAddr = &(*src_2)._kind_6.sons.p->data[idx_2];
						GC_ref__vm_u1333((*src_2)._kind_6.sons.p->data[idx_2]);
					}
					goto LA266_;
LA271_: ;
					{
						NIM_BOOL T274_;
						tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A T278_;
						T274_ = (NIM_BOOL)0;
						T274_ = ((*src_2).kind >= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)20) && (*src_2).kind <= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)22));
						if (!(T274_)) goto LA275_;
						T274_ = ltpercent___system_u1092(idx_2, (*src_2)._kind_3.strVal.len);
LA275_: ;
						if (!T274_) goto LA276_;
						nimZeroMem((void*)(&T278_), sizeof(tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A));
						takeCharAddress__vm_u864((*colonenv__1).c0, src_2, ((NI64) (idx_2)), (*colonenv__1).pc2, (&T278_));
						if (NIM_UNLIKELY(*nimErr_)) goto LA219_;
						eqsink___vmdef_u1715((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), T278_);
						if (NIM_UNLIKELY(*nimErr_)) goto LA219_;
					}
					goto LA266_;
LA276_: ;
					{
						NimStringV2 colontmpD__41;
						NimStringV2 colontmpD__42;
						NimStringV2 T281_;
						tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T290_;
						colontmpD__41.len = 0; colontmpD__41.p = NIM_NIL;
						colontmpD__42.len = 0; colontmpD__42.p = NIM_NIL;
						T281_.len = 0; T281_.p = NIM_NIL;
						{
							NI T284_;
							T284_ = (NI)0;
							T284_ = safeLen__ast_u3197(src_2);
							if (NIM_UNLIKELY(*nimErr_)) goto LA280_;
							if (!((NI)(T284_ - ((NI)1)) < ((NI)0))) goto LA285_;
							colontmpD__41 = TM__pyAIA9cUF0h9c4j2HfNQPfYw_357;
							T281_ = colontmpD__41;
						}
						goto LA282_;
LA285_: ;
						{
							NimStringV2 colontmpD__43;
							NimStringV2 colontmpD__44;
							NimStringV2 T288_;
							NI T289_;
							colontmpD__43.len = 0; colontmpD__43.p = NIM_NIL;
							colontmpD__44.len = 0; colontmpD__44.p = NIM_NIL;
							T288_.len = 0; T288_.p = NIM_NIL;
							colontmpD__43 = dollar___systemZdollars_u9(idx_2);
							if (NIM_UNLIKELY(*nimErr_)) goto LA280_;
							T289_ = (NI)0;
							T289_ = safeLen__ast_u3197(src_2);
							if (NIM_UNLIKELY(*nimErr_)) goto LA280_;
							colontmpD__44 = dollar___systemZdollars_u9((NI)(T289_ - ((NI)1)));
							if (NIM_UNLIKELY(*nimErr_)) goto LA280_;
							T288_ = rawNewString(colontmpD__43.len + colontmpD__44.len + 19);
appendString((&T288_), TM__pyAIA9cUF0h9c4j2HfNQPfYw_358);
appendString((&T288_), colontmpD__43);
appendString((&T288_), TM__pyAIA9cUF0h9c4j2HfNQPfYw_359);
appendString((&T288_), colontmpD__44);
							colontmpD__42 = T288_;
							eqdestroy___system_u2691(colontmpD__44);
							eqdestroy___system_u2691(colontmpD__43);
							T281_ = colontmpD__42;
						}
LA282_: ;
						nimZeroMem((void*)(&T290_), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
						stackTraceImpl__vm_u73((*colonenv__1).c0, (*colonenv__1).tos1, (*colonenv__1).pc2, T281_, T290_, TM__pyAIA9cUF0h9c4j2HfNQPfYw_230);
						if (NIM_UNLIKELY(*nimErr_)) goto LA280_;
						eqdestroy___system_u2691(colontmpD__42);
						eqdestroy___system_u2691(colontmpD__41);
						eqdestroy___ast_u3252(src_2);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						eqdestroy___vmprofiler_u19(savedFrame_1);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						eqdestroy___vm_u14829(colonenv__1);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						goto BeforeRet_;
						{
							LA280_:;
						}
						{
							eqdestroy___system_u2691(colontmpD__42);
							eqdestroy___system_u2691(colontmpD__41);
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA219_;
					}
LA266_: ;
				}
				break;
				}
				{
					LA219_:;
				}
				{
					oldNimErrFin219_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3252(src_2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin219_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)27):
			{
				NimStringV2 s_1;
				NI rb_13;
				NI rc_4;
				NI idx_3;
				s_1.len = 0; s_1.p = NIM_NIL;
				rb_13 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				rc_4 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(40ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				idx_3 = ((NI) ((*(*colonenv__1).tos1).slots.p->data[rc_4].intVal));
				s_1 = (*(*(*colonenv__1).tos1).slots.p->data[rb_13].node)._kind_3.strVal;
				{
					NIM_BOOL T298_;
					T298_ = (NIM_BOOL)0;
					T298_ = ltpercent___system_u1092(idx_3, s_1.len);
					if (!T298_) goto LA299_;
					(*(*colonenv__1).tos1).slots.p->data[ra_1].intVal = ((NI64) (((NU8)(s_1.p->data[idx_3]))));
				}
				goto LA296_;
LA299_: ;
				{
					NimStringV2 colontmpD__45;
					NimStringV2 colontmpD__46;
					NimStringV2 T303_;
					tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T310_;
					colontmpD__45.len = 0; colontmpD__45.p = NIM_NIL;
					colontmpD__46.len = 0; colontmpD__46.p = NIM_NIL;
					T303_.len = 0; T303_.p = NIM_NIL;
					{
						if (!((NI)(s_1.len - ((NI)1)) < ((NI)0))) goto LA306_;
						colontmpD__45 = TM__pyAIA9cUF0h9c4j2HfNQPfYw_360;
						T303_ = colontmpD__45;
					}
					goto LA304_;
LA306_: ;
					{
						NimStringV2 colontmpD__47;
						NimStringV2 colontmpD__48;
						NimStringV2 T309_;
						colontmpD__47.len = 0; colontmpD__47.p = NIM_NIL;
						colontmpD__48.len = 0; colontmpD__48.p = NIM_NIL;
						T309_.len = 0; T309_.p = NIM_NIL;
						colontmpD__47 = dollar___systemZdollars_u9(idx_3);
						if (NIM_UNLIKELY(*nimErr_)) goto LA302_;
						colontmpD__48 = dollar___systemZdollars_u9((NI)(s_1.len - ((NI)1)));
						if (NIM_UNLIKELY(*nimErr_)) goto LA302_;
						T309_ = rawNewString(colontmpD__47.len + colontmpD__48.len + 19);
appendString((&T309_), TM__pyAIA9cUF0h9c4j2HfNQPfYw_361);
appendString((&T309_), colontmpD__47);
appendString((&T309_), TM__pyAIA9cUF0h9c4j2HfNQPfYw_362);
appendString((&T309_), colontmpD__48);
						colontmpD__46 = T309_;
						eqdestroy___system_u2691(colontmpD__48);
						eqdestroy___system_u2691(colontmpD__47);
						T303_ = colontmpD__46;
					}
LA304_: ;
					nimZeroMem((void*)(&T310_), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
					stackTraceImpl__vm_u73((*colonenv__1).c0, (*colonenv__1).tos1, (*colonenv__1).pc2, T303_, T310_, TM__pyAIA9cUF0h9c4j2HfNQPfYw_230);
					if (NIM_UNLIKELY(*nimErr_)) goto LA302_;
					eqdestroy___system_u2691(colontmpD__46);
					eqdestroy___system_u2691(colontmpD__45);
					eqdestroy___vmprofiler_u19(savedFrame_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					eqdestroy___vm_u14829(colonenv__1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					goto BeforeRet_;
					{
						LA302_:;
					}
					{
						eqdestroy___system_u2691(colontmpD__46);
						eqdestroy___system_u2691(colontmpD__45);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				}
LA296_: ;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)28):
			{
				NI rb_14;
				NI rc_5;
				NI idx_4;
				NimStringV2* s_2;
				rb_14 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				rc_5 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(40ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				{
					NimStringV2 colontmpD__49;
					NimStringV2 colontmpD__50;
					NimStringV2 T319_;
					tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T326_;
					if (!(IL64(2147483647) < (*(*colonenv__1).tos1).slots.p->data[rc_5].intVal)) goto LA316_;
					colontmpD__49.len = 0; colontmpD__49.p = NIM_NIL;
					colontmpD__50.len = 0; colontmpD__50.p = NIM_NIL;
					T319_.len = 0; T319_.p = NIM_NIL;
					{
						if (!NIM_FALSE) goto LA322_;
						colontmpD__49 = TM__pyAIA9cUF0h9c4j2HfNQPfYw_363;
						T319_ = colontmpD__49;
					}
					goto LA320_;
LA322_: ;
					{
						NimStringV2 colontmpD__51;
						NimStringV2 colontmpD__52;
						NimStringV2 T325_;
						colontmpD__51.len = 0; colontmpD__51.p = NIM_NIL;
						colontmpD__52.len = 0; colontmpD__52.p = NIM_NIL;
						T325_.len = 0; T325_.p = NIM_NIL;
						colontmpD__51 = dollar___systemZdollars_u29((*(*colonenv__1).tos1).slots.p->data[rc_5].intVal);
						if (NIM_UNLIKELY(*nimErr_)) goto LA318_;
						colontmpD__52 = dollar___systemZdollars_u9(((NI)2147483647));
						if (NIM_UNLIKELY(*nimErr_)) goto LA318_;
						T325_ = rawNewString(colontmpD__51.len + colontmpD__52.len + 19);
appendString((&T325_), TM__pyAIA9cUF0h9c4j2HfNQPfYw_364);
appendString((&T325_), colontmpD__51);
appendString((&T325_), TM__pyAIA9cUF0h9c4j2HfNQPfYw_365);
appendString((&T325_), colontmpD__52);
						colontmpD__50 = T325_;
						eqdestroy___system_u2691(colontmpD__52);
						eqdestroy___system_u2691(colontmpD__51);
						T319_ = colontmpD__50;
					}
LA320_: ;
					nimZeroMem((void*)(&T326_), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
					stackTraceImpl__vm_u73((*colonenv__1).c0, (*colonenv__1).tos1, (*colonenv__1).pc2, T319_, T326_, TM__pyAIA9cUF0h9c4j2HfNQPfYw_230);
					if (NIM_UNLIKELY(*nimErr_)) goto LA318_;
					eqdestroy___system_u2691(colontmpD__50);
					eqdestroy___system_u2691(colontmpD__49);
					eqdestroy___vmprofiler_u19(savedFrame_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					eqdestroy___vm_u14829(colonenv__1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					goto BeforeRet_;
					{
						LA318_:;
					}
					{
						eqdestroy___system_u2691(colontmpD__50);
						eqdestroy___system_u2691(colontmpD__49);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				}
LA316_: ;
				idx_4 = ((NI) ((*(*colonenv__1).tos1).slots.p->data[rc_5].intVal));
				s_2 = (&(*(*(*colonenv__1).tos1).slots.p->data[rb_14].node)._kind_3.strVal);
				{
					NIM_BOOL T331_;
					tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A T334_;
					T331_ = (NIM_BOOL)0;
					T331_ = ltpercent___system_u1092(idx_4, (*s_2).len);
					if (!T331_) goto LA332_;
					nimZeroMem((void*)(&T334_), sizeof(tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A));
					takeCharAddress__vm_u864((*colonenv__1).c0, (*(*colonenv__1).tos1).slots.p->data[rb_14].node, ((NI64) (idx_4)), (*colonenv__1).pc2, (&T334_));
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqsink___vmdef_u1715((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), T334_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				}
				goto LA329_;
LA332_: ;
				{
					NimStringV2 colontmpD__53;
					NimStringV2 colontmpD__54;
					NimStringV2 T337_;
					tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T344_;
					colontmpD__53.len = 0; colontmpD__53.p = NIM_NIL;
					colontmpD__54.len = 0; colontmpD__54.p = NIM_NIL;
					T337_.len = 0; T337_.p = NIM_NIL;
					{
						if (!((NI)((*s_2).len - ((NI)1)) < ((NI)0))) goto LA340_;
						colontmpD__53 = TM__pyAIA9cUF0h9c4j2HfNQPfYw_366;
						T337_ = colontmpD__53;
					}
					goto LA338_;
LA340_: ;
					{
						NimStringV2 colontmpD__55;
						NimStringV2 colontmpD__56;
						NimStringV2 T343_;
						colontmpD__55.len = 0; colontmpD__55.p = NIM_NIL;
						colontmpD__56.len = 0; colontmpD__56.p = NIM_NIL;
						T343_.len = 0; T343_.p = NIM_NIL;
						colontmpD__55 = dollar___systemZdollars_u9(idx_4);
						if (NIM_UNLIKELY(*nimErr_)) goto LA336_;
						colontmpD__56 = dollar___systemZdollars_u9((NI)((*s_2).len - ((NI)1)));
						if (NIM_UNLIKELY(*nimErr_)) goto LA336_;
						T343_ = rawNewString(colontmpD__55.len + colontmpD__56.len + 19);
appendString((&T343_), TM__pyAIA9cUF0h9c4j2HfNQPfYw_367);
appendString((&T343_), colontmpD__55);
appendString((&T343_), TM__pyAIA9cUF0h9c4j2HfNQPfYw_368);
appendString((&T343_), colontmpD__56);
						colontmpD__54 = T343_;
						eqdestroy___system_u2691(colontmpD__56);
						eqdestroy___system_u2691(colontmpD__55);
						T337_ = colontmpD__54;
					}
LA338_: ;
					nimZeroMem((void*)(&T344_), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
					stackTraceImpl__vm_u73((*colonenv__1).c0, (*colonenv__1).tos1, (*colonenv__1).pc2, T337_, T344_, TM__pyAIA9cUF0h9c4j2HfNQPfYw_230);
					if (NIM_UNLIKELY(*nimErr_)) goto LA336_;
					eqdestroy___system_u2691(colontmpD__54);
					eqdestroy___system_u2691(colontmpD__53);
					eqdestroy___vmprofiler_u19(savedFrame_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					eqdestroy___vm_u14829(colonenv__1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					goto BeforeRet_;
					{
						LA336_:;
					}
					{
						eqdestroy___system_u2691(colontmpD__54);
						eqdestroy___system_u2691(colontmpD__53);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				}
LA329_: ;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)18):
			{
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* arr_1;
				NI rb_15;
				NI rc_6;
				NI idx_5;
				arr_1 = NIM_NIL;
				rb_15 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				rc_6 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(40ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA348_;
				idx_5 = ((NI) ((*(*colonenv__1).tos1).slots.p->data[rb_15].intVal));
				eqcopy___ast_u3255(&arr_1, (*(*colonenv__1).tos1).slots.p->data[ra_1].node);
				if (NIM_UNLIKELY(*nimErr_)) goto LA348_;
				switch ((*arr_1).kind) {
				case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)160):
				{
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* src_3;
					NI64 left_3;
					NI64 right_3;
					NI64 realIndex_3;
					src_3 = NIM_NIL;
					eqcopy___ast_u3255(&src_3, (*arr_1)._kind_6.sons.p->data[((NI)0)]);
					if (NIM_UNLIKELY(*nimErr_)) goto LA350_;
					left_3 = (*(*arr_1)._kind_6.sons.p->data[((NI)1)])._kind_1.intVal;
					right_3 = (*(*arr_1)._kind_6.sons.p->data[((NI)2)])._kind_1.intVal;
					realIndex_3 = (NI64)(left_3 + ((NI64) (idx_5)));
					{
						tyObject_HSlice__QbYBq0DTmYHIHa8KuurQ6Q T353_;
						NIM_BOOL T354_;
						T353_ = dotdot___vm_u1109(((NI)0), (NI64)(right_3 - left_3));
						T354_ = (NIM_BOOL)0;
						T354_ = contains__vm_u1214(T353_, idx_5);
						if (!T354_) goto LA355_;
						switch ((*src_3).kind) {
						case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)20) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)22):
						{
							nimPrepareStrMutationV2((&(*src_3)._kind_3.strVal));
							(*src_3)._kind_3.strVal.p->data[((NI) (realIndex_3))] = ((NIM_CHAR) ((*(*colonenv__1).tos1).slots.p->data[rc_6].intVal));
						}
						break;
						case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)41):
						{
							{
								tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T363_;
								if (!((*(*colonenv__1).tos1).slots.p->data[rc_6].kind == ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2))) goto LA361_;
								T363_ = NIM_NIL;
								T363_ = newIntNode__ast_u5200(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)6), (*(*colonenv__1).tos1).slots.p->data[rc_6].intVal);
								if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T363_); goto LA350_;}
								eqsink___ast_u3261(&(*src_3)._kind_6.sons.p->data[((NI) (realIndex_3))], T363_);
								if (NIM_UNLIKELY(*nimErr_)) goto LA350_;
							}
							goto LA359_;
LA361_: ;
							{
								eqcopy___ast_u3255(&(*src_3)._kind_6.sons.p->data[((NI) (realIndex_3))], (*(*colonenv__1).tos1).slots.p->data[rc_6].node);
								if (NIM_UNLIKELY(*nimErr_)) goto LA350_;
							}
LA359_: ;
						}
						break;
						default:
						{
							tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T366_;
							nimZeroMem((void*)(&T366_), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
							stackTraceImpl__vm_u73((*colonenv__1).c0, (*colonenv__1).tos1, (*colonenv__1).pc2, TM__pyAIA9cUF0h9c4j2HfNQPfYw_370, T366_, TM__pyAIA9cUF0h9c4j2HfNQPfYw_230);
							if (NIM_UNLIKELY(*nimErr_)) goto LA350_;
							eqdestroy___ast_u3252(src_3);
							if (NIM_UNLIKELY(*nimErr_)) goto LA348_;
							eqdestroy___ast_u3252(arr_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
							eqdestroy___vmprofiler_u19(savedFrame_1);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
							eqdestroy___vm_u14829(colonenv__1);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
							goto BeforeRet_;
						}
						break;
						}
					}
					goto LA351_;
LA355_: ;
					{
						NimStringV2 colontmpD__57;
						NimStringV2 colontmpD__58;
						NimStringV2 T369_;
						tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T376_;
						colontmpD__57.len = 0; colontmpD__57.p = NIM_NIL;
						colontmpD__58.len = 0; colontmpD__58.p = NIM_NIL;
						T369_.len = 0; T369_.p = NIM_NIL;
						{
							if (!(((NI) (right_3)) < ((NI)0))) goto LA372_;
							colontmpD__57 = TM__pyAIA9cUF0h9c4j2HfNQPfYw_371;
							T369_ = colontmpD__57;
						}
						goto LA370_;
LA372_: ;
						{
							NimStringV2 colontmpD__59;
							NimStringV2 colontmpD__60;
							NimStringV2 T375_;
							colontmpD__59.len = 0; colontmpD__59.p = NIM_NIL;
							colontmpD__60.len = 0; colontmpD__60.p = NIM_NIL;
							T375_.len = 0; T375_.p = NIM_NIL;
							colontmpD__59 = dollar___systemZdollars_u9(idx_5);
							if (NIM_UNLIKELY(*nimErr_)) goto LA368_;
							colontmpD__60 = dollar___systemZdollars_u9(((NI) (right_3)));
							if (NIM_UNLIKELY(*nimErr_)) goto LA368_;
							T375_ = rawNewString(colontmpD__59.len + colontmpD__60.len + 19);
appendString((&T375_), TM__pyAIA9cUF0h9c4j2HfNQPfYw_372);
appendString((&T375_), colontmpD__59);
appendString((&T375_), TM__pyAIA9cUF0h9c4j2HfNQPfYw_373);
appendString((&T375_), colontmpD__60);
							colontmpD__58 = T375_;
							eqdestroy___system_u2691(colontmpD__60);
							eqdestroy___system_u2691(colontmpD__59);
							T369_ = colontmpD__58;
						}
LA370_: ;
						nimZeroMem((void*)(&T376_), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
						stackTraceImpl__vm_u73((*colonenv__1).c0, (*colonenv__1).tos1, (*colonenv__1).pc2, T369_, T376_, TM__pyAIA9cUF0h9c4j2HfNQPfYw_230);
						if (NIM_UNLIKELY(*nimErr_)) goto LA368_;
						eqdestroy___system_u2691(colontmpD__58);
						eqdestroy___system_u2691(colontmpD__57);
						eqdestroy___ast_u3252(src_3);
						if (NIM_UNLIKELY(*nimErr_)) goto LA348_;
						eqdestroy___ast_u3252(arr_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						eqdestroy___vmprofiler_u19(savedFrame_1);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						eqdestroy___vm_u14829(colonenv__1);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						goto BeforeRet_;
						{
							LA368_:;
						}
						{
							eqdestroy___system_u2691(colontmpD__58);
							eqdestroy___system_u2691(colontmpD__57);
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA350_;
					}
LA351_: ;
					{
						LA350_:;
					}
					{
						oldNimErrFin350_ = *nimErr_; *nimErr_ = NIM_FALSE;
						eqdestroy___ast_u3252(src_3);
						if (NIM_UNLIKELY(*nimErr_)) goto LA348_;
						*nimErr_ = oldNimErrFin350_;
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA348_;
				}
				break;
				case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)20) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)22):
				{
					{
						NIM_BOOL T384_;
						T384_ = (NIM_BOOL)0;
						T384_ = ltpercent___system_u1092(idx_5, (*arr_1)._kind_3.strVal.len);
						if (!T384_) goto LA385_;
						nimPrepareStrMutationV2((&(*arr_1)._kind_3.strVal));
						(*arr_1)._kind_3.strVal.p->data[idx_5] = ((NIM_CHAR) (((NI) ((*(*colonenv__1).tos1).slots.p->data[rc_6].intVal))));
					}
					goto LA382_;
LA385_: ;
					{
						NimStringV2 colontmpD__61;
						NimStringV2 colontmpD__62;
						NimStringV2 T389_;
						tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T396_;
						colontmpD__61.len = 0; colontmpD__61.p = NIM_NIL;
						colontmpD__62.len = 0; colontmpD__62.p = NIM_NIL;
						T389_.len = 0; T389_.p = NIM_NIL;
						{
							if (!((NI)((*arr_1)._kind_3.strVal.len - ((NI)1)) < ((NI)0))) goto LA392_;
							colontmpD__61 = TM__pyAIA9cUF0h9c4j2HfNQPfYw_374;
							T389_ = colontmpD__61;
						}
						goto LA390_;
LA392_: ;
						{
							NimStringV2 colontmpD__63;
							NimStringV2 colontmpD__64;
							NimStringV2 T395_;
							colontmpD__63.len = 0; colontmpD__63.p = NIM_NIL;
							colontmpD__64.len = 0; colontmpD__64.p = NIM_NIL;
							T395_.len = 0; T395_.p = NIM_NIL;
							colontmpD__63 = dollar___systemZdollars_u9(idx_5);
							if (NIM_UNLIKELY(*nimErr_)) goto LA388_;
							colontmpD__64 = dollar___systemZdollars_u9((NI)((*arr_1)._kind_3.strVal.len - ((NI)1)));
							if (NIM_UNLIKELY(*nimErr_)) goto LA388_;
							T395_ = rawNewString(colontmpD__63.len + colontmpD__64.len + 19);
appendString((&T395_), TM__pyAIA9cUF0h9c4j2HfNQPfYw_375);
appendString((&T395_), colontmpD__63);
appendString((&T395_), TM__pyAIA9cUF0h9c4j2HfNQPfYw_376);
appendString((&T395_), colontmpD__64);
							colontmpD__62 = T395_;
							eqdestroy___system_u2691(colontmpD__64);
							eqdestroy___system_u2691(colontmpD__63);
							T389_ = colontmpD__62;
						}
LA390_: ;
						nimZeroMem((void*)(&T396_), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
						stackTraceImpl__vm_u73((*colonenv__1).c0, (*colonenv__1).tos1, (*colonenv__1).pc2, T389_, T396_, TM__pyAIA9cUF0h9c4j2HfNQPfYw_230);
						if (NIM_UNLIKELY(*nimErr_)) goto LA388_;
						eqdestroy___system_u2691(colontmpD__62);
						eqdestroy___system_u2691(colontmpD__61);
						eqdestroy___ast_u3252(arr_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						eqdestroy___vmprofiler_u19(savedFrame_1);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						eqdestroy___vm_u14829(colonenv__1);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						goto BeforeRet_;
						{
							LA388_:;
						}
						{
							eqdestroy___system_u2691(colontmpD__62);
							eqdestroy___system_u2691(colontmpD__61);
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA348_;
					}
LA382_: ;
				}
				break;
				default:
				{
					{
						NI T402_;
						NIM_BOOL T403_;
						T402_ = (NI)0;
						T402_ = len__ast_u3190(arr_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA348_;
						T403_ = (NIM_BOOL)0;
						T403_ = ltpercent___system_u1092(idx_5, T402_);
						if (!T403_) goto LA404_;
						writeField__vm_u516(&(*arr_1)._kind_6.sons.p->data[idx_5], (*(*colonenv__1).tos1).slots.p->data[rc_6]);
						if (NIM_UNLIKELY(*nimErr_)) goto LA348_;
					}
					goto LA400_;
LA404_: ;
					{
						NimStringV2 colontmpD__65;
						NimStringV2 colontmpD__66;
						NimStringV2 T408_;
						tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T417_;
						colontmpD__65.len = 0; colontmpD__65.p = NIM_NIL;
						colontmpD__66.len = 0; colontmpD__66.p = NIM_NIL;
						T408_.len = 0; T408_.p = NIM_NIL;
						{
							NI T411_;
							T411_ = (NI)0;
							T411_ = safeLen__ast_u3197(arr_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA407_;
							if (!((NI)(T411_ - ((NI)1)) < ((NI)0))) goto LA412_;
							colontmpD__65 = TM__pyAIA9cUF0h9c4j2HfNQPfYw_377;
							T408_ = colontmpD__65;
						}
						goto LA409_;
LA412_: ;
						{
							NimStringV2 colontmpD__67;
							NimStringV2 colontmpD__68;
							NimStringV2 T415_;
							NI T416_;
							colontmpD__67.len = 0; colontmpD__67.p = NIM_NIL;
							colontmpD__68.len = 0; colontmpD__68.p = NIM_NIL;
							T415_.len = 0; T415_.p = NIM_NIL;
							colontmpD__67 = dollar___systemZdollars_u9(idx_5);
							if (NIM_UNLIKELY(*nimErr_)) goto LA407_;
							T416_ = (NI)0;
							T416_ = safeLen__ast_u3197(arr_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA407_;
							colontmpD__68 = dollar___systemZdollars_u9((NI)(T416_ - ((NI)1)));
							if (NIM_UNLIKELY(*nimErr_)) goto LA407_;
							T415_ = rawNewString(colontmpD__67.len + colontmpD__68.len + 19);
appendString((&T415_), TM__pyAIA9cUF0h9c4j2HfNQPfYw_378);
appendString((&T415_), colontmpD__67);
appendString((&T415_), TM__pyAIA9cUF0h9c4j2HfNQPfYw_379);
appendString((&T415_), colontmpD__68);
							colontmpD__66 = T415_;
							eqdestroy___system_u2691(colontmpD__68);
							eqdestroy___system_u2691(colontmpD__67);
							T408_ = colontmpD__66;
						}
LA409_: ;
						nimZeroMem((void*)(&T417_), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
						stackTraceImpl__vm_u73((*colonenv__1).c0, (*colonenv__1).tos1, (*colonenv__1).pc2, T408_, T417_, TM__pyAIA9cUF0h9c4j2HfNQPfYw_230);
						if (NIM_UNLIKELY(*nimErr_)) goto LA407_;
						eqdestroy___system_u2691(colontmpD__66);
						eqdestroy___system_u2691(colontmpD__65);
						eqdestroy___ast_u3252(arr_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						eqdestroy___vmprofiler_u19(savedFrame_1);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						eqdestroy___vm_u14829(colonenv__1);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						goto BeforeRet_;
						{
							LA407_:;
						}
						{
							eqdestroy___system_u2691(colontmpD__66);
							eqdestroy___system_u2691(colontmpD__65);
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA348_;
					}
LA400_: ;
				}
				break;
				}
				{
					LA348_:;
				}
				{
					oldNimErrFin348_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3252(arr_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin348_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)19):
			{
				NI rb_16;
				NI rc_7;
				rb_16 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				rc_7 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(40ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				{
					NIM_BOOL T425_;
					NIM_BOOL T426_;
					NIM_BOOL T427_;
					NI T428_;
					NIM_BOOL T431_;
					NIM_BOOL T434_;
					tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T438_;
					T425_ = (NIM_BOOL)0;
					T426_ = (NIM_BOOL)0;
					T427_ = (NIM_BOOL)0;
					T428_ = (*(*colonenv__1).tos1).slots.len;
					T427_ = (T428_ <= rb_16);
					if (T427_) goto LA429_;
					T427_ = ((*(*colonenv__1).tos1).slots.p->data[rb_16].kind == ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)0));
LA429_: ;
					T426_ = T427_;
					if (T426_) goto LA430_;
					T431_ = (NIM_BOOL)0;
					T431_ = ((*(*colonenv__1).tos1).slots.p->data[rb_16].kind == ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1));
					if (!(T431_)) goto LA432_;
					T431_ = ((*(*colonenv__1).tos1).slots.p->data[rb_16].node == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL));
LA432_: ;
					T426_ = T431_;
LA430_: ;
					T425_ = T426_;
					if (T425_) goto LA433_;
					T434_ = (NIM_BOOL)0;
					T434_ = ((*(*colonenv__1).tos1).slots.p->data[rb_16].kind == ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)5));
					if (!(T434_)) goto LA435_;
					T434_ = ((*(*(*colonenv__1).tos1).slots.p->data[rb_16].nodeAddr) == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL));
LA435_: ;
					T425_ = T434_;
LA433_: ;
					if (!T425_) goto LA436_;
					nimZeroMem((void*)(&T438_), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
					stackTraceImpl__vm_u73((*colonenv__1).c0, (*colonenv__1).tos1, (*colonenv__1).pc2, TM__pyAIA9cUF0h9c4j2HfNQPfYw_380, T438_, TM__pyAIA9cUF0h9c4j2HfNQPfYw_230);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___vmprofiler_u19(savedFrame_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					eqdestroy___vm_u14829(colonenv__1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					goto BeforeRet_;
				}
				goto LA423_;
LA436_: ;
				{
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* src_4;
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T441_;
					src_4 = NIM_NIL;
					T441_ = NIM_NIL;
					{
						if (!((*(*colonenv__1).tos1).slots.p->data[rb_16].kind == ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1))) goto LA444_;
						eqcopy___ast_u3255(&src_4, (*(*colonenv__1).tos1).slots.p->data[rb_16].node);
						if (NIM_UNLIKELY(*nimErr_)) goto LA440_;
					}
					goto LA442_;
LA444_: ;
					{
						eqcopy___ast_u3255(&src_4, (*(*(*colonenv__1).tos1).slots.p->data[rb_16].nodeAddr));
						if (NIM_UNLIKELY(*nimErr_)) goto LA440_;
					}
LA442_: ;
					switch ((*src_4).kind) {
					case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)1) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)23):
					{
						NimStringV2 colontmpD__69;
						NimStringV2 colontmpD__70;
						NimStringV2 colontmpD__71;
						NimStringV2 T449_;
						tyTuple__NF6bgG5XEXlP7DfqszlNdg T450_;
						tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T451_;
						colontmpD__69.len = 0; colontmpD__69.p = NIM_NIL;
						colontmpD__70.len = 0; colontmpD__70.p = NIM_NIL;
						colontmpD__71.len = 0; colontmpD__71.p = NIM_NIL;
						T449_.len = 0; T449_.p = NIM_NIL;
						T450_.Field0 = TM__pyAIA9cUF0h9c4j2HfNQPfYw_384;
						T450_.Field1 = (*src_4).kind;
						T450_.Field2 = TM__pyAIA9cUF0h9c4j2HfNQPfYw_386;
						colontmpD__69 = typeToString__types_u54((*src_4).typField, ((tyEnum_TPreferedDesc__ddj0M89bv09cBYthgD4XTq3Q)0));
						if (NIM_UNLIKELY(*nimErr_)) goto LA448_;
						T450_.Field3 = colontmpD__69;
						T450_.Field4 = TM__pyAIA9cUF0h9c4j2HfNQPfYw_388;
						T450_.Field5 = rc_7;
						colontmpD__70 = dollar___vm_u1541((&T450_));
						if (NIM_UNLIKELY(*nimErr_)) goto LA448_;
						T449_ = rawNewString(colontmpD__70.len + 32);
appendString((&T449_), TM__pyAIA9cUF0h9c4j2HfNQPfYw_382);
appendString((&T449_), colontmpD__70);
						colontmpD__71 = T449_;
						nimZeroMem((void*)(&T451_), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
						stackTraceImpl__vm_u73((*colonenv__1).c0, (*colonenv__1).tos1, (*colonenv__1).pc2, colontmpD__71, T451_, TM__pyAIA9cUF0h9c4j2HfNQPfYw_230);
						if (NIM_UNLIKELY(*nimErr_)) goto LA448_;
						eqdestroy___system_u2691(colontmpD__71);
						eqdestroy___system_u2691(colontmpD__70);
						eqdestroy___system_u2691(colontmpD__69);
						eqdestroy___ast_u3252(src_4);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						eqdestroy___vmprofiler_u19(savedFrame_1);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						eqdestroy___vm_u14829(colonenv__1);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						goto BeforeRet_;
						{
							LA448_:;
						}
						{
							eqdestroy___system_u2691(colontmpD__71);
							eqdestroy___system_u2691(colontmpD__70);
							eqdestroy___system_u2691(colontmpD__69);
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA440_;
					}
					break;
					case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)38):
					{
						tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_1;
						n_1 = NIM_NIL;
						n_1 = skipColon__ast_u7347((*src_4)._kind_6.sons.p->data[(NI)(rc_7 + ((NI)1))]);
						if (NIM_UNLIKELY(*nimErr_)) goto LA440_;
						eqsink___ast_u3261(&(*(*colonenv__1).tos1).slots.p->data[ra_1].node, n_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA440_;
					}
					break;
					case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)160):
					{
						tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_2;
						tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T456_;
						n_2 = NIM_NIL;
						T456_ = NIM_NIL;
						{
							NIM_BOOL T459_;
							T459_ = (NIM_BOOL)0;
							T459_ = !(((*src_4).typField == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL)));
							if (!(T459_)) goto LA460_;
							T459_ = (((*(*src_4).typField).flags &((NU64)1<<((NU)((((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)33)))&63U)))!=0);
LA460_: ;
							if (!T459_) goto LA461_;
							eqcopy___ast_u3255(&n_2, (*src_4)._kind_6.sons.p->data[rc_7]);
							if (NIM_UNLIKELY(*nimErr_)) goto LA440_;
						}
						goto LA457_;
LA461_: ;
						{
							n_2 = skipColon__ast_u7347((*src_4)._kind_6.sons.p->data[rc_7]);
							if (NIM_UNLIKELY(*nimErr_)) goto LA440_;
						}
LA457_: ;
						eqsink___ast_u3261(&(*(*colonenv__1).tos1).slots.p->data[ra_1].node, n_2);
						if (NIM_UNLIKELY(*nimErr_)) goto LA440_;
					}
					break;
					default:
					{
						tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_3;
						n_3 = NIM_NIL;
						eqcopy___ast_u3255(&n_3, (*src_4)._kind_6.sons.p->data[rc_7]);
						if (NIM_UNLIKELY(*nimErr_)) goto LA440_;
						eqsink___ast_u3261(&(*(*colonenv__1).tos1).slots.p->data[ra_1].node, n_3);
						if (NIM_UNLIKELY(*nimErr_)) goto LA440_;
					}
					break;
					}
					{
						LA440_:;
					}
					{
						oldNimErrFin440_ = *nimErr_; *nimErr_ = NIM_FALSE;
						eqdestroy___ast_u3252(src_4);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						*nimErr_ = oldNimErrFin440_;
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				}
LA423_: ;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)20):
			{
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* src_5;
				NI rb_17;
				NI rc_8;
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T469_;
				src_5 = NIM_NIL;
				rb_17 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				rc_8 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(40ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)5));
				if (NIM_UNLIKELY(*nimErr_)) goto LA468_;
				T469_ = NIM_NIL;
				{
					if (!((*(*colonenv__1).tos1).slots.p->data[rb_17].kind == ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1))) goto LA472_;
					eqcopy___ast_u3255(&src_5, (*(*colonenv__1).tos1).slots.p->data[rb_17].node);
					if (NIM_UNLIKELY(*nimErr_)) goto LA468_;
				}
				goto LA470_;
LA472_: ;
				{
					eqcopy___ast_u3255(&src_5, (*(*(*colonenv__1).tos1).slots.p->data[rb_17].nodeAddr));
					if (NIM_UNLIKELY(*nimErr_)) goto LA468_;
				}
LA470_: ;
				switch ((*src_5).kind) {
				case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)1) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)23):
				{
					tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T476_;
					nimZeroMem((void*)(&T476_), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
					stackTraceImpl__vm_u73((*colonenv__1).c0, (*colonenv__1).tos1, (*colonenv__1).pc2, TM__pyAIA9cUF0h9c4j2HfNQPfYw_389, T476_, TM__pyAIA9cUF0h9c4j2HfNQPfYw_230);
					if (NIM_UNLIKELY(*nimErr_)) goto LA468_;
					eqdestroy___ast_u3252(src_5);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___vmprofiler_u19(savedFrame_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					eqdestroy___vm_u14829(colonenv__1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					goto BeforeRet_;
				}
				break;
				case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)38):
				{
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_4;
					n_4 = NIM_NIL;
					eqcopy___ast_u3255(&n_4, (*src_5)._kind_6.sons.p->data[(NI)(rc_8 + ((NI)1))]);
					if (NIM_UNLIKELY(*nimErr_)) goto LA468_;
					{
						if (!((*n_4).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)34))) goto LA480_;
						(*(*colonenv__1).tos1).slots.p->data[ra_1].nodeAddr = &(*n_4)._kind_6.sons.p->data[((NI)1)];
						GC_ref__vm_u1333((*n_4)._kind_6.sons.p->data[((NI)1)]);
					}
					goto LA478_;
LA480_: ;
					{
						(*(*colonenv__1).tos1).slots.p->data[ra_1].nodeAddr = &(*src_5)._kind_6.sons.p->data[(NI)(rc_8 + ((NI)1))];
						GC_ref__vm_u1333((*src_5)._kind_6.sons.p->data[(NI)(rc_8 + ((NI)1))]);
					}
LA478_: ;
					eqdestroy___ast_u3252(n_4);
					if (NIM_UNLIKELY(*nimErr_)) goto LA468_;
				}
				break;
				default:
				{
					(*(*colonenv__1).tos1).slots.p->data[ra_1].nodeAddr = &(*src_5)._kind_6.sons.p->data[rc_8];
					GC_ref__vm_u1333((*src_5)._kind_6.sons.p->data[rc_8]);
				}
				break;
				}
				{
					LA468_:;
				}
				{
					oldNimErrFin468_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3252(src_5);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin468_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)21):
			{
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* dest_1;
				NI rb_18;
				NI rc_9;
				NI shiftedRb_1;
				dest_1 = NIM_NIL;
				rb_18 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				rc_9 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(40ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA487_;
				shiftedRb_1 = (NI)(rb_18 + ((*(*(*colonenv__1).tos1).slots.p->data[ra_1].node).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)38)));
				eqcopy___ast_u3255(&dest_1, (*(*colonenv__1).tos1).slots.p->data[ra_1].node);
				if (NIM_UNLIKELY(*nimErr_)) goto LA487_;
				{
					tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T492_;
					if (!((*dest_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)23))) goto LA490_;
					nimZeroMem((void*)(&T492_), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
					stackTraceImpl__vm_u73((*colonenv__1).c0, (*colonenv__1).tos1, (*colonenv__1).pc2, TM__pyAIA9cUF0h9c4j2HfNQPfYw_390, T492_, TM__pyAIA9cUF0h9c4j2HfNQPfYw_230);
					if (NIM_UNLIKELY(*nimErr_)) goto LA487_;
					eqdestroy___ast_u3252(dest_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___vmprofiler_u19(savedFrame_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					eqdestroy___vm_u14829(colonenv__1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					goto BeforeRet_;
				}
				goto LA488_;
LA490_: ;
				{
					if (!((*(*dest_1)._kind_6.sons.p->data[shiftedRb_1]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)34))) goto LA494_;
					writeField__vm_u516(&(*(*dest_1)._kind_6.sons.p->data[shiftedRb_1])._kind_6.sons.p->data[((NI)1)], (*(*colonenv__1).tos1).slots.p->data[rc_9]);
					if (NIM_UNLIKELY(*nimErr_)) goto LA487_;
					(*(*(*dest_1)._kind_6.sons.p->data[shiftedRb_1])._kind_6.sons.p->data[((NI)1)]).flags |= ((NU32)1)<<(((((tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw)24))) & 31);
				}
				goto LA488_;
LA494_: ;
				{
					writeField__vm_u516(&(*dest_1)._kind_6.sons.p->data[shiftedRb_1], (*(*colonenv__1).tos1).slots.p->data[rc_9]);
					if (NIM_UNLIKELY(*nimErr_)) goto LA487_;
					(*(*dest_1)._kind_6.sons.p->data[shiftedRb_1]).flags |= ((NU32)1)<<(((((tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw)24))) & 31);
				}
LA488_: ;
				{
					LA487_:;
				}
				{
					oldNimErrFin487_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3252(dest_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin487_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)26):
			{
				NI rb_19;
				NI rc_10;
				NI idx_6;
				rb_19 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				rc_10 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(40ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				idx_6 = ((NI) ((*(*colonenv__1).tos1).slots.p->data[rb_19].intVal));
				{
					NIM_BOOL T502_;
					T502_ = (NIM_BOOL)0;
					T502_ = ltpercent___system_u1092(idx_6, (*(*(*colonenv__1).tos1).slots.p->data[ra_1].node)._kind_3.strVal.len);
					if (!T502_) goto LA503_;
					nimPrepareStrMutationV2((&(*(*(*colonenv__1).tos1).slots.p->data[ra_1].node)._kind_3.strVal));
					(*(*(*colonenv__1).tos1).slots.p->data[ra_1].node)._kind_3.strVal.p->data[idx_6] = ((NIM_CHAR) (((NI) ((*(*colonenv__1).tos1).slots.p->data[rc_10].intVal))));
				}
				goto LA500_;
LA503_: ;
				{
					NimStringV2 colontmpD__72;
					NimStringV2 colontmpD__73;
					NimStringV2 T507_;
					tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T514_;
					colontmpD__72.len = 0; colontmpD__72.p = NIM_NIL;
					colontmpD__73.len = 0; colontmpD__73.p = NIM_NIL;
					T507_.len = 0; T507_.p = NIM_NIL;
					{
						if (!((NI)((*(*(*colonenv__1).tos1).slots.p->data[ra_1].node)._kind_3.strVal.len - ((NI)1)) < ((NI)0))) goto LA510_;
						colontmpD__72 = TM__pyAIA9cUF0h9c4j2HfNQPfYw_391;
						T507_ = colontmpD__72;
					}
					goto LA508_;
LA510_: ;
					{
						NimStringV2 colontmpD__74;
						NimStringV2 colontmpD__75;
						NimStringV2 T513_;
						colontmpD__74.len = 0; colontmpD__74.p = NIM_NIL;
						colontmpD__75.len = 0; colontmpD__75.p = NIM_NIL;
						T513_.len = 0; T513_.p = NIM_NIL;
						colontmpD__74 = dollar___systemZdollars_u9(idx_6);
						if (NIM_UNLIKELY(*nimErr_)) goto LA506_;
						colontmpD__75 = dollar___systemZdollars_u9((NI)((*(*(*colonenv__1).tos1).slots.p->data[ra_1].node)._kind_3.strVal.len - ((NI)1)));
						if (NIM_UNLIKELY(*nimErr_)) goto LA506_;
						T513_ = rawNewString(colontmpD__74.len + colontmpD__75.len + 19);
appendString((&T513_), TM__pyAIA9cUF0h9c4j2HfNQPfYw_392);
appendString((&T513_), colontmpD__74);
appendString((&T513_), TM__pyAIA9cUF0h9c4j2HfNQPfYw_393);
appendString((&T513_), colontmpD__75);
						colontmpD__73 = T513_;
						eqdestroy___system_u2691(colontmpD__75);
						eqdestroy___system_u2691(colontmpD__74);
						T507_ = colontmpD__73;
					}
LA508_: ;
					nimZeroMem((void*)(&T514_), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
					stackTraceImpl__vm_u73((*colonenv__1).c0, (*colonenv__1).tos1, (*colonenv__1).pc2, T507_, T514_, TM__pyAIA9cUF0h9c4j2HfNQPfYw_230);
					if (NIM_UNLIKELY(*nimErr_)) goto LA506_;
					eqdestroy___system_u2691(colontmpD__73);
					eqdestroy___system_u2691(colontmpD__72);
					eqdestroy___vmprofiler_u19(savedFrame_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					eqdestroy___vm_u14829(colonenv__1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					goto BeforeRet_;
					{
						LA506_:;
					}
					{
						eqdestroy___system_u2691(colontmpD__73);
						eqdestroy___system_u2691(colontmpD__72);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				}
LA500_: ;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)22):
			{
				NI rb_20;
				rb_20 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)4));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				(*(*colonenv__1).tos1).slots.p->data[ra_1].regAddr = (&(*(*colonenv__1).tos1).slots.p->data[rb_20]);
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)23):
			{
				NI rb_21;
				rb_21 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)5));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				switch ((*(*colonenv__1).tos1).slots.p->data[rb_21].kind) {
				case ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1):
				{
					(*(*colonenv__1).tos1).slots.p->data[ra_1].nodeAddr = &(*(*colonenv__1).tos1).slots.p->data[rb_21].node;
					GC_ref__vm_u1333((*(*colonenv__1).tos1).slots.p->data[rb_21].node);
				}
				break;
				case ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)5):
				{
					(*(*colonenv__1).tos1).slots.p->data[ra_1].nodeAddr = (*(*colonenv__1).tos1).slots.p->data[rb_21].nodeAddr;
				}
				break;
				default:
				{
					NimStringV2 colontmpD__76;
					NimStringV2 colontmpD__77;
					NimStringV2 T523_;
					tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T524_;
					colontmpD__76.len = 0; colontmpD__76.p = NIM_NIL;
					colontmpD__77.len = 0; colontmpD__77.p = NIM_NIL;
					T523_.len = 0; T523_.p = NIM_NIL;
					colontmpD__76 = dollar___vmdef_u304((*(*colonenv__1).tos1).slots.p->data[rb_21].kind);
					T523_ = rawNewString(colontmpD__76.len + 41);
appendString((&T523_), TM__pyAIA9cUF0h9c4j2HfNQPfYw_395);
appendString((&T523_), colontmpD__76);
					colontmpD__77 = T523_;
					nimZeroMem((void*)(&T524_), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
					stackTraceImpl__vm_u73((*colonenv__1).c0, (*colonenv__1).tos1, (*colonenv__1).pc2, colontmpD__77, T524_, TM__pyAIA9cUF0h9c4j2HfNQPfYw_230);
					if (NIM_UNLIKELY(*nimErr_)) goto LA522_;
					eqdestroy___system_u2691(colontmpD__77);
					eqdestroy___system_u2691(colontmpD__76);
					eqdestroy___vmprofiler_u19(savedFrame_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					eqdestroy___vm_u14829(colonenv__1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					goto BeforeRet_;
					{
						LA522_:;
					}
					{
						eqdestroy___system_u2691(colontmpD__77);
						eqdestroy___system_u2691(colontmpD__76);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				}
				break;
				}
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)24):
			{
				NI ra_3;
				NI rb_22;
				ra_3 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(8ULL & (64 - 1))) & 65535ULL)));
				rb_22 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				switch ((*(*colonenv__1).tos1).slots.p->data[rb_22].kind) {
				case ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)5):
				{
					ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_3]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqcopy___ast_u3255(&(*(*colonenv__1).tos1).slots.p->data[ra_3].node, (*(*(*colonenv__1).tos1).slots.p->data[rb_22].nodeAddr));
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				}
				break;
				case ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)4):
				{
					ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_3]), (*(*(*colonenv__1).tos1).slots.p->data[rb_22].regAddr).kind);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqcopy___vmdef_u1709((&(*(*colonenv__1).tos1).slots.p->data[ra_3]), (*(*(*colonenv__1).tos1).slots.p->data[rb_22].regAddr));
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				}
				break;
				case ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1):
				{
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* nodeX60gensym519__1;
					tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typX60gensym519__1;
					NIM_BOOL colontmpD__78;
					NIM_BOOL colontmpD__79;
					nodeX60gensym519__1 = NIM_NIL;
					typX60gensym519__1 = NIM_NIL;
					colontmpD__78 = (NIM_BOOL)0;
					colontmpD__79 = (NIM_BOOL)0;
					{
						if (!((*(*(*colonenv__1).tos1).slots.p->data[rb_22].node).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)141))) goto LA534_;
						eqcopy___ast_u3255(&(*(*colonenv__1).tos1).slots.p->data[ra_3].node, (*(*(*colonenv__1).tos1).slots.p->data[rb_22].node)._kind_6.sons.p->data[((NI)0)]);
						if (NIM_UNLIKELY(*nimErr_)) goto LA531_;
					}
					goto LA532_;
LA534_: ;
					{
						NIM_BOOL T542_;
						eqcopy___ast_u3255(&nodeX60gensym519__1, (*(*colonenv__1).tos1).slots.p->data[rb_22].node);
						if (NIM_UNLIKELY(*nimErr_)) goto LA531_;
						{
							tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T541_;
							if (!((*nodeX60gensym519__1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)23))) goto LA539_;
							nimZeroMem((void*)(&T541_), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
							stackTraceImpl__vm_u73((*colonenv__1).c0, (*colonenv__1).tos1, (*colonenv__1).pc2, TM__pyAIA9cUF0h9c4j2HfNQPfYw_396, T541_, TM__pyAIA9cUF0h9c4j2HfNQPfYw_397);
							if (NIM_UNLIKELY(*nimErr_)) goto LA531_;
							eqdestroy___ast_u3378(typX60gensym519__1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
							eqdestroy___ast_u3252(nodeX60gensym519__1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
							eqdestroy___vmprofiler_u19(savedFrame_1);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
							eqdestroy___vm_u14829(colonenv__1);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
							goto BeforeRet_;
						}
LA539_: ;
						eqcopy___ast_u3381(&typX60gensym519__1, (*nodeX60gensym519__1).typField);
						if (NIM_UNLIKELY(*nimErr_)) goto LA531_;
						T542_ = (NIM_BOOL)0;
						{
							NIM_BOOL T545_;
							NIM_BOOL T547_;
							tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ2X60gensym519__1;
							tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* T552_;
							T545_ = (NIM_BOOL)0;
							T545_ = (((*nodeX60gensym519__1).flags &((NU32)1<<((NU)((((tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw)14)))&31U)))!=0);
							if (T545_) goto LA546_;
							T547_ = (NIM_BOOL)0;
							T547_ = !((typX60gensym519__1 == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL)));
							if (!(T547_)) goto LA548_;
							T547_ = ((*typX60gensym519__1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)21));
LA548_: ;
							T545_ = T547_;
LA546_: ;
							if (!T545_) goto LA549_;
							typ2X60gensym519__1 = NIM_NIL;
							T552_ = NIM_NIL;
							{
								if (!((*typX60gensym519__1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)21))) goto LA555_;
								typ2X60gensym519__1 = elementType__ast_u5331(typX60gensym519__1);
								if (NIM_UNLIKELY(*nimErr_)) goto LA551_;
							}
							goto LA553_;
LA555_: ;
							{
								eqcopy___ast_u3381(&typ2X60gensym519__1, typX60gensym519__1);
								if (NIM_UNLIKELY(*nimErr_)) goto LA551_;
							}
LA553_: ;
							{
								NIM_BOOL T560_;
								NimStringV2 colontmpD__80;
								NimStringV2 colontmpD__81;
								NimStringV2 colontmpD__82;
								NimStringV2 T564_;
								tyTuple__dsvP9bgd7x7RN0ykJDjb3Sg T565_;
								tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T566_;
								T560_ = (NIM_BOOL)0;
								T560_ = derefPtrToReg__vm_u144((*nodeX60gensym519__1)._kind_1.intVal, typ2X60gensym519__1, (&(*(*colonenv__1).tos1).slots.p->data[ra_3]), NIM_FALSE);
								if (NIM_UNLIKELY(*nimErr_)) goto LA551_;
								if (!!(T560_)) goto LA561_;
								colontmpD__80.len = 0; colontmpD__80.p = NIM_NIL;
								colontmpD__81.len = 0; colontmpD__81.p = NIM_NIL;
								colontmpD__82.len = 0; colontmpD__82.p = NIM_NIL;
								T564_.len = 0; T564_.p = NIM_NIL;
								colontmpD__80 = typeToString__types_u54(typX60gensym519__1, ((tyEnum_TPreferedDesc__ddj0M89bv09cBYthgD4XTq3Q)0));
								if (NIM_UNLIKELY(*nimErr_)) goto LA563_;
								T565_.Field0 = colontmpD__80;
								T565_.Field1 = (*typX60gensym519__1).kind;
								colontmpD__81 = dollar___vm_u1803(T565_);
								if (NIM_UNLIKELY(*nimErr_)) goto LA563_;
								T564_ = rawNewString(colontmpD__81.len + 28);
appendString((&T564_), TM__pyAIA9cUF0h9c4j2HfNQPfYw_399);
appendString((&T564_), colontmpD__81);
								colontmpD__82 = T564_;
								nimZeroMem((void*)(&T566_), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
								stackTraceImpl__vm_u73((*colonenv__1).c0, (*colonenv__1).tos1, (*colonenv__1).pc2, colontmpD__82, T566_, TM__pyAIA9cUF0h9c4j2HfNQPfYw_397);
								if (NIM_UNLIKELY(*nimErr_)) goto LA563_;
								eqdestroy___system_u2691(colontmpD__82);
								eqdestroy___system_u2691(colontmpD__81);
								eqdestroy___system_u2691(colontmpD__80);
								eqdestroy___ast_u3378(typ2X60gensym519__1);
								if (NIM_UNLIKELY(*nimErr_)) goto LA531_;
								eqdestroy___ast_u3378(typX60gensym519__1);
								if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
								eqdestroy___ast_u3252(nodeX60gensym519__1);
								if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
								eqdestroy___vmprofiler_u19(savedFrame_1);
								if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
								eqdestroy___vm_u14829(colonenv__1);
								if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
								goto BeforeRet_;
								{
									LA563_:;
								}
								{
									eqdestroy___system_u2691(colontmpD__82);
									eqdestroy___system_u2691(colontmpD__81);
									eqdestroy___system_u2691(colontmpD__80);
								}
								if (NIM_UNLIKELY(*nimErr_)) goto LA551_;
							}
LA561_: ;
							colontmpD__78 = NIM_TRUE;
							T542_ = colontmpD__78;
							{
								LA551_:;
							}
							{
								oldNimErrFin551_ = *nimErr_; *nimErr_ = NIM_FALSE;
								eqdestroy___ast_u3378(typ2X60gensym519__1);
								if (NIM_UNLIKELY(*nimErr_)) goto LA531_;
								*nimErr_ = oldNimErrFin551_;
							}
							if (NIM_UNLIKELY(*nimErr_)) goto LA531_;
						}
						goto LA543_;
LA549_: ;
						{
							colontmpD__79 = NIM_FALSE;
							T542_ = colontmpD__79;
						}
LA543_: ;
						if (!!(T542_)) goto LA572_;
						ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_3]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1));
						if (NIM_UNLIKELY(*nimErr_)) goto LA531_;
						eqcopy___ast_u3255(&(*(*colonenv__1).tos1).slots.p->data[ra_3].node, (*(*colonenv__1).tos1).slots.p->data[rb_22].node);
						if (NIM_UNLIKELY(*nimErr_)) goto LA531_;
					}
					goto LA532_;
LA572_: ;
LA532_: ;
					{
						LA531_:;
					}
					{
						oldNimErrFin531_ = *nimErr_; *nimErr_ = NIM_FALSE;
						eqdestroy___ast_u3378(typX60gensym519__1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						eqdestroy___ast_u3252(nodeX60gensym519__1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						*nimErr_ = oldNimErrFin531_;
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				}
				break;
				default:
				{
					NimStringV2 colontmpD__83;
					NimStringV2 colontmpD__84;
					NimStringV2 T578_;
					tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T579_;
					colontmpD__83.len = 0; colontmpD__83.p = NIM_NIL;
					colontmpD__84.len = 0; colontmpD__84.p = NIM_NIL;
					T578_.len = 0; T578_.p = NIM_NIL;
					colontmpD__83 = dollar___vmdef_u304((*(*colonenv__1).tos1).slots.p->data[rb_22].kind);
					T578_ = rawNewString(colontmpD__83.len + 38);
appendString((&T578_), TM__pyAIA9cUF0h9c4j2HfNQPfYw_401);
appendString((&T578_), colontmpD__83);
					colontmpD__84 = T578_;
					nimZeroMem((void*)(&T579_), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
					stackTraceImpl__vm_u73((*colonenv__1).c0, (*colonenv__1).tos1, (*colonenv__1).pc2, colontmpD__84, T579_, TM__pyAIA9cUF0h9c4j2HfNQPfYw_230);
					if (NIM_UNLIKELY(*nimErr_)) goto LA577_;
					eqdestroy___system_u2691(colontmpD__84);
					eqdestroy___system_u2691(colontmpD__83);
					eqdestroy___vmprofiler_u19(savedFrame_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					eqdestroy___vm_u14829(colonenv__1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					goto BeforeRet_;
					{
						LA577_:;
					}
					{
						eqdestroy___system_u2691(colontmpD__84);
						eqdestroy___system_u2691(colontmpD__83);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				}
				break;
				}
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)25):
			{
				NI ra_4;
				NI rc_11;
				ra_4 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(8ULL & (64 - 1))) & 65535ULL)));
				rc_11 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(40ULL & (64 - 1))) & 65535ULL)));
				switch ((*(*colonenv__1).tos1).slots.p->data[ra_4].kind) {
				case ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)5):
				{
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_5;
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** nAddr_1;
					n_5 = NIM_NIL;
					n_5 = regToNode__vm_u542((*(*colonenv__1).tos1).slots.p->data[rc_11]);
					if (NIM_UNLIKELY(*nimErr_)) goto LA584_;
					nAddr_1 = (*(*colonenv__1).tos1).slots.p->data[ra_4].nodeAddr;
					{
						tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T589_;
						if (!((*nAddr_1) == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL))) goto LA587_;
						nimZeroMem((void*)(&T589_), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
						stackTraceImpl__vm_u73((*colonenv__1).c0, (*colonenv__1).tos1, (*colonenv__1).pc2, TM__pyAIA9cUF0h9c4j2HfNQPfYw_403, T589_, TM__pyAIA9cUF0h9c4j2HfNQPfYw_230);
						if (NIM_UNLIKELY(*nimErr_)) goto LA584_;
						eqdestroy___ast_u3252(n_5);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						eqdestroy___vmprofiler_u19(savedFrame_1);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						eqdestroy___vm_u14829(colonenv__1);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						goto BeforeRet_;
					}
LA587_: ;
					{
						NIM_BOOL T592_;
						T592_ = (NIM_BOOL)0;
						T592_ = !((((*(*nAddr_1)).flags &((NU32)1<<((NU)((((tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw)13)))&31U)))!=0));
						if (!(T592_)) goto LA593_;
						T592_ = !((((*n_5).flags &((NU32)1<<((NU)((((tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw)13)))&31U)))!=0));
LA593_: ;
						if (!T592_) goto LA594_;
						eqcopy___ast_u3273((&(*(*nAddr_1))), (&(*n_5)));
						if (NIM_UNLIKELY(*nimErr_)) goto LA584_;
					}
					goto LA590_;
LA594_: ;
					{
						eqsink___ast_u3261(&(*nAddr_1), n_5);
						if (NIM_UNLIKELY(*nimErr_)) goto LA584_;
						eqwasMoved___ast_u3249(&n_5);
						if (NIM_UNLIKELY(*nimErr_)) goto LA584_;
					}
LA590_: ;
					{
						LA584_:;
					}
					{
						oldNimErrFin584_ = *nimErr_; *nimErr_ = NIM_FALSE;
						eqdestroy___ast_u3252(n_5);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						*nimErr_ = oldNimErrFin584_;
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				}
				break;
				case ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)4):
				{
					eqcopy___vmdef_u1709((&(*(*(*colonenv__1).tos1).slots.p->data[ra_4].regAddr)), (*(*colonenv__1).tos1).slots.p->data[rc_11]);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				}
				break;
				case ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1):
				{
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* nodeX60gensym555__1;
					tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typX60gensym555__1;
					NIM_BOOL colontmpD__85;
					NIM_BOOL colontmpD__86;
					nodeX60gensym555__1 = NIM_NIL;
					typX60gensym555__1 = NIM_NIL;
					colontmpD__85 = (NIM_BOOL)0;
					colontmpD__86 = (NIM_BOOL)0;
					{
						NIM_BOOL T609_;
						tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__90;
						eqcopy___ast_u3255(&nodeX60gensym555__1, (*(*colonenv__1).tos1).slots.p->data[ra_4].node);
						if (NIM_UNLIKELY(*nimErr_)) goto LA601_;
						{
							tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T608_;
							if (!((*nodeX60gensym555__1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)23))) goto LA606_;
							nimZeroMem((void*)(&T608_), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
							stackTraceImpl__vm_u73((*colonenv__1).c0, (*colonenv__1).tos1, (*colonenv__1).pc2, TM__pyAIA9cUF0h9c4j2HfNQPfYw_404, T608_, TM__pyAIA9cUF0h9c4j2HfNQPfYw_405);
							if (NIM_UNLIKELY(*nimErr_)) goto LA601_;
							eqdestroy___ast_u3378(typX60gensym555__1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
							eqdestroy___ast_u3252(nodeX60gensym555__1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
							eqdestroy___vmprofiler_u19(savedFrame_1);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
							eqdestroy___vm_u14829(colonenv__1);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
							goto BeforeRet_;
						}
LA606_: ;
						eqcopy___ast_u3381(&typX60gensym555__1, (*nodeX60gensym555__1).typField);
						if (NIM_UNLIKELY(*nimErr_)) goto LA601_;
						T609_ = (NIM_BOOL)0;
						{
							NIM_BOOL T612_;
							NIM_BOOL T614_;
							tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ2X60gensym555__1;
							tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* T619_;
							T612_ = (NIM_BOOL)0;
							T612_ = (((*nodeX60gensym555__1).flags &((NU32)1<<((NU)((((tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw)14)))&31U)))!=0);
							if (T612_) goto LA613_;
							T614_ = (NIM_BOOL)0;
							T614_ = !((typX60gensym555__1 == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL)));
							if (!(T614_)) goto LA615_;
							T614_ = ((*typX60gensym555__1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)21));
LA615_: ;
							T612_ = T614_;
LA613_: ;
							if (!T612_) goto LA616_;
							typ2X60gensym555__1 = NIM_NIL;
							T619_ = NIM_NIL;
							{
								if (!((*typX60gensym555__1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)21))) goto LA622_;
								typ2X60gensym555__1 = elementType__ast_u5331(typX60gensym555__1);
								if (NIM_UNLIKELY(*nimErr_)) goto LA618_;
							}
							goto LA620_;
LA622_: ;
							{
								eqcopy___ast_u3381(&typ2X60gensym555__1, typX60gensym555__1);
								if (NIM_UNLIKELY(*nimErr_)) goto LA618_;
							}
LA620_: ;
							{
								NIM_BOOL T627_;
								NimStringV2 colontmpD__87;
								NimStringV2 colontmpD__88;
								NimStringV2 colontmpD__89;
								NimStringV2 T631_;
								tyTuple__dsvP9bgd7x7RN0ykJDjb3Sg T632_;
								tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T633_;
								T627_ = (NIM_BOOL)0;
								T627_ = derefPtrToReg__vm_u144((*nodeX60gensym555__1)._kind_1.intVal, typ2X60gensym555__1, (&(*(*colonenv__1).tos1).slots.p->data[rc_11]), NIM_TRUE);
								if (NIM_UNLIKELY(*nimErr_)) goto LA618_;
								if (!!(T627_)) goto LA628_;
								colontmpD__87.len = 0; colontmpD__87.p = NIM_NIL;
								colontmpD__88.len = 0; colontmpD__88.p = NIM_NIL;
								colontmpD__89.len = 0; colontmpD__89.p = NIM_NIL;
								T631_.len = 0; T631_.p = NIM_NIL;
								colontmpD__87 = typeToString__types_u54(typX60gensym555__1, ((tyEnum_TPreferedDesc__ddj0M89bv09cBYthgD4XTq3Q)0));
								if (NIM_UNLIKELY(*nimErr_)) goto LA630_;
								T632_.Field0 = colontmpD__87;
								T632_.Field1 = (*typX60gensym555__1).kind;
								colontmpD__88 = dollar___vm_u1803(T632_);
								if (NIM_UNLIKELY(*nimErr_)) goto LA630_;
								T631_ = rawNewString(colontmpD__88.len + 28);
appendString((&T631_), TM__pyAIA9cUF0h9c4j2HfNQPfYw_406);
appendString((&T631_), colontmpD__88);
								colontmpD__89 = T631_;
								nimZeroMem((void*)(&T633_), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
								stackTraceImpl__vm_u73((*colonenv__1).c0, (*colonenv__1).tos1, (*colonenv__1).pc2, colontmpD__89, T633_, TM__pyAIA9cUF0h9c4j2HfNQPfYw_405);
								if (NIM_UNLIKELY(*nimErr_)) goto LA630_;
								eqdestroy___system_u2691(colontmpD__89);
								eqdestroy___system_u2691(colontmpD__88);
								eqdestroy___system_u2691(colontmpD__87);
								eqdestroy___ast_u3378(typ2X60gensym555__1);
								if (NIM_UNLIKELY(*nimErr_)) goto LA601_;
								eqdestroy___ast_u3378(typX60gensym555__1);
								if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
								eqdestroy___ast_u3252(nodeX60gensym555__1);
								if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
								eqdestroy___vmprofiler_u19(savedFrame_1);
								if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
								eqdestroy___vm_u14829(colonenv__1);
								if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
								goto BeforeRet_;
								{
									LA630_:;
								}
								{
									eqdestroy___system_u2691(colontmpD__89);
									eqdestroy___system_u2691(colontmpD__88);
									eqdestroy___system_u2691(colontmpD__87);
								}
								if (NIM_UNLIKELY(*nimErr_)) goto LA618_;
							}
LA628_: ;
							colontmpD__85 = NIM_TRUE;
							T609_ = colontmpD__85;
							{
								LA618_:;
							}
							{
								oldNimErrFin618_ = *nimErr_; *nimErr_ = NIM_FALSE;
								eqdestroy___ast_u3378(typ2X60gensym555__1);
								if (NIM_UNLIKELY(*nimErr_)) goto LA601_;
								*nimErr_ = oldNimErrFin618_;
							}
							if (NIM_UNLIKELY(*nimErr_)) goto LA601_;
						}
						goto LA610_;
LA616_: ;
						{
							colontmpD__86 = NIM_FALSE;
							T609_ = colontmpD__86;
						}
LA610_: ;
						if (!!(T609_)) goto LA639_;
						colontmpD__90 = NIM_NIL;
						colontmpD__90 = regToNode__vm_u542((*(*colonenv__1).tos1).slots.p->data[rc_11]);
						if (NIM_UNLIKELY(*nimErr_)) goto LA601_;
						eqcopy___ast_u3273((&(*(*(*colonenv__1).tos1).slots.p->data[ra_4].node)), (&(*colontmpD__90)));
						if (NIM_UNLIKELY(*nimErr_)) goto LA601_;
						(*(*(*colonenv__1).tos1).slots.p->data[ra_4].node).flags |= ((NU32)1)<<(((((tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw)13))) & 31);
						eqdestroy___ast_u3252(colontmpD__90);
						if (NIM_UNLIKELY(*nimErr_)) goto LA601_;
					}
LA639_: ;
					{
						LA601_:;
					}
					{
						oldNimErrFin601_ = *nimErr_; *nimErr_ = NIM_FALSE;
						eqdestroy___ast_u3378(typX60gensym555__1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						eqdestroy___ast_u3252(nodeX60gensym555__1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						*nimErr_ = oldNimErrFin601_;
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				}
				break;
				default:
				{
					tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T644_;
					nimZeroMem((void*)(&T644_), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
					stackTraceImpl__vm_u73((*colonenv__1).c0, (*colonenv__1).tos1, (*colonenv__1).pc2, TM__pyAIA9cUF0h9c4j2HfNQPfYw_407, T644_, TM__pyAIA9cUF0h9c4j2HfNQPfYw_230);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___vmprofiler_u19(savedFrame_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					eqdestroy___vm_u14829(colonenv__1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					goto BeforeRet_;
				}
				break;
				}
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)30):
			{
				NI rb_23;
				NI rc_12;
				NI64 bVal_1;
				NI64 cVal_1;
				NI64 sum_1;
				rb_23 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				rc_12 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(40ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				bVal_1 = (*(*colonenv__1).tos1).slots.p->data[rb_23].intVal;
				cVal_1 = (*(*colonenv__1).tos1).slots.p->data[rc_12].intVal;
				sum_1 = pluspercent___system_u801(bVal_1, cVal_1);
				{
					NIM_BOOL T648_;
					T648_ = (NIM_BOOL)0;
					T648_ = (IL64(0) <= (NI64)(sum_1 ^ bVal_1));
					if (T648_) goto LA649_;
					T648_ = (IL64(0) <= (NI64)(sum_1 ^ cVal_1));
LA649_: ;
					if (!T648_) goto LA650_;
					(*(*colonenv__1).tos1).slots.p->data[ra_1].intVal = sum_1;
				}
				goto LA646_;
LA650_: ;
				{
					tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T653_;
					nimZeroMem((void*)(&T653_), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
					stackTraceImpl__vm_u73((*colonenv__1).c0, (*colonenv__1).tos1, (*colonenv__1).pc2, TM__pyAIA9cUF0h9c4j2HfNQPfYw_409, T653_, TM__pyAIA9cUF0h9c4j2HfNQPfYw_230);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___vmprofiler_u19(savedFrame_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					eqdestroy___vm_u14829(colonenv__1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					goto BeforeRet_;
				}
LA646_: ;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)31):
			{
				NI rb_24;
				NI imm_2;
				NI64 bVal_2;
				NI cVal_2;
				NI64 sum_2;
				rb_24 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				imm_2 = (NI)(((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(40ULL & (64 - 1))) & 65535ULL))) - ((NI)128));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				bVal_2 = (*(*colonenv__1).tos1).slots.p->data[rb_24].intVal;
				cVal_2 = imm_2;
				sum_2 = pluspercent___system_u801(bVal_2, ((NI64) (cVal_2)));
				{
					NIM_BOOL T657_;
					T657_ = (NIM_BOOL)0;
					T657_ = (IL64(0) <= (NI64)(sum_2 ^ bVal_2));
					if (T657_) goto LA658_;
					T657_ = (IL64(0) <= (NI64)(sum_2 ^ ((NI64) (cVal_2))));
LA658_: ;
					if (!T657_) goto LA659_;
					(*(*colonenv__1).tos1).slots.p->data[ra_1].intVal = sum_2;
				}
				goto LA655_;
LA659_: ;
				{
					tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T662_;
					nimZeroMem((void*)(&T662_), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
					stackTraceImpl__vm_u73((*colonenv__1).c0, (*colonenv__1).tos1, (*colonenv__1).pc2, TM__pyAIA9cUF0h9c4j2HfNQPfYw_410, T662_, TM__pyAIA9cUF0h9c4j2HfNQPfYw_230);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___vmprofiler_u19(savedFrame_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					eqdestroy___vm_u14829(colonenv__1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					goto BeforeRet_;
				}
LA655_: ;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)32):
			{
				NI rb_25;
				NI rc_13;
				NI64 bVal_3;
				NI64 cVal_3;
				NI64 diff_1;
				rb_25 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				rc_13 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(40ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				bVal_3 = (*(*colonenv__1).tos1).slots.p->data[rb_25].intVal;
				cVal_3 = (*(*colonenv__1).tos1).slots.p->data[rc_13].intVal;
				diff_1 = minuspercent___system_u821(bVal_3, cVal_3);
				{
					NIM_BOOL T666_;
					T666_ = (NIM_BOOL)0;
					T666_ = (IL64(0) <= (NI64)(diff_1 ^ bVal_3));
					if (T666_) goto LA667_;
					T666_ = (IL64(0) <= (NI64)(diff_1 ^ (NI64)((NU64) ~(cVal_3))));
LA667_: ;
					if (!T666_) goto LA668_;
					(*(*colonenv__1).tos1).slots.p->data[ra_1].intVal = diff_1;
				}
				goto LA664_;
LA668_: ;
				{
					tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T671_;
					nimZeroMem((void*)(&T671_), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
					stackTraceImpl__vm_u73((*colonenv__1).c0, (*colonenv__1).tos1, (*colonenv__1).pc2, TM__pyAIA9cUF0h9c4j2HfNQPfYw_411, T671_, TM__pyAIA9cUF0h9c4j2HfNQPfYw_230);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___vmprofiler_u19(savedFrame_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					eqdestroy___vm_u14829(colonenv__1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					goto BeforeRet_;
				}
LA664_: ;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)33):
			{
				NI rb_26;
				NI imm_3;
				NI64 bVal_4;
				NI cVal_4;
				NI64 diff_2;
				rb_26 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				imm_3 = (NI)(((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(40ULL & (64 - 1))) & 65535ULL))) - ((NI)128));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				bVal_4 = (*(*colonenv__1).tos1).slots.p->data[rb_26].intVal;
				cVal_4 = imm_3;
				diff_2 = minuspercent___system_u821(bVal_4, ((NI64) (cVal_4)));
				{
					NIM_BOOL T675_;
					T675_ = (NIM_BOOL)0;
					T675_ = (IL64(0) <= (NI64)(diff_2 ^ bVal_4));
					if (T675_) goto LA676_;
					T675_ = (IL64(0) <= (NI64)(diff_2 ^ ((NI64) ((NI)((NU32) ~(cVal_4))))));
LA676_: ;
					if (!T675_) goto LA677_;
					(*(*colonenv__1).tos1).slots.p->data[ra_1].intVal = diff_2;
				}
				goto LA673_;
LA677_: ;
				{
					tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T680_;
					nimZeroMem((void*)(&T680_), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
					stackTraceImpl__vm_u73((*colonenv__1).c0, (*colonenv__1).tos1, (*colonenv__1).pc2, TM__pyAIA9cUF0h9c4j2HfNQPfYw_412, T680_, TM__pyAIA9cUF0h9c4j2HfNQPfYw_230);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___vmprofiler_u19(savedFrame_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					eqdestroy___vm_u14829(colonenv__1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					goto BeforeRet_;
				}
LA673_: ;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)34):
			{
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* node_1;
				NI rb_27;
				NI imm_4;
				NI high_1;
				node_1 = NIM_NIL;
				rb_27 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				imm_4 = (NI)(((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(40ULL & (64 - 1))) & 65535ULL))) - ((NI)128));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				high_1 = (NI)(imm_4 & ((NI)1));
				eqcopy___ast_u3255(&node_1, (*(*colonenv__1).tos1).slots.p->data[rb_27].node);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				{
					NI T686_;
					if (!!(((NI)(imm_4 & ((NI)16)) == ((NI)0)))) goto LA684_;
					T686_ = (NI)0;
					T686_ = safeLen__ast_u3197((*(*colonenv__1).tos1).slots.p->data[rb_27].node);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					(*(*colonenv__1).tos1).slots.p->data[ra_1].intVal = ((NI64) ((NI)(T686_ - high_1)));
				}
				goto LA682_;
LA684_: ;
				{
					switch ((*node_1).kind) {
					case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)160):
					{
						(*(*colonenv__1).tos1).slots.p->data[ra_1].intVal = (NI64)((NI64)((NI64)((*(*node_1)._kind_6.sons.p->data[((NI)2)])._kind_1.intVal - (*(*node_1)._kind_6.sons.p->data[((NI)1)])._kind_1.intVal) + IL64(1)) - ((NI64) (high_1)));
					}
					break;
					default:
					{
						NI T690_;
						T690_ = (NI)0;
						T690_ = safeArrLen__ast_u3204(node_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						(*(*colonenv__1).tos1).slots.p->data[ra_1].intVal = ((NI64) ((NI)(T690_ - high_1)));
					}
					break;
					}
				}
LA682_: ;
				eqdestroy___ast_u3252(node_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)35):
			{
				NI rb_28;
				NI imm_5;
				rb_28 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				imm_5 = (NI)(((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(40ULL & (64 - 1))) & 65535ULL))) - ((NI)128));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				(*(*colonenv__1).tos1).slots.p->data[ra_1].intVal = ((NI64) ((NI)((*(*(*colonenv__1).tos1).slots.p->data[rb_28].node)._kind_3.strVal.len - imm_5)));
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)36):
			{
				NI rb_29;
				NI imm_6;
				rb_29 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				imm_6 = (NI)(((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(40ULL & (64 - 1))) & 65535ULL))) - ((NI)128));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				{
					if (!((*(*(*colonenv__1).tos1).slots.p->data[rb_29].node).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)23))) goto LA695_;
					(*(*colonenv__1).tos1).slots.p->data[ra_1].intVal = ((NI64) (((NI32)-(imm_6))));
				}
				goto LA693_;
LA695_: ;
				{
					(*(*colonenv__1).tos1).slots.p->data[ra_1].intVal = ((NI64) ((NI)(nimCStrLen(nimToCStringConv((*(*(*colonenv__1).tos1).slots.p->data[rb_29].node)._kind_3.strVal)) - imm_6)));
				}
LA693_: ;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)37):
			{
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* b_1;
				NI rb_30;
				b_1 = NIM_NIL;
				rb_30 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA699_;
				b_1 = regToNode__vm_u542((*(*colonenv__1).tos1).slots.p->data[rb_30]);
				if (NIM_UNLIKELY(*nimErr_)) goto LA699_;
				{
					NIM_BOOL T702_;
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__91;
					T702_ = (NIM_BOOL)0;
					T702_ = inSet__nimsets_u8((*(*colonenv__1).tos1).slots.p->data[ra_1].node, b_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA699_;
					if (!!(T702_)) goto LA703_;
					colontmpD__91 = NIM_NIL;
					colontmpD__91 = copyTree__ast_u6891(b_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA705_;
					add__ast_u3215((*(*colonenv__1).tos1).slots.p->data[ra_1].node, colontmpD__91);
					if (NIM_UNLIKELY(*nimErr_)) goto LA705_;
					{
						LA705_:;
					}
					{
						oldNimErrFin705_ = *nimErr_; *nimErr_ = NIM_FALSE;
						eqdestroy___ast_u3252(colontmpD__91);
						if (NIM_UNLIKELY(*nimErr_)) goto LA699_;
						*nimErr_ = oldNimErrFin705_;
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA699_;
				}
LA703_: ;
				{
					LA699_:;
				}
				{
					oldNimErrFin699_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3252(b_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin699_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)38):
			{
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* r_1;
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__92;
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__93;
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__94;
				NI rb_31;
				NI rc_14;
				r_1 = NIM_NIL;
				colontmpD__92 = NIM_NIL;
				colontmpD__93 = NIM_NIL;
				colontmpD__94 = NIM_NIL;
				rb_31 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				rc_14 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(40ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA711_;
				r_1 = newNode__ast_u4069(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)44));
				if (NIM_UNLIKELY(*nimErr_)) goto LA711_;
				colontmpD__92 = regToNode__vm_u542((*(*colonenv__1).tos1).slots.p->data[rb_31]);
				if (NIM_UNLIKELY(*nimErr_)) goto LA711_;
				add__ast_u3215(r_1, colontmpD__92);
				if (NIM_UNLIKELY(*nimErr_)) goto LA711_;
				colontmpD__93 = regToNode__vm_u542((*(*colonenv__1).tos1).slots.p->data[rc_14]);
				if (NIM_UNLIKELY(*nimErr_)) goto LA711_;
				add__ast_u3215(r_1, colontmpD__93);
				if (NIM_UNLIKELY(*nimErr_)) goto LA711_;
				colontmpD__94 = copyTree__ast_u6891(r_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA711_;
				add__ast_u3215((*(*colonenv__1).tos1).slots.p->data[ra_1].node, colontmpD__94);
				if (NIM_UNLIKELY(*nimErr_)) goto LA711_;
				{
					LA711_:;
				}
				{
					oldNimErrFin711_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3252(colontmpD__94);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___ast_u3252(colontmpD__93);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___ast_u3252(colontmpD__92);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___ast_u3252(r_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin711_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)39):
			{
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* b_2;
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__95;
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* r_2;
				NI rb_32;
				b_2 = NIM_NIL;
				colontmpD__95 = NIM_NIL;
				r_2 = NIM_NIL;
				rb_32 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA715_;
				b_2 = newNodeIT__ast_u4112(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)39), (*(*(*colonenv__1).tos1).slots.p->data[ra_1].node).info, (*(*(*colonenv__1).tos1).slots.p->data[ra_1].node).typField);
				if (NIM_UNLIKELY(*nimErr_)) goto LA715_;
				colontmpD__95 = regToNode__vm_u542((*(*colonenv__1).tos1).slots.p->data[rb_32]);
				if (NIM_UNLIKELY(*nimErr_)) goto LA715_;
				add__ast_u3215(b_2, colontmpD__95);
				if (NIM_UNLIKELY(*nimErr_)) goto LA715_;
				r_2 = diffSets__nimsets_u138((*(*colonenv__1).c0).config, (*(*colonenv__1).tos1).slots.p->data[ra_1].node, b_2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA715_;
				discardSons__ast_u3188((*(*colonenv__1).tos1).slots.p->data[ra_1].node);
				if (NIM_UNLIKELY(*nimErr_)) goto LA715_;
				{
					NI i_1;
					NI colontmp_;
					NI i_2;
					i_1 = (NI)0;
					colontmp_ = (NI)0;
					colontmp_ = len__ast_u3190(r_2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA715_;
					i_2 = ((NI)0);
					{
						while (1) {
							if (!(i_2 < colontmp_)) goto LA718;
							i_1 = i_2;
							add__ast_u3215((*(*colonenv__1).tos1).slots.p->data[ra_1].node, (*r_2)._kind_6.sons.p->data[i_1]);
							if (NIM_UNLIKELY(*nimErr_)) goto LA715_;
							i_2 += ((NI)1);
						} LA718: ;
					}
				}
				{
					LA715_:;
				}
				{
					oldNimErrFin715_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3252(r_2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___ast_u3252(colontmpD__95);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___ast_u3252(b_2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin715_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)40):
			{
				NI rb_33;
				NI64 T722_;
				rb_33 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				T722_ = (NI64)0;
				T722_ = cardSet__nimsets_u191((*(*colonenv__1).c0).config, (*(*colonenv__1).tos1).slots.p->data[rb_33].node);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				(*(*colonenv__1).tos1).slots.p->data[ra_1].intVal = T722_;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)41):
			{
				NI rb_34;
				NI rc_15;
				NI64 bVal_5;
				NI64 cVal_5;
				NI64 product_1;
				NF floatProd_1;
				NF T724_;
				NF T725_;
				NF resAsFloat_1;
				rb_34 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				rc_15 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(40ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				bVal_5 = (*(*colonenv__1).tos1).slots.p->data[rb_34].intVal;
				cVal_5 = (*(*colonenv__1).tos1).slots.p->data[rc_15].intVal;
				product_1 = starpercent___system_u841(bVal_5, cVal_5);
				T724_ = (NF)0;
				T724_ = toBiggestFloat__system_u1698(bVal_5);
				T725_ = (NF)0;
				T725_ = toBiggestFloat__system_u1698(cVal_5);
				floatProd_1 = ((NF)(T724_) * (NF)(T725_));
				resAsFloat_1 = toBiggestFloat__system_u1698(product_1);
				{
					if (!(resAsFloat_1 == floatProd_1)) goto LA728_;
					(*(*colonenv__1).tos1).slots.p->data[ra_1].intVal = product_1;
				}
				goto LA726_;
LA728_: ;
				{
					NF T731_;
					NF T732_;
					T731_ = (NF)0;
					T731_ = abs__system_u5136(((NF)(resAsFloat_1) - (NF)(floatProd_1)));
					T732_ = (NF)0;
					T732_ = abs__system_u5136(floatProd_1);
					if (!(((NF)(32.0) * (NF)(T731_)) <= T732_)) goto LA733_;
					(*(*colonenv__1).tos1).slots.p->data[ra_1].intVal = product_1;
				}
				goto LA726_;
LA733_: ;
				{
					tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T736_;
					nimZeroMem((void*)(&T736_), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
					stackTraceImpl__vm_u73((*colonenv__1).c0, (*colonenv__1).tos1, (*colonenv__1).pc2, TM__pyAIA9cUF0h9c4j2HfNQPfYw_413, T736_, TM__pyAIA9cUF0h9c4j2HfNQPfYw_230);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___vmprofiler_u19(savedFrame_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					eqdestroy___vm_u14829(colonenv__1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					goto BeforeRet_;
				}
LA726_: ;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)42):
			{
				NI rb_35;
				NI rc_16;
				rb_35 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				rc_16 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(40ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				{
					tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T742_;
					if (!((*(*colonenv__1).tos1).slots.p->data[rc_16].intVal == IL64(0))) goto LA740_;
					nimZeroMem((void*)(&T742_), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
					stackTraceImpl__vm_u73((*colonenv__1).c0, (*colonenv__1).tos1, (*colonenv__1).pc2, TM__pyAIA9cUF0h9c4j2HfNQPfYw_415, T742_, TM__pyAIA9cUF0h9c4j2HfNQPfYw_230);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___vmprofiler_u19(savedFrame_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					eqdestroy___vm_u14829(colonenv__1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					goto BeforeRet_;
				}
				goto LA738_;
LA740_: ;
				{
					(*(*colonenv__1).tos1).slots.p->data[ra_1].intVal = (NI64)((*(*colonenv__1).tos1).slots.p->data[rb_35].intVal / (*(*colonenv__1).tos1).slots.p->data[rc_16].intVal);
				}
LA738_: ;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)43):
			{
				NI rb_36;
				NI rc_17;
				rb_36 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				rc_17 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(40ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				{
					tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T749_;
					if (!((*(*colonenv__1).tos1).slots.p->data[rc_17].intVal == IL64(0))) goto LA747_;
					nimZeroMem((void*)(&T749_), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
					stackTraceImpl__vm_u73((*colonenv__1).c0, (*colonenv__1).tos1, (*colonenv__1).pc2, TM__pyAIA9cUF0h9c4j2HfNQPfYw_416, T749_, TM__pyAIA9cUF0h9c4j2HfNQPfYw_230);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___vmprofiler_u19(savedFrame_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					eqdestroy___vm_u14829(colonenv__1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					goto BeforeRet_;
				}
				goto LA745_;
LA747_: ;
				{
					(*(*colonenv__1).tos1).slots.p->data[ra_1].intVal = (NI64)((*(*colonenv__1).tos1).slots.p->data[rb_36].intVal % (*(*colonenv__1).tos1).slots.p->data[rc_17].intVal);
				}
LA745_: ;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)44):
			{
				NI rb_37;
				NI rc_18;
				rb_37 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				rc_18 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(40ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)3));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				(*(*colonenv__1).tos1).slots.p->data[ra_1].floatVal = ((NF)((*(*colonenv__1).tos1).slots.p->data[rb_37].floatVal) + (NF)((*(*colonenv__1).tos1).slots.p->data[rc_18].floatVal));
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)45):
			{
				NI rb_38;
				NI rc_19;
				rb_38 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				rc_19 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(40ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)3));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				(*(*colonenv__1).tos1).slots.p->data[ra_1].floatVal = ((NF)((*(*colonenv__1).tos1).slots.p->data[rb_38].floatVal) - (NF)((*(*colonenv__1).tos1).slots.p->data[rc_19].floatVal));
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)46):
			{
				NI rb_39;
				NI rc_20;
				rb_39 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				rc_20 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(40ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)3));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				(*(*colonenv__1).tos1).slots.p->data[ra_1].floatVal = ((NF)((*(*colonenv__1).tos1).slots.p->data[rb_39].floatVal) * (NF)((*(*colonenv__1).tos1).slots.p->data[rc_20].floatVal));
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)47):
			{
				NI rb_40;
				NI rc_21;
				rb_40 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				rc_21 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(40ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)3));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				(*(*colonenv__1).tos1).slots.p->data[ra_1].floatVal = ((NF)((*(*colonenv__1).tos1).slots.p->data[rb_40].floatVal) / (NF)((*(*colonenv__1).tos1).slots.p->data[rc_21].floatVal));
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)48):
			{
				NI rb_41;
				NI rc_22;
				NU64 b_3;
				NU64 c_2;
				NI64 a_1;
				rb_41 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				rc_22 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(40ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				b_3 = ((NU64) ((*(*colonenv__1).tos1).slots.p->data[rb_41].intVal));
				c_2 = ((NU64) ((*(*colonenv__1).tos1).slots.p->data[rc_22].intVal));
				a_1 = ((NI64) ((NU64)((NU64)(b_3) >> (NU64)(c_2 & (64 - 1)))));
				(*(*colonenv__1).tos1).slots.p->data[ra_1].intVal = a_1;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)49):
			{
				NI rb_42;
				NI rc_23;
				rb_42 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				rc_23 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(40ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				(*(*colonenv__1).tos1).slots.p->data[ra_1].intVal = (NI64)((NU64)((*(*colonenv__1).tos1).slots.p->data[rb_42].intVal) << (NU64)((*(*colonenv__1).tos1).slots.p->data[rc_23].intVal & (64 - 1)));
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)50):
			{
				NI rb_43;
				NI rc_24;
				rb_43 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				rc_24 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(40ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				(*(*colonenv__1).tos1).slots.p->data[ra_1].intVal = (NI64)((NI64)((*(*colonenv__1).tos1).slots.p->data[rb_43].intVal) >> (NU64)((*(*colonenv__1).tos1).slots.p->data[rc_24].intVal & (64 - 1)));
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)51):
			{
				NI rb_44;
				NI rc_25;
				rb_44 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				rc_25 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(40ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				(*(*colonenv__1).tos1).slots.p->data[ra_1].intVal = (NI64)((*(*colonenv__1).tos1).slots.p->data[rb_44].intVal & (*(*colonenv__1).tos1).slots.p->data[rc_25].intVal);
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)52):
			{
				NI rb_45;
				NI rc_26;
				rb_45 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				rc_26 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(40ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				(*(*colonenv__1).tos1).slots.p->data[ra_1].intVal = (NI64)((*(*colonenv__1).tos1).slots.p->data[rb_45].intVal | (*(*colonenv__1).tos1).slots.p->data[rc_26].intVal);
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)53):
			{
				NI rb_46;
				NI rc_27;
				rb_46 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				rc_27 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(40ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				(*(*colonenv__1).tos1).slots.p->data[ra_1].intVal = (NI64)((*(*colonenv__1).tos1).slots.p->data[rb_46].intVal ^ (*(*colonenv__1).tos1).slots.p->data[rc_27].intVal);
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)54):
			{
				NI rb_47;
				NI rc_28;
				rb_47 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				rc_28 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(40ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				(*(*colonenv__1).tos1).slots.p->data[ra_1].intVal = pluspercent___system_u801((*(*colonenv__1).tos1).slots.p->data[rb_47].intVal, (*(*colonenv__1).tos1).slots.p->data[rc_28].intVal);
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)55):
			{
				NI rb_48;
				NI rc_29;
				rb_48 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				rc_29 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(40ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				(*(*colonenv__1).tos1).slots.p->data[ra_1].intVal = minuspercent___system_u821((*(*colonenv__1).tos1).slots.p->data[rb_48].intVal, (*(*colonenv__1).tos1).slots.p->data[rc_29].intVal);
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)56):
			{
				NI rb_49;
				NI rc_30;
				rb_49 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				rc_30 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(40ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				(*(*colonenv__1).tos1).slots.p->data[ra_1].intVal = starpercent___system_u841((*(*colonenv__1).tos1).slots.p->data[rb_49].intVal, (*(*colonenv__1).tos1).slots.p->data[rc_30].intVal);
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)57):
			{
				NI rb_50;
				NI rc_31;
				rb_50 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				rc_31 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(40ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				(*(*colonenv__1).tos1).slots.p->data[ra_1].intVal = slashpercent___system_u861((*(*colonenv__1).tos1).slots.p->data[rb_50].intVal, (*(*colonenv__1).tos1).slots.p->data[rc_31].intVal);
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)58):
			{
				NI rb_51;
				NI rc_32;
				rb_51 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				rc_32 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(40ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				(*(*colonenv__1).tos1).slots.p->data[ra_1].intVal = percentpercent___system_u881((*(*colonenv__1).tos1).slots.p->data[rb_51].intVal, (*(*colonenv__1).tos1).slots.p->data[rc_32].intVal);
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)59):
			{
				NI rb_52;
				NI rc_33;
				rb_52 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				rc_33 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(40ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				(*(*colonenv__1).tos1).slots.p->data[ra_1].intVal = ((NI64) (((*(*colonenv__1).tos1).slots.p->data[rb_52].intVal == (*(*colonenv__1).tos1).slots.p->data[rc_33].intVal)));
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)60):
			{
				NI rb_53;
				NI rc_34;
				rb_53 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				rc_34 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(40ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				(*(*colonenv__1).tos1).slots.p->data[ra_1].intVal = ((NI64) (((*(*colonenv__1).tos1).slots.p->data[rb_53].intVal <= (*(*colonenv__1).tos1).slots.p->data[rc_34].intVal)));
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)61):
			{
				NI rb_54;
				NI rc_35;
				rb_54 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				rc_35 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(40ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				(*(*colonenv__1).tos1).slots.p->data[ra_1].intVal = ((NI64) (((*(*colonenv__1).tos1).slots.p->data[rb_54].intVal < (*(*colonenv__1).tos1).slots.p->data[rc_35].intVal)));
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)62):
			{
				NI rb_55;
				NI rc_36;
				rb_55 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				rc_36 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(40ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				(*(*colonenv__1).tos1).slots.p->data[ra_1].intVal = ((NI64) (((*(*colonenv__1).tos1).slots.p->data[rb_55].floatVal == (*(*colonenv__1).tos1).slots.p->data[rc_36].floatVal)));
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)63):
			{
				NI rb_56;
				NI rc_37;
				rb_56 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				rc_37 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(40ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				(*(*colonenv__1).tos1).slots.p->data[ra_1].intVal = ((NI64) (((*(*colonenv__1).tos1).slots.p->data[rb_56].floatVal <= (*(*colonenv__1).tos1).slots.p->data[rc_37].floatVal)));
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)64):
			{
				NI rb_57;
				NI rc_38;
				rb_57 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				rc_38 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(40ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				(*(*colonenv__1).tos1).slots.p->data[ra_1].intVal = ((NI64) (((*(*colonenv__1).tos1).slots.p->data[rb_57].floatVal < (*(*colonenv__1).tos1).slots.p->data[rc_38].floatVal)));
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)65):
			{
				NI rb_58;
				NI rc_39;
				NIM_BOOL T773_;
				rb_58 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				rc_39 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(40ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				T773_ = (NIM_BOOL)0;
				T773_ = lteqpercent___system_u1088((*(*colonenv__1).tos1).slots.p->data[rb_58].intVal, (*(*colonenv__1).tos1).slots.p->data[rc_39].intVal);
				(*(*colonenv__1).tos1).slots.p->data[ra_1].intVal = ((NI64) (T773_));
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)66):
			{
				NI rb_59;
				NI rc_40;
				NIM_BOOL T775_;
				rb_59 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				rc_40 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(40ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				T775_ = (NIM_BOOL)0;
				T775_ = ltpercent___system_u1108((*(*colonenv__1).tos1).slots.p->data[rb_59].intVal, (*(*colonenv__1).tos1).slots.p->data[rc_40].intVal);
				(*(*colonenv__1).tos1).slots.p->data[ra_1].intVal = ((NI64) (T775_));
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)67):
			{
				tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A rbReg_1;
				tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A tmpX60gensym903__1;
				tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A rcReg_1;
				tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A tmpX60gensym905__1;
				NIM_BOOL ret_1;
				NI rb_60;
				NI rc_41;
				nimZeroMem((void*)(&rbReg_1), sizeof(tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A));
				nimZeroMem((void*)(&tmpX60gensym903__1), sizeof(tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A));
				nimZeroMem((void*)(&rcReg_1), sizeof(tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A));
				nimZeroMem((void*)(&tmpX60gensym905__1), sizeof(tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A));
				ret_1 = NIM_FALSE;
				rb_60 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				rc_41 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(40ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				eqcopy___vmdef_u1709((&tmpX60gensym903__1), (*(*colonenv__1).tos1).slots.p->data[rb_60]);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				{
					while (1) {
						if (!(tmpX60gensym903__1.kind == ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)4))) goto LA778;
						eqcopy___vmdef_u1709((&tmpX60gensym903__1), (*tmpX60gensym903__1.regAddr));
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					} LA778: ;
				}
				rbReg_1 = tmpX60gensym903__1;
				eqcopy___vmdef_u1709((&tmpX60gensym905__1), (*(*colonenv__1).tos1).slots.p->data[rc_41]);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				{
					while (1) {
						if (!(tmpX60gensym905__1.kind == ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)4))) goto LA780;
						eqcopy___vmdef_u1709((&tmpX60gensym905__1), (*tmpX60gensym905__1.regAddr));
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					} LA780: ;
				}
				rcReg_1 = tmpX60gensym905__1;
				{
					if (!(rbReg_1.kind == ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)5))) goto LA783_;
					{
						if (!(rcReg_1.kind == ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)5))) goto LA787_;
						ret_1 = (rbReg_1.nodeAddr == rcReg_1.nodeAddr);
					}
					goto LA785_;
LA787_: ;
					{
						ret_1 = ptrEquality__vm_u2392(rbReg_1.nodeAddr, rcReg_1.node);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					}
LA785_: ;
				}
				goto LA781_;
LA783_: ;
				{
					if (!(rcReg_1.kind == ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)5))) goto LA791_;
					ret_1 = ptrEquality__vm_u2392(rcReg_1.nodeAddr, rbReg_1.node);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				}
				goto LA781_;
LA791_: ;
				{
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* nb_2;
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* nc_1;
					nb_2 = NIM_NIL;
					nc_1 = NIM_NIL;
					nb_2 = rbReg_1.node;
					eqwasMoved___ast_u3249(&rbReg_1.node);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					nc_1 = rcReg_1.node;
					eqwasMoved___ast_u3249(&rcReg_1.node);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					{
						if (!!(((*nb_2).kind == (*nc_1).kind))) goto LA796_;
					}
					goto LA794_;
LA796_: ;
					{
						NIM_BOOL T799_;
						T799_ = (NIM_BOOL)0;
						T799_ = (nb_2 == nc_1);
						if (T799_) goto LA800_;
						T799_ = ((*nb_2).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)23));
LA800_: ;
						if (!T799_) goto LA801_;
						ret_1 = NIM_TRUE;
					}
					goto LA794_;
LA801_: ;
					{
						NIM_BOOL T804_;
						NIM_BOOL T805_;
						NIM_BOOL T806_;
						T804_ = (NIM_BOOL)0;
						T805_ = (NIM_BOOL)0;
						T806_ = (NIM_BOOL)0;
						T806_ = ((*nb_2).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3) || (*nb_2).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)160) || (*nb_2).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)155));
						if (!(T806_)) goto LA807_;
						T806_ = !(((*nb_2).typField == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL)));
LA807_: ;
						T805_ = T806_;
						if (!(T805_)) goto LA808_;
						T805_ = ((*(*nb_2).typField).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)25));
LA808_: ;
						T804_ = T805_;
						if (!(T804_)) goto LA809_;
						T804_ = sameConstant__vmgen_u1074(nb_2, nc_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
LA809_: ;
						if (!T804_) goto LA810_;
						ret_1 = NIM_TRUE;
					}
					goto LA794_;
LA810_: ;
					{
						NIM_BOOL T813_;
						NIM_BOOL T814_;
						tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* tb_1;
						tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* tc_1;
						NIM_BOOL T819_;
						T813_ = (NIM_BOOL)0;
						T814_ = (NIM_BOOL)0;
						T814_ = ((*nb_2).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)6));
						if (!(T814_)) goto LA815_;
						T814_ = ((*nc_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)6));
LA815_: ;
						T813_ = T814_;
						if (!(T813_)) goto LA816_;
						T813_ = ((*nb_2)._kind_1.intVal == (*nc_1)._kind_1.intVal);
LA816_: ;
						if (!T813_) goto LA817_;
						tb_1 = NIM_NIL;
						tc_1 = NIM_NIL;
						tb_1 = skipTypes__ast_u5379((*nb_2).typField, TM__pyAIA9cUF0h9c4j2HfNQPfYw_417);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						tc_1 = skipTypes__ast_u5379((*nc_1).typField, TM__pyAIA9cUF0h9c4j2HfNQPfYw_417);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						T819_ = (NIM_BOOL)0;
						T819_ = ((*tb_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)26) || (*tb_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)21));
						if (!(T819_)) goto LA820_;
						T819_ = ((*tc_1).kind == (*tb_1).kind);
LA820_: ;
						ret_1 = T819_;
						eqdestroy___ast_u3378(tc_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						eqdestroy___ast_u3378(tb_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					}
					goto LA794_;
LA817_: ;
LA794_: ;
					eqdestroy___ast_u3252(nc_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___ast_u3252(nb_2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				}
LA781_: ;
				(*(*colonenv__1).tos1).slots.p->data[ra_1].intVal = ((NI64) (ret_1));
				eqdestroy___vmdef_u1706(rcReg_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				eqdestroy___vmdef_u1706(rbReg_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)68):
			{
				NI rb_61;
				NI rc_42;
				NIM_BOOL T822_;
				rb_61 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				rc_42 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(40ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				T822_ = (NIM_BOOL)0;
				T822_ = exprStructuralEquivalent__trees_u63((*(*colonenv__1).tos1).slots.p->data[rb_61].node, (*(*colonenv__1).tos1).slots.p->data[rc_42].node, NIM_TRUE);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				(*(*colonenv__1).tos1).slots.p->data[ra_1].intVal = ((NI64) (T822_));
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)69):
			{
				NI rb_62;
				NI rc_43;
				NIM_BOOL T824_;
				rb_62 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				rc_43 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(40ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				T824_ = (NIM_BOOL)0;
				T824_ = sameTypeOrNil__types_u1837((*(*(*colonenv__1).tos1).slots.p->data[rb_62].node).typField, (*(*(*colonenv__1).tos1).slots.p->data[rc_43].node).typField, 12);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				(*(*colonenv__1).tos1).slots.p->data[ra_1].intVal = ((NI64) (T824_));
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)70):
			{
				NI rb_63;
				NI rc_44;
				rb_63 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				rc_44 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(40ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				(*(*colonenv__1).tos1).slots.p->data[ra_1].intVal = ((NI64) (!(((*(*colonenv__1).tos1).slots.p->data[rb_63].intVal == (*(*colonenv__1).tos1).slots.p->data[rc_44].intVal))));
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)71):
			{
				NI rb_64;
				rb_64 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				(*(*colonenv__1).tos1).slots.p->data[ra_1].intVal = (NI64)(IL64(1) - (*(*colonenv__1).tos1).slots.p->data[rb_64].intVal);
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)72):
			{
				NI rb_65;
				NI64 val_1;
				rb_65 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				val_1 = (*(*colonenv__1).tos1).slots.p->data[rb_65].intVal;
				{
					if (!!((val_1 == (IL64(-9223372036854775807) - IL64(1))))) goto LA830_;
					(*(*colonenv__1).tos1).slots.p->data[ra_1].intVal = -(val_1);
				}
				goto LA828_;
LA830_: ;
				{
					tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T833_;
					nimZeroMem((void*)(&T833_), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
					stackTraceImpl__vm_u73((*colonenv__1).c0, (*colonenv__1).tos1, (*colonenv__1).pc2, TM__pyAIA9cUF0h9c4j2HfNQPfYw_418, T833_, TM__pyAIA9cUF0h9c4j2HfNQPfYw_230);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___vmprofiler_u19(savedFrame_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					eqdestroy___vm_u14829(colonenv__1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					goto BeforeRet_;
				}
LA828_: ;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)73):
			{
				NI rb_66;
				rb_66 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)3));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				(*(*colonenv__1).tos1).slots.p->data[ra_1].floatVal = -((*(*colonenv__1).tos1).slots.p->data[rb_66].floatVal);
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)74):
			{
				NI rb_67;
				rb_67 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				(*(*colonenv__1).tos1).slots.p->data[ra_1].intVal = (NI64)((NU64) ~((*(*colonenv__1).tos1).slots.p->data[rb_67].intVal));
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)75):
			{
				NI rb_68;
				NI rc_45;
				rb_68 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				rc_45 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(40ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				(*(*colonenv__1).tos1).slots.p->data[ra_1].intVal = ((NI64) (eqStrings((*(*(*colonenv__1).tos1).slots.p->data[rb_68].node)._kind_3.strVal, (*(*(*colonenv__1).tos1).slots.p->data[rc_45].node)._kind_3.strVal)));
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)76):
			{
				NI rb_69;
				NI rc_46;
				NIM_BOOL bNil_1;
				NIM_BOOL cNil_1;
				NIM_BOOL T838_;
				NIM_BOOL T839_;
				NIM_BOOL T842_;
				NIM_BOOL T843_;
				rb_69 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				rc_46 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(40ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				bNil_1 = ((*(*(*colonenv__1).tos1).slots.p->data[rb_69].node).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)23));
				cNil_1 = ((*(*(*colonenv__1).tos1).slots.p->data[rc_46].node).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)23));
				T838_ = (NIM_BOOL)0;
				T839_ = (NIM_BOOL)0;
				T839_ = bNil_1;
				if (!(T839_)) goto LA840_;
				T839_ = cNil_1;
LA840_: ;
				T838_ = T839_;
				if (T838_) goto LA841_;
				T842_ = (NIM_BOOL)0;
				T843_ = (NIM_BOOL)0;
				T843_ = !(bNil_1);
				if (!(T843_)) goto LA844_;
				T843_ = !(cNil_1);
LA844_: ;
				T842_ = T843_;
				if (!(T842_)) goto LA845_;
				T842_ = eqStrings((*(*(*colonenv__1).tos1).slots.p->data[rb_69].node)._kind_3.strVal, (*(*(*colonenv__1).tos1).slots.p->data[rc_46].node)._kind_3.strVal);
LA845_: ;
				T838_ = T842_;
LA841_: ;
				(*(*colonenv__1).tos1).slots.p->data[ra_1].intVal = ((NI64) (T838_));
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)77):
			{
				NI rb_70;
				NI rc_47;
				rb_70 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				rc_47 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(40ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				(*(*colonenv__1).tos1).slots.p->data[ra_1].intVal = ((NI64) ((cmpStrings((*(*(*colonenv__1).tos1).slots.p->data[rb_70].node)._kind_3.strVal, (*(*(*colonenv__1).tos1).slots.p->data[rc_47].node)._kind_3.strVal) <= 0)));
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)78):
			{
				NI rb_71;
				NI rc_48;
				rb_71 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				rc_48 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(40ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				(*(*colonenv__1).tos1).slots.p->data[ra_1].intVal = ((NI64) ((cmpStrings((*(*(*colonenv__1).tos1).slots.p->data[rb_71].node)._kind_3.strVal, (*(*(*colonenv__1).tos1).slots.p->data[rc_48].node)._kind_3.strVal) < 0)));
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)80):
			{
				NI rb_72;
				NI rc_49;
				NIM_BOOL T849_;
				rb_72 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				rc_49 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(40ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				T849_ = (NIM_BOOL)0;
				T849_ = containsSets__nimsets_u159((*(*colonenv__1).c0).config, (*(*colonenv__1).tos1).slots.p->data[rb_72].node, (*(*colonenv__1).tos1).slots.p->data[rc_49].node);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				(*(*colonenv__1).tos1).slots.p->data[ra_1].intVal = ((NI64) (T849_));
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)79):
			{
				NI rb_73;
				NI rc_50;
				NIM_BOOL T851_;
				rb_73 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				rc_50 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(40ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				T851_ = (NIM_BOOL)0;
				T851_ = equalSets__nimsets_u166((*(*colonenv__1).c0).config, (*(*colonenv__1).tos1).slots.p->data[rb_73].node, (*(*colonenv__1).tos1).slots.p->data[rc_50].node);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				(*(*colonenv__1).tos1).slots.p->data[ra_1].intVal = ((NI64) (T851_));
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)81):
			{
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_2;
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* b_4;
				NI rb_74;
				NI rc_51;
				NIM_BOOL T854_;
				NIM_BOOL T856_;
				a_2 = NIM_NIL;
				b_4 = NIM_NIL;
				rb_74 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				rc_51 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(40ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA853_;
				eqcopy___ast_u3255(&a_2, (*(*colonenv__1).tos1).slots.p->data[rb_74].node);
				if (NIM_UNLIKELY(*nimErr_)) goto LA853_;
				eqcopy___ast_u3255(&b_4, (*(*colonenv__1).tos1).slots.p->data[rc_51].node);
				if (NIM_UNLIKELY(*nimErr_)) goto LA853_;
				T854_ = (NIM_BOOL)0;
				T854_ = containsSets__nimsets_u159((*(*colonenv__1).c0).config, a_2, b_4);
				if (NIM_UNLIKELY(*nimErr_)) goto LA853_;
				if (!(T854_)) goto LA855_;
				T856_ = (NIM_BOOL)0;
				T856_ = equalSets__nimsets_u166((*(*colonenv__1).c0).config, a_2, b_4);
				if (NIM_UNLIKELY(*nimErr_)) goto LA853_;
				T854_ = !(T856_);
LA855_: ;
				(*(*colonenv__1).tos1).slots.p->data[ra_1].intVal = ((NI64) (T854_));
				{
					LA853_:;
				}
				{
					oldNimErrFin853_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3252(b_4);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___ast_u3252(a_2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin853_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)82):
			{
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__96;
				NI rb_75;
				NI rc_52;
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T861_;
				tySequence__9ahcSjIErJohSBBFLwuF56Q T862_;
				colontmpD__96 = NIM_NIL;
				rb_75 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				rc_52 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(40ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA860_;
				T861_ = NIM_NIL;
				T861_ = newNode__ast_u4069(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)39));
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T861_); goto LA860_;}
				eqsink___ast_u3261(&(*(*colonenv__1).tos1).slots.p->data[ra_1].node, T861_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA860_;
				colontmpD__96 = intersectSets__nimsets_u145((*(*colonenv__1).c0).config, (*(*colonenv__1).tos1).slots.p->data[rb_75].node, (*(*colonenv__1).tos1).slots.p->data[rc_52].node);
				if (NIM_UNLIKELY(*nimErr_)) goto LA860_;
				T862_.len = 0; T862_.p = NIM_NIL;
				T862_ = (*colontmpD__96)._kind_6.sons;
				eqwasMoved___ast_u3693((&(*colontmpD__96)._kind_6.sons));
				eqsink___ast_u3705((&(*(*(*colonenv__1).tos1).slots.p->data[ra_1].node)._kind_6.sons), T862_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA860_;
				{
					LA860_:;
				}
				{
					oldNimErrFin860_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3252(colontmpD__96);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin860_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)83):
			{
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__97;
				NI rb_76;
				NI rc_53;
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T867_;
				tySequence__9ahcSjIErJohSBBFLwuF56Q T868_;
				colontmpD__97 = NIM_NIL;
				rb_76 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				rc_53 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(40ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA866_;
				T867_ = NIM_NIL;
				T867_ = newNode__ast_u4069(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)39));
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T867_); goto LA866_;}
				eqsink___ast_u3261(&(*(*colonenv__1).tos1).slots.p->data[ra_1].node, T867_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA866_;
				colontmpD__97 = unionSets__nimsets_u131((*(*colonenv__1).c0).config, (*(*colonenv__1).tos1).slots.p->data[rb_76].node, (*(*colonenv__1).tos1).slots.p->data[rc_53].node);
				if (NIM_UNLIKELY(*nimErr_)) goto LA866_;
				T868_.len = 0; T868_.p = NIM_NIL;
				T868_ = (*colontmpD__97)._kind_6.sons;
				eqwasMoved___ast_u3693((&(*colontmpD__97)._kind_6.sons));
				eqsink___ast_u3705((&(*(*(*colonenv__1).tos1).slots.p->data[ra_1].node)._kind_6.sons), T868_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA866_;
				{
					LA866_:;
				}
				{
					oldNimErrFin866_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3252(colontmpD__97);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin866_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)84):
			{
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__98;
				NI rb_77;
				NI rc_54;
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T873_;
				tySequence__9ahcSjIErJohSBBFLwuF56Q T874_;
				colontmpD__98 = NIM_NIL;
				rb_77 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				rc_54 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(40ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA872_;
				T873_ = NIM_NIL;
				T873_ = newNode__ast_u4069(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)39));
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T873_); goto LA872_;}
				eqsink___ast_u3261(&(*(*colonenv__1).tos1).slots.p->data[ra_1].node, T873_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA872_;
				colontmpD__98 = diffSets__nimsets_u138((*(*colonenv__1).c0).config, (*(*colonenv__1).tos1).slots.p->data[rb_77].node, (*(*colonenv__1).tos1).slots.p->data[rc_54].node);
				if (NIM_UNLIKELY(*nimErr_)) goto LA872_;
				T874_.len = 0; T874_.p = NIM_NIL;
				T874_ = (*colontmpD__98)._kind_6.sons;
				eqwasMoved___ast_u3693((&(*colontmpD__98)._kind_6.sons));
				eqsink___ast_u3705((&(*(*(*colonenv__1).tos1).slots.p->data[ra_1].node)._kind_6.sons), T874_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA872_;
				{
					LA872_:;
				}
				{
					oldNimErrFin872_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3252(colontmpD__98);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin872_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)85):
			{
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__99;
				NI rb_78;
				NI rc_55;
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T879_;
				tySequence__9ahcSjIErJohSBBFLwuF56Q T880_;
				colontmpD__99 = NIM_NIL;
				rb_78 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				rc_55 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(40ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA878_;
				T879_ = NIM_NIL;
				T879_ = newNode__ast_u4069(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)39));
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T879_); goto LA878_;}
				eqsink___ast_u3261(&(*(*colonenv__1).tos1).slots.p->data[ra_1].node, T879_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA878_;
				colontmpD__99 = symdiffSets__nimsets_u152((*(*colonenv__1).c0).config, (*(*colonenv__1).tos1).slots.p->data[rb_78].node, (*(*colonenv__1).tos1).slots.p->data[rc_55].node);
				if (NIM_UNLIKELY(*nimErr_)) goto LA878_;
				T880_.len = 0; T880_.p = NIM_NIL;
				T880_ = (*colontmpD__99)._kind_6.sons;
				eqwasMoved___ast_u3693((&(*colontmpD__99)._kind_6.sons));
				eqsink___ast_u3705((&(*(*(*colonenv__1).tos1).slots.p->data[ra_1].node)._kind_6.sons), T880_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA878_;
				{
					LA878_:;
				}
				{
					oldNimErrFin878_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3252(colontmpD__99);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin878_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)86):
			{
				NI rb_79;
				NI rc_56;
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T884_;
				NimStringV2 T885_;
				rb_79 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				rc_56 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(40ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				T884_ = NIM_NIL;
				T884_ = newNode__ast_u4069(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)20));
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T884_); goto LA1_;}
				eqsink___ast_u3261(&(*(*colonenv__1).tos1).slots.p->data[ra_1].node, T884_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				T885_.len = 0; T885_.p = NIM_NIL;
				{
					if (!((*(*colonenv__1).tos1).slots.p->data[rb_79].kind == ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1))) goto LA888_;
					eqcopy___system_u2694((&(*(*(*colonenv__1).tos1).slots.p->data[ra_1].node)._kind_3.strVal), (*(*(*colonenv__1).tos1).slots.p->data[rb_79].node)._kind_3.strVal);
				}
				goto LA886_;
LA888_: ;
				{
					NimStringV2 T891_;
					T891_.len = 0; T891_.p = NIM_NIL;
					T891_ = nimCharToStr(((NIM_CHAR) ((((NI) ((*(*colonenv__1).tos1).slots.p->data[rb_79].intVal))))));
					eqsink___system_u2700((&(*(*(*colonenv__1).tos1).slots.p->data[ra_1].node)._kind_3.strVal), T891_);
				}
LA886_: ;
				{
					NI i_3;
					NI colontmp__2;
					NI colontmp__3;
					NI res_1;
					i_3 = (NI)0;
					colontmp__2 = (NI)0;
					colontmp__3 = (NI)0;
					colontmp__2 = (NI)(rb_79 + ((NI)1));
					colontmp__3 = (NI)((NI)(rb_79 + rc_56) - ((NI)1));
					res_1 = colontmp__2;
					{
						while (1) {
							NimStringV2 colontmpD__100;
							NimStringV2 colontmpD__101;
							NimStringV2 T895_;
							if (!(res_1 <= colontmp__3)) goto LA894;
							colontmpD__100.len = 0; colontmpD__100.p = NIM_NIL;
							colontmpD__101.len = 0; colontmpD__101.p = NIM_NIL;
							i_3 = ((NI) (res_1));
							T895_.len = 0; T895_.p = NIM_NIL;
							{
								if (!((*(*colonenv__1).tos1).slots.p->data[i_3].kind == ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1))) goto LA898_;
								eqcopy___system_u2694((&colontmpD__100), (*(*(*colonenv__1).tos1).slots.p->data[i_3].node)._kind_3.strVal);
								T895_ = colontmpD__100;
							}
							goto LA896_;
LA898_: ;
							{
								colontmpD__101 = nimCharToStr(((NIM_CHAR) ((((NI) ((*(*colonenv__1).tos1).slots.p->data[i_3].intVal))))));
								T895_ = colontmpD__101;
							}
LA896_: ;
							prepareAdd((&(*(*(*colonenv__1).tos1).slots.p->data[ra_1].node)._kind_3.strVal), T895_.len + 0);
appendString((&(*(*(*colonenv__1).tos1).slots.p->data[ra_1].node)._kind_3.strVal), T895_);
							res_1 += ((NI)1);
							eqdestroy___system_u2691(colontmpD__101);
							eqdestroy___system_u2691(colontmpD__100);
						} LA894: ;
					}
				}
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)103):
			{
				NI rb_80;
				rb_80 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				nimAddCharV1((&(*(*(*colonenv__1).tos1).slots.p->data[ra_1].node)._kind_3.strVal), ((NIM_CHAR) (((NI) ((*(*colonenv__1).tos1).slots.p->data[rb_80].intVal)))));
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)104):
			{
				NI rb_81;
				rb_81 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				prepareAdd((&(*(*(*colonenv__1).tos1).slots.p->data[ra_1].node)._kind_3.strVal), (*(*(*colonenv__1).tos1).slots.p->data[rb_81].node)._kind_3.strVal.len + 0);
appendString((&(*(*(*colonenv__1).tos1).slots.p->data[ra_1].node)._kind_3.strVal), (*(*(*colonenv__1).tos1).slots.p->data[rb_81].node)._kind_3.strVal);
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)105):
			{
				NI rb_82;
				rb_82 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				{
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__102;
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__103;
					if (!((*(*(*colonenv__1).tos1).slots.p->data[ra_1].node).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)41))) goto LA906_;
					colontmpD__102 = NIM_NIL;
					colontmpD__103 = NIM_NIL;
					colontmpD__102 = regToNode__vm_u542((*(*colonenv__1).tos1).slots.p->data[rb_82]);
					if (NIM_UNLIKELY(*nimErr_)) goto LA908_;
					colontmpD__103 = copyValue__vm_u486(colontmpD__102);
					if (NIM_UNLIKELY(*nimErr_)) goto LA908_;
					add__ast_u3215((*(*colonenv__1).tos1).slots.p->data[ra_1].node, colontmpD__103);
					if (NIM_UNLIKELY(*nimErr_)) goto LA908_;
					{
						LA908_:;
					}
					{
						oldNimErrFin908_ = *nimErr_; *nimErr_ = NIM_FALSE;
						eqdestroy___ast_u3252(colontmpD__103);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						eqdestroy___ast_u3252(colontmpD__102);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						*nimErr_ = oldNimErrFin908_;
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				}
				goto LA904_;
LA906_: ;
				{
					tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T912_;
					nimZeroMem((void*)(&T912_), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
					stackTraceImpl__vm_u73((*colonenv__1).c0, (*colonenv__1).tos1, (*colonenv__1).pc2, TM__pyAIA9cUF0h9c4j2HfNQPfYw_419, T912_, TM__pyAIA9cUF0h9c4j2HfNQPfYw_230);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___vmprofiler_u19(savedFrame_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					eqdestroy___vm_u14829(colonenv__1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					goto BeforeRet_;
				}
LA904_: ;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)156):
			{
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_3;
				NI rb_83;
				a_3 = NIM_NIL;
				rb_83 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA914_;
				eqcopy___ast_u3255(&a_3, (*(*colonenv__1).tos1).slots.p->data[rb_83].node);
				if (NIM_UNLIKELY(*nimErr_)) goto LA914_;
				{
					if (!((*a_3).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)143))) goto LA917_;
					eqcopy___ast_u3255(&a_3, (*a_3)._kind_6.sons.p->data[((NI)0)]);
					if (NIM_UNLIKELY(*nimErr_)) goto LA914_;
				}
LA917_: ;
				{
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T923_;
					if (!((*a_3).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3))) goto LA921_;
					T923_ = NIM_NIL;
					{
						tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T928_;
						if (!((*(*a_3)._kind_4.sym).ast == 0)) goto LA926_;
						T928_ = NIM_NIL;
						T928_ = newNode__ast_u4069(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)23));
						if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T928_); goto LA914_;}
						eqsink___ast_u3261(&(*(*colonenv__1).tos1).slots.p->data[ra_1].node, T928_);
						if (NIM_UNLIKELY(*nimErr_)) goto LA914_;
					}
					goto LA924_;
LA926_: ;
					{
						tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T930_;
						T930_ = NIM_NIL;
						T930_ = copyTree__ast_u6891((*(*a_3)._kind_4.sym).ast);
						if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T930_); goto LA914_;}
						eqsink___ast_u3261(&(*(*colonenv__1).tos1).slots.p->data[ra_1].node, T930_);
						if (NIM_UNLIKELY(*nimErr_)) goto LA914_;
					}
LA924_: ;
					(*(*(*colonenv__1).tos1).slots.p->data[ra_1].node).flags |= ((NU32)1)<<(((((tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw)13))) & 31);
				}
				goto LA919_;
LA921_: ;
				{
					tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T932_;
					nimZeroMem((void*)(&T932_), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
					stackTraceImpl__vm_u73((*colonenv__1).c0, (*colonenv__1).tos1, (*colonenv__1).pc2, TM__pyAIA9cUF0h9c4j2HfNQPfYw_421, T932_, TM__pyAIA9cUF0h9c4j2HfNQPfYw_230);
					if (NIM_UNLIKELY(*nimErr_)) goto LA914_;
					eqdestroy___ast_u3252(a_3);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___vmprofiler_u19(savedFrame_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					eqdestroy___vm_u14829(colonenv__1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					goto BeforeRet_;
				}
LA919_: ;
				{
					LA914_:;
				}
				{
					oldNimErrFin914_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3252(a_3);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin914_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)157):
			{
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_4;
				NI rb_84;
				a_4 = NIM_NIL;
				rb_84 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA936_;
				eqcopy___ast_u3255(&a_4, (*(*colonenv__1).tos1).slots.p->data[rb_84].node);
				if (NIM_UNLIKELY(*nimErr_)) goto LA936_;
				{
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T941_;
					if (!((*a_4).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3))) goto LA939_;
					T941_ = NIM_NIL;
					{
						tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T946_;
						if (!((*(*a_4)._kind_4.sym).ast == 0)) goto LA944_;
						T946_ = NIM_NIL;
						T946_ = newNode__ast_u4069(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)23));
						if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T946_); goto LA936_;}
						eqsink___ast_u3261(&(*(*colonenv__1).tos1).slots.p->data[ra_1].node, T946_);
						if (NIM_UNLIKELY(*nimErr_)) goto LA936_;
					}
					goto LA942_;
LA944_: ;
					{
						tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* ast_1;
						tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T952_;
						tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T953_;
						ast_1 = NIM_NIL;
						ast_1 = shallowCopy__ast_u6876((*(*a_4)._kind_4.sym).ast);
						if (NIM_UNLIKELY(*nimErr_)) goto LA948_;
						{
							NI i_4;
							NI colontmp__4;
							NI i_5;
							i_4 = (NI)0;
							colontmp__4 = (NI)0;
							colontmp__4 = len__ast_u3190((*(*a_4)._kind_4.sym).ast);
							if (NIM_UNLIKELY(*nimErr_)) goto LA948_;
							i_5 = ((NI)0);
							{
								while (1) {
									if (!(i_5 < colontmp__4)) goto LA951;
									i_4 = i_5;
									eqcopy___ast_u3255(&(*ast_1)._kind_6.sons.p->data[i_4], (*(*(*a_4)._kind_4.sym).ast)._kind_6.sons.p->data[i_4]);
									if (NIM_UNLIKELY(*nimErr_)) goto LA948_;
									i_5 += ((NI)1);
								} LA951: ;
							}
						}
						T952_ = NIM_NIL;
						T952_ = transformBody__transf_u26((*(*colonenv__1).c0).graph, (*(*colonenv__1).c0).Sup.idgen, (*a_4)._kind_4.sym, 5);
						if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T952_); goto LA948_;}
						eqsink___ast_u3261(&(*ast_1)._kind_6.sons.p->data[((NI)6)], T952_);
						if (NIM_UNLIKELY(*nimErr_)) goto LA948_;
						T953_ = NIM_NIL;
						T953_ = copyTree__ast_u6891(ast_1);
						if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T953_); goto LA948_;}
						eqsink___ast_u3261(&(*(*colonenv__1).tos1).slots.p->data[ra_1].node, T953_);
						if (NIM_UNLIKELY(*nimErr_)) goto LA948_;
						{
							LA948_:;
						}
						{
							oldNimErrFin948_ = *nimErr_; *nimErr_ = NIM_FALSE;
							eqdestroy___ast_u3252(ast_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA936_;
							*nimErr_ = oldNimErrFin948_;
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA936_;
					}
LA942_: ;
				}
LA939_: ;
				{
					LA936_:;
				}
				{
					oldNimErrFin936_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3252(a_4);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin936_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)190):
			{
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_5;
				NI rb_85;
				a_5 = NIM_NIL;
				rb_85 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA959_;
				eqcopy___ast_u3255(&a_5, (*(*colonenv__1).tos1).slots.p->data[rb_85].node);
				if (NIM_UNLIKELY(*nimErr_)) goto LA959_;
				{
					tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD__104;
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T964_;
					if (!((*a_5).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3))) goto LA962_;
					colontmpD__104 = NIM_NIL;
					T964_ = NIM_NIL;
					{
						tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T969_;
						colontmpD__104 = owner__ast_u6254((*a_5)._kind_4.sym);
						if (NIM_UNLIKELY(*nimErr_)) goto LA959_;
						if (!(colontmpD__104 == 0)) goto LA967_;
						T969_ = NIM_NIL;
						T969_ = newNode__ast_u4069(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)23));
						if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T969_); goto LA959_;}
						eqsink___ast_u3261(&(*(*colonenv__1).tos1).slots.p->data[ra_1].node, T969_);
						if (NIM_UNLIKELY(*nimErr_)) goto LA959_;
					}
					goto LA965_;
LA967_: ;
					{
						tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD__105;
						tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T971_;
						colontmpD__105 = NIM_NIL;
						colontmpD__105 = skipGenericOwner__ast_u7111((*a_5)._kind_4.sym);
						if (NIM_UNLIKELY(*nimErr_)) goto LA959_;
						T971_ = NIM_NIL;
						T971_ = newSymNode__ast_u5168(colontmpD__105);
						if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T971_); goto LA959_;}
						eqsink___ast_u3261(&(*(*colonenv__1).tos1).slots.p->data[ra_1].node, T971_);
						if (NIM_UNLIKELY(*nimErr_)) goto LA959_;
						eqdestroy___ast_u4574(colontmpD__105);
						if (NIM_UNLIKELY(*nimErr_)) goto LA959_;
					}
LA965_: ;
					(*(*(*colonenv__1).tos1).slots.p->data[ra_1].node).flags |= ((NU32)1)<<(((((tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw)13))) & 31);
					eqdestroy___ast_u4574(colontmpD__104);
					if (NIM_UNLIKELY(*nimErr_)) goto LA959_;
				}
				goto LA960_;
LA962_: ;
				{
					tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T973_;
					nimZeroMem((void*)(&T973_), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
					stackTraceImpl__vm_u73((*colonenv__1).c0, (*colonenv__1).tos1, (*colonenv__1).pc2, TM__pyAIA9cUF0h9c4j2HfNQPfYw_422, T973_, TM__pyAIA9cUF0h9c4j2HfNQPfYw_230);
					if (NIM_UNLIKELY(*nimErr_)) goto LA959_;
					eqdestroy___ast_u3252(a_5);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___vmprofiler_u19(savedFrame_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					eqdestroy___vm_u14829(colonenv__1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					goto BeforeRet_;
				}
LA960_: ;
				{
					LA959_:;
				}
				{
					oldNimErrFin959_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3252(a_5);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin959_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)191):
			{
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_6;
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* b_5;
				NI rb_86;
				NI rc_57;
				a_6 = NIM_NIL;
				b_5 = NIM_NIL;
				rb_86 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				rc_57 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(40ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA977_;
				eqcopy___ast_u3255(&a_6, (*(*colonenv__1).tos1).slots.p->data[rb_86].node);
				if (NIM_UNLIKELY(*nimErr_)) goto LA977_;
				eqcopy___ast_u3255(&b_5, (*(*colonenv__1).tos1).slots.p->data[rc_57].node);
				if (NIM_UNLIKELY(*nimErr_)) goto LA977_;
				{
					NIM_BOOL T980_;
					NIM_BOOL T981_;
					NIM_BOOL T982_;
					NI64 T988_;
					T980_ = (NIM_BOOL)0;
					T981_ = (NIM_BOOL)0;
					T982_ = (NIM_BOOL)0;
					T982_ = ((*a_6).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3));
					if (!(T982_)) goto LA983_;
					T982_ = ((*(*a_6)._kind_4.sym).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)12) || (*(*a_6)._kind_4.sym).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)13) || (*(*a_6)._kind_4.sym).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)18) || (*(*a_6)._kind_4.sym).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)17) || (*(*a_6)._kind_4.sym).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)15) || (*(*a_6)._kind_4.sym).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)14) || (*(*a_6)._kind_4.sym).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)16));
LA983_: ;
					T981_ = T982_;
					if (!(T981_)) goto LA984_;
					T981_ = ((*b_5).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3));
LA984_: ;
					T980_ = T981_;
					if (!(T980_)) goto LA985_;
					T980_ = ((*(*b_5)._kind_4.sym).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)12) || (*(*b_5)._kind_4.sym).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)13) || (*(*b_5)._kind_4.sym).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)18) || (*(*b_5)._kind_4.sym).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)17) || (*(*b_5)._kind_4.sym).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)15) || (*(*b_5)._kind_4.sym).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)14) || (*(*b_5)._kind_4.sym).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)16));
LA985_: ;
					if (!T980_) goto LA986_;
					T988_ = (NI64)0;
					{
						NIM_BOOL T991_;
						T991_ = (NIM_BOOL)0;
						T991_ = (((*(*a_6)._kind_4.sym).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)2)))&63U)))!=0);
						if (!(T991_)) goto LA992_;
						T991_ = ((*(*a_6)._kind_4.sym).instantiatedFrom == (*b_5)._kind_4.sym);
LA992_: ;
						if (!T991_) goto LA993_;
						(*(*colonenv__1).tos1).slots.p->data[ra_1].intVal = IL64(1);
					}
					goto LA989_;
LA993_: ;
					{
						(*(*colonenv__1).tos1).slots.p->data[ra_1].intVal = IL64(0);
					}
LA989_: ;
				}
				goto LA978_;
LA986_: ;
				{
					tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T997_;
					nimZeroMem((void*)(&T997_), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
					stackTraceImpl__vm_u73((*colonenv__1).c0, (*colonenv__1).tos1, (*colonenv__1).pc2, TM__pyAIA9cUF0h9c4j2HfNQPfYw_424, T997_, TM__pyAIA9cUF0h9c4j2HfNQPfYw_230);
					if (NIM_UNLIKELY(*nimErr_)) goto LA977_;
					eqdestroy___ast_u3252(b_5);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___ast_u3252(a_6);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___vmprofiler_u19(savedFrame_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					eqdestroy___vm_u14829(colonenv__1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					goto BeforeRet_;
				}
LA978_: ;
				{
					LA977_:;
				}
				{
					oldNimErrFin977_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3252(b_5);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___ast_u3252(a_6);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin977_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)158):
			{
				NI rb_87;
				rb_87 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				{
					if (!(rb_87 == ((NI)1))) goto LA1003_;
					msgWriteln__msgs_u737((*(*colonenv__1).c0).config, (*(*(*colonenv__1).tos1).slots.p->data[ra_1].node)._kind_3.strVal, 5);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				}
				goto LA1001_;
LA1003_: ;
				{
					NimStringV2 outp_1;
					outp_1.len = 0; outp_1.p = NIM_NIL;
					outp_1 = TM__pyAIA9cUF0h9c4j2HfNQPfYw_425;
					{
						NI i_6;
						NI colontmp__5;
						NI res_2;
						i_6 = (NI)0;
						colontmp__5 = (NI)0;
						colontmp__5 = ((NI)((NI)(ra_1 + rb_87) - ((NI)1)));
						res_2 = ra_1;
						{
							while (1) {
								if (!(res_2 <= colontmp__5)) goto LA1009;
								i_6 = ((NI) (res_2));
								prepareAdd((&outp_1), (*(*(*colonenv__1).tos1).slots.p->data[i_6].node)._kind_3.strVal.len + 0);
appendString((&outp_1), (*(*(*colonenv__1).tos1).slots.p->data[i_6].node)._kind_3.strVal);
								res_2 += ((NI)1);
							} LA1009: ;
						}
					}
					msgWriteln__msgs_u737((*(*colonenv__1).c0).config, outp_1, 5);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1006_;
					{
						LA1006_:;
					}
					{
						eqdestroy___system_u2691(outp_1);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				}
LA1001_: ;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)87):
			{
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__106;
				NI rb_88;
				NI rc_58;
				NIM_BOOL T1014_;
				colontmpD__106 = NIM_NIL;
				rb_88 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				rc_58 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(40ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1013_;
				colontmpD__106 = regToNode__vm_u542((*(*colonenv__1).tos1).slots.p->data[rc_58]);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1013_;
				T1014_ = (NIM_BOOL)0;
				T1014_ = inSet__nimsets_u8((*(*colonenv__1).tos1).slots.p->data[rb_88].node, colontmpD__106);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1013_;
				(*(*colonenv__1).tos1).slots.p->data[ra_1].intVal = ((NI64) (T1014_));
				{
					LA1013_:;
				}
				{
					oldNimErrFin1013_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3252(colontmpD__106);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin1013_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)94):
			{
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* coll_1;
				NI rb_89;
				NI rc_59;
				tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A* rcAddr_1;
				coll_1 = NIM_NIL;
				rb_89 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				rc_59 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(40ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1018_;
				rcAddr_1 = (&(*(*colonenv__1).tos1).slots.p->data[rc_59]);
				{
					if (!((*rcAddr_1).kind == ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)4))) goto LA1021_;
					rcAddr_1 = (*rcAddr_1).regAddr;
				}
				goto LA1019_;
LA1021_: ;
				{
					tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A T1026_;
					if (!!(((*(*colonenv__1).tos1).slots.p->data[rc_59].kind == ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)3)))) goto LA1024_;
					nimZeroMem((void*)(&T1026_), sizeof(tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A));
					nimZeroMem((void*)(&T1026_), sizeof(tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A));
					T1026_.kind = ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)3);
					T1026_.floatVal = 0;
					eqsink___vmdef_u1715((&(*(*colonenv__1).tos1).slots.p->data[rc_59]), T1026_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1018_;
				}
				goto LA1019_;
LA1024_: ;
LA1019_: ;
				eqcopy___ast_u3255(&coll_1, (*(*colonenv__1).tos1).slots.p->data[rb_89].node);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1018_;
				switch ((*coll_1).kind) {
				case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)160):
				{
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* data_1;
					NI64 left_4;
					NI64 right_4;
					data_1 = NIM_NIL;
					eqcopy___ast_u3255(&data_1, (*coll_1)._kind_6.sons.p->data[((NI)0)]);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1028_;
					left_4 = (*(*coll_1)._kind_6.sons.p->data[((NI)1)])._kind_1.intVal;
					right_4 = (*(*coll_1)._kind_6.sons.p->data[((NI)2)])._kind_1.intVal;
					switch ((*data_1).kind) {
					case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)20) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)22):
					{
						NI T1030_;
						T1030_ = (NI)0;
						T1030_ = nimParseBiggestFloat(((((*data_1)._kind_3.strVal).p) ? ((NIM_CHAR*)(*data_1)._kind_3.strVal.p->data+(((NI) (left_4)))) : NIM_NIL), (((NI) (right_4)))-(((NI) (left_4)))+1, (&(*rcAddr_1).floatVal));
						(*(*colonenv__1).tos1).slots.p->data[ra_1].intVal = ((NI64) (T1030_));
					}
					break;
					case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)41):
					{
						NimStringV2 s_3;
						NI T1035_;
						s_3.len = 0; s_3.p = NIM_NIL;
						s_3 = rawNewString(((NI) ((NI64)((NI64)(right_4 - left_4) + IL64(1)))));
						{
							NI64 i_7;
							NI64 res_3;
							i_7 = (NI64)0;
							res_3 = left_4;
							{
								while (1) {
									if (!(res_3 <= right_4)) goto LA1034;
									i_7 = res_3;
									nimAddCharV1((&s_3), ((NIM_CHAR) ((*(*data_1)._kind_6.sons.p->data[((NI) (i_7))])._kind_1.intVal)));
									res_3 += ((NI)1);
								} LA1034: ;
							}
						}
						T1035_ = (NI)0;
						T1035_ = parseBiggestFloat__pureZparseutils_u1009(s_3, (&(*rcAddr_1).floatVal), ((NI)0));
						if (NIM_UNLIKELY(*nimErr_)) goto LA1028_;
						(*(*colonenv__1).tos1).slots.p->data[ra_1].intVal = ((NI64) (T1035_));
						eqdestroy___system_u2691(s_3);
					}
					break;
					default:
					{
						internalErrorImpl__msgs_u1598((*(*colonenv__1).c0).config, (*(*colonenv__1).c0).debug.p->data[(*colonenv__1).pc2], TM__pyAIA9cUF0h9c4j2HfNQPfYw_427, TM__pyAIA9cUF0h9c4j2HfNQPfYw_428);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1028_;
					}
					break;
					}
					{
						LA1028_:;
					}
					{
						oldNimErrFin1028_ = *nimErr_; *nimErr_ = NIM_FALSE;
						eqdestroy___ast_u3252(data_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1018_;
						*nimErr_ = oldNimErrFin1028_;
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA1018_;
				}
				break;
				default:
				{
					NI T1040_;
					T1040_ = (NI)0;
					T1040_ = parseBiggestFloat__pureZparseutils_u1009((*(*(*colonenv__1).tos1).slots.p->data[rb_89].node)._kind_3.strVal, (&(*rcAddr_1).floatVal), ((NI)0));
					if (NIM_UNLIKELY(*nimErr_)) goto LA1018_;
					(*(*colonenv__1).tos1).slots.p->data[ra_1].intVal = ((NI64) (T1040_));
				}
				break;
				}
				{
					LA1018_:;
				}
				{
					oldNimErrFin1018_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3252(coll_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin1018_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)106):
			{
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__107;
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__108;
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__109;
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__110;
				NI rb_90;
				NI rc_60;
				colontmpD__107 = NIM_NIL;
				colontmpD__108 = NIM_NIL;
				colontmpD__109 = NIM_NIL;
				colontmpD__110 = NIM_NIL;
				rb_90 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				rc_60 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(40ULL & (64 - 1))) & 65535ULL)));
				{
					NIM_BOOL T1047_;
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__111;
					NimStringV2 colontmpD__112;
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__113;
					NimStringV2 colontmpD__114;
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__115;
					NimStringV2 colontmpD__116;
					NimStringV2 colontmpD__117;
					NimStringV2 colontmpD__118;
					tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T1052_;
					NimStringV2 T1053_;
					tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T1054_;
					T1047_ = (NIM_BOOL)0;
					colontmpD__107 = regToNode__vm_u542((*(*colonenv__1).tos1).slots.p->data[rb_90]);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1044_;
					colontmpD__108 = regToNode__vm_u542((*(*colonenv__1).tos1).slots.p->data[ra_1]);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1044_;
					T1047_ = leValueConv__semfold_u621(colontmpD__107, colontmpD__108);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1044_;
					if (!(T1047_)) goto LA1048_;
					colontmpD__109 = regToNode__vm_u542((*(*colonenv__1).tos1).slots.p->data[ra_1]);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1044_;
					colontmpD__110 = regToNode__vm_u542((*(*colonenv__1).tos1).slots.p->data[rc_60]);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1044_;
					T1047_ = leValueConv__semfold_u621(colontmpD__109, colontmpD__110);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1044_;
LA1048_: ;
					if (!!(T1047_)) goto LA1049_;
					colontmpD__111 = NIM_NIL;
					colontmpD__112.len = 0; colontmpD__112.p = NIM_NIL;
					colontmpD__113 = NIM_NIL;
					colontmpD__114.len = 0; colontmpD__114.p = NIM_NIL;
					colontmpD__115 = NIM_NIL;
					colontmpD__116.len = 0; colontmpD__116.p = NIM_NIL;
					colontmpD__117.len = 0; colontmpD__117.p = NIM_NIL;
					colontmpD__118.len = 0; colontmpD__118.p = NIM_NIL;
					colontmpD__111 = regToNode__vm_u542((*(*colonenv__1).tos1).slots.p->data[ra_1]);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1051_;
					colontmpD__112 = dollar___renderer_u2166(colontmpD__111);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1051_;
					T1052_[0] = colontmpD__112;
					T1053_.len = 0; T1053_.p = NIM_NIL;
					colontmpD__113 = regToNode__vm_u542((*(*colonenv__1).tos1).slots.p->data[rb_90]);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1051_;
					colontmpD__114 = dollar___renderer_u2166(colontmpD__113);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1051_;
					colontmpD__115 = regToNode__vm_u542((*(*colonenv__1).tos1).slots.p->data[rc_60]);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1051_;
					colontmpD__116 = dollar___renderer_u2166(colontmpD__115);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1051_;
					T1053_ = rawNewString(colontmpD__114.len + colontmpD__116.len + 4);
appendString((&T1053_), TM__pyAIA9cUF0h9c4j2HfNQPfYw_432);
appendString((&T1053_), colontmpD__114);
appendString((&T1053_), TM__pyAIA9cUF0h9c4j2HfNQPfYw_433);
appendString((&T1053_), colontmpD__116);
appendString((&T1053_), TM__pyAIA9cUF0h9c4j2HfNQPfYw_435);
					colontmpD__117 = T1053_;
					T1052_[1] = colontmpD__117;
					colontmpD__118 = nsuFormatOpenArray(TM__pyAIA9cUF0h9c4j2HfNQPfYw_430, T1052_, 2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1051_;
					nimZeroMem((void*)(&T1054_), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
					stackTraceImpl__vm_u73((*colonenv__1).c0, (*colonenv__1).tos1, (*colonenv__1).pc2, colontmpD__118, T1054_, TM__pyAIA9cUF0h9c4j2HfNQPfYw_230);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1051_;
					eqdestroy___system_u2691(colontmpD__118);
					eqdestroy___system_u2691(colontmpD__117);
					eqdestroy___system_u2691(colontmpD__116);
					eqdestroy___ast_u3252(colontmpD__115);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1044_;
					eqdestroy___system_u2691(colontmpD__114);
					eqdestroy___ast_u3252(colontmpD__113);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1044_;
					eqdestroy___system_u2691(colontmpD__112);
					eqdestroy___ast_u3252(colontmpD__111);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1044_;
					eqdestroy___ast_u3252(colontmpD__110);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___ast_u3252(colontmpD__109);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___ast_u3252(colontmpD__108);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___ast_u3252(colontmpD__107);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___vmprofiler_u19(savedFrame_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					eqdestroy___vm_u14829(colonenv__1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					goto BeforeRet_;
					{
						LA1051_:;
					}
					{
						oldNimErrFin1051_ = *nimErr_; *nimErr_ = NIM_FALSE;
						eqdestroy___system_u2691(colontmpD__118);
						eqdestroy___system_u2691(colontmpD__117);
						eqdestroy___system_u2691(colontmpD__116);
						eqdestroy___ast_u3252(colontmpD__115);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1044_;
						eqdestroy___system_u2691(colontmpD__114);
						eqdestroy___ast_u3252(colontmpD__113);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1044_;
						eqdestroy___system_u2691(colontmpD__112);
						eqdestroy___ast_u3252(colontmpD__111);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1044_;
						*nimErr_ = oldNimErrFin1051_;
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA1044_;
				}
LA1049_: ;
				{
					LA1044_:;
				}
				{
					oldNimErrFin1044_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3252(colontmpD__110);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___ast_u3252(colontmpD__109);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___ast_u3252(colontmpD__108);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___ast_u3252(colontmpD__107);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin1044_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)159):
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)160):
			{
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* bb_1;
				tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* prc_1;
				NI rb_91;
				NI rc_61;
				NIM_BOOL isClosure_1;
				tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* T1073_;
				bb_1 = NIM_NIL;
				prc_1 = NIM_NIL;
				rb_91 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				rc_61 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(40ULL & (64 - 1))) & 65535ULL)));
				eqcopy___ast_u3255(&bb_1, (*(*colonenv__1).tos1).slots.p->data[rb_91].node);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1060_;
				{
					tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T1065_;
					if (!((*bb_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)23))) goto LA1063_;
					nimZeroMem((void*)(&T1065_), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
					stackTraceImpl__vm_u73((*colonenv__1).c0, (*colonenv__1).tos1, (*colonenv__1).pc2, TM__pyAIA9cUF0h9c4j2HfNQPfYw_437, T1065_, TM__pyAIA9cUF0h9c4j2HfNQPfYw_230);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1060_;
					eqdestroy___ast_u4574(prc_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___ast_u3252(bb_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___vmprofiler_u19(savedFrame_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					eqdestroy___vm_u14829(colonenv__1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					goto BeforeRet_;
				}
LA1063_: ;
				isClosure_1 = ((*bb_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)160));
				{
					NIM_BOOL T1068_;
					tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T1072_;
					T1068_ = (NIM_BOOL)0;
					T1068_ = isClosure_1;
					if (!(T1068_)) goto LA1069_;
					T1068_ = ((*(*bb_1)._kind_6.sons.p->data[((NI)0)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)23));
LA1069_: ;
					if (!T1068_) goto LA1070_;
					nimZeroMem((void*)(&T1072_), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
					stackTraceImpl__vm_u73((*colonenv__1).c0, (*colonenv__1).tos1, (*colonenv__1).pc2, TM__pyAIA9cUF0h9c4j2HfNQPfYw_438, T1072_, TM__pyAIA9cUF0h9c4j2HfNQPfYw_230);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1060_;
					eqdestroy___ast_u4574(prc_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___ast_u3252(bb_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___vmprofiler_u19(savedFrame_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					eqdestroy___vm_u14829(colonenv__1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					goto BeforeRet_;
				}
LA1070_: ;
				T1073_ = NIM_NIL;
				{
					if (!!(isClosure_1)) goto LA1076_;
					eqcopy___ast_u4577(&prc_1, (*bb_1)._kind_4.sym);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1060_;
				}
				goto LA1074_;
LA1076_: ;
				{
					eqcopy___ast_u4577(&prc_1, (*(*bb_1)._kind_6.sons.p->data[((NI)0)])._kind_4.sym);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1060_;
				}
LA1074_: ;
				{
					tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg T1083_;
					if (!((*prc_1).offset < ((NI32)-1))) goto LA1081_;
					nimZeroMem((void*)(&T1083_), sizeof(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg));
					T1083_.ra = ra_1;
					T1083_.rb = rb_91;
					T1083_.rc = rc_61;
					T1083_.slots = ((tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A*) ((&(*(*colonenv__1).tos1).slots.p->data[((NI)0)])));
					T1083_.currentException = (*(*colonenv__1).c0).currentExceptionA;
					T1083_.currentLineInfo = (*(*colonenv__1).c0).debug.p->data[(*colonenv__1).pc2];
					(*(*colonenv__1).c0).callbacks.p->data[(NI32)(((NI32)-((*prc_1).offset)) - ((NI32)2))].ClE_0? (*(*colonenv__1).c0).callbacks.p->data[(NI32)(((NI32)-((*prc_1).offset)) - ((NI32)2))].ClP_0((&T1083_), (*(*colonenv__1).c0).callbacks.p->data[(NI32)(((NI32)-((*prc_1).offset)) - ((NI32)2))].ClE_0):((TM__pyAIA9cUF0h9c4j2HfNQPfYw_439)((*(*colonenv__1).c0).callbacks.p->data[(NI32)(((NI32)-((*prc_1).offset)) - ((NI32)2))].ClP_0))((&T1083_));
					if (NIM_UNLIKELY(*nimErr_)) goto LA1060_;
				}
				goto LA1079_;
LA1081_: ;
				{
					NIM_BOOL T1085_;
					T1085_ = (NIM_BOOL)0;
					T1085_ = importcCond__vmgen_u2499((*colonenv__1).c0, prc_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1060_;
					if (!T1085_) goto LA1086_;
					{
						if (!!((((*(*(*colonenv__1).c0).config).features &((NU32)1<<((NU)((((tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ)9)))&31U)))!=0))) goto LA1090_;
						liMessage__msgs_u1227((*(*colonenv__1).c0).config, (*(*colonenv__1).c0).debug.p->data[(*colonenv__1).pc2], ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), TM__pyAIA9cUF0h9c4j2HfNQPfYw_441, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)2), TM__pyAIA9cUF0h9c4j2HfNQPfYw_442, NIM_FALSE, NIM_FALSE);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1060_;
					}
LA1090_: ;
					liMessage__msgs_u1227((*(*colonenv__1).c0).config, (*(*colonenv__1).c0).debug.p->data[(*colonenv__1).pc2], ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), TM__pyAIA9cUF0h9c4j2HfNQPfYw_444, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)2), TM__pyAIA9cUF0h9c4j2HfNQPfYw_445, NIM_FALSE, NIM_FALSE);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1060_;
				}
				goto LA1079_;
LA1086_: ;
				{
					tyObject_TStackFrame__a20zU43j9cYHpYOOr1c2hZQ* newFrame_1;
					tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD__119;
					tyObject_TStackFrame__a20zU43j9cYHpYOOr1c2hZQ* colontmpD__120;
					tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* ret_2;
					tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__121;
					tyObject_VmProcInfo__Jux30icZSrOlvcFTG81Ljg procInfo_1;
					tyObject_TStackFrame__a20zU43j9cYHpYOOr1c2hZQ* T1112_;
					if (!!(((*prc_1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)18)))) goto LA1093_;
					newFrame_1 = NIM_NIL;
					ret_2 = NIM_NIL;
					colontmpD__121 = NIM_NIL;
					procInfo_1 = compile__vm_u803((*colonenv__1).c0, prc_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1095_;
					{
						if (!(procInfo_1.pc < ((NI32) ((*colonenv__1).pc2)))) goto LA1098_;
						{
							if (!((*(*colonenv__1).c0).loopIterations <= ((NI)0))) goto LA1102_;
							{
								if (!(((*(*colonenv__1).c0).features &((NU8)1<<((NU)((((tyEnum_TSandboxFlag__II2KpGKWwJH9bdjbBum5d1g)1)))&7U)))!=0)) goto LA1106_;
								(*(*colonenv__1).c0).loopIterations = (*(*(*colonenv__1).c0).config).maxLoopIterationsVM;
							}
							goto LA1104_;
LA1106_: ;
							{
								NimStringV2 colontmpD__122;
								NimStringV2 colontmpD__123;
								colontmpD__122.len = 0; colontmpD__122.p = NIM_NIL;
								colontmpD__123.len = 0; colontmpD__123.p = NIM_NIL;
								msgWriteln__msgs_u737((*(*colonenv__1).c0).config, TM__pyAIA9cUF0h9c4j2HfNQPfYw_446, 4);
								if (NIM_UNLIKELY(*nimErr_)) goto LA1109_;
								stackTraceAux__vm_u32((*colonenv__1).c0, (*colonenv__1).tos1, (*colonenv__1).pc2, ((NI)100));
								if (NIM_UNLIKELY(*nimErr_)) goto LA1109_;
								colontmpD__122 = dollar___systemZdollars_u9((*(*(*colonenv__1).c0).config).maxLoopIterationsVM);
								if (NIM_UNLIKELY(*nimErr_)) goto LA1109_;
								colontmpD__123 = nsuFormatSingleElem(TM__pyAIA9cUF0h9c4j2HfNQPfYw_448, colontmpD__122);
								if (NIM_UNLIKELY(*nimErr_)) goto LA1109_;
								liMessage__msgs_u1227((*(*colonenv__1).c0).config, (*(*colonenv__1).c0).debug.p->data[(*colonenv__1).pc2], ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), colontmpD__123, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)2), TM__pyAIA9cUF0h9c4j2HfNQPfYw_449, NIM_FALSE, NIM_FALSE);
								if (NIM_UNLIKELY(*nimErr_)) goto LA1109_;
								{
									LA1109_:;
								}
								{
									eqdestroy___system_u2691(colontmpD__123);
									eqdestroy___system_u2691(colontmpD__122);
								}
								if (NIM_UNLIKELY(*nimErr_)) goto LA1095_;
							}
LA1104_: ;
						}
LA1102_: ;
						(*(*colonenv__1).c0).loopIterations -= ((NI)1);
					}
LA1098_: ;
					T1112_ = NIM_NIL;
					T1112_ = (tyObject_TStackFrame__a20zU43j9cYHpYOOr1c2hZQ*) nimNewObj(sizeof(tyObject_TStackFrame__a20zU43j9cYHpYOOr1c2hZQ), NIM_ALIGNOF(tyObject_TStackFrame__a20zU43j9cYHpYOOr1c2hZQ));
					colontmpD__119 = eqdup___ast_u4580(prc_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1095_;
					(*T1112_).prc = colontmpD__119;
					(*T1112_).comesFrom = (*colonenv__1).pc2;
					colontmpD__120 = eqdup___vmprofiler_u25((*colonenv__1).tos1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1095_;
					(*T1112_).next = colontmpD__120;
					newFrame_1 = T1112_;
					newSeq__vm_u2972((&(*newFrame_1).slots), ((NI) ((NI32)(procInfo_1.usedRegisters + ((NI32) (isClosure_1))))));
					colontmpD__121 = returnType__ast_u5354((*prc_1).typ);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1095_;
					ret_2 = colontmpD__121;
					{
						if (!!((ret_2 == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL)))) goto LA1115_;
						{
							NIM_BOOL T1119_;
							T1119_ = (NIM_BOOL)0;
							T1119_ = fitsRegister__vmgen_u1796(ret_2);
							if (NIM_UNLIKELY(*nimErr_)) goto LA1095_;
							if (!T1119_) goto LA1120_;
							ensureKind__vm_u122((&(*newFrame_1).slots.p->data[((NI)0)]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2));
							if (NIM_UNLIKELY(*nimErr_)) goto LA1095_;
							(*newFrame_1).slots.p->data[((NI)0)].intVal = IL64(0);
						}
						goto LA1117_;
LA1120_: ;
						{
							NIM_BOOL T1123_;
							tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__124;
							T1123_ = (NIM_BOOL)0;
							T1123_ = isEmptyType__ast_u7234(ret_2);
							if (NIM_UNLIKELY(*nimErr_)) goto LA1095_;
							if (!!(T1123_)) goto LA1124_;
							colontmpD__124 = NIM_NIL;
							colontmpD__124 = getNullValue__vmgen_u2515((*colonenv__1).c0, ret_2, (*prc_1).info, (*(*colonenv__1).c0).config);
							if (NIM_UNLIKELY(*nimErr_)) goto LA1126_;
							putIntoReg__vm_u523((&(*newFrame_1).slots.p->data[((NI)0)]), colontmpD__124);
							if (NIM_UNLIKELY(*nimErr_)) goto LA1126_;
							{
								LA1126_:;
							}
							{
								oldNimErrFin1126_ = *nimErr_; *nimErr_ = NIM_FALSE;
								eqdestroy___ast_u3252(colontmpD__124);
								if (NIM_UNLIKELY(*nimErr_)) goto LA1095_;
								*nimErr_ = oldNimErrFin1126_;
							}
							if (NIM_UNLIKELY(*nimErr_)) goto LA1095_;
						}
						goto LA1117_;
LA1124_: ;
LA1117_: ;
					}
LA1115_: ;
					{
						NI i_8;
						NI colontmp__6;
						NI res_4;
						i_8 = (NI)0;
						colontmp__6 = (NI)0;
						colontmp__6 = (NI)(rc_61 - ((NI)1));
						res_4 = ((NI)1);
						{
							while (1) {
								if (!(res_4 <= colontmp__6)) goto LA1131;
								i_8 = ((NI) (res_4));
								eqcopy___vmdef_u1709((&(*newFrame_1).slots.p->data[i_8]), (*(*colonenv__1).tos1).slots.p->data[(NI)(rb_91 + i_8)]);
								if (NIM_UNLIKELY(*nimErr_)) goto LA1095_;
								res_4 += ((NI)1);
							} LA1131: ;
						}
					}
					{
						tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__125;
						tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A T1136_;
						if (!isClosure_1) goto LA1134_;
						nimZeroMem((void*)(&T1136_), sizeof(tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A));
						T1136_.kind = ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1);
						colontmpD__125 = eqdup___ast_u3258((*(*(*colonenv__1).tos1).slots.p->data[rb_91].node)._kind_6.sons.p->data[((NI)1)]);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1095_;
						T1136_.node = colontmpD__125;
						eqsink___vmdef_u1715((&(*newFrame_1).slots.p->data[rc_61]), T1136_);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1095_;
					}
LA1134_: ;
					{
						if (!((*(*colonenv__1).c0).callDepth <= ((NI)0))) goto LA1139_;
						{
							if (!(((*(*colonenv__1).c0).features &((NU8)1<<((NU)((((tyEnum_TSandboxFlag__II2KpGKWwJH9bdjbBum5d1g)2)))&7U)))!=0)) goto LA1143_;
							(*(*colonenv__1).c0).callDepth = (*(*(*colonenv__1).c0).config).maxCallDepthVM;
						}
						goto LA1141_;
LA1143_: ;
						{
							NimStringV2 colontmpD__126;
							NimStringV2 colontmpD__127;
							colontmpD__126.len = 0; colontmpD__126.p = NIM_NIL;
							colontmpD__127.len = 0; colontmpD__127.p = NIM_NIL;
							msgWriteln__msgs_u737((*(*colonenv__1).c0).config, TM__pyAIA9cUF0h9c4j2HfNQPfYw_450, 4);
							if (NIM_UNLIKELY(*nimErr_)) goto LA1146_;
							stackTraceAux__vm_u32((*colonenv__1).c0, (*colonenv__1).tos1, (*colonenv__1).pc2, ((NI)100));
							if (NIM_UNLIKELY(*nimErr_)) goto LA1146_;
							colontmpD__126 = dollar___systemZdollars_u9((*(*(*colonenv__1).c0).config).maxCallDepthVM);
							if (NIM_UNLIKELY(*nimErr_)) goto LA1146_;
							colontmpD__127 = nsuFormatSingleElem(TM__pyAIA9cUF0h9c4j2HfNQPfYw_452, colontmpD__126);
							if (NIM_UNLIKELY(*nimErr_)) goto LA1146_;
							liMessage__msgs_u1227((*(*colonenv__1).c0).config, (*(*colonenv__1).c0).debug.p->data[(*colonenv__1).pc2], ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), colontmpD__127, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)2), TM__pyAIA9cUF0h9c4j2HfNQPfYw_453, NIM_FALSE, NIM_FALSE);
							if (NIM_UNLIKELY(*nimErr_)) goto LA1146_;
							{
								LA1146_:;
							}
							{
								eqdestroy___system_u2691(colontmpD__127);
								eqdestroy___system_u2691(colontmpD__126);
							}
							if (NIM_UNLIKELY(*nimErr_)) goto LA1095_;
						}
LA1141_: ;
					}
LA1139_: ;
					(*(*colonenv__1).c0).callDepth -= ((NI)1);
					eqsink___vmprofiler_u28(&(*colonenv__1).tos1, newFrame_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1095_;
					eqwasMoved___vmprofiler_u16(&newFrame_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1095_;
					(*colonenv__1).pc2 = ((NI) ((NI32)(procInfo_1.pc - ((NI32)1))));
					{
						LA1095_:;
					}
					{
						oldNimErrFin1095_ = *nimErr_; *nimErr_ = NIM_FALSE;
						eqdestroy___ast_u3378(colontmpD__121);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1060_;
						eqdestroy___vmprofiler_u19(newFrame_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1060_;
						*nimErr_ = oldNimErrFin1095_;
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA1060_;
				}
				goto LA1079_;
LA1093_: ;
				{
					tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* genSymOwner_1;
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* macroCall_1;
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__128;
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_7;
					tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* T1153_;
					genSymOwner_1 = NIM_NIL;
					macroCall_1 = NIM_NIL;
					colontmpD__128 = NIM_NIL;
					a_7 = NIM_NIL;
					T1153_ = NIM_NIL;
					{
						NIM_BOOL T1156_;
						T1156_ = (NIM_BOOL)0;
						T1156_ = !(((*(*colonenv__1).tos1).next == ((tyObject_TStackFrame__a20zU43j9cYHpYOOr1c2hZQ*) NIM_NIL)));
						if (!(T1156_)) goto LA1157_;
						T1156_ = !(((*(*(*colonenv__1).tos1).next).prc == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)));
LA1157_: ;
						if (!T1156_) goto LA1158_;
						eqcopy___ast_u4577(&genSymOwner_1, (*(*(*colonenv__1).tos1).next).prc);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1152_;
					}
					goto LA1154_;
LA1158_: ;
					{
						eqcopy___ast_u4577(&genSymOwner_1, (*(*colonenv__1).c0).module);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1152_;
					}
LA1154_: ;
					macroCall_1 = newNodeI__ast_u4091(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)27), (*(*colonenv__1).c0).debug.p->data[(*colonenv__1).pc2]);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1152_;
					colontmpD__128 = newSymNode__ast_u5168(prc_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1152_;
					add__ast_u3215(macroCall_1, colontmpD__128);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1152_;
					{
						NI i_9;
						NI colontmp__7;
						NI res_5;
						i_9 = (NI)0;
						colontmp__7 = (NI)0;
						colontmp__7 = (NI)(rc_61 - ((NI)1));
						res_5 = ((NI)1);
						{
							while (1) {
								tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* node_2;
								if (!(res_5 <= colontmp__7)) goto LA1163;
								node_2 = NIM_NIL;
								i_9 = ((NI) (res_5));
								node_2 = regToNode__vm_u542((*(*colonenv__1).tos1).slots.p->data[(NI)(rb_91 + i_9)]);
								if (NIM_UNLIKELY(*nimErr_)) goto LA1164_;
								(*node_2).info = (*(*colonenv__1).c0).debug.p->data[(*colonenv__1).pc2];
								{
									NIM_BOOL producedClosure_1;
									if (!!(((*(*(*prc_1).typ).sons.p->data[i_9]).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)7) || (*(*(*prc_1).typ).sons.p->data[i_9]).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)6)))) goto LA1167_;
									producedClosure_1 = NIM_FALSE;
									annotateType__semmacrosanity_u136(node_2, (*(*prc_1).typ).sons.p->data[i_9], (*(*colonenv__1).c0).config, (&producedClosure_1));
									if (NIM_UNLIKELY(*nimErr_)) goto LA1164_;
								}
LA1167_: ;
								add__ast_u3215(macroCall_1, node_2);
								if (NIM_UNLIKELY(*nimErr_)) goto LA1164_;
								res_5 += ((NI)1);
								{
									LA1164_:;
								}
								{
									oldNimErrFin1164_ = *nimErr_; *nimErr_ = NIM_FALSE;
									eqdestroy___ast_u3252(node_2);
									if (NIM_UNLIKELY(*nimErr_)) goto LA1152_;
									*nimErr_ = oldNimErrFin1164_;
								}
								if (NIM_UNLIKELY(*nimErr_)) goto LA1152_;
							} LA1163: ;
						}
					}
					a_7 = evalTemplate__evaltempl_u344(macroCall_1, prc_1, genSymOwner_1, (*(*colonenv__1).c0).config, (*(*colonenv__1).c0).cache, (*(*colonenv__1).c0).templInstCounter, (*(*colonenv__1).c0).Sup.idgen, NIM_FALSE);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1152_;
					{
						NIM_BOOL T1173_;
						NI T1175_;
						T1173_ = (NIM_BOOL)0;
						T1173_ = ((*a_7).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)115));
						if (!(T1173_)) goto LA1174_;
						T1175_ = (NI)0;
						T1175_ = len__ast_u3190(a_7);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1152_;
						T1173_ = (T1175_ == ((NI)1));
LA1174_: ;
						if (!T1173_) goto LA1176_;
						eqcopy___ast_u3255(&a_7, (*a_7)._kind_6.sons.p->data[((NI)0)]);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1152_;
					}
LA1176_: ;
					recSetFlagIsRef__vm_u808(a_7);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1152_;
					ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA1152_;
					eqsink___ast_u3261(&(*(*colonenv__1).tos1).slots.p->data[ra_1].node, a_7);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1152_;
					eqwasMoved___ast_u3249(&a_7);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1152_;
					{
						LA1152_:;
					}
					{
						oldNimErrFin1152_ = *nimErr_; *nimErr_ = NIM_FALSE;
						eqdestroy___ast_u3252(a_7);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1060_;
						eqdestroy___ast_u3252(colontmpD__128);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1060_;
						eqdestroy___ast_u3252(macroCall_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1060_;
						eqdestroy___ast_u4574(genSymOwner_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1060_;
						*nimErr_ = oldNimErrFin1152_;
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA1060_;
				}
LA1079_: ;
				{
					LA1060_:;
				}
				{
					oldNimErrFin1060_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u4574(prc_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___ast_u3252(bb_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin1060_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)166):
			{
				NI rbx_1;
				rbx_1 = (NI)((NI)(((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 16777215ULL))) - ((NI)8388608)) - ((NI)1));
				{
					if (!!(((*(*colonenv__1).tos1).slots.p->data[ra_1].intVal == IL64(0)))) goto LA1185_;
					(*colonenv__1).pc2 += rbx_1;
				}
LA1185_: ;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)167):
			{
				NI rbx_2;
				rbx_2 = (NI)((NI)(((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 16777215ULL))) - ((NI)8388608)) - ((NI)1));
				{
					if (!((*(*colonenv__1).tos1).slots.p->data[ra_1].intVal == IL64(0))) goto LA1190_;
					(*colonenv__1).pc2 += rbx_2;
				}
LA1190_: ;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)168):
			{
				NI rbx_3;
				rbx_3 = (NI)((NI)(((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 16777215ULL))) - ((NI)8388608)) - ((NI)1));
				(*colonenv__1).pc2 += rbx_3;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)169):
			{
				NI rbx_4;
				rbx_4 = (NI)((NI)(((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 16777215ULL))) - ((NI)8388608)) - ((NI)1));
				(*colonenv__1).pc2 += rbx_4;
				{
					if (!((*(*colonenv__1).c0).loopIterations <= ((NI)0))) goto LA1196_;
					{
						if (!(((*(*colonenv__1).c0).features &((NU8)1<<((NU)((((tyEnum_TSandboxFlag__II2KpGKWwJH9bdjbBum5d1g)1)))&7U)))!=0)) goto LA1200_;
						(*(*colonenv__1).c0).loopIterations = (*(*(*colonenv__1).c0).config).maxLoopIterationsVM;
					}
					goto LA1198_;
LA1200_: ;
					{
						NimStringV2 colontmpD__129;
						NimStringV2 colontmpD__130;
						colontmpD__129.len = 0; colontmpD__129.p = NIM_NIL;
						colontmpD__130.len = 0; colontmpD__130.p = NIM_NIL;
						msgWriteln__msgs_u737((*(*colonenv__1).c0).config, TM__pyAIA9cUF0h9c4j2HfNQPfYw_454, 4);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1203_;
						stackTraceAux__vm_u32((*colonenv__1).c0, (*colonenv__1).tos1, (*colonenv__1).pc2, ((NI)100));
						if (NIM_UNLIKELY(*nimErr_)) goto LA1203_;
						colontmpD__129 = dollar___systemZdollars_u9((*(*(*colonenv__1).c0).config).maxLoopIterationsVM);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1203_;
						colontmpD__130 = nsuFormatSingleElem(TM__pyAIA9cUF0h9c4j2HfNQPfYw_455, colontmpD__129);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1203_;
						liMessage__msgs_u1227((*(*colonenv__1).c0).config, (*(*colonenv__1).c0).debug.p->data[(*colonenv__1).pc2], ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), colontmpD__130, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)2), TM__pyAIA9cUF0h9c4j2HfNQPfYw_449, NIM_FALSE, NIM_FALSE);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1203_;
						{
							LA1203_:;
						}
						{
							eqdestroy___system_u2691(colontmpD__130);
							eqdestroy___system_u2691(colontmpD__129);
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					}
LA1198_: ;
				}
LA1196_: ;
				(*(*colonenv__1).c0).loopIterations -= ((NI)1);
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)170):
			{
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* branch_1;
				NIM_BOOL cond_1;
				branch_1 = NIM_NIL;
				eqcopy___ast_u3255(&branch_1, (*(*(*colonenv__1).c0).constants)._kind_6.sons.p->data[(NI)(((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 16777215ULL))) - ((NI)8388608))]);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1207_;
				cond_1 = NIM_FALSE;
				{
					NI j_1;
					NI colontmp__8;
					NI T1209_;
					NI i_10;
					j_1 = (NI)0;
					colontmp__8 = (NI)0;
					T1209_ = (NI)0;
					T1209_ = len__ast_u3190(branch_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1207_;
					colontmp__8 = (NI)(T1209_ - ((NI)1));
					i_10 = ((NI)0);
					{
						while (1) {
							tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__131;
							if (!(i_10 < colontmp__8)) goto LA1211;
							colontmpD__131 = NIM_NIL;
							j_1 = i_10;
							{
								NIM_BOOL T1215_;
								colontmpD__131 = regToNode__vm_u542((*(*colonenv__1).tos1).slots.p->data[ra_1]);
								if (NIM_UNLIKELY(*nimErr_)) goto LA1212_;
								T1215_ = (NIM_BOOL)0;
								T1215_ = overlap__nimsets_u32(colontmpD__131, (*branch_1)._kind_6.sons.p->data[j_1]);
								if (NIM_UNLIKELY(*nimErr_)) goto LA1212_;
								if (!T1215_) goto LA1216_;
								cond_1 = NIM_TRUE;
								eqdestroy___ast_u3252(colontmpD__131);
								if (NIM_UNLIKELY(*nimErr_)) goto LA1207_;
								goto LA1208;
							}
LA1216_: ;
							i_10 += ((NI)1);
							{
								LA1212_:;
							}
							{
								oldNimErrFin1212_ = *nimErr_; *nimErr_ = NIM_FALSE;
								eqdestroy___ast_u3252(colontmpD__131);
								if (NIM_UNLIKELY(*nimErr_)) goto LA1207_;
								*nimErr_ = oldNimErrFin1212_;
							}
							if (NIM_UNLIKELY(*nimErr_)) goto LA1207_;
						} LA1211: ;
					}
				} LA1208: ;
				(*colonenv__1).pc2 += ((NI)1);
				{
					NU64 instr2_1;
					NI rbx_5;
					if (!!(cond_1)) goto LA1222_;
					instr2_1 = (*(*colonenv__1).c0).code.p->data[(*colonenv__1).pc2];
					rbx_5 = (NI)((NI)(((NI) ((NU64)((NU64)((NU64)(instr2_1) >> (NU64)(24ULL & (64 - 1))) & 16777215ULL))) - ((NI)8388608)) - ((NI)1));
					(*colonenv__1).pc2 += rbx_5;
				}
LA1222_: ;
				{
					LA1207_:;
				}
				{
					oldNimErrFin1207_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3252(branch_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin1207_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)171):
			{
				NI rbx_6;
				rbx_6 = (NI)(((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 16777215ULL))) - ((NI)8388608));
				pushSafePoint__vm_u547((*colonenv__1).tos1, (NI)((*colonenv__1).pc2 + rbx_6));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)172):
			{
				raiseAssert__stdZassertions_u15(TM__pyAIA9cUF0h9c4j2HfNQPfYw_457);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)173):
			{
				{
					if (!!((savedPC_1 < ((NI)0)))) goto LA1231_;
					failedAssertImpl__stdZassertions_u79(TM__pyAIA9cUF0h9c4j2HfNQPfYw_459);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				}
LA1231_: ;
				popSafePoint__vm_u554((*colonenv__1).tos1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)174):
			{
				{
					if (!(((NI)0) <= savedPC_1)) goto LA1236_;
					(*colonenv__1).pc2 = (NI)(savedPC_1 - ((NI)1));
					savedPC_1 = ((NI)-1);
					{
						if (!!(((*colonenv__1).tos1 == savedFrame_1))) goto LA1240_;
						eqcopy___vmprofiler_u22(&(*colonenv__1).tos1, savedFrame_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					}
LA1240_: ;
				}
LA1236_: ;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)161):
			{
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* raised_1;
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* exceptionNameNode_1;
				tyObject_TStackFrame__a20zU43j9cYHpYOOr1c2hZQ* frame_1;
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T1244_;
				tyTuple__BQblRMJ3qVZJdz8oXhBMaQ jumpTo_1;
				raised_1 = NIM_NIL;
				exceptionNameNode_1 = NIM_NIL;
				frame_1 = NIM_NIL;
				T1244_ = NIM_NIL;
				{
					if (!((*(*colonenv__1).tos1).slots.p->data[ra_1].kind == ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)0))) goto LA1247_;
					eqcopy___ast_u3255(&raised_1, (*(*colonenv__1).c0).currentExceptionA);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1243_;
				}
				goto LA1245_;
LA1247_: ;
				{
					eqcopy___ast_u3255(&raised_1, (*(*colonenv__1).tos1).slots.p->data[ra_1].node);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1243_;
				}
LA1245_: ;
				eqcopy___ast_u3255(&(*(*colonenv__1).c0).currentExceptionA, raised_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1243_;
				exceptionNameNode_1 = newStrNode__ast_u5422(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)20), (*(*(*(*(*(*colonenv__1).c0).currentExceptionA).typField).sym).name).s);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1243_;
				{
					if (!((*(*(*(*colonenv__1).c0).currentExceptionA)._kind_6.sons.p->data[((NI)2)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)34))) goto LA1252_;
					eqcopy___ast_u3381(&(*exceptionNameNode_1).typField, (*(*(*(*(*colonenv__1).c0).currentExceptionA)._kind_6.sons.p->data[((NI)2)])._kind_6.sons.p->data[((NI)1)]).typField);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1243_;
					eqsink___ast_u3261(&(*(*(*(*colonenv__1).c0).currentExceptionA)._kind_6.sons.p->data[((NI)2)])._kind_6.sons.p->data[((NI)1)], exceptionNameNode_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1243_;
					eqwasMoved___ast_u3249(&exceptionNameNode_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1243_;
				}
				goto LA1250_;
LA1252_: ;
				{
					eqcopy___ast_u3381(&(*exceptionNameNode_1).typField, (*(*(*(*colonenv__1).c0).currentExceptionA)._kind_6.sons.p->data[((NI)2)]).typField);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1243_;
					eqsink___ast_u3261(&(*(*(*colonenv__1).c0).currentExceptionA)._kind_6.sons.p->data[((NI)2)], exceptionNameNode_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1243_;
					eqwasMoved___ast_u3249(&exceptionNameNode_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1243_;
				}
LA1250_: ;
				(*(*colonenv__1).c0).exceptionInstr = (*colonenv__1).pc2;
				eqcopy___vmprofiler_u22(&frame_1, (*colonenv__1).tos1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1243_;
				jumpTo_1 = findExceptionHandler__vm_u566((*colonenv__1).c0, frame_1, raised_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1243_;
				{
					while (1) {
						NIM_BOOL T1257_;
						T1257_ = (NIM_BOOL)0;
						T1257_ = (jumpTo_1.Field0 == ((tyEnum_ExceptionGoto__UXGPMKK1kMiyMPS9b1jNcmg)2));
						if (!(T1257_)) goto LA1258_;
						T1257_ = !(((*frame_1).next == 0));
LA1258_: ;
						if (!T1257_) goto LA1256;
						eqcopy___vmprofiler_u22(&frame_1, (*frame_1).next);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1243_;
						jumpTo_1 = findExceptionHandler__vm_u566((*colonenv__1).c0, frame_1, raised_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1243_;
					} LA1256: ;
				}
				switch (jumpTo_1.Field0) {
				case ((tyEnum_ExceptionGoto__UXGPMKK1kMiyMPS9b1jNcmg)0):
				{
					savedPC_1 = ((NI)-1);
					(*colonenv__1).pc2 = (NI)(jumpTo_1.Field1 - ((NI)1));
					{
						if (!!(((*colonenv__1).tos1 == frame_1))) goto LA1262_;
						eqsink___vmprofiler_u28(&(*colonenv__1).tos1, frame_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1243_;
						eqwasMoved___vmprofiler_u16(&frame_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1243_;
					}
LA1262_: ;
				}
				break;
				case ((tyEnum_ExceptionGoto__UXGPMKK1kMiyMPS9b1jNcmg)1):
				{
					savedPC_1 = (*colonenv__1).pc2;
					eqcopy___vmprofiler_u22(&savedFrame_1, (*colonenv__1).tos1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1243_;
					(*colonenv__1).pc2 = (NI)(jumpTo_1.Field1 - ((NI)1));
					{
						if (!!(((*colonenv__1).tos1 == frame_1))) goto LA1267_;
						eqsink___vmprofiler_u28(&(*colonenv__1).tos1, frame_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1243_;
						eqwasMoved___vmprofiler_u16(&frame_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1243_;
					}
LA1267_: ;
				}
				break;
				case ((tyEnum_ExceptionGoto__UXGPMKK1kMiyMPS9b1jNcmg)2):
				{
					bailOut__vm_u119((*colonenv__1).c0, (*colonenv__1).tos1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1243_;
				}
				break;
				default: __builtin_unreachable();
				}
				{
					LA1243_:;
				}
				{
					oldNimErrFin1243_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___vmprofiler_u19(frame_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___ast_u3252(exceptionNameNode_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___ast_u3252(raised_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin1243_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)175):
			{
				tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_2;
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T1274_;
				typ_2 = NIM_NIL;
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1273_;
				eqcopy___ast_u3381(&typ_2, (*(*colonenv__1).c0).types.p->data[(NI)(((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 16777215ULL))) - ((NI)8388608))]);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1273_;
				T1274_ = NIM_NIL;
				T1274_ = getNullValue__vmgen_u2515((*colonenv__1).c0, typ_2, (*(*colonenv__1).c0).debug.p->data[(*colonenv__1).pc2], (*(*colonenv__1).c0).config);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T1274_); goto LA1273_;}
				eqsink___ast_u3261(&(*(*colonenv__1).tos1).slots.p->data[ra_1].node, T1274_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1273_;
				(*(*(*colonenv__1).tos1).slots.p->data[ra_1].node).flags |= ((NU32)1)<<(((((tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw)13))) & 31);
				{
					LA1273_:;
				}
				{
					oldNimErrFin1273_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3378(typ_2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin1273_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)176):
			{
				tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_3;
				NU64 instr2_2;
				NI count_1;
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T1279_;
				typ_3 = NIM_NIL;
				eqcopy___ast_u3381(&typ_3, (*(*colonenv__1).c0).types.p->data[(NI)(((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 16777215ULL))) - ((NI)8388608))]);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1278_;
				(*colonenv__1).pc2 += ((NI)1);
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1278_;
				instr2_2 = (*(*colonenv__1).c0).code.p->data[(*colonenv__1).pc2];
				count_1 = ((NI) ((*(*colonenv__1).tos1).slots.p->data[((NI) ((NU64)((NU64)((NU64)(instr2_2) >> (NU64)(8ULL & (64 - 1))) & 65535ULL)))].intVal));
				T1279_ = NIM_NIL;
				T1279_ = newNodeI__ast_u4091(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)41), (*(*colonenv__1).c0).debug.p->data[(*colonenv__1).pc2]);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T1279_); goto LA1278_;}
				eqsink___ast_u3261(&(*(*colonenv__1).tos1).slots.p->data[ra_1].node, T1279_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1278_;
				eqcopy___ast_u3381(&(*(*(*colonenv__1).tos1).slots.p->data[ra_1].node).typField, typ_3);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1278_;
				newSeq__ast_u4100((&(*(*(*colonenv__1).tos1).slots.p->data[ra_1].node)._kind_6.sons), (count_1));
				{
					NI i_11;
					NI i_12;
					i_11 = (NI)0;
					i_12 = ((NI)0);
					{
						while (1) {
							tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__132;
							tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T1284_;
							if (!(i_12 < count_1)) goto LA1282;
							colontmpD__132 = NIM_NIL;
							i_11 = i_12;
							colontmpD__132 = elementType__ast_u5331(typ_3);
							if (NIM_UNLIKELY(*nimErr_)) goto LA1283_;
							T1284_ = NIM_NIL;
							T1284_ = getNullValue__vmgen_u2515((*colonenv__1).c0, colontmpD__132, (*(*colonenv__1).c0).debug.p->data[(*colonenv__1).pc2], (*(*colonenv__1).c0).config);
							if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T1284_); goto LA1283_;}
							eqsink___ast_u3261(&(*(*(*colonenv__1).tos1).slots.p->data[ra_1].node)._kind_6.sons.p->data[i_11], T1284_);
							if (NIM_UNLIKELY(*nimErr_)) goto LA1283_;
							i_12 += ((NI)1);
							{
								LA1283_:;
							}
							{
								oldNimErrFin1283_ = *nimErr_; *nimErr_ = NIM_FALSE;
								eqdestroy___ast_u3378(colontmpD__132);
								if (NIM_UNLIKELY(*nimErr_)) goto LA1278_;
								*nimErr_ = oldNimErrFin1283_;
							}
							if (NIM_UNLIKELY(*nimErr_)) goto LA1278_;
						} LA1282: ;
					}
				}
				{
					LA1278_:;
				}
				{
					oldNimErrFin1278_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3378(typ_3);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin1278_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)165):
			{
				NI rb_92;
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T1290_;
				NimStringV2 T1291_;
				rb_92 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				T1290_ = NIM_NIL;
				T1290_ = newNodeI__ast_u4091(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)20), (*(*colonenv__1).c0).debug.p->data[(*colonenv__1).pc2]);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T1290_); goto LA1_;}
				eqsink___ast_u3261(&(*(*colonenv__1).tos1).slots.p->data[ra_1].node, T1290_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				T1291_.len = 0; T1291_.p = NIM_NIL;
				T1291_ = mnewString((((NI) ((*(*colonenv__1).tos1).slots.p->data[rb_92].intVal))));
				eqsink___system_u2700((&(*(*(*colonenv__1).tos1).slots.p->data[ra_1].node)._kind_3.strVal), T1291_);
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)185):
			{
				NI rbx_7;
				rbx_7 = (NI)(((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 16777215ULL))) - ((NI)8388608));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				(*(*colonenv__1).tos1).slots.p->data[ra_1].intVal = ((NI64) (rbx_7));
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)177):
			{
				tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_4;
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T1295_;
				typ_4 = NIM_NIL;
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1294_;
				eqcopy___ast_u3381(&typ_4, (*(*colonenv__1).c0).types.p->data[(NI)(((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 16777215ULL))) - ((NI)8388608))]);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1294_;
				T1295_ = NIM_NIL;
				T1295_ = getNullValue__vmgen_u2515((*colonenv__1).c0, typ_4, (*(*colonenv__1).c0).debug.p->data[(*colonenv__1).pc2], (*(*colonenv__1).c0).config);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T1295_); goto LA1294_;}
				eqsink___ast_u3261(&(*(*colonenv__1).tos1).slots.p->data[ra_1].node, T1295_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1294_;
				{
					LA1294_:;
				}
				{
					oldNimErrFin1294_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3378(typ_4);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin1294_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)178):
			{
				tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_5;
				tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__133;
				typ_5 = NIM_NIL;
				colontmpD__133 = NIM_NIL;
				eqcopy___ast_u3381(&typ_5, (*(*colonenv__1).c0).types.p->data[(NI)(((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 16777215ULL))) - ((NI)8388608))]);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				{
					colontmpD__133 = skipTypes__ast_u5379(typ_5, TM__pyAIA9cUF0h9c4j2HfNQPfYw_466);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					if (!((*colontmpD__133).kind >= ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)36) && (*colontmpD__133).kind <= ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)39))) goto LA1301_;
					ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)3));
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					(*(*colonenv__1).tos1).slots.p->data[ra_1].floatVal = 0.0;
				}
				goto LA1299_;
LA1301_: ;
				{
					ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2));
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					(*(*colonenv__1).tos1).slots.p->data[ra_1].intVal = IL64(0);
				}
LA1299_: ;
				eqdestroy___ast_u3378(colontmpD__133);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				eqdestroy___ast_u3378(typ_5);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)179):
			{
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* cnst_1;
				NI rb_93;
				cnst_1 = NIM_NIL;
				rb_93 = (NI)(((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 16777215ULL))) - ((NI)8388608));
				eqcopy___ast_u3255(&cnst_1, (*(*(*colonenv__1).c0).constants)._kind_6.sons.p->data[rb_93]);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				{
					NIM_BOOL T1307_;
					T1307_ = (NIM_BOOL)0;
					T1307_ = fitsRegister__vmgen_u1796((*cnst_1).typField);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					if (!T1307_) goto LA1308_;
					reset__vmdef_u1670((&(*(*colonenv__1).tos1).slots.p->data[ra_1]));
					putIntoReg__vm_u523((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), cnst_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				}
				goto LA1305_;
LA1308_: ;
				{
					ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqsink___ast_u3261(&(*(*colonenv__1).tos1).slots.p->data[ra_1].node, cnst_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqwasMoved___ast_u3249(&cnst_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				}
LA1305_: ;
				eqdestroy___ast_u3252(cnst_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)180):
			{
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* cnst_2;
				NI rb_94;
				cnst_2 = NIM_NIL;
				rb_94 = (NI)(((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 16777215ULL))) - ((NI)8388608));
				eqcopy___ast_u3255(&cnst_2, (*(*(*colonenv__1).c0).constants)._kind_6.sons.p->data[rb_94]);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1312_;
				{
					NIM_BOOL T1315_;
					T1315_ = (NIM_BOOL)0;
					T1315_ = fitsRegister__vmgen_u1796((*cnst_2).typField);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1312_;
					if (!T1315_) goto LA1316_;
					putIntoReg__vm_u523((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), cnst_2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1312_;
				}
				goto LA1313_;
LA1316_: ;
				{
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T1319_;
					ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA1312_;
					T1319_ = NIM_NIL;
					T1319_ = copyTree__ast_u6891(cnst_2);
					if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T1319_); goto LA1312_;}
					eqsink___ast_u3261(&(*(*colonenv__1).tos1).slots.p->data[ra_1].node, T1319_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1312_;
				}
LA1313_: ;
				{
					LA1312_:;
				}
				{
					oldNimErrFin1312_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3252(cnst_2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin1312_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)181):
			{
				NI rb_95;
				rb_95 = (NI)((NI)(((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 16777215ULL))) - ((NI)8388608)) - ((NI)1));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				eqcopy___ast_u3255(&(*(*colonenv__1).tos1).slots.p->data[ra_1].node, (*(*(*colonenv__1).c0).globals)._kind_6.sons.p->data[rb_95]);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)183):
			{
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* node_3;
				tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_6;
				NI rb_96;
				node_3 = NIM_NIL;
				typ_6 = NIM_NIL;
				rb_96 = (NI)((NI)(((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 16777215ULL))) - ((NI)8388608)) - ((NI)1));
				eqcopy___ast_u3255(&node_3, (*(*(*colonenv__1).c0).globals)._kind_6.sons.p->data[rb_96]);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1324_;
				eqcopy___ast_u3381(&typ_6, (*node_3).typField);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1324_;
				{
					NimStringV2 colontmpD__134;
					NimStringV2 colontmpD__135;
					NimStringV2 T1329_;
					if (!!(((*node_3).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)6)))) goto LA1327_;
					colontmpD__134.len = 0; colontmpD__134.p = NIM_NIL;
					colontmpD__135.len = 0; colontmpD__135.p = NIM_NIL;
					T1329_.len = 0; T1329_.p = NIM_NIL;
					colontmpD__134 = dollar___nodekinds_u168((*node_3).kind);
					T1329_ = rawNewString(colontmpD__134.len + 40);
appendString((&T1329_), TM__pyAIA9cUF0h9c4j2HfNQPfYw_468);
appendString((&T1329_), colontmpD__134);
					colontmpD__135 = T1329_;
					failedAssertImpl__stdZassertions_u79(colontmpD__135);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1324_;
					eqdestroy___system_u2691(colontmpD__135);
					eqdestroy___system_u2691(colontmpD__134);
				}
LA1327_: ;
				{
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* node2_2;
					if (!((*typ_6).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)21))) goto LA1332_;
					node2_2 = NIM_NIL;
					ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA1324_;
					node2_2 = newNodeIT__ast_u4112(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)6), (*(*colonenv__1).c0).debug.p->data[(*colonenv__1).pc2], typ_6);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1324_;
					(*node2_2)._kind_1.intVal = ((NI64) ((*((NI*) ((*node_3)._kind_1.intVal)))));
					(*node2_2).flags |= ((NU32)1)<<(((((tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw)14))) & 31);
					eqsink___ast_u3261(&(*(*colonenv__1).tos1).slots.p->data[ra_1].node, node2_2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1324_;
				}
				goto LA1330_;
LA1332_: ;
				{
					NIM_BOOL T1335_;
					NimStringV2 colontmpD__136;
					tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__137;
					NimStringV2 colontmpD__138;
					NimStringV2 colontmpD__139;
					NimStringV2 T1339_;
					tyTuple__dsvP9bgd7x7RN0ykJDjb3Sg T1340_;
					tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T1341_;
					T1335_ = (NIM_BOOL)0;
					T1335_ = derefPtrToReg__vm_u144((*node_3)._kind_1.intVal, typ_6, (&(*(*colonenv__1).tos1).slots.p->data[ra_1]), NIM_FALSE);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1324_;
					if (!!(T1335_)) goto LA1336_;
					colontmpD__136.len = 0; colontmpD__136.p = NIM_NIL;
					colontmpD__137 = NIM_NIL;
					colontmpD__138.len = 0; colontmpD__138.p = NIM_NIL;
					colontmpD__139.len = 0; colontmpD__139.p = NIM_NIL;
					T1339_.len = 0; T1339_.p = NIM_NIL;
					colontmpD__136 = typeToString__types_u54(typ_6, ((tyEnum_TPreferedDesc__ddj0M89bv09cBYthgD4XTq3Q)0));
					if (NIM_UNLIKELY(*nimErr_)) goto LA1338_;
					T1340_.Field0 = colontmpD__136;
					colontmpD__137 = elementType__ast_u5331(typ_6);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1338_;
					T1340_.Field1 = (*colontmpD__137).kind;
					colontmpD__138 = dollar___vm_u1803(T1340_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1338_;
					T1339_ = rawNewString(colontmpD__138.len + 29);
appendString((&T1339_), TM__pyAIA9cUF0h9c4j2HfNQPfYw_470);
appendString((&T1339_), colontmpD__138);
					colontmpD__139 = T1339_;
					nimZeroMem((void*)(&T1341_), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
					stackTraceImpl__vm_u73((*colonenv__1).c0, (*colonenv__1).tos1, (*colonenv__1).pc2, colontmpD__139, T1341_, TM__pyAIA9cUF0h9c4j2HfNQPfYw_230);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1338_;
					eqdestroy___system_u2691(colontmpD__139);
					eqdestroy___system_u2691(colontmpD__138);
					eqdestroy___ast_u3378(colontmpD__137);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1324_;
					eqdestroy___system_u2691(colontmpD__136);
					eqdestroy___ast_u3378(typ_6);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___ast_u3252(node_3);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___vmprofiler_u19(savedFrame_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					eqdestroy___vm_u14829(colonenv__1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					goto BeforeRet_;
					{
						LA1338_:;
					}
					{
						oldNimErrFin1338_ = *nimErr_; *nimErr_ = NIM_FALSE;
						eqdestroy___system_u2691(colontmpD__139);
						eqdestroy___system_u2691(colontmpD__138);
						eqdestroy___ast_u3378(colontmpD__137);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1324_;
						eqdestroy___system_u2691(colontmpD__136);
						*nimErr_ = oldNimErrFin1338_;
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA1324_;
				}
				goto LA1330_;
LA1336_: ;
LA1330_: ;
				{
					LA1324_:;
				}
				{
					oldNimErrFin1324_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3378(typ_6);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___ast_u3252(node_3);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin1324_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)184):
			{
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* node_4;
				tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_7;
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* node2_3;
				NI rb_97;
				node_4 = NIM_NIL;
				typ_7 = NIM_NIL;
				node2_3 = NIM_NIL;
				rb_97 = (NI)((NI)(((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 16777215ULL))) - ((NI)8388608)) - ((NI)1));
				eqcopy___ast_u3255(&node_4, (*(*(*colonenv__1).c0).globals)._kind_6.sons.p->data[rb_97]);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				eqcopy___ast_u3381(&typ_7, (*node_4).typField);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				node2_3 = newNodeIT__ast_u4112(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)6), (*node_4).info, typ_7);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				(*node2_3)._kind_1.intVal = (*node_4)._kind_1.intVal;
				(*node2_3).flags |= ((NU32)1)<<(((((tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw)14))) & 31);
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				eqsink___ast_u3261(&(*(*colonenv__1).tos1).slots.p->data[ra_1].node, node2_3);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				eqdestroy___ast_u3378(typ_7);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				eqdestroy___ast_u3252(node_4);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)182):
			{
				NI rb_98;
				rb_98 = (NI)((NI)(((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 16777215ULL))) - ((NI)8388608)) - ((NI)1));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)5));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				(*(*colonenv__1).tos1).slots.p->data[ra_1].nodeAddr = &(*(*(*colonenv__1).c0).globals)._kind_6.sons.p->data[rb_98];
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)88):
			{
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__140;
				NI rb_99;
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T1350_;
				NimStringV2 T1351_;
				colontmpD__140 = NIM_NIL;
				rb_99 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1349_;
				T1350_ = NIM_NIL;
				T1350_ = newNode__ast_u4069(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)20));
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T1350_); goto LA1349_;}
				eqsink___ast_u3261(&(*(*colonenv__1).tos1).slots.p->data[ra_1].node, T1350_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1349_;
				colontmpD__140 = regToNode__vm_u542((*(*colonenv__1).tos1).slots.p->data[rb_99]);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1349_;
				T1351_.len = 0; T1351_.p = NIM_NIL;
				T1351_ = renderTree__renderer_u59(colontmpD__140, 1036);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T1351_); goto LA1349_;}
				eqsink___system_u2700((&(*(*(*colonenv__1).tos1).slots.p->data[ra_1].node)._kind_3.strVal), T1351_);
				{
					LA1349_:;
				}
				{
					oldNimErrFin1349_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3252(colontmpD__140);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin1349_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)97):
			{
				{
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__141;
					tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T1360_;
					tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T1361_;
					NI T1362_;
					if (!((*(*colonenv__1).c0).mode == ((tyEnum_TEvalMode__sQljSFf0fjnsNV1fpgXakg)0) || (*(*colonenv__1).c0).mode == ((tyEnum_TEvalMode__sQljSFf0fjnsNV1fpgXakg)3) || (*(*colonenv__1).c0).mode == ((tyEnum_TEvalMode__sQljSFf0fjnsNV1fpgXakg)4))) goto LA1357_;
					colontmpD__141 = NIM_NIL;
					liMessage__msgs_u1227((*(*colonenv__1).c0).config, (*(*colonenv__1).c0).debug.p->data[(*colonenv__1).pc2], ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)98), TM__pyAIA9cUF0h9c4j2HfNQPfYw_471, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), TM__pyAIA9cUF0h9c4j2HfNQPfYw_472, NIM_FALSE, NIM_FALSE);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1359_;
					colontmpD__141 = regToNode__vm_u542((*(*colonenv__1).tos1).slots.p->data[ra_1]);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1359_;
					T1360_ = toInt128__types_u1207(((NI)1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA1359_;
					T1361_ = getOrdValue__types_u171(colontmpD__141, T1360_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1359_;
					T1362_ = (NI)0;
					T1362_ = toInt__int128_u257(T1361_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1359_;
					msgQuit__msgs_u479(((NI8) (T1362_)));
					if (NIM_UNLIKELY(*nimErr_)) goto LA1359_;
					{
						LA1359_:;
					}
					{
						oldNimErrFin1359_ = *nimErr_; *nimErr_ = NIM_FALSE;
						eqdestroy___ast_u3252(colontmpD__141);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						*nimErr_ = oldNimErrFin1359_;
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				}
				goto LA1355_;
LA1357_: ;
				{
					nimZeroMem((void*)Result, sizeof(tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A));
					(*Result).kind = ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)0);
					eqdestroy___vmprofiler_u19(savedFrame_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					eqdestroy___vm_u14829(colonenv__1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					goto BeforeRet_;
				}
LA1355_: ;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)98):
			{
				NimStringV2 msg_1;
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* disc_1;
				NimStringV2 msg2_1;
				NimStringV2 colontmpD__142;
				NimStringV2 T1368_;
				tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T1369_;
				msg_1.len = 0; msg_1.p = NIM_NIL;
				disc_1 = NIM_NIL;
				msg2_1.len = 0; msg2_1.p = NIM_NIL;
				colontmpD__142.len = 0; colontmpD__142.p = NIM_NIL;
				eqcopy___system_u2694((&msg_1), (*(*(*colonenv__1).tos1).slots.p->data[ra_1].node)._kind_3.strVal);
				disc_1 = regToNode__vm_u542((*(*colonenv__1).tos1).slots.p->data[((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)))]);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1367_;
				T1368_.len = 0; T1368_.p = NIM_NIL;
				colontmpD__142 = dollar___renderer_u2166(disc_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1367_;
				T1368_ = rawNewString(msg_1.len + colontmpD__142.len + 1);
appendString((&T1368_), msg_1);
appendString((&T1368_), colontmpD__142);
appendString((&T1368_), TM__pyAIA9cUF0h9c4j2HfNQPfYw_474);
				msg2_1 = T1368_;
				nimZeroMem((void*)(&T1369_), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
				stackTraceImpl__vm_u73((*colonenv__1).c0, (*colonenv__1).tos1, (*colonenv__1).pc2, msg2_1, T1369_, TM__pyAIA9cUF0h9c4j2HfNQPfYw_230);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1367_;
				eqdestroy___system_u2691(colontmpD__142);
				eqdestroy___system_u2691(msg2_1);
				eqdestroy___ast_u3252(disc_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				eqdestroy___system_u2691(msg_1);
				eqdestroy___vmprofiler_u19(savedFrame_1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				eqdestroy___vm_u14829(colonenv__1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				goto BeforeRet_;
				{
					LA1367_:;
				}
				{
					oldNimErrFin1367_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___system_u2691(colontmpD__142);
					eqdestroy___system_u2691(msg2_1);
					eqdestroy___ast_u3252(disc_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___system_u2691(msg_1);
					*nimErr_ = oldNimErrFin1367_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)89):
			{
				NI rb_100;
				rb_100 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				setLengthStrV2((&(*(*(*colonenv__1).tos1).slots.p->data[ra_1].node)._kind_3.strVal), (((NI) ((*(*colonenv__1).tos1).slots.p->data[rb_100].intVal))));
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)92):
			{
				tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_8;
				NI rb_101;
				NI rc_62;
				NI T1375_;
				typ_8 = NIM_NIL;
				rb_101 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				rc_62 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(40ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1374_;
				eqcopy___ast_u3381(&typ_8, (*(*colonenv__1).c0).types.p->data[((NI) ((*(*colonenv__1).tos1).slots.p->data[rc_62].intVal))]);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1374_;
				T1375_ = (NI)0;
				T1375_ = inheritanceDiff__types_u2785((*(*(*colonenv__1).tos1).slots.p->data[rb_101].node).typField, typ_8);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1374_;
				(*(*colonenv__1).tos1).slots.p->data[ra_1].intVal = ((NI64) ((T1375_ <= ((NI)0))));
				{
					LA1374_:;
				}
				{
					oldNimErrFin1374_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3378(typ_8);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin1374_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)93):
			{
				tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t1_1;
				tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t2_1;
				NIM_BOOL colontmpD__143;
				NIM_BOOL colontmpD__144;
				NI rb_102;
				NI rc_63;
				NIM_BOOL match_1;
				t1_1 = NIM_NIL;
				t2_1 = NIM_NIL;
				colontmpD__143 = (NIM_BOOL)0;
				colontmpD__144 = (NIM_BOOL)0;
				rb_102 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				rc_63 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(40ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1379_;
				t1_1 = skipTypes__ast_u5379((*(*(*colonenv__1).tos1).slots.p->data[rb_102].node).typField, TM__pyAIA9cUF0h9c4j2HfNQPfYw_475);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1379_;
				eqcopy___ast_u3381(&t2_1, (*(*colonenv__1).c0).types.p->data[((NI) ((*(*colonenv__1).tos1).slots.p->data[rc_63].intVal))]);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1379_;
				{
					if (!((*t2_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)52))) goto LA1382_;
					colontmpD__143 = NIM_TRUE;
					match_1 = colontmpD__143;
				}
				goto LA1380_;
LA1382_: ;
				{
					tySet_tyEnum_TTypeCmpFlag__1219bojhd9apB6FQkQGJbzzQ T1386_;
					T1386_ = 0;
					colontmpD__144 = sameType__types_u1812(t1_1, t2_1, T1386_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1385_;
					match_1 = colontmpD__144;
					{
						LA1385_:;
					}
					{
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA1379_;
				}
LA1380_: ;
				(*(*colonenv__1).tos1).slots.p->data[ra_1].intVal = ((NI64) (match_1));
				{
					LA1379_:;
				}
				{
					oldNimErrFin1379_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3378(t2_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___ast_u3378(t1_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin1379_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)90):
			{
				NI rb_103;
				NI newLen_1;
				rb_103 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				newLen_1 = ((NI) ((*(*colonenv__1).tos1).slots.p->data[rb_103].intVal));
				{
					tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T1396_;
					if (!((*(*colonenv__1).tos1).slots.p->data[ra_1].node == 0)) goto LA1394_;
					nimZeroMem((void*)(&T1396_), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
					stackTraceImpl__vm_u73((*colonenv__1).c0, (*colonenv__1).tos1, (*colonenv__1).pc2, TM__pyAIA9cUF0h9c4j2HfNQPfYw_476, T1396_, TM__pyAIA9cUF0h9c4j2HfNQPfYw_230);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___vmprofiler_u19(savedFrame_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					eqdestroy___vm_u14829(colonenv__1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					goto BeforeRet_;
				}
				goto LA1392_;
LA1394_: ;
				{
					setLenSeq__vm_u823((*colonenv__1).c0, (*(*colonenv__1).tos1).slots.p->data[ra_1].node, newLen_1, (*(*colonenv__1).c0).debug.p->data[(*colonenv__1).pc2]);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				}
LA1392_: ;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)99):
			{
				NI rb_104;
				NI64 min_1;
				NI64 max_1;
				rb_104 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				min_1 = -((NI64)((NU64)(IL64(1)) << (NU64)((NI)(rb_104 - ((NI)1)) & (64 - 1))));
				max_1 = (NI64)((NI64)((NU64)(IL64(1)) << (NU64)((NI)(rb_104 - ((NI)1)) & (64 - 1))) - IL64(1));
				{
					NIM_BOOL T1401_;
					tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T1405_;
					T1401_ = (NIM_BOOL)0;
					T1401_ = ((*(*colonenv__1).tos1).slots.p->data[ra_1].intVal < min_1);
					if (T1401_) goto LA1402_;
					T1401_ = (max_1 < (*(*colonenv__1).tos1).slots.p->data[ra_1].intVal);
LA1402_: ;
					if (!T1401_) goto LA1403_;
					nimZeroMem((void*)(&T1405_), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
					stackTraceImpl__vm_u73((*colonenv__1).c0, (*colonenv__1).tos1, (*colonenv__1).pc2, TM__pyAIA9cUF0h9c4j2HfNQPfYw_478, T1405_, TM__pyAIA9cUF0h9c4j2HfNQPfYw_230);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___vmprofiler_u19(savedFrame_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					eqdestroy___vm_u14829(colonenv__1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					goto BeforeRet_;
				}
LA1403_: ;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)101):
			{
				NI rb_105;
				NI rc_64;
				NI64 min_2;
				NI64 max_2;
				rb_105 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				rc_64 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(40ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				min_2 = (*(*colonenv__1).tos1).slots.p->data[rb_105].intVal;
				max_2 = (*(*colonenv__1).tos1).slots.p->data[rc_64].intVal;
				{
					NIM_BOOL T1409_;
					tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T1413_;
					T1409_ = (NIM_BOOL)0;
					T1409_ = ((*(*colonenv__1).tos1).slots.p->data[ra_1].intVal < min_2);
					if (T1409_) goto LA1410_;
					T1409_ = (max_2 < (*(*colonenv__1).tos1).slots.p->data[ra_1].intVal);
LA1410_: ;
					if (!T1409_) goto LA1411_;
					nimZeroMem((void*)(&T1413_), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
					stackTraceImpl__vm_u73((*colonenv__1).c0, (*colonenv__1).tos1, (*colonenv__1).pc2, TM__pyAIA9cUF0h9c4j2HfNQPfYw_479, T1413_, TM__pyAIA9cUF0h9c4j2HfNQPfYw_230);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___vmprofiler_u19(savedFrame_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					eqdestroy___vm_u14829(colonenv__1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					goto BeforeRet_;
				}
LA1411_: ;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)100):
			{
				NI rb_106;
				rb_106 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				(*(*colonenv__1).tos1).slots.p->data[ra_1].intVal = (NI64)((*(*colonenv__1).tos1).slots.p->data[ra_1].intVal & (NI64)((NI64)((NU64)(IL64(1)) << (NU64)(rb_106 & (64 - 1))) - IL64(1)));
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)102):
			{
				NI rb_107;
				NI imm_7;
				rb_107 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				imm_7 = (NI)(((NI)64) - rb_107);
				(*(*colonenv__1).tos1).slots.p->data[ra_1].intVal = (NI64)((NI64)((NI64)((NU64)((*(*colonenv__1).tos1).slots.p->data[ra_1].intVal) << (NU64)(imm_7 & (64 - 1)))) >> (NU64)(imm_7 & (64 - 1)));
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)91):
			{
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* node_5;
				NI rb_108;
				NIM_BOOL T1417_;
				NIM_BOOL T1418_;
				NIM_BOOL T1421_;
				NIM_BOOL T1422_;
				NIM_BOOL T1423_;
				NIM_BOOL T1424_;
				NIM_BOOL T1425_;
				NI T1429_;
				node_5 = NIM_NIL;
				rb_108 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				eqcopy___ast_u3255(&node_5, (*(*colonenv__1).tos1).slots.p->data[rb_108].node);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				T1417_ = (NIM_BOOL)0;
				T1418_ = (NIM_BOOL)0;
				T1418_ = ((*node_5).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)23));
				if (!(T1418_)) goto LA1419_;
				T1418_ = !((((*node_5).flags &((NU32)1<<((NU)((((tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw)13)))&31U)))!=0));
LA1419_: ;
				T1417_ = T1418_;
				if (T1417_) goto LA1420_;
				T1421_ = (NIM_BOOL)0;
				T1422_ = (NIM_BOOL)0;
				T1423_ = (NIM_BOOL)0;
				T1424_ = (NIM_BOOL)0;
				T1425_ = (NIM_BOOL)0;
				T1425_ = !(((*node_5).typField == 0));
				if (!(T1425_)) goto LA1426_;
				T1425_ = ((*(*node_5).typField).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)25));
LA1426_: ;
				T1424_ = T1425_;
				if (!(T1424_)) goto LA1427_;
				T1424_ = ((*(*node_5).typField).callConv == ((tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ)9));
LA1427_: ;
				T1423_ = T1424_;
				if (!(T1423_)) goto LA1428_;
				T1429_ = (NI)0;
				T1429_ = safeLen__ast_u3197(node_5);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				T1423_ = (((NI)0) < T1429_);
LA1428_: ;
				T1422_ = T1423_;
				if (!(T1422_)) goto LA1430_;
				T1422_ = ((*(*node_5)._kind_6.sons.p->data[((NI)0)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)23));
LA1430_: ;
				T1421_ = T1422_;
				if (!(T1421_)) goto LA1431_;
				T1421_ = ((*(*node_5)._kind_6.sons.p->data[((NI)1)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)23));
LA1431_: ;
				T1417_ = T1421_;
LA1420_: ;
				(*(*colonenv__1).tos1).slots.p->data[ra_1].intVal = ((NI64) (T1417_));
				eqdestroy___ast_u3252(node_5);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)186):
			{
				NI rbx_8;
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T1433_;
				rbx_8 = (NI)(((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 16777215ULL))) - ((NI)8388608));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				T1433_ = NIM_NIL;
				T1433_ = copyTree__ast_u6891((*(*(*colonenv__1).c0).constants)._kind_6.sons.p->data[rbx_8]);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T1433_); goto LA1_;}
				eqsink___ast_u3261(&(*(*colonenv__1).tos1).slots.p->data[ra_1].node, T1433_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				(*(*(*colonenv__1).tos1).slots.p->data[ra_1].node).flags |= ((NU32)1)<<(((((tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw)13))) & 31);
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)187):
			{
				tyProc__c9bXGQkBnyyGGVw063jrwZw callback_1;
				tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg args_1;
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__145;
				tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA colontmpD__146;
				NI rb_109;
				NI rc_65;
				NI idx_7;
				nimZeroMem((void*)(&callback_1), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
				nimZeroMem((void*)(&args_1), sizeof(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg));
				rb_109 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				rc_65 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(40ULL & (64 - 1))) & 65535ULL)));
				idx_7 = ((NI) ((*(*colonenv__1).tos1).slots.p->data[(NI)((NI)(rb_109 + rc_65) - ((NI)1))].intVal));
				eqcopy___vmdef_u1388((&callback_1), (*(*colonenv__1).c0).callbacks.p->data[idx_7], NIM_FALSE);
				args_1.ra = ra_1;
				args_1.rb = rb_109;
				args_1.rc = rc_65;
				args_1.slots = ((tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A*) ((&(*(*colonenv__1).tos1).slots.p->data[((NI)0)])));
				colontmpD__145 = eqdup___ast_u3258((*(*colonenv__1).c0).currentExceptionA);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				args_1.currentException = colontmpD__145;
				colontmpD__146 = eqdup___lineinfos_u2037((*(*colonenv__1).c0).debug.p->data[(*colonenv__1).pc2]);
				args_1.currentLineInfo = colontmpD__146;
				callback_1.ClE_0? callback_1.ClP_0((&args_1), callback_1.ClE_0):((TM__pyAIA9cUF0h9c4j2HfNQPfYw_480)(callback_1.ClP_0))((&args_1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				(*(*(*colonenv__1).tos1).slots.p->data[ra_1].node).flags |= ((NU32)1)<<(((((tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw)13))) & 31);
				eqdestroy___vm_u12910((&args_1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				eqdestroy___vmdef_u1385(callback_1);
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)162):
			{
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* src_6;
				NI rb_110;
				NI rc_66;
				NI idx_8;
				src_6 = NIM_NIL;
				rb_110 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				rc_66 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(40ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1436_;
				idx_8 = ((NI) ((*(*colonenv__1).tos1).slots.p->data[rc_66].intVal));
				eqcopy___ast_u3255(&src_6, (*(*colonenv__1).tos1).slots.p->data[rb_110].node);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1436_;
				{
					NimStringV2 colontmpD__147;
					NimStringV2 colontmpD__148;
					NimStringV2 T1442_;
					tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T1443_;
					if (!((*src_6).kind >= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)1) && (*src_6).kind <= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)23))) goto LA1439_;
					colontmpD__147.len = 0; colontmpD__147.p = NIM_NIL;
					colontmpD__148.len = 0; colontmpD__148.p = NIM_NIL;
					T1442_.len = 0; T1442_.p = NIM_NIL;
					colontmpD__147 = dollar___nodekinds_u168((*src_6).kind);
					T1442_ = rawNewString(colontmpD__147.len + 32);
appendString((&T1442_), TM__pyAIA9cUF0h9c4j2HfNQPfYw_482);
appendString((&T1442_), colontmpD__147);
					colontmpD__148 = T1442_;
					nimZeroMem((void*)(&T1443_), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
					stackTraceImpl__vm_u73((*colonenv__1).c0, (*colonenv__1).tos1, (*colonenv__1).pc2, colontmpD__148, T1443_, TM__pyAIA9cUF0h9c4j2HfNQPfYw_230);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1441_;
					eqdestroy___system_u2691(colontmpD__148);
					eqdestroy___system_u2691(colontmpD__147);
					eqdestroy___ast_u3252(src_6);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___vmprofiler_u19(savedFrame_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					eqdestroy___vm_u14829(colonenv__1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					goto BeforeRet_;
					{
						LA1441_:;
					}
					{
						eqdestroy___system_u2691(colontmpD__148);
						eqdestroy___system_u2691(colontmpD__147);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA1436_;
				}
				goto LA1437_;
LA1439_: ;
				{
					NI T1447_;
					NIM_BOOL T1448_;
					NimStringV2 colontmpD__149;
					NimStringV2 colontmpD__150;
					NimStringV2 T1452_;
					tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T1461_;
					T1447_ = (NI)0;
					T1447_ = len__ast_u3190(src_6);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1436_;
					T1448_ = (NIM_BOOL)0;
					T1448_ = lteqpercent___system_u1072(T1447_, idx_8);
					if (!T1448_) goto LA1449_;
					colontmpD__149.len = 0; colontmpD__149.p = NIM_NIL;
					colontmpD__150.len = 0; colontmpD__150.p = NIM_NIL;
					T1452_.len = 0; T1452_.p = NIM_NIL;
					{
						NI T1455_;
						T1455_ = (NI)0;
						T1455_ = len__ast_u3190(src_6);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1451_;
						if (!((NI)(T1455_ - ((NI)1)) < ((NI)0))) goto LA1456_;
						colontmpD__149 = TM__pyAIA9cUF0h9c4j2HfNQPfYw_483;
						T1452_ = colontmpD__149;
					}
					goto LA1453_;
LA1456_: ;
					{
						NimStringV2 colontmpD__151;
						NimStringV2 colontmpD__152;
						NimStringV2 T1459_;
						NI T1460_;
						colontmpD__151.len = 0; colontmpD__151.p = NIM_NIL;
						colontmpD__152.len = 0; colontmpD__152.p = NIM_NIL;
						T1459_.len = 0; T1459_.p = NIM_NIL;
						colontmpD__151 = dollar___systemZdollars_u9(idx_8);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1451_;
						T1460_ = (NI)0;
						T1460_ = len__ast_u3190(src_6);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1451_;
						colontmpD__152 = dollar___systemZdollars_u9((NI)(T1460_ - ((NI)1)));
						if (NIM_UNLIKELY(*nimErr_)) goto LA1451_;
						T1459_ = rawNewString(colontmpD__151.len + colontmpD__152.len + 19);
appendString((&T1459_), TM__pyAIA9cUF0h9c4j2HfNQPfYw_484);
appendString((&T1459_), colontmpD__151);
appendString((&T1459_), TM__pyAIA9cUF0h9c4j2HfNQPfYw_485);
appendString((&T1459_), colontmpD__152);
						colontmpD__150 = T1459_;
						eqdestroy___system_u2691(colontmpD__152);
						eqdestroy___system_u2691(colontmpD__151);
						T1452_ = colontmpD__150;
					}
LA1453_: ;
					nimZeroMem((void*)(&T1461_), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
					stackTraceImpl__vm_u73((*colonenv__1).c0, (*colonenv__1).tos1, (*colonenv__1).pc2, T1452_, T1461_, TM__pyAIA9cUF0h9c4j2HfNQPfYw_230);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1451_;
					eqdestroy___system_u2691(colontmpD__150);
					eqdestroy___system_u2691(colontmpD__149);
					eqdestroy___ast_u3252(src_6);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___vmprofiler_u19(savedFrame_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					eqdestroy___vm_u14829(colonenv__1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					goto BeforeRet_;
					{
						LA1451_:;
					}
					{
						eqdestroy___system_u2691(colontmpD__150);
						eqdestroy___system_u2691(colontmpD__149);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA1436_;
				}
				goto LA1437_;
LA1449_: ;
				{
					eqcopy___ast_u3255(&(*(*colonenv__1).tos1).slots.p->data[ra_1].node, (*src_6)._kind_6.sons.p->data[idx_8]);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1436_;
				}
LA1437_: ;
				{
					LA1436_:;
				}
				{
					oldNimErrFin1436_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3252(src_6);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin1436_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)163):
			{
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* dest_2;
				NI rb_111;
				NI rc_67;
				NI idx_9;
				dest_2 = NIM_NIL;
				rb_111 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				rc_67 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(40ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1468_;
				idx_9 = ((NI) ((*(*colonenv__1).tos1).slots.p->data[rb_111].intVal));
				eqcopy___ast_u3255(&dest_2, (*(*colonenv__1).tos1).slots.p->data[ra_1].node);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1468_;
				{
					NIM_BOOL T1471_;
					tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T1475_;
					T1471_ = (NIM_BOOL)0;
					T1471_ = (((*dest_2).flags &((NU32)1<<((NU)((((tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw)7)))&31U)))!=0);
					if (!(T1471_)) goto LA1472_;
					T1471_ = !((((*(*(*colonenv__1).c0).config).legacyFeatures &((NU8)1<<((NU)((((tyEnum_LegacyFeature__yvNVqOQTgcxHpvo1MvfBfA)0)))&7U)))!=0));
LA1472_: ;
					if (!T1471_) goto LA1473_;
					nimZeroMem((void*)(&T1475_), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
					stackTraceImpl__vm_u73((*colonenv__1).c0, (*colonenv__1).tos1, (*colonenv__1).pc2, TM__pyAIA9cUF0h9c4j2HfNQPfYw_487, T1475_, TM__pyAIA9cUF0h9c4j2HfNQPfYw_230);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1468_;
					eqdestroy___ast_u3252(dest_2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___vmprofiler_u19(savedFrame_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					eqdestroy___vm_u14829(colonenv__1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					goto BeforeRet_;
				}
				goto LA1469_;
LA1473_: ;
				{
					NimStringV2 colontmpD__153;
					NimStringV2 colontmpD__154;
					NimStringV2 T1480_;
					tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T1481_;
					if (!((*dest_2).kind >= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)1) && (*dest_2).kind <= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)23))) goto LA1477_;
					colontmpD__153.len = 0; colontmpD__153.p = NIM_NIL;
					colontmpD__154.len = 0; colontmpD__154.p = NIM_NIL;
					T1480_.len = 0; T1480_.p = NIM_NIL;
					colontmpD__153 = dollar___nodekinds_u168((*dest_2).kind);
					T1480_ = rawNewString(colontmpD__153.len + 32);
appendString((&T1480_), TM__pyAIA9cUF0h9c4j2HfNQPfYw_489);
appendString((&T1480_), colontmpD__153);
					colontmpD__154 = T1480_;
					nimZeroMem((void*)(&T1481_), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
					stackTraceImpl__vm_u73((*colonenv__1).c0, (*colonenv__1).tos1, (*colonenv__1).pc2, colontmpD__154, T1481_, TM__pyAIA9cUF0h9c4j2HfNQPfYw_230);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1479_;
					eqdestroy___system_u2691(colontmpD__154);
					eqdestroy___system_u2691(colontmpD__153);
					eqdestroy___ast_u3252(dest_2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___vmprofiler_u19(savedFrame_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					eqdestroy___vm_u14829(colonenv__1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					goto BeforeRet_;
					{
						LA1479_:;
					}
					{
						eqdestroy___system_u2691(colontmpD__154);
						eqdestroy___system_u2691(colontmpD__153);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA1468_;
				}
				goto LA1469_;
LA1477_: ;
				{
					NI T1485_;
					NIM_BOOL T1486_;
					NimStringV2 colontmpD__155;
					NimStringV2 colontmpD__156;
					NimStringV2 T1490_;
					tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T1499_;
					T1485_ = (NI)0;
					T1485_ = len__ast_u3190(dest_2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1468_;
					T1486_ = (NIM_BOOL)0;
					T1486_ = lteqpercent___system_u1072(T1485_, idx_9);
					if (!T1486_) goto LA1487_;
					colontmpD__155.len = 0; colontmpD__155.p = NIM_NIL;
					colontmpD__156.len = 0; colontmpD__156.p = NIM_NIL;
					T1490_.len = 0; T1490_.p = NIM_NIL;
					{
						NI T1493_;
						T1493_ = (NI)0;
						T1493_ = len__ast_u3190(dest_2);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1489_;
						if (!((NI)(T1493_ - ((NI)1)) < ((NI)0))) goto LA1494_;
						colontmpD__155 = TM__pyAIA9cUF0h9c4j2HfNQPfYw_490;
						T1490_ = colontmpD__155;
					}
					goto LA1491_;
LA1494_: ;
					{
						NimStringV2 colontmpD__157;
						NimStringV2 colontmpD__158;
						NimStringV2 T1497_;
						NI T1498_;
						colontmpD__157.len = 0; colontmpD__157.p = NIM_NIL;
						colontmpD__158.len = 0; colontmpD__158.p = NIM_NIL;
						T1497_.len = 0; T1497_.p = NIM_NIL;
						colontmpD__157 = dollar___systemZdollars_u9(idx_9);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1489_;
						T1498_ = (NI)0;
						T1498_ = len__ast_u3190(dest_2);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1489_;
						colontmpD__158 = dollar___systemZdollars_u9((NI)(T1498_ - ((NI)1)));
						if (NIM_UNLIKELY(*nimErr_)) goto LA1489_;
						T1497_ = rawNewString(colontmpD__157.len + colontmpD__158.len + 19);
appendString((&T1497_), TM__pyAIA9cUF0h9c4j2HfNQPfYw_491);
appendString((&T1497_), colontmpD__157);
appendString((&T1497_), TM__pyAIA9cUF0h9c4j2HfNQPfYw_492);
appendString((&T1497_), colontmpD__158);
						colontmpD__156 = T1497_;
						eqdestroy___system_u2691(colontmpD__158);
						eqdestroy___system_u2691(colontmpD__157);
						T1490_ = colontmpD__156;
					}
LA1491_: ;
					nimZeroMem((void*)(&T1499_), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
					stackTraceImpl__vm_u73((*colonenv__1).c0, (*colonenv__1).tos1, (*colonenv__1).pc2, T1490_, T1499_, TM__pyAIA9cUF0h9c4j2HfNQPfYw_230);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1489_;
					eqdestroy___system_u2691(colontmpD__156);
					eqdestroy___system_u2691(colontmpD__155);
					eqdestroy___ast_u3252(dest_2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___vmprofiler_u19(savedFrame_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					eqdestroy___vm_u14829(colonenv__1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					goto BeforeRet_;
					{
						LA1489_:;
					}
					{
						eqdestroy___system_u2691(colontmpD__156);
						eqdestroy___system_u2691(colontmpD__155);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA1468_;
				}
				goto LA1469_;
LA1487_: ;
				{
					eqcopy___ast_u3255(&(*dest_2)._kind_6.sons.p->data[idx_9], (*(*colonenv__1).tos1).slots.p->data[rc_67].node);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1468_;
				}
LA1469_: ;
				{
					LA1468_:;
				}
				{
					oldNimErrFin1468_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3252(dest_2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin1468_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)107):
			{
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* u_1;
				NI rb_112;
				NI rc_68;
				u_1 = NIM_NIL;
				rb_112 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				rc_68 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(40ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1506_;
				eqcopy___ast_u3255(&u_1, (*(*colonenv__1).tos1).slots.p->data[rb_112].node);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1506_;
				{
					NIM_BOOL T1509_;
					tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T1513_;
					T1509_ = (NIM_BOOL)0;
					T1509_ = (((*u_1).flags &((NU32)1<<((NU)((((tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw)7)))&31U)))!=0);
					if (!(T1509_)) goto LA1510_;
					T1509_ = !((((*(*(*colonenv__1).c0).config).legacyFeatures &((NU8)1<<((NU)((((tyEnum_LegacyFeature__yvNVqOQTgcxHpvo1MvfBfA)0)))&7U)))!=0));
LA1510_: ;
					if (!T1509_) goto LA1511_;
					nimZeroMem((void*)(&T1513_), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
					stackTraceImpl__vm_u73((*colonenv__1).c0, (*colonenv__1).tos1, (*colonenv__1).pc2, TM__pyAIA9cUF0h9c4j2HfNQPfYw_493, T1513_, TM__pyAIA9cUF0h9c4j2HfNQPfYw_230);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1506_;
					eqdestroy___ast_u3252(u_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___vmprofiler_u19(savedFrame_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					eqdestroy___vm_u14829(colonenv__1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					goto BeforeRet_;
				}
				goto LA1507_;
LA1511_: ;
				{
					NimStringV2 colontmpD__159;
					NimStringV2 colontmpD__160;
					NimStringV2 T1518_;
					tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T1519_;
					if (!((*u_1).kind >= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)1) && (*u_1).kind <= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)23))) goto LA1515_;
					colontmpD__159.len = 0; colontmpD__159.p = NIM_NIL;
					colontmpD__160.len = 0; colontmpD__160.p = NIM_NIL;
					T1518_.len = 0; T1518_.p = NIM_NIL;
					colontmpD__159 = dollar___nodekinds_u168((*u_1).kind);
					T1518_ = rawNewString(colontmpD__159.len + 26);
appendString((&T1518_), TM__pyAIA9cUF0h9c4j2HfNQPfYw_495);
appendString((&T1518_), colontmpD__159);
					colontmpD__160 = T1518_;
					nimZeroMem((void*)(&T1519_), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
					stackTraceImpl__vm_u73((*colonenv__1).c0, (*colonenv__1).tos1, (*colonenv__1).pc2, colontmpD__160, T1519_, TM__pyAIA9cUF0h9c4j2HfNQPfYw_230);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1517_;
					eqdestroy___system_u2691(colontmpD__160);
					eqdestroy___system_u2691(colontmpD__159);
					eqdestroy___ast_u3252(u_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___vmprofiler_u19(savedFrame_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					eqdestroy___vm_u14829(colonenv__1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					goto BeforeRet_;
					{
						LA1517_:;
					}
					{
						eqdestroy___system_u2691(colontmpD__160);
						eqdestroy___system_u2691(colontmpD__159);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA1506_;
				}
				goto LA1507_;
LA1515_: ;
				{
					add__ast_u3215(u_1, (*(*colonenv__1).tos1).slots.p->data[rc_68].node);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1506_;
				}
LA1507_: ;
				eqsink___ast_u3261(&(*(*colonenv__1).tos1).slots.p->data[ra_1].node, u_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1506_;
				eqwasMoved___ast_u3249(&u_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1506_;
				{
					LA1506_:;
				}
				{
					oldNimErrFin1506_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3252(u_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin1506_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)108):
			{
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* x_1;
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* u_2;
				NI rb_113;
				NI rc_69;
				x_1 = NIM_NIL;
				u_2 = NIM_NIL;
				rb_113 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				rc_69 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(40ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1526_;
				eqcopy___ast_u3255(&x_1, (*(*colonenv__1).tos1).slots.p->data[rc_69].node);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1526_;
				eqcopy___ast_u3255(&u_2, (*(*colonenv__1).tos1).slots.p->data[rb_113].node);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1526_;
				{
					NIM_BOOL T1529_;
					tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T1533_;
					T1529_ = (NIM_BOOL)0;
					T1529_ = (((*u_2).flags &((NU32)1<<((NU)((((tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw)7)))&31U)))!=0);
					if (!(T1529_)) goto LA1530_;
					T1529_ = !((((*(*(*colonenv__1).c0).config).legacyFeatures &((NU8)1<<((NU)((((tyEnum_LegacyFeature__yvNVqOQTgcxHpvo1MvfBfA)0)))&7U)))!=0));
LA1530_: ;
					if (!T1529_) goto LA1531_;
					nimZeroMem((void*)(&T1533_), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
					stackTraceImpl__vm_u73((*colonenv__1).c0, (*colonenv__1).tos1, (*colonenv__1).pc2, TM__pyAIA9cUF0h9c4j2HfNQPfYw_496, T1533_, TM__pyAIA9cUF0h9c4j2HfNQPfYw_230);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1526_;
					eqdestroy___ast_u3252(u_2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___ast_u3252(x_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___vmprofiler_u19(savedFrame_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					eqdestroy___vm_u14829(colonenv__1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					goto BeforeRet_;
				}
				goto LA1527_;
LA1531_: ;
				{
					NimStringV2 colontmpD__161;
					NimStringV2 colontmpD__162;
					NimStringV2 T1538_;
					tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T1539_;
					if (!((*u_2).kind >= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)1) && (*u_2).kind <= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)23))) goto LA1535_;
					colontmpD__161.len = 0; colontmpD__161.p = NIM_NIL;
					colontmpD__162.len = 0; colontmpD__162.p = NIM_NIL;
					T1538_.len = 0; T1538_.p = NIM_NIL;
					colontmpD__161 = dollar___nodekinds_u168((*u_2).kind);
					T1538_ = rawNewString(colontmpD__161.len + 26);
appendString((&T1538_), TM__pyAIA9cUF0h9c4j2HfNQPfYw_497);
appendString((&T1538_), colontmpD__161);
					colontmpD__162 = T1538_;
					nimZeroMem((void*)(&T1539_), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
					stackTraceImpl__vm_u73((*colonenv__1).c0, (*colonenv__1).tos1, (*colonenv__1).pc2, colontmpD__162, T1539_, TM__pyAIA9cUF0h9c4j2HfNQPfYw_230);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1537_;
					eqdestroy___system_u2691(colontmpD__162);
					eqdestroy___system_u2691(colontmpD__161);
					eqdestroy___ast_u3252(u_2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___ast_u3252(x_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___vmprofiler_u19(savedFrame_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					eqdestroy___vm_u14829(colonenv__1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					goto BeforeRet_;
					{
						LA1537_:;
					}
					{
						eqdestroy___system_u2691(colontmpD__162);
						eqdestroy___system_u2691(colontmpD__161);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA1526_;
				}
				goto LA1527_;
LA1535_: ;
				{
					{
						NI i_13;
						NI colontmp__9;
						NI i_14;
						i_13 = (NI)0;
						colontmp__9 = (NI)0;
						colontmp__9 = len__ast_u3190(x_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1526_;
						i_14 = ((NI)0);
						{
							while (1) {
								if (!(i_14 < colontmp__9)) goto LA1545;
								i_13 = i_14;
								add__ast_u3215(u_2, (*x_1)._kind_6.sons.p->data[i_13]);
								if (NIM_UNLIKELY(*nimErr_)) goto LA1526_;
								i_14 += ((NI)1);
							} LA1545: ;
						}
					}
				}
LA1527_: ;
				eqsink___ast_u3261(&(*(*colonenv__1).tos1).slots.p->data[ra_1].node, u_2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1526_;
				eqwasMoved___ast_u3249(&u_2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1526_;
				{
					LA1526_:;
				}
				{
					oldNimErrFin1526_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3252(u_2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___ast_u3252(x_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin1526_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)109):
			{
				NI rb_114;
				rb_114 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				(*(*colonenv__1).tos1).slots.p->data[ra_1].intVal = ((NI64) ((*(*(*colonenv__1).tos1).slots.p->data[rb_114].node).kind));
				(*(*colonenv__1).c0).comesFromHeuristic = (*(*(*colonenv__1).tos1).slots.p->data[rb_114].node).info;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)110):
			{
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_8;
				NI rb_115;
				a_8 = NIM_NIL;
				rb_115 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1550_;
				eqcopy___ast_u3255(&a_8, (*(*colonenv__1).tos1).slots.p->data[rb_115].node);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1550_;
				{
					if (!((*a_8).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3))) goto LA1553_;
					(*(*colonenv__1).tos1).slots.p->data[ra_1].intVal = ((NI64) ((*(*a_8)._kind_4.sym).kind));
				}
				goto LA1551_;
LA1553_: ;
				{
					tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T1556_;
					nimZeroMem((void*)(&T1556_), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
					stackTraceImpl__vm_u73((*colonenv__1).c0, (*colonenv__1).tos1, (*colonenv__1).pc2, TM__pyAIA9cUF0h9c4j2HfNQPfYw_498, T1556_, TM__pyAIA9cUF0h9c4j2HfNQPfYw_230);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1550_;
					eqdestroy___ast_u3252(a_8);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___vmprofiler_u19(savedFrame_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					eqdestroy___vm_u14829(colonenv__1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					goto BeforeRet_;
				}
LA1551_: ;
				(*(*colonenv__1).c0).comesFromHeuristic = (*(*(*colonenv__1).tos1).slots.p->data[rb_115].node).info;
				{
					LA1550_:;
				}
				{
					oldNimErrFin1550_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3252(a_8);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin1550_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)111):
			{
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_9;
				NI rb_116;
				a_9 = NIM_NIL;
				rb_116 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1560_;
				eqcopy___ast_u3255(&a_9, (*(*colonenv__1).tos1).slots.p->data[rb_116].node);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1560_;
				{
					if (!((*a_9).kind >= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)5) && (*a_9).kind <= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)15))) goto LA1563_;
					(*(*colonenv__1).tos1).slots.p->data[ra_1].intVal = (*a_9)._kind_1.intVal;
				}
				goto LA1561_;
LA1563_: ;
				{
					NIM_BOOL T1566_;
					T1566_ = (NIM_BOOL)0;
					T1566_ = ((*a_9).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3));
					if (!(T1566_)) goto LA1567_;
					T1566_ = ((*(*a_9)._kind_4.sym).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)20));
LA1567_: ;
					if (!T1566_) goto LA1568_;
					(*(*colonenv__1).tos1).slots.p->data[ra_1].intVal = ((NI64) ((*(*a_9)._kind_4.sym).position));
				}
				goto LA1561_;
LA1568_: ;
				{
					tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T1571_;
					nimZeroMem((void*)(&T1571_), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
					stackTraceImpl__vm_u73((*colonenv__1).c0, (*colonenv__1).tos1, (*colonenv__1).pc2, TM__pyAIA9cUF0h9c4j2HfNQPfYw_500, T1571_, TM__pyAIA9cUF0h9c4j2HfNQPfYw_230);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1560_;
					eqdestroy___ast_u3252(a_9);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___vmprofiler_u19(savedFrame_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					eqdestroy___vm_u14829(colonenv__1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					goto BeforeRet_;
				}
LA1561_: ;
				{
					LA1560_:;
				}
				{
					oldNimErrFin1560_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3252(a_9);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin1560_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)112):
			{
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_10;
				NI rb_117;
				a_10 = NIM_NIL;
				rb_117 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)3));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1575_;
				eqcopy___ast_u3255(&a_10, (*(*colonenv__1).tos1).slots.p->data[rb_117].node);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1575_;
				switch ((*a_10).kind) {
				case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)16) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)18):
				{
					(*(*colonenv__1).tos1).slots.p->data[ra_1].floatVal = (*a_10)._kind_2.floatVal;
				}
				break;
				default:
				{
					tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T1578_;
					nimZeroMem((void*)(&T1578_), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
					stackTraceImpl__vm_u73((*colonenv__1).c0, (*colonenv__1).tos1, (*colonenv__1).pc2, TM__pyAIA9cUF0h9c4j2HfNQPfYw_502, T1578_, TM__pyAIA9cUF0h9c4j2HfNQPfYw_230);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1575_;
					eqdestroy___ast_u3252(a_10);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___vmprofiler_u19(savedFrame_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					eqdestroy___vm_u14829(colonenv__1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					goto BeforeRet_;
				}
				break;
				}
				{
					LA1575_:;
				}
				{
					oldNimErrFin1575_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3252(a_10);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin1575_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)113):
			{
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_11;
				NI rb_118;
				a_11 = NIM_NIL;
				rb_118 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1582_;
				eqcopy___ast_u3255(&a_11, (*(*colonenv__1).tos1).slots.p->data[rb_118].node);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1582_;
				{
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T1587_;
					if (!((*a_11).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3))) goto LA1585_;
					T1587_ = NIM_NIL;
					T1587_ = copyNode__ast_u6736(a_11);
					if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T1587_); goto LA1582_;}
					eqsink___ast_u3261(&(*(*colonenv__1).tos1).slots.p->data[ra_1].node, T1587_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1582_;
				}
				goto LA1583_;
LA1585_: ;
				{
					tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T1589_;
					nimZeroMem((void*)(&T1589_), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
					stackTraceImpl__vm_u73((*colonenv__1).c0, (*colonenv__1).tos1, (*colonenv__1).pc2, TM__pyAIA9cUF0h9c4j2HfNQPfYw_504, T1589_, TM__pyAIA9cUF0h9c4j2HfNQPfYw_230);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1582_;
					eqdestroy___ast_u3252(a_11);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___vmprofiler_u19(savedFrame_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					eqdestroy___vm_u14829(colonenv__1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					goto BeforeRet_;
				}
LA1583_: ;
				{
					LA1582_:;
				}
				{
					oldNimErrFin1582_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3252(a_11);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin1582_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)114):
			{
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_12;
				NI rb_119;
				a_12 = NIM_NIL;
				rb_119 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1593_;
				eqcopy___ast_u3255(&a_12, (*(*colonenv__1).tos1).slots.p->data[rb_119].node);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1593_;
				{
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T1598_;
					if (!((*a_12).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)2))) goto LA1596_;
					T1598_ = NIM_NIL;
					T1598_ = copyNode__ast_u6736(a_12);
					if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T1598_); goto LA1593_;}
					eqsink___ast_u3261(&(*(*colonenv__1).tos1).slots.p->data[ra_1].node, T1598_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1593_;
				}
				goto LA1594_;
LA1596_: ;
				{
					tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T1600_;
					nimZeroMem((void*)(&T1600_), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
					stackTraceImpl__vm_u73((*colonenv__1).c0, (*colonenv__1).tos1, (*colonenv__1).pc2, TM__pyAIA9cUF0h9c4j2HfNQPfYw_506, T1600_, TM__pyAIA9cUF0h9c4j2HfNQPfYw_230);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1593_;
					eqdestroy___ast_u3252(a_12);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___vmprofiler_u19(savedFrame_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					eqdestroy___vm_u14829(colonenv__1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					goto BeforeRet_;
				}
LA1594_: ;
				{
					LA1593_:;
				}
				{
					oldNimErrFin1593_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3252(a_12);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin1593_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)140):
			{
				NI rb_120;
				rb_120 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				(*(*colonenv__1).tos1).slots.p->data[ra_1].intVal = IL64(-1);
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)115):
			{
				NI rb_121;
				NI rc_70;
				rb_121 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				rc_70 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(40ULL & (64 - 1))) & 65535ULL)));
				switch (rc_70) {
				case ((NI)0):
				{
					ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					{
						NIM_BOOL T1608_;
						tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T1612_;
						T1608_ = (NIM_BOOL)0;
						T1608_ = ((*(*colonenv__1).tos1).slots.p->data[rb_121].kind == ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1));
						if (!(T1608_)) goto LA1609_;
						T1608_ = !(((*(*(*colonenv__1).tos1).slots.p->data[rb_121].node).typField == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL)));
LA1609_: ;
						if (!T1608_) goto LA1610_;
						T1612_ = NIM_NIL;
						T1612_ = opMapTypeToAst__vmdeps_u296((*(*colonenv__1).c0).cache, (*(*(*colonenv__1).tos1).slots.p->data[rb_121].node).typField, (*(*colonenv__1).c0).debug.p->data[(*colonenv__1).pc2], (*(*colonenv__1).c0).Sup.idgen);
						if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T1612_); goto LA1_;}
						eqsink___ast_u3261(&(*(*colonenv__1).tos1).slots.p->data[ra_1].node, T1612_);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					}
					goto LA1606_;
LA1610_: ;
					{
						NIM_BOOL T1614_;
						NIM_BOOL T1615_;
						tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T1620_;
						T1614_ = (NIM_BOOL)0;
						T1615_ = (NIM_BOOL)0;
						T1615_ = ((*(*colonenv__1).tos1).slots.p->data[rb_121].kind == ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1));
						if (!(T1615_)) goto LA1616_;
						T1615_ = ((*(*(*colonenv__1).tos1).slots.p->data[rb_121].node).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3));
LA1616_: ;
						T1614_ = T1615_;
						if (!(T1614_)) goto LA1617_;
						T1614_ = !(((*(*(*(*colonenv__1).tos1).slots.p->data[rb_121].node)._kind_4.sym).typ == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL)));
LA1617_: ;
						if (!T1614_) goto LA1618_;
						T1620_ = NIM_NIL;
						T1620_ = opMapTypeToAst__vmdeps_u296((*(*colonenv__1).c0).cache, (*(*(*(*colonenv__1).tos1).slots.p->data[rb_121].node)._kind_4.sym).typ, (*(*colonenv__1).c0).debug.p->data[(*colonenv__1).pc2], (*(*colonenv__1).c0).Sup.idgen);
						if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T1620_); goto LA1_;}
						eqsink___ast_u3261(&(*(*colonenv__1).tos1).slots.p->data[ra_1].node, T1620_);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					}
					goto LA1606_;
LA1618_: ;
					{
						tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T1622_;
						nimZeroMem((void*)(&T1622_), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
						stackTraceImpl__vm_u73((*colonenv__1).c0, (*colonenv__1).tos1, (*colonenv__1).pc2, TM__pyAIA9cUF0h9c4j2HfNQPfYw_508, T1622_, TM__pyAIA9cUF0h9c4j2HfNQPfYw_230);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						eqdestroy___vmprofiler_u19(savedFrame_1);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						eqdestroy___vm_u14829(colonenv__1);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						goto BeforeRet_;
					}
LA1606_: ;
				}
				break;
				case ((NI)1):
				{
					ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2));
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					{
						NIM_BOOL T1626_;
						T1626_ = (NIM_BOOL)0;
						T1626_ = ((*(*colonenv__1).tos1).slots.p->data[rb_121].kind == ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1));
						if (!(T1626_)) goto LA1627_;
						T1626_ = !(((*(*(*colonenv__1).tos1).slots.p->data[rb_121].node).typField == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL)));
LA1627_: ;
						if (!T1626_) goto LA1628_;
						(*(*colonenv__1).tos1).slots.p->data[ra_1].intVal = ((NI64) ((*(*(*(*colonenv__1).tos1).slots.p->data[rb_121].node).typField).kind));
					}
					goto LA1624_;
LA1628_: ;
					{
						NIM_BOOL T1631_;
						NIM_BOOL T1632_;
						T1631_ = (NIM_BOOL)0;
						T1632_ = (NIM_BOOL)0;
						T1632_ = ((*(*colonenv__1).tos1).slots.p->data[rb_121].kind == ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1));
						if (!(T1632_)) goto LA1633_;
						T1632_ = ((*(*(*colonenv__1).tos1).slots.p->data[rb_121].node).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3));
LA1633_: ;
						T1631_ = T1632_;
						if (!(T1631_)) goto LA1634_;
						T1631_ = !(((*(*(*(*colonenv__1).tos1).slots.p->data[rb_121].node)._kind_4.sym).typ == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL)));
LA1634_: ;
						if (!T1631_) goto LA1635_;
						(*(*colonenv__1).tos1).slots.p->data[ra_1].intVal = ((NI64) ((*(*(*(*(*colonenv__1).tos1).slots.p->data[rb_121].node)._kind_4.sym).typ).kind));
					}
					goto LA1624_;
LA1635_: ;
LA1624_: ;
				}
				break;
				case ((NI)2):
				{
					ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					{
						NIM_BOOL T1640_;
						tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T1644_;
						T1640_ = (NIM_BOOL)0;
						T1640_ = ((*(*colonenv__1).tos1).slots.p->data[rb_121].kind == ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1));
						if (!(T1640_)) goto LA1641_;
						T1640_ = !(((*(*(*colonenv__1).tos1).slots.p->data[rb_121].node).typField == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL)));
LA1641_: ;
						if (!T1640_) goto LA1642_;
						T1644_ = NIM_NIL;
						T1644_ = opMapTypeInstToAst__vmdeps_u302((*(*colonenv__1).c0).cache, (*(*(*colonenv__1).tos1).slots.p->data[rb_121].node).typField, (*(*colonenv__1).c0).debug.p->data[(*colonenv__1).pc2], (*(*colonenv__1).c0).Sup.idgen, NIM_FALSE);
						if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T1644_); goto LA1_;}
						eqsink___ast_u3261(&(*(*colonenv__1).tos1).slots.p->data[ra_1].node, T1644_);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					}
					goto LA1638_;
LA1642_: ;
					{
						NIM_BOOL T1646_;
						NIM_BOOL T1647_;
						tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T1652_;
						T1646_ = (NIM_BOOL)0;
						T1647_ = (NIM_BOOL)0;
						T1647_ = ((*(*colonenv__1).tos1).slots.p->data[rb_121].kind == ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1));
						if (!(T1647_)) goto LA1648_;
						T1647_ = ((*(*(*colonenv__1).tos1).slots.p->data[rb_121].node).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3));
LA1648_: ;
						T1646_ = T1647_;
						if (!(T1646_)) goto LA1649_;
						T1646_ = !(((*(*(*(*colonenv__1).tos1).slots.p->data[rb_121].node)._kind_4.sym).typ == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL)));
LA1649_: ;
						if (!T1646_) goto LA1650_;
						T1652_ = NIM_NIL;
						T1652_ = opMapTypeInstToAst__vmdeps_u302((*(*colonenv__1).c0).cache, (*(*(*(*colonenv__1).tos1).slots.p->data[rb_121].node)._kind_4.sym).typ, (*(*colonenv__1).c0).debug.p->data[(*colonenv__1).pc2], (*(*colonenv__1).c0).Sup.idgen, NIM_FALSE);
						if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T1652_); goto LA1_;}
						eqsink___ast_u3261(&(*(*colonenv__1).tos1).slots.p->data[ra_1].node, T1652_);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					}
					goto LA1638_;
LA1650_: ;
					{
						tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T1654_;
						nimZeroMem((void*)(&T1654_), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
						stackTraceImpl__vm_u73((*colonenv__1).c0, (*colonenv__1).tos1, (*colonenv__1).pc2, TM__pyAIA9cUF0h9c4j2HfNQPfYw_509, T1654_, TM__pyAIA9cUF0h9c4j2HfNQPfYw_230);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						eqdestroy___vmprofiler_u19(savedFrame_1);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						eqdestroy___vm_u14829(colonenv__1);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						goto BeforeRet_;
					}
LA1638_: ;
				}
				break;
				case ((NI)3):
				{
					ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					{
						NIM_BOOL T1658_;
						tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T1662_;
						T1658_ = (NIM_BOOL)0;
						T1658_ = ((*(*colonenv__1).tos1).slots.p->data[rb_121].kind == ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1));
						if (!(T1658_)) goto LA1659_;
						T1658_ = !(((*(*(*colonenv__1).tos1).slots.p->data[rb_121].node).typField == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL)));
LA1659_: ;
						if (!T1658_) goto LA1660_;
						T1662_ = NIM_NIL;
						T1662_ = opMapTypeImplToAst__vmdeps_u309((*(*colonenv__1).c0).cache, (*(*(*colonenv__1).tos1).slots.p->data[rb_121].node).typField, (*(*colonenv__1).c0).debug.p->data[(*colonenv__1).pc2], (*(*colonenv__1).c0).Sup.idgen);
						if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T1662_); goto LA1_;}
						eqsink___ast_u3261(&(*(*colonenv__1).tos1).slots.p->data[ra_1].node, T1662_);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					}
					goto LA1656_;
LA1660_: ;
					{
						NIM_BOOL T1664_;
						NIM_BOOL T1665_;
						tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T1670_;
						T1664_ = (NIM_BOOL)0;
						T1665_ = (NIM_BOOL)0;
						T1665_ = ((*(*colonenv__1).tos1).slots.p->data[rb_121].kind == ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1));
						if (!(T1665_)) goto LA1666_;
						T1665_ = ((*(*(*colonenv__1).tos1).slots.p->data[rb_121].node).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3));
LA1666_: ;
						T1664_ = T1665_;
						if (!(T1664_)) goto LA1667_;
						T1664_ = !(((*(*(*(*colonenv__1).tos1).slots.p->data[rb_121].node)._kind_4.sym).typ == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL)));
LA1667_: ;
						if (!T1664_) goto LA1668_;
						T1670_ = NIM_NIL;
						T1670_ = opMapTypeImplToAst__vmdeps_u309((*(*colonenv__1).c0).cache, (*(*(*(*colonenv__1).tos1).slots.p->data[rb_121].node)._kind_4.sym).typ, (*(*colonenv__1).c0).debug.p->data[(*colonenv__1).pc2], (*(*colonenv__1).c0).Sup.idgen);
						if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T1670_); goto LA1_;}
						eqsink___ast_u3261(&(*(*colonenv__1).tos1).slots.p->data[ra_1].node, T1670_);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					}
					goto LA1656_;
LA1668_: ;
					{
						tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T1672_;
						nimZeroMem((void*)(&T1672_), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
						stackTraceImpl__vm_u73((*colonenv__1).c0, (*colonenv__1).tos1, (*colonenv__1).pc2, TM__pyAIA9cUF0h9c4j2HfNQPfYw_510, T1672_, TM__pyAIA9cUF0h9c4j2HfNQPfYw_230);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						eqdestroy___vmprofiler_u19(savedFrame_1);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						eqdestroy___vm_u14829(colonenv__1);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						goto BeforeRet_;
					}
LA1656_: ;
				}
				break;
				default:
				{
					ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					{
						NIM_BOOL T1676_;
						tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T1680_;
						T1676_ = (NIM_BOOL)0;
						T1676_ = ((*(*colonenv__1).tos1).slots.p->data[rb_121].kind == ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1));
						if (!(T1676_)) goto LA1677_;
						T1676_ = !(((*(*(*colonenv__1).tos1).slots.p->data[rb_121].node).typField == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL)));
LA1677_: ;
						if (!T1676_) goto LA1678_;
						T1680_ = NIM_NIL;
						T1680_ = opMapTypeInstToAst__vmdeps_u302((*(*colonenv__1).c0).cache, (*(*(*colonenv__1).tos1).slots.p->data[rb_121].node).typField, (*(*colonenv__1).c0).debug.p->data[(*colonenv__1).pc2], (*(*colonenv__1).c0).Sup.idgen, NIM_TRUE);
						if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T1680_); goto LA1_;}
						eqsink___ast_u3261(&(*(*colonenv__1).tos1).slots.p->data[ra_1].node, T1680_);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					}
					goto LA1674_;
LA1678_: ;
					{
						NIM_BOOL T1682_;
						NIM_BOOL T1683_;
						tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T1688_;
						T1682_ = (NIM_BOOL)0;
						T1683_ = (NIM_BOOL)0;
						T1683_ = ((*(*colonenv__1).tos1).slots.p->data[rb_121].kind == ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1));
						if (!(T1683_)) goto LA1684_;
						T1683_ = ((*(*(*colonenv__1).tos1).slots.p->data[rb_121].node).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3));
LA1684_: ;
						T1682_ = T1683_;
						if (!(T1682_)) goto LA1685_;
						T1682_ = !(((*(*(*(*colonenv__1).tos1).slots.p->data[rb_121].node)._kind_4.sym).typ == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL)));
LA1685_: ;
						if (!T1682_) goto LA1686_;
						T1688_ = NIM_NIL;
						T1688_ = opMapTypeInstToAst__vmdeps_u302((*(*colonenv__1).c0).cache, (*(*(*(*colonenv__1).tos1).slots.p->data[rb_121].node)._kind_4.sym).typ, (*(*colonenv__1).c0).debug.p->data[(*colonenv__1).pc2], (*(*colonenv__1).c0).Sup.idgen, NIM_TRUE);
						if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T1688_); goto LA1_;}
						eqsink___ast_u3261(&(*(*colonenv__1).tos1).slots.p->data[ra_1].node, T1688_);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					}
					goto LA1674_;
LA1686_: ;
					{
						tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T1690_;
						nimZeroMem((void*)(&T1690_), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
						stackTraceImpl__vm_u73((*colonenv__1).c0, (*colonenv__1).tos1, (*colonenv__1).pc2, TM__pyAIA9cUF0h9c4j2HfNQPfYw_511, T1690_, TM__pyAIA9cUF0h9c4j2HfNQPfYw_230);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						eqdestroy___vmprofiler_u19(savedFrame_1);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						eqdestroy___vm_u14829(colonenv__1);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						goto BeforeRet_;
					}
LA1674_: ;
				}
				break;
				}
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)118):
			{
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_6;
				NI rb_122;
				NI imm_8;
				n_6 = NIM_NIL;
				rb_122 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				imm_8 = (NI)(((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(40ULL & (64 - 1))) & 65535ULL))) - ((NI)128));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1692_;
				eqcopy___ast_u3255(&n_6, (*(*colonenv__1).tos1).slots.p->data[rb_122].node);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1692_;
				switch (imm_8) {
				case ((NI)0):
				{
					{
						tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T1698_;
						if (!((*n_6).typField == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL))) goto LA1696_;
						nimZeroMem((void*)(&T1698_), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
						stackTraceImpl__vm_u73((*colonenv__1).c0, (*colonenv__1).tos1, (*colonenv__1).pc2, TM__pyAIA9cUF0h9c4j2HfNQPfYw_512, T1698_, TM__pyAIA9cUF0h9c4j2HfNQPfYw_230);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1692_;
						eqdestroy___ast_u3252(n_6);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						eqdestroy___vmprofiler_u19(savedFrame_1);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						eqdestroy___vm_u14829(colonenv__1);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						goto BeforeRet_;
					}
					goto LA1694_;
LA1696_: ;
					{
						NI64 T1700_;
						T1700_ = (NI64)0;
						T1700_ = getSize__types_u3397((*(*colonenv__1).c0).config, (*n_6).typField);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1692_;
						(*(*colonenv__1).tos1).slots.p->data[ra_1].intVal = T1700_;
					}
LA1694_: ;
				}
				break;
				case ((NI)1):
				{
					{
						tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T1706_;
						if (!((*n_6).typField == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL))) goto LA1704_;
						nimZeroMem((void*)(&T1706_), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
						stackTraceImpl__vm_u73((*colonenv__1).c0, (*colonenv__1).tos1, (*colonenv__1).pc2, TM__pyAIA9cUF0h9c4j2HfNQPfYw_513, T1706_, TM__pyAIA9cUF0h9c4j2HfNQPfYw_230);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1692_;
						eqdestroy___ast_u3252(n_6);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						eqdestroy___vmprofiler_u19(savedFrame_1);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						eqdestroy___vm_u14829(colonenv__1);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						goto BeforeRet_;
					}
					goto LA1702_;
LA1704_: ;
					{
						NI64 T1708_;
						T1708_ = (NI64)0;
						T1708_ = getAlign__types_u3393((*(*colonenv__1).c0).config, (*n_6).typField);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1692_;
						(*(*colonenv__1).tos1).slots.p->data[ra_1].intVal = T1708_;
					}
LA1702_: ;
				}
				break;
				default:
				{
					{
						tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T1714_;
						if (!!(((*n_6).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3)))) goto LA1712_;
						nimZeroMem((void*)(&T1714_), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
						stackTraceImpl__vm_u73((*colonenv__1).c0, (*colonenv__1).tos1, (*colonenv__1).pc2, TM__pyAIA9cUF0h9c4j2HfNQPfYw_514, T1714_, TM__pyAIA9cUF0h9c4j2HfNQPfYw_230);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1692_;
						eqdestroy___ast_u3252(n_6);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						eqdestroy___vmprofiler_u19(savedFrame_1);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						eqdestroy___vm_u14829(colonenv__1);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						goto BeforeRet_;
					}
					goto LA1710_;
LA1712_: ;
					{
						tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T1718_;
						if (!!(((*(*n_6)._kind_4.sym).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)19)))) goto LA1716_;
						nimZeroMem((void*)(&T1718_), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
						stackTraceImpl__vm_u73((*colonenv__1).c0, (*colonenv__1).tos1, (*colonenv__1).pc2, TM__pyAIA9cUF0h9c4j2HfNQPfYw_516, T1718_, TM__pyAIA9cUF0h9c4j2HfNQPfYw_230);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1692_;
						eqdestroy___ast_u3252(n_6);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						eqdestroy___vmprofiler_u19(savedFrame_1);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						eqdestroy___vm_u14829(colonenv__1);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						goto BeforeRet_;
					}
					goto LA1710_;
LA1716_: ;
					{
						(*(*colonenv__1).tos1).slots.p->data[ra_1].intVal = ((NI64) ((*(*n_6)._kind_4.sym).offset));
					}
LA1710_: ;
				}
				break;
				}
				{
					LA1692_:;
				}
				{
					oldNimErrFin1692_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3252(n_6);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin1692_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)116):
			{
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_13;
				NI rb_123;
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T1724_;
				a_13 = NIM_NIL;
				rb_123 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1723_;
				T1724_ = NIM_NIL;
				T1724_ = newNode__ast_u4069(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)20));
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T1724_); goto LA1723_;}
				eqsink___ast_u3261(&(*(*colonenv__1).tos1).slots.p->data[ra_1].node, T1724_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1723_;
				eqcopy___ast_u3255(&a_13, (*(*colonenv__1).tos1).slots.p->data[rb_123].node);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1723_;
				switch ((*a_13).kind) {
				case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)20) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)22):
				{
					eqcopy___system_u2694((&(*(*(*colonenv__1).tos1).slots.p->data[ra_1].node)._kind_3.strVal), (*a_13)._kind_3.strVal);
				}
				break;
				case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)125):
				{
					NimStringV2 T1727_;
					T1727_.len = 0; T1727_.p = NIM_NIL;
					T1727_ = comment__ast_u836(a_13);
					if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T1727_); goto LA1723_;}
					eqsink___system_u2700((&(*(*(*colonenv__1).tos1).slots.p->data[ra_1].node)._kind_3.strVal), T1727_);
				}
				break;
				case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)2):
				{
					eqcopy___system_u2694((&(*(*(*colonenv__1).tos1).slots.p->data[ra_1].node)._kind_3.strVal), (*(*a_13)._kind_5.ident).s);
				}
				break;
				case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3):
				{
					eqcopy___system_u2694((&(*(*(*colonenv__1).tos1).slots.p->data[ra_1].node)._kind_3.strVal), (*(*(*a_13)._kind_4.sym).name).s);
				}
				break;
				default:
				{
					tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T1731_;
					nimZeroMem((void*)(&T1731_), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
					stackTraceImpl__vm_u73((*colonenv__1).c0, (*colonenv__1).tos1, (*colonenv__1).pc2, TM__pyAIA9cUF0h9c4j2HfNQPfYw_518, T1731_, TM__pyAIA9cUF0h9c4j2HfNQPfYw_230);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1723_;
					eqdestroy___ast_u3252(a_13);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___vmprofiler_u19(savedFrame_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					eqdestroy___vm_u14829(colonenv__1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					goto BeforeRet_;
				}
				break;
				}
				{
					LA1723_:;
				}
				{
					oldNimErrFin1723_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3252(a_13);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin1723_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)117):
			{
				NI rb_124;
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T1735_;
				rb_124 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				T1735_ = NIM_NIL;
				T1735_ = newNode__ast_u4069(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)20));
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T1735_); goto LA1_;}
				eqsink___ast_u3261(&(*(*colonenv__1).tos1).slots.p->data[ra_1].node, T1735_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				{
					tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T1740_;
					if (!!(((*(*(*colonenv__1).tos1).slots.p->data[rb_124].node).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3)))) goto LA1738_;
					nimZeroMem((void*)(&T1740_), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
					stackTraceImpl__vm_u73((*colonenv__1).c0, (*colonenv__1).tos1, (*colonenv__1).pc2, TM__pyAIA9cUF0h9c4j2HfNQPfYw_519, T1740_, TM__pyAIA9cUF0h9c4j2HfNQPfYw_230);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___vmprofiler_u19(savedFrame_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					eqdestroy___vm_u14829(colonenv__1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					goto BeforeRet_;
				}
				goto LA1736_;
LA1738_: ;
				{
					tyArray__dnD8kjh6rJ1Yy5jHvid0Ow T1742_;
					NimStringV2 T1743_;
					nimZeroMem((void*)T1742_, sizeof(tyArray__dnD8kjh6rJ1Yy5jHvid0Ow));
					sigHash__sighashes_u522((*(*(*colonenv__1).tos1).slots.p->data[rb_124].node)._kind_4.sym, (*(*colonenv__1).c0).config, T1742_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					T1743_.len = 0; T1743_.p = NIM_NIL;
					T1743_ = dollar___modulegraphs_u10732(T1742_);
					if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T1743_); goto LA1_;}
					eqsink___system_u2700((&(*(*(*colonenv__1).tos1).slots.p->data[ra_1].node)._kind_3.strVal), T1743_);
				}
LA1736_: ;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)141):
			{
				NI rb_125;
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T1745_;
				NimStringV2 T1746_;
				rb_125 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				T1745_ = NIM_NIL;
				T1745_ = newNode__ast_u4069(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)20));
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T1745_); goto LA1_;}
				eqsink___ast_u3261(&(*(*colonenv__1).tos1).slots.p->data[ra_1].node, T1745_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				T1746_.len = 0; T1746_.p = NIM_NIL;
				T1746_ = opSlurp__vmdeps_u10((*(*(*colonenv__1).tos1).slots.p->data[rb_125].node)._kind_3.strVal, (*(*colonenv__1).c0).debug.p->data[(*colonenv__1).pc2], (*(*colonenv__1).c0).module, (*(*colonenv__1).c0).config);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T1746_); goto LA1_;}
				eqsink___system_u2700((&(*(*(*colonenv__1).tos1).slots.p->data[ra_1].node)._kind_3.strVal), T1746_);
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)142):
			{
				NI rb_126;
				NI rc_71;
				NI rd_1;
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T1748_;
				rb_126 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				rc_71 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(40ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				(*colonenv__1).pc2 += ((NI)1);
				rd_1 = ((NI) ((NU64)((NU64)((NU64)((*(*colonenv__1).c0).code.p->data[(*colonenv__1).pc2]) >> (NU64)(8ULL & (64 - 1))) & 65535ULL)));
				T1748_ = NIM_NIL;
				T1748_ = newNode__ast_u4069(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)20));
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T1748_); goto LA1_;}
				eqsink___ast_u3261(&(*(*colonenv__1).tos1).slots.p->data[ra_1].node, T1748_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				{
					NIM_BOOL T1751_;
					T1751_ = (NIM_BOOL)0;
					T1751_ = NIM_FALSE;
					if (T1751_) goto LA1752_;
					T1751_ = ((*(*(*colonenv__1).c0).config).cmd == ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)8));
LA1752_: ;
					if (!T1751_) goto LA1753_;
					eqsink___system_u2700((&(*(*(*colonenv__1).tos1).slots.p->data[ra_1].node)._kind_3.strVal), TM__pyAIA9cUF0h9c4j2HfNQPfYw_520);
				}
				goto LA1749_;
LA1753_: ;
				{
					tyTuple__XOVT24GHXwqiEj5GCsEGCA colontmpD__163;
					nimZeroMem((void*)(&colontmpD__163), sizeof(tyTuple__XOVT24GHXwqiEj5GCsEGCA));
					colontmpD__163 = opGorge__gorgeimpl_u14((*(*(*colonenv__1).tos1).slots.p->data[rb_126].node)._kind_3.strVal, (*(*(*colonenv__1).tos1).slots.p->data[rc_71].node)._kind_3.strVal, (*(*(*colonenv__1).tos1).slots.p->data[rd_1].node)._kind_3.strVal, (*(*colonenv__1).c0).debug.p->data[(*colonenv__1).pc2], (*(*colonenv__1).c0).config);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1756_;
					eqcopy___system_u2694((&(*(*(*colonenv__1).tos1).slots.p->data[ra_1].node)._kind_3.strVal), colontmpD__163.Field0);
					{
						LA1756_:;
					}
					{
						eqdestroy___pureZosproc_u1951(colontmpD__163);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				}
LA1749_: ;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)146):
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)147):
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)148):
			{
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_14;
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* b_6;
				tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA colontmpD__164;
				tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA colontmpD__165;
				NI rb_127;
				tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_2;
				a_14 = NIM_NIL;
				b_6 = NIM_NIL;
				nimZeroMem((void*)(&colontmpD__164), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
				nimZeroMem((void*)(&colontmpD__165), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
				rb_127 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1760_;
				eqcopy___ast_u3255(&a_14, (*(*colonenv__1).tos1).slots.p->data[ra_1].node);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1760_;
				eqcopy___ast_u3255(&b_6, (*(*colonenv__1).tos1).slots.p->data[rb_127].node);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1760_;
				{
					if (!((*b_6).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)23))) goto LA1763_;
					colontmpD__164 = (*(*colonenv__1).c0).debug.p->data[(*colonenv__1).pc2];
					info_2 = colontmpD__164;
				}
				goto LA1761_;
LA1763_: ;
				{
					colontmpD__165 = (*b_6).info;
					info_2 = colontmpD__165;
				}
LA1761_: ;
				{
					if (!(((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(0ULL & (64 - 1))) & 255ULL))) == ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)146))) goto LA1768_;
					stackTraceImpl__vm_u73((*colonenv__1).c0, (*colonenv__1).tos1, (*colonenv__1).pc2, (*a_14)._kind_3.strVal, info_2, TM__pyAIA9cUF0h9c4j2HfNQPfYw_230);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1760_;
					eqdestroy___ast_u3252(b_6);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___ast_u3252(a_14);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___vmprofiler_u19(savedFrame_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					eqdestroy___vm_u14829(colonenv__1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					goto BeforeRet_;
				}
				goto LA1766_;
LA1768_: ;
				{
					if (!(((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(0ULL & (64 - 1))) & 255ULL))) == ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)147))) goto LA1771_;
					liMessage__msgs_u1227((*(*colonenv__1).c0).config, info_2, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)85), (*a_14)._kind_3.strVal, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), TM__pyAIA9cUF0h9c4j2HfNQPfYw_521, NIM_FALSE, NIM_FALSE);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1760_;
				}
				goto LA1766_;
LA1771_: ;
				{
					if (!(((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(0ULL & (64 - 1))) & 255ULL))) == ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)148))) goto LA1774_;
					liMessage__msgs_u1227((*(*colonenv__1).c0).config, info_2, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)118), (*a_14)._kind_3.strVal, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), TM__pyAIA9cUF0h9c4j2HfNQPfYw_522, NIM_FALSE, NIM_FALSE);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1760_;
				}
				goto LA1766_;
LA1774_: ;
LA1766_: ;
				{
					LA1760_:;
				}
				{
					oldNimErrFin1760_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3252(b_6);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___ast_u3252(a_14);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin1760_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)143):
			{
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* ast_2;
				NI rb_128;
				NI rc_72;
				tyProc__urLEtt9bmeGdJpEukhLR9a1A T1780_;
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T1781_;
				ast_2 = NIM_NIL;
				rb_128 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				rc_72 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(40ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1779_;
				eqsink___system_u2700((&(*colonenv__1).error3), TM__pyAIA9cUF0h9c4j2HfNQPfYw_523);
				nimZeroMem((void*)(&T1780_), sizeof(tyProc__urLEtt9bmeGdJpEukhLR9a1A));
				T1780_.ClP_0 = colonanonymous___vm_u3895; T1780_.ClE_0 = colonenv__1;
				ast_2 = parseString__parser_u1772((*(*(*colonenv__1).tos1).slots.p->data[rb_128].node)._kind_3.strVal, (*(*colonenv__1).c0).cache, (*(*colonenv__1).c0).config, (*(*(*colonenv__1).tos1).slots.p->data[rc_72].node)._kind_3.strVal, ((NI)0), T1780_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1779_;
				T1781_ = NIM_NIL;
				T1781_ = newNode__ast_u4069(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)1));
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T1781_); goto LA1779_;}
				eqsink___ast_u3261(&(*(*colonenv__1).tos1).slots.p->data[ra_1].node, T1781_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1779_;
				{
					if (!(((NI)0) < (*colonenv__1).error3.len)) goto LA1784_;
					eqcopy___system_u2694((&(*(*colonenv__1).c0).errorFlag), (*colonenv__1).error3);
				}
				goto LA1782_;
LA1784_: ;
				{
					NI T1787_;
					NimStringV2 T1790_;
					T1787_ = (NI)0;
					T1787_ = len__ast_u3190(ast_2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1779_;
					if (!!((T1787_ == ((NI)1)))) goto LA1788_;
					T1790_.len = 0; T1790_.p = NIM_NIL;
					T1790_ = formatMsg__msgs_u1220((*(*colonenv__1).c0).config, (*(*colonenv__1).c0).debug.p->data[(*colonenv__1).pc2], ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), TM__pyAIA9cUF0h9c4j2HfNQPfYw_525);
					if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T1790_); goto LA1779_;}
					eqsink___system_u2700((&(*(*colonenv__1).c0).errorFlag), T1790_);
				}
				goto LA1782_;
LA1788_: ;
				{
					eqcopy___ast_u3255(&(*(*colonenv__1).tos1).slots.p->data[ra_1].node, (*ast_2)._kind_6.sons.p->data[((NI)0)]);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1779_;
				}
LA1782_: ;
				{
					LA1779_:;
				}
				{
					oldNimErrFin1779_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3252(ast_2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin1779_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)144):
			{
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* ast_3;
				NI rb_129;
				NI rc_73;
				tyProc__urLEtt9bmeGdJpEukhLR9a1A T1796_;
				ast_3 = NIM_NIL;
				rb_129 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				rc_73 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(40ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1795_;
				eqsink___system_u2700((&(*colonenv__1).error4), TM__pyAIA9cUF0h9c4j2HfNQPfYw_526);
				nimZeroMem((void*)(&T1796_), sizeof(tyProc__urLEtt9bmeGdJpEukhLR9a1A));
				T1796_.ClP_0 = colonanonymous___vm_u3916; T1796_.ClE_0 = colonenv__1;
				ast_3 = parseString__parser_u1772((*(*(*colonenv__1).tos1).slots.p->data[rb_129].node)._kind_3.strVal, (*(*colonenv__1).c0).cache, (*(*colonenv__1).c0).config, (*(*(*colonenv__1).tos1).slots.p->data[rc_73].node)._kind_3.strVal, ((NI)0), T1796_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1795_;
				{
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T1801_;
					if (!(((NI)0) < (*colonenv__1).error4.len)) goto LA1799_;
					eqcopy___system_u2694((&(*(*colonenv__1).c0).errorFlag), (*colonenv__1).error4);
					T1801_ = NIM_NIL;
					T1801_ = newNode__ast_u4069(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)1));
					if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T1801_); goto LA1795_;}
					eqsink___ast_u3261(&(*(*colonenv__1).tos1).slots.p->data[ra_1].node, T1801_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1795_;
				}
				goto LA1797_;
LA1799_: ;
				{
					eqsink___ast_u3261(&(*(*colonenv__1).tos1).slots.p->data[ra_1].node, ast_3);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1795_;
					eqwasMoved___ast_u3249(&ast_3);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1795_;
				}
LA1797_: ;
				{
					LA1795_:;
				}
				{
					oldNimErrFin1795_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3252(ast_3);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin1795_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)145):
			{
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T1806_;
				T1806_ = NIM_NIL;
				T1806_ = newNode__ast_u4069(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)20));
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T1806_); goto LA1_;}
				eqsink___ast_u3261(&(*(*colonenv__1).tos1).slots.p->data[ra_1].node, T1806_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				eqcopy___system_u2694((&(*(*(*colonenv__1).tos1).slots.p->data[ra_1].node)._kind_3.strVal), (*(*colonenv__1).c0).errorFlag);
				setLengthStrV2((&(*(*colonenv__1).c0).errorFlag), ((NI)0));
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)164):
			{
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				{
					if (!!(((*(*colonenv__1).c0).callsite == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL)))) goto LA1810_;
					eqcopy___ast_u3255(&(*(*colonenv__1).tos1).slots.p->data[ra_1].node, (*(*colonenv__1).c0).callsite);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				}
				goto LA1808_;
LA1810_: ;
				{
					tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T1813_;
					nimZeroMem((void*)(&T1813_), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
					stackTraceImpl__vm_u73((*colonenv__1).c0, (*colonenv__1).tos1, (*colonenv__1).pc2, TM__pyAIA9cUF0h9c4j2HfNQPfYw_528, T1813_, TM__pyAIA9cUF0h9c4j2HfNQPfYw_230);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___vmprofiler_u19(savedFrame_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					eqdestroy___vm_u14829(colonenv__1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					goto BeforeRet_;
				}
LA1808_: ;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)149):
			{
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_7;
				NI rb_130;
				NI imm_9;
				n_7 = NIM_NIL;
				rb_130 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				imm_9 = (NI)(((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(40ULL & (64 - 1))) & 65535ULL))) - ((NI)128));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1815_;
				eqcopy___ast_u3255(&n_7, (*(*colonenv__1).tos1).slots.p->data[rb_130].node);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1815_;
				switch (imm_9) {
				case ((NI)0):
				{
					NimStringV2 colontmpD__166;
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T1817_;
					colontmpD__166.len = 0; colontmpD__166.p = NIM_NIL;
					colontmpD__166 = toFullPath__msgs_u624((*(*colonenv__1).c0).config, (*n_7).info.fileIndex);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1815_;
					T1817_ = NIM_NIL;
					T1817_ = newStrNode__ast_u5422(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)20), colontmpD__166);
					if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T1817_); goto LA1815_;}
					eqsink___ast_u3261(&(*(*colonenv__1).tos1).slots.p->data[ra_1].node, T1817_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1815_;
					eqdestroy___system_u2691(colontmpD__166);
				}
				break;
				case ((NI)1):
				{
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T1819_;
					T1819_ = NIM_NIL;
					T1819_ = newIntNode__ast_u5200(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)6), ((NI64) (((NI) ((*n_7).info.line)))));
					if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T1819_); goto LA1815_;}
					eqsink___ast_u3261(&(*(*colonenv__1).tos1).slots.p->data[ra_1].node, T1819_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1815_;
				}
				break;
				case ((NI)2):
				{
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T1821_;
					T1821_ = NIM_NIL;
					T1821_ = newIntNode__ast_u5200(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)6), ((NI64) (((NI) ((*n_7).info.col)))));
					if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T1821_); goto LA1815_;}
					eqsink___ast_u3261(&(*(*colonenv__1).tos1).slots.p->data[ra_1].node, T1821_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1815_;
				}
				break;
				default:
				{
					{
						NimStringV2 argX60gensym1779__1;
						if (!NIM_TRUE) goto LA1825_;
						argX60gensym1779__1.len = 0; argX60gensym1779__1.p = NIM_NIL;
						argX60gensym1779__1 = toFileLineCol__msgs_u701(TM__pyAIA9cUF0h9c4j2HfNQPfYw_535);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1827_;
						internalErrorImpl__msgs_u1598((*(*colonenv__1).c0).config, unknownLineInfo__lineinfos_u364, argX60gensym1779__1, TM__pyAIA9cUF0h9c4j2HfNQPfYw_535);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1827_;
						{
							LA1827_:;
						}
						{
							eqdestroy___system_u2691(argX60gensym1779__1);
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA1815_;
					}
LA1825_: ;
				}
				break;
				}
				(*(*(*colonenv__1).tos1).slots.p->data[ra_1].node).info = (*n_7).info;
				eqcopy___ast_u3381(&(*(*(*colonenv__1).tos1).slots.p->data[ra_1].node).typField, (*n_7).typField);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1815_;
				{
					LA1815_:;
				}
				{
					oldNimErrFin1815_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3252(n_7);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin1815_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)150):
			{
				NI rb_131;
				rb_131 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				(*(*(*colonenv__1).tos1).slots.p->data[ra_1].node).info = (*(*(*colonenv__1).tos1).slots.p->data[rb_131].node).info;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)151):
			{
				NI rb_132;
				rb_132 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				(*(*(*colonenv__1).tos1).slots.p->data[ra_1].node).info.line = ((NU16) ((*(*colonenv__1).tos1).slots.p->data[rb_132].intVal));
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)152):
			{
				NI rb_133;
				rb_133 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				(*(*(*colonenv__1).tos1).slots.p->data[ra_1].node).info.col = ((NI16) ((*(*colonenv__1).tos1).slots.p->data[rb_133].intVal));
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)153):
			{
				NI rb_134;
				NI32 T1836_;
				rb_134 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				T1836_ = (NI32)0;
				T1836_ = fileInfoIdx__msgs_u414((*(*colonenv__1).c0).config, (*(*(*colonenv__1).tos1).slots.p->data[rb_134].node)._kind_3.strVal);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				(*(*(*colonenv__1).tos1).slots.p->data[ra_1].node).info.fileIndex = T1836_;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)154):
			{
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* aNode_1;
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* bNode_1;
				NI colontmpD__167;
				NI colontmpD__168;
				NI rb_135;
				NI rc_74;
				NCSTRING aStrVal_1;
				NCSTRING bStrVal_1;
				NI T1864_;
				aNode_1 = NIM_NIL;
				bNode_1 = NIM_NIL;
				colontmpD__167 = (NI)0;
				colontmpD__168 = (NI)0;
				rb_135 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				rc_74 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(40ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				eqcopy___ast_u3255(&aNode_1, (*(*colonenv__1).tos1).slots.p->data[rb_135].node);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				eqcopy___ast_u3255(&bNode_1, (*(*colonenv__1).tos1).slots.p->data[rc_74].node);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				{
					if (!((*aNode_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)31))) goto LA1840_;
					eqcopy___ast_u3255(&aNode_1, (*aNode_1)._kind_6.sons.p->data[((NI)1)]);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				}
LA1840_: ;
				{
					if (!((*aNode_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)53))) goto LA1844_;
					eqcopy___ast_u3255(&aNode_1, (*aNode_1)._kind_6.sons.p->data[((NI)0)]);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				}
LA1844_: ;
				{
					if (!((*bNode_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)31))) goto LA1848_;
					eqcopy___ast_u3255(&bNode_1, (*bNode_1)._kind_6.sons.p->data[((NI)1)]);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				}
LA1848_: ;
				{
					if (!((*bNode_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)53))) goto LA1852_;
					eqcopy___ast_u3255(&bNode_1, (*bNode_1)._kind_6.sons.p->data[((NI)0)]);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				}
LA1852_: ;
				aStrVal_1 = ((NCSTRING) NIM_NIL);
				bStrVal_1 = ((NCSTRING) NIM_NIL);
				switch ((*aNode_1).kind) {
				case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)20) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)22):
				{
					aStrVal_1 = nimToCStringConv((*aNode_1)._kind_3.strVal);
				}
				break;
				case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)2):
				{
					aStrVal_1 = nimToCStringConv((*(*aNode_1)._kind_5.ident).s);
				}
				break;
				case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3):
				{
					aStrVal_1 = nimToCStringConv((*(*(*aNode_1)._kind_4.sym).name).s);
				}
				break;
				case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)57):
				case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)56):
				case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)165):
				{
					aStrVal_1 = nimToCStringConv((*(*(*(*aNode_1)._kind_6.sons.p->data[((NI)0)])._kind_4.sym).name).s);
				}
				break;
				default:
				{
				}
				break;
				}
				switch ((*bNode_1).kind) {
				case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)20) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)22):
				{
					bStrVal_1 = nimToCStringConv((*bNode_1)._kind_3.strVal);
				}
				break;
				case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)2):
				{
					bStrVal_1 = nimToCStringConv((*(*bNode_1)._kind_5.ident).s);
				}
				break;
				case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3):
				{
					bStrVal_1 = nimToCStringConv((*(*(*bNode_1)._kind_4.sym).name).s);
				}
				break;
				case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)57):
				case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)56):
				case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)165):
				{
					bStrVal_1 = nimToCStringConv((*(*(*(*bNode_1)._kind_6.sons.p->data[((NI)0)])._kind_4.sym).name).s);
				}
				break;
				default:
				{
				}
				break;
				}
				T1864_ = (NI)0;
				{
					NIM_BOOL T1867_;
					NIM_BOOL T1868_;
					NIM_BOOL T1870_;
					NI T1873_;
					T1867_ = (NIM_BOOL)0;
					T1868_ = (NIM_BOOL)0;
					T1868_ = eqeq___system_u8603(aStrVal_1, ((NCSTRING) NIM_NIL));
					T1867_ = !(T1868_);
					if (!(T1867_)) goto LA1869_;
					T1870_ = (NIM_BOOL)0;
					T1870_ = eqeq___system_u8603(bStrVal_1, ((NCSTRING) NIM_NIL));
					T1867_ = !(T1870_);
LA1869_: ;
					if (!T1867_) goto LA1871_;
					T1873_ = (NI)0;
					T1873_ = cmpIgnoreStyle__idents_u18(aStrVal_1, bStrVal_1, ((NI)2147483647));
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					colontmpD__167 = (T1873_ == ((NI)0));
					T1864_ = colontmpD__167;
				}
				goto LA1865_;
LA1871_: ;
				{
					colontmpD__168 = ((NI)0);
					T1864_ = colontmpD__168;
				}
LA1865_: ;
				(*(*colonenv__1).tos1).slots.p->data[ra_1].intVal = ((NI64) (T1864_));
				eqdestroy___ast_u3252(bNode_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				eqdestroy___ast_u3252(aNode_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)155):
			{
				NI rb_136;
				rb_136 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				{
					tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T1880_;
					if (!!(((*(*(*colonenv__1).tos1).slots.p->data[rb_136].node).kind >= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)20) && (*(*(*colonenv__1).tos1).slots.p->data[rb_136].node).kind <= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)22)))) goto LA1878_;
					nimZeroMem((void*)(&T1880_), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
					stackTraceImpl__vm_u73((*colonenv__1).c0, (*colonenv__1).tos1, (*colonenv__1).pc2, TM__pyAIA9cUF0h9c4j2HfNQPfYw_536, T1880_, TM__pyAIA9cUF0h9c4j2HfNQPfYw_230);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___vmprofiler_u19(savedFrame_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					eqdestroy___vm_u14829(colonenv__1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					goto BeforeRet_;
				}
				goto LA1876_;
LA1878_: ;
				{
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T1882_;
					tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* T1883_;
					T1882_ = NIM_NIL;
					T1882_ = newNodeI__ast_u4091(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)2), (*(*colonenv__1).c0).debug.p->data[(*colonenv__1).pc2]);
					if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T1882_); goto LA1_;}
					eqsink___ast_u3261(&(*(*colonenv__1).tos1).slots.p->data[ra_1].node, T1882_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					T1883_ = NIM_NIL;
					T1883_ = getIdent__idents_u206((*(*colonenv__1).c0).cache, (*(*(*colonenv__1).tos1).slots.p->data[rb_136].node)._kind_3.strVal);
					if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___idents_u155(T1883_); goto LA1_;}
					eqsink___idents_u164(&(*(*(*colonenv__1).tos1).slots.p->data[ra_1].node)._kind_5.ident, T1883_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					(*(*(*colonenv__1).tos1).slots.p->data[ra_1].node).flags |= ((NU32)1)<<(((((tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw)13))) & 31);
				}
LA1876_: ;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)188):
			{
				tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_9;
				typ_9 = NIM_NIL;
				eqcopy___ast_u3381(&typ_9, (*(*colonenv__1).c0).types.p->data[(NI)(((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 16777215ULL))) - ((NI)8388608))]);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				{
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* temp_1;
					if (!!(((*(*colonenv__1).tos1).slots.p->data[ra_1].kind == ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1)))) goto LA1887_;
					temp_1 = NIM_NIL;
					temp_1 = regToNode__vm_u542((*(*colonenv__1).tos1).slots.p->data[ra_1]);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqsink___ast_u3261(&(*(*colonenv__1).tos1).slots.p->data[ra_1].node, temp_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					(*(*(*colonenv__1).tos1).slots.p->data[ra_1].node).info = (*(*colonenv__1).c0).debug.p->data[(*colonenv__1).pc2];
				}
LA1887_: ;
				eqsink___ast_u3387(&(*(*(*colonenv__1).tos1).slots.p->data[ra_1].node).typField, typ_9);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)95):
			{
				tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* desttyp_1;
				tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* srctyp_1;
				NI rb_137;
				desttyp_1 = NIM_NIL;
				srctyp_1 = NIM_NIL;
				rb_137 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				(*colonenv__1).pc2 += ((NI)1);
				eqcopy___ast_u3381(&desttyp_1, (*(*colonenv__1).c0).types.p->data[(NI)(((NI) ((NU64)((NU64)((NU64)((*(*colonenv__1).c0).code.p->data[(*colonenv__1).pc2]) >> (NU64)(24ULL & (64 - 1))) & 16777215ULL))) - ((NI)8388608))]);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1890_;
				(*colonenv__1).pc2 += ((NI)1);
				eqcopy___ast_u3381(&srctyp_1, (*(*colonenv__1).c0).types.p->data[(NI)(((NI) ((NU64)((NU64)((NU64)((*(*colonenv__1).c0).code.p->data[(*colonenv__1).pc2]) >> (NU64)(24ULL & (64 - 1))) & 16777215ULL))) - ((NI)8388608))]);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1890_;
				{
					tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew* T1893_;
					NIM_BOOL T1894_;
					NimStringV2 colontmpD__169;
					NimStringV2 colontmpD__170;
					NimStringV2 colontmpD__171;
					tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T1898_;
					tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T1899_;
					T1893_ = NIM_NIL;
					T1893_ = (*colonenv__1).c0;
					T1894_ = (NIM_BOOL)0;
					T1894_ = opConv__vm_u731(T1893_, (&(*(*colonenv__1).tos1).slots.p->data[ra_1]), (*(*colonenv__1).tos1).slots.p->data[rb_137], desttyp_1, srctyp_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1890_;
					if (!T1894_) goto LA1895_;
					colontmpD__169.len = 0; colontmpD__169.p = NIM_NIL;
					colontmpD__170.len = 0; colontmpD__170.p = NIM_NIL;
					colontmpD__171.len = 0; colontmpD__171.p = NIM_NIL;
					colontmpD__169 = typeToString__types_u54(srctyp_1, ((tyEnum_TPreferedDesc__ddj0M89bv09cBYthgD4XTq3Q)0));
					if (NIM_UNLIKELY(*nimErr_)) goto LA1897_;
					T1898_[0] = colontmpD__169;
					colontmpD__170 = typeToString__types_u54(desttyp_1, ((tyEnum_TPreferedDesc__ddj0M89bv09cBYthgD4XTq3Q)0));
					if (NIM_UNLIKELY(*nimErr_)) goto LA1897_;
					T1898_[1] = colontmpD__170;
					colontmpD__171 = nsuFormatOpenArray(TM__pyAIA9cUF0h9c4j2HfNQPfYw_555, T1898_, 2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1897_;
					nimZeroMem((void*)(&T1899_), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
					stackTraceImpl__vm_u73((*colonenv__1).c0, (*colonenv__1).tos1, (*colonenv__1).pc2, colontmpD__171, T1899_, TM__pyAIA9cUF0h9c4j2HfNQPfYw_230);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1897_;
					eqdestroy___system_u2691(colontmpD__171);
					eqdestroy___system_u2691(colontmpD__170);
					eqdestroy___system_u2691(colontmpD__169);
					eqdestroy___ast_u3378(srctyp_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___ast_u3378(desttyp_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___vmprofiler_u19(savedFrame_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					eqdestroy___vm_u14829(colonenv__1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					goto BeforeRet_;
					{
						LA1897_:;
					}
					{
						eqdestroy___system_u2691(colontmpD__171);
						eqdestroy___system_u2691(colontmpD__170);
						eqdestroy___system_u2691(colontmpD__169);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA1890_;
				}
LA1895_: ;
				{
					LA1890_:;
				}
				{
					oldNimErrFin1890_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3378(srctyp_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___ast_u3378(desttyp_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin1890_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)96):
			{
				tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* desttyp_2;
				tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* srctyp_2;
				NI rb_138;
				desttyp_2 = NIM_NIL;
				srctyp_2 = NIM_NIL;
				rb_138 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				(*colonenv__1).pc2 += ((NI)1);
				eqcopy___ast_u3381(&desttyp_2, (*(*colonenv__1).c0).types.p->data[(NI)(((NI) ((NU64)((NU64)((NU64)((*(*colonenv__1).c0).code.p->data[(*colonenv__1).pc2]) >> (NU64)(24ULL & (64 - 1))) & 16777215ULL))) - ((NI)8388608))]);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1905_;
				(*colonenv__1).pc2 += ((NI)1);
				eqcopy___ast_u3381(&srctyp_2, (*(*colonenv__1).c0).types.p->data[(NI)(((NI) ((NU64)((NU64)((NU64)((*(*colonenv__1).c0).code.p->data[(*colonenv__1).pc2]) >> (NU64)(24ULL & (64 - 1))) & 16777215ULL))) - ((NI)8388608))]);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1905_;
				liMessage__msgs_u1227((*(*colonenv__1).c0).config, (*(*colonenv__1).c0).debug.p->data[(*colonenv__1).pc2], ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), TM__pyAIA9cUF0h9c4j2HfNQPfYw_557, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)2), TM__pyAIA9cUF0h9c4j2HfNQPfYw_558, NIM_FALSE, NIM_FALSE);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1905_;
				{
					LA1905_:;
				}
				{
					oldNimErrFin1905_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3378(srctyp_2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___ast_u3378(desttyp_2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin1905_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)119):
			{
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* dest_3;
				NI rb_139;
				dest_3 = NIM_NIL;
				rb_139 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1909_;
				eqcopy___ast_u3255(&dest_3, (*(*colonenv__1).tos1).slots.p->data[ra_1].node);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1909_;
				{
					NIM_BOOL T1912_;
					T1912_ = (NIM_BOOL)0;
					T1912_ = ((*dest_3).kind >= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)5) && (*dest_3).kind <= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)15));
					if (!(T1912_)) goto LA1913_;
					T1912_ = ((*(*colonenv__1).tos1).slots.p->data[rb_139].kind == ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2));
LA1913_: ;
					if (!T1912_) goto LA1914_;
					(*dest_3)._kind_1.intVal = (*(*colonenv__1).tos1).slots.p->data[rb_139].intVal;
				}
				goto LA1910_;
LA1914_: ;
				{
					NIM_BOOL T1917_;
					tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T1921_;
					T1917_ = (NIM_BOOL)0;
					T1917_ = ((*dest_3).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3));
					if (!(T1917_)) goto LA1918_;
					T1917_ = ((*(*dest_3)._kind_4.sym).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)20));
LA1918_: ;
					if (!T1917_) goto LA1919_;
					nimZeroMem((void*)(&T1921_), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
					stackTraceImpl__vm_u73((*colonenv__1).c0, (*colonenv__1).tos1, (*colonenv__1).pc2, TM__pyAIA9cUF0h9c4j2HfNQPfYw_560, T1921_, TM__pyAIA9cUF0h9c4j2HfNQPfYw_230);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1909_;
					eqdestroy___ast_u3252(dest_3);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___vmprofiler_u19(savedFrame_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					eqdestroy___vm_u14829(colonenv__1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					goto BeforeRet_;
				}
				goto LA1910_;
LA1919_: ;
				{
					tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T1923_;
					nimZeroMem((void*)(&T1923_), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
					stackTraceImpl__vm_u73((*colonenv__1).c0, (*colonenv__1).tos1, (*colonenv__1).pc2, TM__pyAIA9cUF0h9c4j2HfNQPfYw_561, T1923_, TM__pyAIA9cUF0h9c4j2HfNQPfYw_230);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1909_;
					eqdestroy___ast_u3252(dest_3);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___vmprofiler_u19(savedFrame_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					eqdestroy___vm_u14829(colonenv__1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					goto BeforeRet_;
				}
LA1910_: ;
				{
					LA1909_:;
				}
				{
					oldNimErrFin1909_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3252(dest_3);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin1909_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)120):
			{
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* dest_4;
				NI rb_140;
				dest_4 = NIM_NIL;
				rb_140 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1927_;
				eqcopy___ast_u3255(&dest_4, (*(*colonenv__1).tos1).slots.p->data[ra_1].node);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1927_;
				{
					NIM_BOOL T1930_;
					T1930_ = (NIM_BOOL)0;
					T1930_ = ((*dest_4).kind >= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)16) && (*dest_4).kind <= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)18));
					if (!(T1930_)) goto LA1931_;
					T1930_ = ((*(*colonenv__1).tos1).slots.p->data[rb_140].kind == ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)3));
LA1931_: ;
					if (!T1930_) goto LA1932_;
					(*dest_4)._kind_2.floatVal = (*(*colonenv__1).tos1).slots.p->data[rb_140].floatVal;
				}
				goto LA1928_;
LA1932_: ;
				{
					tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T1935_;
					nimZeroMem((void*)(&T1935_), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
					stackTraceImpl__vm_u73((*colonenv__1).c0, (*colonenv__1).tos1, (*colonenv__1).pc2, TM__pyAIA9cUF0h9c4j2HfNQPfYw_562, T1935_, TM__pyAIA9cUF0h9c4j2HfNQPfYw_230);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1927_;
					eqdestroy___ast_u3252(dest_4);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___vmprofiler_u19(savedFrame_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					eqdestroy___vm_u14829(colonenv__1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					goto BeforeRet_;
				}
LA1928_: ;
				{
					LA1927_:;
				}
				{
					oldNimErrFin1927_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3252(dest_4);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin1927_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)121):
			{
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* dest_5;
				NI rb_141;
				dest_5 = NIM_NIL;
				rb_141 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1939_;
				eqcopy___ast_u3255(&dest_5, (*(*colonenv__1).tos1).slots.p->data[ra_1].node);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1939_;
				{
					NIM_BOOL T1942_;
					T1942_ = (NIM_BOOL)0;
					T1942_ = ((*dest_5).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3));
					if (!(T1942_)) goto LA1943_;
					T1942_ = ((*(*(*colonenv__1).tos1).slots.p->data[rb_141].node).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3));
LA1943_: ;
					if (!T1942_) goto LA1944_;
					eqcopy___ast_u4577(&(*dest_5)._kind_4.sym, (*(*(*colonenv__1).tos1).slots.p->data[rb_141].node)._kind_4.sym);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1939_;
				}
				goto LA1940_;
LA1944_: ;
				{
					tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T1947_;
					nimZeroMem((void*)(&T1947_), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
					stackTraceImpl__vm_u73((*colonenv__1).c0, (*colonenv__1).tos1, (*colonenv__1).pc2, TM__pyAIA9cUF0h9c4j2HfNQPfYw_563, T1947_, TM__pyAIA9cUF0h9c4j2HfNQPfYw_230);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1939_;
					eqdestroy___ast_u3252(dest_5);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___vmprofiler_u19(savedFrame_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					eqdestroy___vm_u14829(colonenv__1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					goto BeforeRet_;
				}
LA1940_: ;
				{
					LA1939_:;
				}
				{
					oldNimErrFin1939_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3252(dest_5);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin1939_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)122):
			{
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* dest_6;
				NI rb_142;
				dest_6 = NIM_NIL;
				rb_142 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1951_;
				eqcopy___ast_u3255(&dest_6, (*(*colonenv__1).tos1).slots.p->data[ra_1].node);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1951_;
				{
					NIM_BOOL T1954_;
					T1954_ = (NIM_BOOL)0;
					T1954_ = ((*dest_6).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)2));
					if (!(T1954_)) goto LA1955_;
					T1954_ = ((*(*(*colonenv__1).tos1).slots.p->data[rb_142].node).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)2));
LA1955_: ;
					if (!T1954_) goto LA1956_;
					eqcopy___idents_u158(&(*dest_6)._kind_5.ident, (*(*(*colonenv__1).tos1).slots.p->data[rb_142].node)._kind_5.ident);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1951_;
				}
				goto LA1952_;
LA1956_: ;
				{
					tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T1959_;
					nimZeroMem((void*)(&T1959_), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
					stackTraceImpl__vm_u73((*colonenv__1).c0, (*colonenv__1).tos1, (*colonenv__1).pc2, TM__pyAIA9cUF0h9c4j2HfNQPfYw_564, T1959_, TM__pyAIA9cUF0h9c4j2HfNQPfYw_230);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1951_;
					eqdestroy___ast_u3252(dest_6);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___vmprofiler_u19(savedFrame_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					eqdestroy___vm_u14829(colonenv__1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					goto BeforeRet_;
				}
LA1952_: ;
				{
					LA1951_:;
				}
				{
					oldNimErrFin1951_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3252(dest_6);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin1951_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)123):
			{
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* dest_7;
				NI rb_143;
				dest_7 = NIM_NIL;
				rb_143 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1963_;
				eqcopy___ast_u3255(&dest_7, (*(*colonenv__1).tos1).slots.p->data[ra_1].node);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1963_;
				{
					NIM_BOOL T1966_;
					T1966_ = (NIM_BOOL)0;
					T1966_ = ((*dest_7).kind >= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)20) && (*dest_7).kind <= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)22));
					if (!(T1966_)) goto LA1967_;
					T1966_ = ((*(*colonenv__1).tos1).slots.p->data[rb_143].kind == ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1));
LA1967_: ;
					if (!T1966_) goto LA1968_;
					eqcopy___system_u2694((&(*dest_7)._kind_3.strVal), (*(*(*colonenv__1).tos1).slots.p->data[rb_143].node)._kind_3.strVal);
				}
				goto LA1964_;
LA1968_: ;
				{
					NIM_BOOL T1971_;
					T1971_ = (NIM_BOOL)0;
					T1971_ = ((*dest_7).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)125));
					if (!(T1971_)) goto LA1972_;
					T1971_ = ((*(*colonenv__1).tos1).slots.p->data[rb_143].kind == ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1));
LA1972_: ;
					if (!T1971_) goto LA1973_;
					commenteq___ast_u1334(dest_7, (*(*(*colonenv__1).tos1).slots.p->data[rb_143].node)._kind_3.strVal);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1963_;
				}
				goto LA1964_;
LA1973_: ;
				{
					tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T1976_;
					nimZeroMem((void*)(&T1976_), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
					stackTraceImpl__vm_u73((*colonenv__1).c0, (*colonenv__1).tos1, (*colonenv__1).pc2, TM__pyAIA9cUF0h9c4j2HfNQPfYw_565, T1976_, TM__pyAIA9cUF0h9c4j2HfNQPfYw_230);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1963_;
					eqdestroy___ast_u3252(dest_7);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___vmprofiler_u19(savedFrame_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					eqdestroy___vm_u14829(colonenv__1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					goto BeforeRet_;
				}
LA1964_: ;
				{
					LA1963_:;
				}
				{
					oldNimErrFin1963_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3252(dest_7);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin1963_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)124):
			{
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* cc_1;
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* x_2;
				tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA colontmpD__172;
				tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA colontmpD__173;
				tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA colontmpD__174;
				tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA colontmpD__175;
				NI rb_144;
				NI rc_75;
				NI64 k_1;
				tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T1987_;
				cc_1 = NIM_NIL;
				x_2 = NIM_NIL;
				nimZeroMem((void*)(&colontmpD__172), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
				nimZeroMem((void*)(&colontmpD__173), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
				nimZeroMem((void*)(&colontmpD__174), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
				nimZeroMem((void*)(&colontmpD__175), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
				rb_144 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				rc_75 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(40ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1980_;
				k_1 = (*(*colonenv__1).tos1).slots.p->data[rb_144].intVal;
				{
					NIM_BOOL T1983_;
					T1983_ = (NIM_BOOL)0;
					T1983_ = (k_1 < IL64(0));
					if (T1983_) goto LA1984_;
					T1983_ = (IL64(165) < k_1);
LA1984_: ;
					if (!T1983_) goto LA1985_;
					internalErrorImpl__msgs_u1598((*(*colonenv__1).c0).config, (*(*colonenv__1).c0).debug.p->data[(*colonenv__1).pc2], TM__pyAIA9cUF0h9c4j2HfNQPfYw_567, TM__pyAIA9cUF0h9c4j2HfNQPfYw_568);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1980_;
				}
LA1985_: ;
				eqcopy___ast_u3255(&cc_1, (*(*colonenv__1).tos1).slots.p->data[rc_75].node);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1980_;
				{
					if (!!(((*cc_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)23)))) goto LA1990_;
					colontmpD__172 = (*cc_1).info;
					T1987_ = colontmpD__172;
				}
				goto LA1988_;
LA1990_: ;
				{
					if (!!(((*(*colonenv__1).c0).comesFromHeuristic.line == ((NU16)0)))) goto LA1993_;
					colontmpD__173 = (*(*colonenv__1).c0).comesFromHeuristic;
					T1987_ = colontmpD__173;
				}
				goto LA1988_;
LA1993_: ;
				{
					NIM_BOOL T1996_;
					NI T1998_;
					T1996_ = (NIM_BOOL)0;
					T1996_ = !(((*(*colonenv__1).c0).callsite == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL)));
					if (!(T1996_)) goto LA1997_;
					T1998_ = (NI)0;
					T1998_ = safeLen__ast_u3197((*(*colonenv__1).c0).callsite);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1980_;
					T1996_ = (((NI)1) < T1998_);
LA1997_: ;
					if (!T1996_) goto LA1999_;
					colontmpD__174 = (*(*(*(*colonenv__1).c0).callsite)._kind_6.sons.p->data[((NI)1)]).info;
					T1987_ = colontmpD__174;
				}
				goto LA1988_;
LA1999_: ;
				{
					colontmpD__175 = (*(*colonenv__1).c0).debug.p->data[(*colonenv__1).pc2];
					T1987_ = colontmpD__175;
				}
LA1988_: ;
				x_2 = newNodeI__ast_u4091(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw) (((NI) (k_1)))), T1987_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1980_;
				(*x_2).flags |= ((NU32)1)<<(((((tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw)13))) & 31);
				{
					if (!((*x_2).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)2))) goto LA2004_;
					eqcopy___idents_u158(&(*x_2)._kind_5.ident, (*(*(*colonenv__1).c0).cache).emptyIdent);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1980_;
				}
LA2004_: ;
				eqsink___ast_u3261(&(*(*colonenv__1).tos1).slots.p->data[ra_1].node, x_2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1980_;
				eqwasMoved___ast_u3249(&x_2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1980_;
				{
					LA1980_:;
				}
				{
					oldNimErrFin1980_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3252(x_2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___ast_u3252(cc_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin1980_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)125):
			{
				NI rb_145;
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T2009_;
				rb_145 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				T2009_ = NIM_NIL;
				T2009_ = copyNode__ast_u6736((*(*colonenv__1).tos1).slots.p->data[rb_145].node);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T2009_); goto LA1_;}
				eqsink___ast_u3261(&(*(*colonenv__1).tos1).slots.p->data[ra_1].node, T2009_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)126):
			{
				NI rb_146;
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T2011_;
				rb_146 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				T2011_ = NIM_NIL;
				T2011_ = copyTree__ast_u6891((*(*colonenv__1).tos1).slots.p->data[rb_146].node);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T2011_); goto LA1_;}
				eqsink___ast_u3261(&(*(*colonenv__1).tos1).slots.p->data[ra_1].node, T2011_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)127):
			{
				NI rb_147;
				NI rc_76;
				NI bb_2;
				rb_147 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				rc_76 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(40ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				bb_2 = ((NI) ((*(*colonenv__1).tos1).slots.p->data[rb_147].intVal));
				{
					NI i_15;
					NI colontmp__10;
					NI i_16;
					i_15 = (NI)0;
					colontmp__10 = (NI)0;
					colontmp__10 = ((NI) ((*(*colonenv__1).tos1).slots.p->data[rc_76].intVal));
					i_16 = ((NI)0);
					{
						while (1) {
							if (!(i_16 < colontmp__10)) goto LA2015;
							i_15 = i_16;
							delSon__ast_u6724((*(*colonenv__1).tos1).slots.p->data[ra_1].node, bb_2);
							if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
							i_16 += ((NI)1);
						} LA2015: ;
					}
				}
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)128):
			{
				NimStringV2 name_1;
				tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_1;
				tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* colontmpD__176;
				tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD__177;
				NI rb_148;
				NI rc_77;
				NI64 k_2;
				NimStringV2 T2018_;
				tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ T2030_;
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T2031_;
				name_1.len = 0; name_1.p = NIM_NIL;
				sym_1 = NIM_NIL;
				colontmpD__176 = NIM_NIL;
				colontmpD__177 = NIM_NIL;
				rb_148 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				rc_77 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(40ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA2017_;
				k_2 = (*(*colonenv__1).tos1).slots.p->data[rb_148].intVal;
				T2018_.len = 0; T2018_.p = NIM_NIL;
				{
					if (!((*(*(*colonenv__1).tos1).slots.p->data[rc_77].node)._kind_3.strVal.len == ((NI)0))) goto LA2021_;
					name_1 = TM__pyAIA9cUF0h9c4j2HfNQPfYw_570;
				}
				goto LA2019_;
LA2021_: ;
				{
					eqcopy___system_u2694((&name_1), (*(*(*colonenv__1).tos1).slots.p->data[rc_77].node)._kind_3.strVal);
				}
LA2019_: ;
				{
					NIM_BOOL T2026_;
					T2026_ = (NIM_BOOL)0;
					T2026_ = (k_2 < IL64(0));
					if (T2026_) goto LA2027_;
					T2026_ = (IL64(24) < k_2);
LA2027_: ;
					if (!T2026_) goto LA2028_;
					internalErrorImpl__msgs_u1598((*(*colonenv__1).c0).config, (*(*colonenv__1).c0).debug.p->data[(*colonenv__1).pc2], TM__pyAIA9cUF0h9c4j2HfNQPfYw_572, TM__pyAIA9cUF0h9c4j2HfNQPfYw_573);
					if (NIM_UNLIKELY(*nimErr_)) goto LA2017_;
				}
LA2028_: ;
				colontmpD__176 = getIdent__idents_u206((*(*colonenv__1).c0).cache, name_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA2017_;
				colontmpD__177 = owner__ast_u6254((*(*colonenv__1).c0).module);
				if (NIM_UNLIKELY(*nimErr_)) goto LA2017_;
				T2030_ = 0;
				sym_1 = newSym__ast_u4205(((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q) (k_2)), colontmpD__176, (*(*colonenv__1).c0).Sup.idgen, colontmpD__177, (*(*colonenv__1).c0).debug.p->data[(*colonenv__1).pc2], T2030_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA2017_;
				(*sym_1).flags |= ((NU64)1)<<(((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)37))) & 63);
				T2031_ = NIM_NIL;
				T2031_ = newSymNode__ast_u5168(sym_1);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T2031_); goto LA2017_;}
				eqsink___ast_u3261(&(*(*colonenv__1).tos1).slots.p->data[ra_1].node, T2031_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA2017_;
				(*(*(*colonenv__1).tos1).slots.p->data[ra_1].node).flags |= ((NU32)1)<<(((((tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw)13))) & 31);
				{
					LA2017_:;
				}
				{
					oldNimErrFin2017_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u4574(colontmpD__177);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___idents_u155(colontmpD__176);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___ast_u4574(sym_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___system_u2691(name_1);
					*nimErr_ = oldNimErrFin2017_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)129):
			{
				NimStringV2 destKey_1;
				NI rb_149;
				NI64 T2035_;
				destKey_1.len = 0; destKey_1.p = NIM_NIL;
				rb_149 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				destKey_1 = (*(*(*colonenv__1).tos1).slots.p->data[rb_149].node)._kind_3.strVal;
				T2035_ = (NI64)0;
				T2035_ = getOrDefault__vm_u4335((*(*(*colonenv__1).c0).graph).cacheCounters, destKey_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				(*(*colonenv__1).tos1).slots.p->data[ra_1].intVal = T2035_;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)130):
			{
				tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_1;
				NimStringV2 destKey_2;
				NI rb_150;
				NI rc_78;
				NI64 by_1;
				NI64 v_1;
				g_1 = NIM_NIL;
				destKey_2.len = 0; destKey_2.p = NIM_NIL;
				eqcopy___modulegraphs_u14756(&g_1, (*(*colonenv__1).c0).graph);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				rb_150 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				rc_78 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(40ULL & (64 - 1))) & 65535ULL)));
				destKey_2 = (*(*(*colonenv__1).tos1).slots.p->data[rb_150].node)._kind_3.strVal;
				by_1 = (*(*colonenv__1).tos1).slots.p->data[rc_78].intVal;
				v_1 = getOrDefault__vm_u4335((*g_1).cacheCounters, destKey_2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				X5BX5Deq___vm_u4773((&(*g_1).cacheCounters), destKey_2, (NI64)(v_1 + by_1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				recordInc__macrocacheimpl_u27((*colonenv__1).c0, (*(*colonenv__1).c0).debug.p->data[(*colonenv__1).pc2], destKey_2, by_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				eqdestroy___modulegraphs_u14753(g_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)131):
			{
				tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_2;
				NimStringV2 destKey_3;
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* val_2;
				NI rb_151;
				NI rc_79;
				g_2 = NIM_NIL;
				destKey_3.len = 0; destKey_3.p = NIM_NIL;
				val_2 = NIM_NIL;
				eqcopy___modulegraphs_u14756(&g_2, (*(*colonenv__1).c0).graph);
				if (NIM_UNLIKELY(*nimErr_)) goto LA2038_;
				rb_151 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				rc_79 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(40ULL & (64 - 1))) & 65535ULL)));
				destKey_3 = (*(*(*colonenv__1).tos1).slots.p->data[rb_151].node)._kind_3.strVal;
				eqcopy___ast_u3255(&val_2, (*(*colonenv__1).tos1).slots.p->data[rc_79].node);
				if (NIM_UNLIKELY(*nimErr_)) goto LA2038_;
				{
					NIM_BOOL T2041_;
					tyArray__TAsXwXSUBvAawE1kIQ5ziQ T2044_;
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T2045_;
					T2041_ = (NIM_BOOL)0;
					T2041_ = contains__vm_u5937((*g_2).cacheSeqs, destKey_3);
					if (NIM_UNLIKELY(*nimErr_)) goto LA2038_;
					if (!!(T2041_)) goto LA2042_;
					nimZeroMem((void*)T2044_, sizeof(tyArray__TAsXwXSUBvAawE1kIQ5ziQ));
					T2044_[0] = val_2;
					T2045_ = NIM_NIL;
					T2045_ = newTree__ast_u4170(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)115), T2044_, 1);
					if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T2045_); goto LA2038_;}
					X5BX5Deq___vm_u6248((&(*g_2).cacheSeqs), destKey_3, T2045_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA2038_;
				}
				goto LA2039_;
LA2042_: ;
				{
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** T2047_;
					T2047_ = (tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ**)0;
					T2047_ = X5BX5D___vm_u7388((&(*g_2).cacheSeqs), destKey_3);
					if (NIM_UNLIKELY(*nimErr_)) goto LA2038_;
					add__ast_u3215((*T2047_), val_2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA2038_;
				}
LA2039_: ;
				recordAdd__macrocacheimpl_u40((*colonenv__1).c0, (*(*colonenv__1).c0).debug.p->data[(*colonenv__1).pc2], destKey_3, val_2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA2038_;
				{
					LA2038_:;
				}
				{
					oldNimErrFin2038_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3252(val_2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___modulegraphs_u14753(g_2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin2038_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)132):
			{
				tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_3;
				NimStringV2 destKey_4;
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* val_3;
				NI rb_152;
				NI rc_80;
				g_3 = NIM_NIL;
				destKey_4.len = 0; destKey_4.p = NIM_NIL;
				val_3 = NIM_NIL;
				eqcopy___modulegraphs_u14756(&g_3, (*(*colonenv__1).c0).graph);
				if (NIM_UNLIKELY(*nimErr_)) goto LA2051_;
				rb_152 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				rc_80 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(40ULL & (64 - 1))) & 65535ULL)));
				destKey_4 = (*(*(*colonenv__1).tos1).slots.p->data[rb_152].node)._kind_3.strVal;
				eqcopy___ast_u3255(&val_3, (*(*colonenv__1).tos1).slots.p->data[rc_80].node);
				if (NIM_UNLIKELY(*nimErr_)) goto LA2051_;
				{
					NIM_BOOL T2054_;
					tyArray__TAsXwXSUBvAawE1kIQ5ziQ T2057_;
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T2058_;
					T2054_ = (NIM_BOOL)0;
					T2054_ = contains__vm_u5937((*g_3).cacheSeqs, destKey_4);
					if (NIM_UNLIKELY(*nimErr_)) goto LA2051_;
					if (!!(T2054_)) goto LA2055_;
					nimZeroMem((void*)T2057_, sizeof(tyArray__TAsXwXSUBvAawE1kIQ5ziQ));
					T2057_[0] = val_3;
					T2058_ = NIM_NIL;
					T2058_ = newTree__ast_u4170(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)115), T2057_, 1);
					if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T2058_); goto LA2051_;}
					X5BX5Deq___vm_u6248((&(*g_3).cacheSeqs), destKey_4, T2058_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA2051_;
				}
				goto LA2052_;
LA2055_: ;
				{
					{
						tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** T2073_;
						{
							tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* existing_1;
							tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** colontmp__11;
							existing_1 = NIM_NIL;
							existing_1 = 0;
							colontmp__11 = (tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ**)0;
							colontmp__11 = X5BX5D___vm_u7388((&(*g_3).cacheSeqs), destKey_4);
							if (NIM_UNLIKELY(*nimErr_)) goto LA2062_;
							{
								NI i_17;
								NI colontmp__12;
								NI i_18;
								i_17 = (NI)0;
								colontmp__12 = (NI)0;
								colontmp__12 = safeLen__ast_u3197((*colontmp__11));
								if (NIM_UNLIKELY(*nimErr_)) goto LA2062_;
								i_18 = ((NI)0);
								{
									while (1) {
										if (!(i_18 < colontmp__12)) goto LA2065;
										i_17 = i_18;
										eqcopy___ast_u3255(&existing_1, (*(*colontmp__11))._kind_6.sons.p->data[i_17]);
										if (NIM_UNLIKELY(*nimErr_)) goto LA2062_;
										{
											NIM_BOOL T2068_;
											T2068_ = (NIM_BOOL)0;
											T2068_ = exprStructuralEquivalent__trees_u63(existing_1, val_3, NIM_TRUE);
											if (NIM_UNLIKELY(*nimErr_)) goto LA2062_;
											if (!T2068_) goto LA2069_;
											eqdestroy___ast_u3252(existing_1);
											if (NIM_UNLIKELY(*nimErr_)) goto LA2051_;
											goto LA2060;
										}
LA2069_: ;
										i_18 += ((NI)1);
									} LA2065: ;
								}
							}
							{
								LA2062_:;
							}
							{
								oldNimErrFin2062_ = *nimErr_; *nimErr_ = NIM_FALSE;
								eqdestroy___ast_u3252(existing_1);
								if (NIM_UNLIKELY(*nimErr_)) goto LA2051_;
								*nimErr_ = oldNimErrFin2062_;
							}
							if (NIM_UNLIKELY(*nimErr_)) goto LA2051_;
						}
						T2073_ = (tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ**)0;
						T2073_ = X5BX5D___vm_u7388((&(*g_3).cacheSeqs), destKey_4);
						if (NIM_UNLIKELY(*nimErr_)) goto LA2051_;
						add__ast_u3215((*T2073_), val_3);
						if (NIM_UNLIKELY(*nimErr_)) goto LA2051_;
					} LA2060: ;
				}
LA2052_: ;
				recordIncl__macrocacheimpl_u46((*colonenv__1).c0, (*(*colonenv__1).c0).debug.p->data[(*colonenv__1).pc2], destKey_4, val_3);
				if (NIM_UNLIKELY(*nimErr_)) goto LA2051_;
				{
					LA2051_:;
				}
				{
					oldNimErrFin2051_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3252(val_3);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___modulegraphs_u14753(g_3);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin2051_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)133):
			{
				tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_4;
				NimStringV2 destKey_5;
				NI colontmpD__178;
				NI colontmpD__179;
				NI rb_153;
				NI T2078_;
				g_4 = NIM_NIL;
				destKey_5.len = 0; destKey_5.p = NIM_NIL;
				colontmpD__178 = (NI)0;
				colontmpD__179 = (NI)0;
				eqcopy___modulegraphs_u14756(&g_4, (*(*colonenv__1).c0).graph);
				if (NIM_UNLIKELY(*nimErr_)) goto LA2077_;
				rb_153 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA2077_;
				destKey_5 = (*(*(*colonenv__1).tos1).slots.p->data[rb_153].node)._kind_3.strVal;
				T2078_ = (NI)0;
				{
					NIM_BOOL T2081_;
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** T2085_;
					T2081_ = (NIM_BOOL)0;
					T2081_ = contains__vm_u5937((*g_4).cacheSeqs, destKey_5);
					if (NIM_UNLIKELY(*nimErr_)) goto LA2077_;
					if (!T2081_) goto LA2082_;
					T2085_ = (tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ**)0;
					T2085_ = X5BX5D___vm_u7388((&(*g_4).cacheSeqs), destKey_5);
					if (NIM_UNLIKELY(*nimErr_)) goto LA2084_;
					colontmpD__178 = len__ast_u3190((*T2085_));
					if (NIM_UNLIKELY(*nimErr_)) goto LA2084_;
					T2078_ = colontmpD__178;
					{
						LA2084_:;
					}
					{
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA2077_;
				}
				goto LA2079_;
LA2082_: ;
				{
					colontmpD__179 = ((NI)0);
					T2078_ = colontmpD__179;
				}
LA2079_: ;
				(*(*colonenv__1).tos1).slots.p->data[ra_1].intVal = ((NI64) (T2078_));
				{
					LA2077_:;
				}
				{
					oldNimErrFin2077_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___modulegraphs_u14753(g_4);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin2077_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)134):
			{
				tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_5;
				NimStringV2 destKey_6;
				NI rb_154;
				NI rc_81;
				NI64 idx_10;
				g_5 = NIM_NIL;
				destKey_6.len = 0; destKey_6.p = NIM_NIL;
				eqcopy___modulegraphs_u14756(&g_5, (*(*colonenv__1).c0).graph);
				if (NIM_UNLIKELY(*nimErr_)) goto LA2092_;
				rb_154 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				rc_81 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(40ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA2092_;
				idx_10 = (*(*colonenv__1).tos1).slots.p->data[rc_81].intVal;
				destKey_6 = (*(*(*colonenv__1).tos1).slots.p->data[rb_154].node)._kind_3.strVal;
				{
					NIM_BOOL T2095_;
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** T2097_;
					NI T2098_;
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** T2101_;
					T2095_ = (NIM_BOOL)0;
					T2095_ = contains__vm_u5937((*g_5).cacheSeqs, destKey_6);
					if (NIM_UNLIKELY(*nimErr_)) goto LA2092_;
					if (!(T2095_)) goto LA2096_;
					T2097_ = (tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ**)0;
					T2097_ = X5BX5D___vm_u7388((&(*g_5).cacheSeqs), destKey_6);
					if (NIM_UNLIKELY(*nimErr_)) goto LA2092_;
					T2098_ = (NI)0;
					T2098_ = len__ast_u3190((*T2097_));
					if (NIM_UNLIKELY(*nimErr_)) goto LA2092_;
					T2095_ = ltpercent___system_u1108(idx_10, ((NI64) (T2098_)));
LA2096_: ;
					if (!T2095_) goto LA2099_;
					T2101_ = (tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ**)0;
					T2101_ = X5BX5D___vm_u7388((&(*g_5).cacheSeqs), destKey_6);
					if (NIM_UNLIKELY(*nimErr_)) goto LA2092_;
					eqcopy___ast_u3255(&(*(*colonenv__1).tos1).slots.p->data[ra_1].node, (*(*T2101_))._kind_6.sons.p->data[((NI) (idx_10))]);
					if (NIM_UNLIKELY(*nimErr_)) goto LA2092_;
				}
				goto LA2093_;
LA2099_: ;
				{
					NimStringV2 colontmpD__180;
					NimStringV2 colontmpD__181;
					NimStringV2 T2104_;
					tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T2118_;
					colontmpD__180.len = 0; colontmpD__180.p = NIM_NIL;
					colontmpD__181.len = 0; colontmpD__181.p = NIM_NIL;
					T2104_.len = 0; T2104_.p = NIM_NIL;
					{
						tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** T2107_;
						NI T2108_;
						T2107_ = (tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ**)0;
						T2107_ = X5BX5D___vm_u7388((&(*g_5).cacheSeqs), destKey_6);
						if (NIM_UNLIKELY(*nimErr_)) goto LA2103_;
						T2108_ = (NI)0;
						T2108_ = len__ast_u3190((*T2107_));
						if (NIM_UNLIKELY(*nimErr_)) goto LA2103_;
						if (!((NI)(T2108_ - ((NI)1)) < ((NI)0))) goto LA2109_;
						colontmpD__180 = TM__pyAIA9cUF0h9c4j2HfNQPfYw_574;
						T2104_ = colontmpD__180;
					}
					goto LA2105_;
LA2109_: ;
					{
						NimStringV2 colontmpD__182;
						NimStringV2 colontmpD__183;
						NimStringV2 T2113_;
						tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** T2114_;
						NI T2115_;
						colontmpD__182.len = 0; colontmpD__182.p = NIM_NIL;
						colontmpD__183.len = 0; colontmpD__183.p = NIM_NIL;
						T2113_.len = 0; T2113_.p = NIM_NIL;
						colontmpD__182 = dollar___systemZdollars_u29(idx_10);
						if (NIM_UNLIKELY(*nimErr_)) goto LA2112_;
						T2114_ = (tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ**)0;
						T2114_ = X5BX5D___vm_u7388((&(*g_5).cacheSeqs), destKey_6);
						if (NIM_UNLIKELY(*nimErr_)) goto LA2112_;
						T2115_ = (NI)0;
						T2115_ = len__ast_u3190((*T2114_));
						if (NIM_UNLIKELY(*nimErr_)) goto LA2112_;
						colontmpD__183 = dollar___systemZdollars_u9((NI)(T2115_ - ((NI)1)));
						if (NIM_UNLIKELY(*nimErr_)) goto LA2112_;
						T2113_ = rawNewString(colontmpD__182.len + colontmpD__183.len + 19);
appendString((&T2113_), TM__pyAIA9cUF0h9c4j2HfNQPfYw_575);
appendString((&T2113_), colontmpD__182);
appendString((&T2113_), TM__pyAIA9cUF0h9c4j2HfNQPfYw_576);
appendString((&T2113_), colontmpD__183);
						colontmpD__181 = T2113_;
						T2104_ = colontmpD__181;
						{
							LA2112_:;
						}
						{
							eqdestroy___system_u2691(colontmpD__183);
							eqdestroy___system_u2691(colontmpD__182);
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA2103_;
					}
LA2105_: ;
					nimZeroMem((void*)(&T2118_), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
					stackTraceImpl__vm_u73((*colonenv__1).c0, (*colonenv__1).tos1, (*colonenv__1).pc2, T2104_, T2118_, TM__pyAIA9cUF0h9c4j2HfNQPfYw_230);
					if (NIM_UNLIKELY(*nimErr_)) goto LA2103_;
					eqdestroy___system_u2691(colontmpD__181);
					eqdestroy___system_u2691(colontmpD__180);
					eqdestroy___modulegraphs_u14753(g_5);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___vmprofiler_u19(savedFrame_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					eqdestroy___vm_u14829(colonenv__1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					goto BeforeRet_;
					{
						LA2103_:;
					}
					{
						eqdestroy___system_u2691(colontmpD__181);
						eqdestroy___system_u2691(colontmpD__180);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA2092_;
				}
LA2093_: ;
				{
					LA2092_:;
				}
				{
					oldNimErrFin2092_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___modulegraphs_u14753(g_5);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin2092_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)135):
			{
				tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_6;
				NimStringV2 destKey_7;
				NimStringV2 key_1;
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* val_4;
				g_6 = NIM_NIL;
				destKey_7.len = 0; destKey_7.p = NIM_NIL;
				key_1.len = 0; key_1.p = NIM_NIL;
				val_4 = NIM_NIL;
				eqcopy___modulegraphs_u14756(&g_6, (*(*colonenv__1).c0).graph);
				if (NIM_UNLIKELY(*nimErr_)) goto LA2124_;
				destKey_7 = (*(*(*colonenv__1).tos1).slots.p->data[ra_1].node)._kind_3.strVal;
				key_1 = (*(*(*colonenv__1).tos1).slots.p->data[((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)))].node)._kind_3.strVal;
				eqcopy___ast_u3255(&val_4, (*(*colonenv__1).tos1).slots.p->data[((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(40ULL & (64 - 1))) & 65535ULL)))].node);
				if (NIM_UNLIKELY(*nimErr_)) goto LA2124_;
				{
					NIM_BOOL T2127_;
					tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw T2130_;
					T2127_ = (NIM_BOOL)0;
					T2127_ = contains__vm_u8108((*g_6).cacheTables, destKey_7);
					if (NIM_UNLIKELY(*nimErr_)) goto LA2124_;
					if (!!(T2127_)) goto LA2128_;
					nimZeroMem((void*)(&T2130_), sizeof(tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw));
					initBTree__vm_u8410((&T2130_));
					if (NIM_UNLIKELY(*nimErr_)) goto LA2124_;
					X5BX5Deq___vm_u8529((&(*g_6).cacheTables), destKey_7, T2130_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA2124_;
				}
LA2128_: ;
				{
					tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw* T2133_;
					NIM_BOOL T2134_;
					tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw* T2137_;
					T2133_ = (tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw*)0;
					T2133_ = X5BX5D___vm_u9673((&(*g_6).cacheTables), destKey_7);
					if (NIM_UNLIKELY(*nimErr_)) goto LA2124_;
					T2134_ = (NIM_BOOL)0;
					T2134_ = contains__vm_u9814((*T2133_), key_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA2124_;
					if (!!(T2134_)) goto LA2135_;
					T2137_ = (tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw*)0;
					T2137_ = X5BX5D___vm_u9673((&(*g_6).cacheTables), destKey_7);
					if (NIM_UNLIKELY(*nimErr_)) goto LA2124_;
					add__vm_u10092(T2137_, key_1, val_4);
					if (NIM_UNLIKELY(*nimErr_)) goto LA2124_;
					recordPut__macrocacheimpl_u33((*colonenv__1).c0, (*(*colonenv__1).c0).debug.p->data[(*colonenv__1).pc2], destKey_7, key_1, val_4);
					if (NIM_UNLIKELY(*nimErr_)) goto LA2124_;
				}
				goto LA2131_;
LA2135_: ;
				{
					NimStringV2 colontmpD__184;
					NimStringV2 T2140_;
					tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T2141_;
					colontmpD__184.len = 0; colontmpD__184.p = NIM_NIL;
					T2140_.len = 0; T2140_.p = NIM_NIL;
					T2140_ = rawNewString(key_1.len + 20);
appendString((&T2140_), TM__pyAIA9cUF0h9c4j2HfNQPfYw_578);
appendString((&T2140_), key_1);
					colontmpD__184 = T2140_;
					nimZeroMem((void*)(&T2141_), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
					stackTraceImpl__vm_u73((*colonenv__1).c0, (*colonenv__1).tos1, (*colonenv__1).pc2, colontmpD__184, T2141_, TM__pyAIA9cUF0h9c4j2HfNQPfYw_230);
					if (NIM_UNLIKELY(*nimErr_)) goto LA2139_;
					eqdestroy___system_u2691(colontmpD__184);
					eqdestroy___ast_u3252(val_4);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___modulegraphs_u14753(g_6);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___vmprofiler_u19(savedFrame_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					eqdestroy___vm_u14829(colonenv__1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					goto BeforeRet_;
					{
						LA2139_:;
					}
					{
						eqdestroy___system_u2691(colontmpD__184);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA2124_;
				}
LA2131_: ;
				{
					LA2124_:;
				}
				{
					oldNimErrFin2124_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3252(val_4);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___modulegraphs_u14753(g_6);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin2124_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)136):
			{
				tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_7;
				NimStringV2 destKey_8;
				NI colontmpD__185;
				NI colontmpD__186;
				NI rb_155;
				NI T2148_;
				g_7 = NIM_NIL;
				destKey_8.len = 0; destKey_8.p = NIM_NIL;
				colontmpD__185 = (NI)0;
				colontmpD__186 = (NI)0;
				eqcopy___modulegraphs_u14756(&g_7, (*(*colonenv__1).c0).graph);
				if (NIM_UNLIKELY(*nimErr_)) goto LA2147_;
				rb_155 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA2147_;
				destKey_8 = (*(*(*colonenv__1).tos1).slots.p->data[rb_155].node)._kind_3.strVal;
				T2148_ = (NI)0;
				{
					NIM_BOOL T2151_;
					tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw* T2155_;
					T2151_ = (NIM_BOOL)0;
					T2151_ = contains__vm_u8108((*g_7).cacheTables, destKey_8);
					if (NIM_UNLIKELY(*nimErr_)) goto LA2147_;
					if (!T2151_) goto LA2152_;
					T2155_ = (tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw*)0;
					T2155_ = X5BX5D___vm_u9673((&(*g_7).cacheTables), destKey_8);
					if (NIM_UNLIKELY(*nimErr_)) goto LA2154_;
					colontmpD__185 = len__vm_u11692((*T2155_));
					if (NIM_UNLIKELY(*nimErr_)) goto LA2154_;
					T2148_ = colontmpD__185;
					{
						LA2154_:;
					}
					{
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA2147_;
				}
				goto LA2149_;
LA2152_: ;
				{
					colontmpD__186 = ((NI)0);
					T2148_ = colontmpD__186;
				}
LA2149_: ;
				(*(*colonenv__1).tos1).slots.p->data[ra_1].intVal = ((NI64) (T2148_));
				{
					LA2147_:;
				}
				{
					oldNimErrFin2147_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___modulegraphs_u14753(g_7);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin2147_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)137):
			{
				tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_8;
				NimStringV2 destKey_9;
				NimStringV2 key_2;
				NI rb_156;
				NI rc_82;
				g_8 = NIM_NIL;
				destKey_9.len = 0; destKey_9.p = NIM_NIL;
				key_2.len = 0; key_2.p = NIM_NIL;
				eqcopy___modulegraphs_u14756(&g_8, (*(*colonenv__1).c0).graph);
				if (NIM_UNLIKELY(*nimErr_)) goto LA2162_;
				rb_156 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				rc_82 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(40ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA2162_;
				destKey_9 = (*(*(*colonenv__1).tos1).slots.p->data[rb_156].node)._kind_3.strVal;
				key_2 = (*(*(*colonenv__1).tos1).slots.p->data[rc_82].node)._kind_3.strVal;
				{
					NIM_BOOL T2165_;
					T2165_ = (NIM_BOOL)0;
					T2165_ = contains__vm_u8108((*g_8).cacheTables, destKey_9);
					if (NIM_UNLIKELY(*nimErr_)) goto LA2162_;
					if (!T2165_) goto LA2166_;
					{
						tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw* T2170_;
						NIM_BOOL T2171_;
						tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw* T2174_;
						tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T2175_;
						T2170_ = (tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw*)0;
						T2170_ = X5BX5D___vm_u9673((&(*g_8).cacheTables), destKey_9);
						if (NIM_UNLIKELY(*nimErr_)) goto LA2162_;
						T2171_ = (NIM_BOOL)0;
						T2171_ = contains__vm_u9814((*T2170_), key_2);
						if (NIM_UNLIKELY(*nimErr_)) goto LA2162_;
						if (!T2171_) goto LA2172_;
						T2174_ = (tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw*)0;
						T2174_ = X5BX5D___vm_u9673((&(*g_8).cacheTables), destKey_9);
						if (NIM_UNLIKELY(*nimErr_)) goto LA2162_;
						T2175_ = NIM_NIL;
						T2175_ = getOrDefault__vm_u12014((*T2174_), key_2);
						if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T2175_); goto LA2162_;}
						eqsink___ast_u3261(&(*(*colonenv__1).tos1).slots.p->data[ra_1].node, T2175_);
						if (NIM_UNLIKELY(*nimErr_)) goto LA2162_;
					}
					goto LA2168_;
LA2172_: ;
					{
						NimStringV2 colontmpD__187;
						NimStringV2 T2178_;
						tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T2179_;
						colontmpD__187.len = 0; colontmpD__187.p = NIM_NIL;
						T2178_.len = 0; T2178_.p = NIM_NIL;
						T2178_ = rawNewString(key_2.len + 20);
appendString((&T2178_), TM__pyAIA9cUF0h9c4j2HfNQPfYw_580);
appendString((&T2178_), key_2);
						colontmpD__187 = T2178_;
						nimZeroMem((void*)(&T2179_), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
						stackTraceImpl__vm_u73((*colonenv__1).c0, (*colonenv__1).tos1, (*colonenv__1).pc2, colontmpD__187, T2179_, TM__pyAIA9cUF0h9c4j2HfNQPfYw_230);
						if (NIM_UNLIKELY(*nimErr_)) goto LA2177_;
						eqdestroy___system_u2691(colontmpD__187);
						eqdestroy___modulegraphs_u14753(g_8);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						eqdestroy___vmprofiler_u19(savedFrame_1);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						eqdestroy___vm_u14829(colonenv__1);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						goto BeforeRet_;
						{
							LA2177_:;
						}
						{
							eqdestroy___system_u2691(colontmpD__187);
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA2162_;
					}
LA2168_: ;
				}
				goto LA2163_;
LA2166_: ;
				{
					NimStringV2 colontmpD__188;
					NimStringV2 T2184_;
					tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T2185_;
					colontmpD__188.len = 0; colontmpD__188.p = NIM_NIL;
					T2184_.len = 0; T2184_.p = NIM_NIL;
					T2184_ = rawNewString(destKey_9.len + 20);
appendString((&T2184_), TM__pyAIA9cUF0h9c4j2HfNQPfYw_581);
appendString((&T2184_), destKey_9);
					colontmpD__188 = T2184_;
					nimZeroMem((void*)(&T2185_), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
					stackTraceImpl__vm_u73((*colonenv__1).c0, (*colonenv__1).tos1, (*colonenv__1).pc2, colontmpD__188, T2185_, TM__pyAIA9cUF0h9c4j2HfNQPfYw_230);
					if (NIM_UNLIKELY(*nimErr_)) goto LA2183_;
					eqdestroy___system_u2691(colontmpD__188);
					eqdestroy___modulegraphs_u14753(g_8);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___vmprofiler_u19(savedFrame_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					eqdestroy___vm_u14829(colonenv__1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					goto BeforeRet_;
					{
						LA2183_:;
					}
					{
						eqdestroy___system_u2691(colontmpD__188);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA2162_;
				}
LA2163_: ;
				{
					LA2162_:;
				}
				{
					oldNimErrFin2162_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___modulegraphs_u14753(g_8);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin2162_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)138):
			{
				tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_9;
				NimStringV2 destKey_10;
				NI colontmpD__189;
				NI colontmpD__190;
				NI rb_157;
				NI rc_83;
				NI T2192_;
				g_9 = NIM_NIL;
				destKey_10.len = 0; destKey_10.p = NIM_NIL;
				colontmpD__189 = (NI)0;
				colontmpD__190 = (NI)0;
				eqcopy___modulegraphs_u14756(&g_9, (*(*colonenv__1).c0).graph);
				if (NIM_UNLIKELY(*nimErr_)) goto LA2191_;
				rb_157 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				rc_83 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(40ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA2191_;
				destKey_10 = (*(*(*colonenv__1).tos1).slots.p->data[rb_157].node)._kind_3.strVal;
				T2192_ = (NI)0;
				{
					NIM_BOOL T2195_;
					tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw* T2199_;
					NIM_BOOL T2200_;
					T2195_ = (NIM_BOOL)0;
					T2195_ = contains__vm_u8108((*g_9).cacheTables, destKey_10);
					if (NIM_UNLIKELY(*nimErr_)) goto LA2191_;
					if (!T2195_) goto LA2196_;
					T2199_ = (tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw*)0;
					T2199_ = X5BX5D___vm_u9673((&(*g_9).cacheTables), destKey_10);
					if (NIM_UNLIKELY(*nimErr_)) goto LA2198_;
					T2200_ = (NIM_BOOL)0;
					T2200_ = hasNext__vm_u12373((*T2199_), ((NI) ((*(*colonenv__1).tos1).slots.p->data[rc_83].intVal)));
					if (NIM_UNLIKELY(*nimErr_)) goto LA2198_;
					colontmpD__189 = T2200_;
					T2192_ = colontmpD__189;
					{
						LA2198_:;
					}
					{
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA2191_;
				}
				goto LA2193_;
LA2196_: ;
				{
					colontmpD__190 = ((NI)0);
					T2192_ = colontmpD__190;
				}
LA2193_: ;
				(*(*colonenv__1).tos1).slots.p->data[ra_1].intVal = ((NI64) (T2192_));
				{
					LA2191_:;
				}
				{
					oldNimErrFin2191_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___modulegraphs_u14753(g_9);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin2191_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)139):
			{
				tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_10;
				NimStringV2 destKey_11;
				NI rb_158;
				NI rc_84;
				NI64 index_1;
				g_10 = NIM_NIL;
				destKey_11.len = 0; destKey_11.p = NIM_NIL;
				eqcopy___modulegraphs_u14756(&g_10, (*(*colonenv__1).c0).graph);
				if (NIM_UNLIKELY(*nimErr_)) goto LA2207_;
				rb_158 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				rc_84 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(40ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA2207_;
				destKey_11 = (*(*(*colonenv__1).tos1).slots.p->data[rb_158].node)._kind_3.strVal;
				index_1 = (*(*colonenv__1).tos1).slots.p->data[rc_84].intVal;
				{
					NIM_BOOL T2210_;
					tyTuple__4wIKrvA4KpCWPy4McN64Pg tmpTuple_1;
					NimStringV2 k_3;
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* v_2;
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__191;
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__192;
					tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw* T2214_;
					NI nextIndex_1;
					tyArray__JEzAlj49cAK8qpM6I2Q9bfcQ T2215_;
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T2216_;
					T2210_ = (NIM_BOOL)0;
					T2210_ = contains__vm_u8108((*g_10).cacheTables, destKey_11);
					if (NIM_UNLIKELY(*nimErr_)) goto LA2207_;
					if (!T2210_) goto LA2211_;
					nimZeroMem((void*)(&tmpTuple_1), sizeof(tyTuple__4wIKrvA4KpCWPy4McN64Pg));
					k_3.len = 0; k_3.p = NIM_NIL;
					v_2 = NIM_NIL;
					colontmpD__191 = NIM_NIL;
					colontmpD__192 = NIM_NIL;
					T2214_ = (tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw*)0;
					T2214_ = X5BX5D___vm_u9673((&(*g_10).cacheTables), destKey_11);
					if (NIM_UNLIKELY(*nimErr_)) goto LA2213_;
					next__vm_u12522((*T2214_), ((NI) (index_1)), (&tmpTuple_1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA2213_;
					k_3 = tmpTuple_1.Field0;
					eqwasMoved___system_u2688((&tmpTuple_1.Field0));
					v_2 = tmpTuple_1.Field1;
					eqwasMoved___ast_u3249(&tmpTuple_1.Field1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA2213_;
					nextIndex_1 = tmpTuple_1.Field2;
					nimZeroMem((void*)T2215_, sizeof(tyArray__JEzAlj49cAK8qpM6I2Q9bfcQ));
					colontmpD__191 = newStrNode__ast_u5426(k_3, (*(*colonenv__1).c0).debug.p->data[(*colonenv__1).pc2]);
					if (NIM_UNLIKELY(*nimErr_)) goto LA2213_;
					T2215_[0] = colontmpD__191;
					T2215_[1] = v_2;
					colontmpD__192 = newIntNode__ast_u5200(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)6), ((NI64) (nextIndex_1)));
					if (NIM_UNLIKELY(*nimErr_)) goto LA2213_;
					T2215_[2] = colontmpD__192;
					T2216_ = NIM_NIL;
					T2216_ = newTree__ast_u4170(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)160), T2215_, 3);
					if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T2216_); goto LA2213_;}
					eqsink___ast_u3261(&(*(*colonenv__1).tos1).slots.p->data[ra_1].node, T2216_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA2213_;
					{
						LA2213_:;
					}
					{
						oldNimErrFin2213_ = *nimErr_; *nimErr_ = NIM_FALSE;
						eqdestroy___ast_u3252(colontmpD__192);
						if (NIM_UNLIKELY(*nimErr_)) goto LA2207_;
						eqdestroy___ast_u3252(colontmpD__191);
						if (NIM_UNLIKELY(*nimErr_)) goto LA2207_;
						eqdestroy___ast_u3252(v_2);
						if (NIM_UNLIKELY(*nimErr_)) goto LA2207_;
						eqdestroy___system_u2691(k_3);
						eqdestroy___vm_u12834(tmpTuple_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA2207_;
						*nimErr_ = oldNimErrFin2213_;
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA2207_;
				}
				goto LA2208_;
LA2211_: ;
				{
					NimStringV2 colontmpD__193;
					NimStringV2 T2221_;
					tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T2222_;
					colontmpD__193.len = 0; colontmpD__193.p = NIM_NIL;
					T2221_.len = 0; T2221_.p = NIM_NIL;
					T2221_ = rawNewString(destKey_11.len + 20);
appendString((&T2221_), TM__pyAIA9cUF0h9c4j2HfNQPfYw_582);
appendString((&T2221_), destKey_11);
					colontmpD__193 = T2221_;
					nimZeroMem((void*)(&T2222_), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
					stackTraceImpl__vm_u73((*colonenv__1).c0, (*colonenv__1).tos1, (*colonenv__1).pc2, colontmpD__193, T2222_, TM__pyAIA9cUF0h9c4j2HfNQPfYw_230);
					if (NIM_UNLIKELY(*nimErr_)) goto LA2220_;
					eqdestroy___system_u2691(colontmpD__193);
					eqdestroy___modulegraphs_u14753(g_10);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___vmprofiler_u19(savedFrame_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					eqdestroy___vm_u14829(colonenv__1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					goto BeforeRet_;
					{
						LA2220_:;
					}
					{
						eqdestroy___system_u2691(colontmpD__193);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA2207_;
				}
LA2208_: ;
				{
					LA2207_:;
				}
				{
					oldNimErrFin2207_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___modulegraphs_u14753(g_10);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin2207_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			break;
			case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)189):
			{
				tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_10;
				NI rb_159;
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T2241_;
				NimStringV2 T2242_;
				typ_10 = NIM_NIL;
				rb_159 = ((NI) ((NU64)((NU64)((NU64)(instr_1) >> (NU64)(24ULL & (64 - 1))) & 65535ULL)));
				ensureKind__vm_u122((&(*(*colonenv__1).tos1).slots.p->data[ra_1]), ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA2228_;
				eqcopy___ast_u3381(&typ_10, (*(*(*colonenv__1).tos1).slots.p->data[rb_159].node).typField);
				if (NIM_UNLIKELY(*nimErr_)) goto LA2228_;
				{
					NimStringV2 argX60gensym2096__1;
					if (!!(!((typ_10 == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL))))) goto LA2231_;
					argX60gensym2096__1.len = 0; argX60gensym2096__1.p = NIM_NIL;
					argX60gensym2096__1 = toFileLineCol__msgs_u701(TM__pyAIA9cUF0h9c4j2HfNQPfYw_583);
					if (NIM_UNLIKELY(*nimErr_)) goto LA2233_;
					internalErrorImpl__msgs_u1598((*(*colonenv__1).c0).config, unknownLineInfo__lineinfos_u364, argX60gensym2096__1, TM__pyAIA9cUF0h9c4j2HfNQPfYw_583);
					if (NIM_UNLIKELY(*nimErr_)) goto LA2233_;
					{
						LA2233_:;
					}
					{
						eqdestroy___system_u2691(argX60gensym2096__1);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA2228_;
				}
LA2231_: ;
				{
					while (1) {
						NIM_BOOL T2238_;
						tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* T2240_;
						T2238_ = (NIM_BOOL)0;
						T2238_ = ((*typ_10).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)8));
						if (!(T2238_)) goto LA2239_;
						T2238_ = hasElementType__ast_u5660(typ_10);
						if (NIM_UNLIKELY(*nimErr_)) goto LA2228_;
LA2239_: ;
						if (!T2238_) goto LA2237;
						T2240_ = NIM_NIL;
						T2240_ = skipModifier__ast_u5338(typ_10);
						if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3378(T2240_); goto LA2228_;}
						eqsink___ast_u3387(&typ_10, T2240_);
						if (NIM_UNLIKELY(*nimErr_)) goto LA2228_;
					} LA2237: ;
				}
				T2241_ = NIM_NIL;
				T2241_ = newNode__ast_u4069(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)20));
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T2241_); goto LA2228_;}
				eqsink___ast_u3261(&(*(*colonenv__1).tos1).slots.p->data[ra_1].node, T2241_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA2228_;
				T2242_.len = 0; T2242_.p = NIM_NIL;
				T2242_ = typeToString__types_u54(typ_10, ((tyEnum_TPreferedDesc__ddj0M89bv09cBYthgD4XTq3Q)2));
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T2242_); goto LA2228_;}
				eqsink___system_u2700((&(*(*(*colonenv__1).tos1).slots.p->data[ra_1].node)._kind_3.strVal), T2242_);
				{
					LA2228_:;
				}
				{
					oldNimErrFin2228_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3378(typ_10);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin2228_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			break;
			default: __builtin_unreachable();
			}
			leave__vmprofiler_u1887((&(*(*colonenv__1).c0).profiler), (*colonenv__1).c0);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			(*colonenv__1).pc2 += ((NI)1);
		}
	}
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___vmprofiler_u19(savedFrame_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___vm_u14829(colonenv__1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, evalMacroCall__vm_u14362)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module_p0, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p1, tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p2, NI* templInstCounter_p3, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p4, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* nOrig_p5, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_p6) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
	tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew* c_1;
	RootObj* colontmpD_;
	tyObject_TStackFrame__a20zU43j9cYHpYOOr1c2hZQ* tos_1;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD__2;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* gp_1;
	tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A colontmpD__3;
	NI sl_1;
	tyEnum_TEvalMode__sQljSFf0fjnsNV1fpgXakg oldMode_1;
	tyObject_VmProcInfo__Jux30icZSrOlvcFTG81Ljg start_1;
	tyObject_TStackFrame__a20zU43j9cYHpYOOr1c2hZQ* T24_;
	NI L_1;
	tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A T29_;
NIM_BOOL oldNimErrFin31_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	c_1 = NIM_NIL;
	tos_1 = NIM_NIL;
	gp_1 = NIM_NIL;
	nimZeroMem((void*)(&colontmpD__3), sizeof(tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A));
	(*(*g_p2).config).evalMacroCounter += ((NI)1);
	{
		if (!(((NI)1000) < (*(*g_p2).config).evalMacroCounter)) goto LA4_;
		liMessage__msgs_u1227((*g_p2).config, (*n_p4).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), TM__pyAIA9cUF0h9c4j2HfNQPfYw_3, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)2), TM__pyAIA9cUF0h9c4j2HfNQPfYw_4, NIM_FALSE, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA4_: ;
	sl_1 = signatureLen__ast_u5610((*sym_p6).typ);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NIM_BOOL T8_;
		NI T9_;
		NimStringV2 colontmpD__4;
		NimStringV2 colontmpD__5;
		NimStringV2 colontmpD__6;
		NimStringV2 colontmpD__7;
		tyArray__dyW7vpmfeTYw8kX3EXuaJA T14_;
		tySet_tyEnum_TRenderFlag__Il2q467fyuki59ci9aspexFg T15_;
		NI T16_;
		NI T17_;
		T8_ = (NIM_BOOL)0;
		T9_ = (NI)0;
		T9_ = safeLen__ast_u3197(n_p4);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T8_ = (T9_ < sl_1);
		if (!(T8_)) goto LA10_;
		T8_ = (((NI)1) < sl_1);
LA10_: ;
		if (!T8_) goto LA11_;
		colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
		colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
		colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
		colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
		T15_ = 0;
		colontmpD__4 = renderTree__renderer_u59(n_p4, T15_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		T14_[0] = colontmpD__4;
		T16_ = (NI)0;
		T16_ = safeLen__ast_u3197(n_p4);
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		colontmpD__5 = dollar___systemZdollars_u9((NI)(T16_ - ((NI)1)));
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		T14_[1] = colontmpD__5;
		T17_ = (NI)0;
		T17_ = paramsLen__ast_u5616((*sym_p6).typ);
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		colontmpD__6 = dollar___systemZdollars_u9(T17_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		T14_[2] = colontmpD__6;
		colontmpD__7 = nsuFormatOpenArray(TM__pyAIA9cUF0h9c4j2HfNQPfYw_7, T14_, 3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		liMessage__msgs_u1227((*g_p2).config, (*n_p4).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), colontmpD__7, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)2), TM__pyAIA9cUF0h9c4j2HfNQPfYw_8, NIM_FALSE, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		{
			LA13_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__7);
			eqdestroy___system_u2691(colontmpD__6);
			eqdestroy___system_u2691(colontmpD__5);
			eqdestroy___system_u2691(colontmpD__4);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA11_: ;
	setupGlobalCtx__vm_u14200(module_p0, g_p2, idgen_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD_ = eqdup___ast_u4951((*g_p2).vm, NIM_TRUE);
	c_1 = (*((tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew**) (&(colontmpD_))));
	oldMode_1 = (*c_1).mode;
	(*c_1).mode = ((tyEnum_TEvalMode__sQljSFf0fjnsNV1fpgXakg)4);
	(*c_1).comesFromHeuristic.line = ((NU16)0);
	eqcopy___ast_u3255(&(*c_1).callsite, nOrig_p5);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	eqcopy___vm_u14411(&(*c_1).templInstCounter, templInstCounter_p3);
	(*c_1).cannotEval = NIM_FALSE;
	start_1 = genProc__vmgen_u3092(c_1, sym_p6);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		if (!(*c_1).cannotEval) goto LA22_;
		result = errorNode__vm_u12981(idgen_p1, module_p0, n_p4);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		eqdestroy___vmdef_u1706(colontmpD__3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3252(gp_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___vmprofiler_u19(tos_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___vmdef_u2206(c_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		goto BeforeRet_;
	}
LA22_: ;
	T24_ = NIM_NIL;
	T24_ = (tyObject_TStackFrame__a20zU43j9cYHpYOOr1c2hZQ*) nimNewObj(sizeof(tyObject_TStackFrame__a20zU43j9cYHpYOOr1c2hZQ), NIM_ALIGNOF(tyObject_TStackFrame__a20zU43j9cYHpYOOr1c2hZQ));
	colontmpD__2 = eqdup___ast_u4580(sym_p6);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	(*T24_).prc = colontmpD__2;
	(*T24_).comesFrom = ((NI)0);
	(*T24_).next = ((tyObject_TStackFrame__a20zU43j9cYHpYOOr1c2hZQ*) NIM_NIL);
	tos_1 = T24_;
	newSeq__vm_u2972((&(*tos_1).slots), ((NI) (start_1.usedRegisters)));
	L_1 = safeLen__ast_u3197(n_p4);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		if (!(L_1 == ((NI)0))) goto LA27_;
		L_1 = ((NI)1);
	}
LA27_: ;
	nimZeroMem((void*)(&T29_), sizeof(tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A));
	T29_.kind = ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1);
	T29_.node = newNodeI__ast_u4091(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)1), (*n_p4).info);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	eqsink___vmdef_u1715((&(*tos_1).slots.p->data[((NI)0)]), T29_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* param_1;
		NI i_1;
		param_1 = NIM_NIL;
		i_1 = (NI)0;
		{
			NI i_2;
			NI colontmp_;
			NI T33_;
			NI i_3;
			i_2 = (NI)0;
			colontmp_ = (NI)0;
			T33_ = (*(*sym_p6).typ).sons.len;
			colontmp_ = T33_;
			i_3 = ((NI)1);
			{
				while (1) {
					tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A T36_;
					if (!(i_3 < colontmp_)) goto LA35;
					i_2 = i_3;
					i_1 = i_2;
					eqcopy___ast_u3381(&param_1, (*(*sym_p6).typ).sons.p->data[i_2]);
					if (NIM_UNLIKELY(*nimErr_)) goto LA31_;
					nimZeroMem((void*)(&T36_), sizeof(tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A));
					setupMacroParam__vm_u14337((*n_p4)._kind_6.sons.p->data[(NI)((NI)(i_1 - ((NI)1)) + ((NI)1))], param_1, (&T36_));
					if (NIM_UNLIKELY(*nimErr_)) goto LA31_;
					eqsink___vmdef_u1715((&(*tos_1).slots.p->data[(NI)((NI)(i_1 - ((NI)1)) + ((NI)1))]), T36_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA31_;
					i_3 += ((NI)1);
				} LA35: ;
			}
		}
		{
			LA31_:;
		}
		{
			oldNimErrFin31_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3378(param_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin31_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	eqcopy___ast_u3255(&gp_1, (*(*sym_p6).ast)._kind_6.sons.p->data[((NI)2)]);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NI i_4;
		NI colontmp__2;
		NI i_5;
		i_4 = (NI)0;
		colontmp__2 = (NI)0;
		colontmp__2 = len__ast_u3190(gp_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		i_5 = ((NI)0);
		{
			while (1) {
				NI idx_1;
				NI T42_;
				if (!(i_5 < colontmp__2)) goto LA41;
				i_4 = i_5;
				T42_ = (NI)0;
				T42_ = signatureLen__ast_u5610((*sym_p6).typ);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				idx_1 = (NI)(T42_ + i_4);
				{
					NI T45_;
					tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A T48_;
					T45_ = (NI)0;
					T45_ = len__ast_u3190(n_p4);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					if (!(idx_1 < T45_)) goto LA46_;
					nimZeroMem((void*)(&T48_), sizeof(tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A));
					setupMacroParam__vm_u14337((*n_p4)._kind_6.sons.p->data[idx_1], (*(*(*gp_1)._kind_6.sons.p->data[i_4])._kind_4.sym).typ, (&T48_));
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqsink___vmdef_u1715((&(*tos_1).slots.p->data[idx_1]), T48_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				}
				goto LA43_;
LA46_: ;
				{
					NimStringV2 colontmpD__8;
					NimStringV2 colontmpD__9;
					NimStringV2 T51_;
					NI T52_;
					colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
					colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
					(*(*g_p2).config).evalMacroCounter -= ((NI)1);
					eqsink___ast_u3261(&(*c_1).callsite, ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL));
					if (NIM_UNLIKELY(*nimErr_)) goto LA50_;
					T51_.len = 0; T51_.p = NIM_NIL;
					T52_ = (NI)0;
					T52_ = len__ast_u3190(gp_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA50_;
					colontmpD__8 = dollar___systemZdollars_u9(T52_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA50_;
					T51_ = rawNewString(colontmpD__8.len + 30);
appendString((&T51_), TM__pyAIA9cUF0h9c4j2HfNQPfYw_307);
appendString((&T51_), colontmpD__8);
appendString((&T51_), TM__pyAIA9cUF0h9c4j2HfNQPfYw_309);
					colontmpD__9 = T51_;
					liMessage__msgs_u1227((*c_1).config, (*n_p4).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), colontmpD__9, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), TM__pyAIA9cUF0h9c4j2HfNQPfYw_310, NIM_FALSE, NIM_FALSE);
					if (NIM_UNLIKELY(*nimErr_)) goto LA50_;
					{
						LA50_:;
					}
					{
						eqdestroy___system_u2691(colontmpD__9);
						eqdestroy___system_u2691(colontmpD__8);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				}
LA43_: ;
				i_5 += ((NI)1);
			} LA41: ;
		}
	}
	rawExecute__vm_u879(c_1, ((NI) (start_1.pc)), tos_1, (&colontmpD__3));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	result = regToNode__vm_u542(colontmpD__3);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		if (!((NU16)((*result).info.line) < (NU16)(((NU16)0)))) goto LA57_;
		(*result).info = (*n_p4).info;
	}
LA57_: ;
	{
		NIM_BOOL T61_;
		T61_ = (NIM_BOOL)0;
		T61_ = cyclicTree__trees_u51(result);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!T61_) goto LA62_;
		liMessage__msgs_u1227((*c_1).config, (*n_p4).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), TM__pyAIA9cUF0h9c4j2HfNQPfYw_585, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)2), TM__pyAIA9cUF0h9c4j2HfNQPfYw_586, NIM_FALSE, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA62_: ;
	(*(*g_p2).config).evalMacroCounter -= ((NI)1);
	eqsink___ast_u3261(&(*c_1).callsite, ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	(*c_1).mode = oldMode_1;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___vmdef_u1706(colontmpD__3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3252(gp_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___vmprofiler_u19(tos_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___vmdef_u2206(c_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(void, initIntSet__pureZcollectionsZintsets_u598)(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* Result) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)Result, sizeof(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA));
	initPackedSet__pureZcollectionsZintsets_u37(Result);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, evalConstExprAux__vm_u14217)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module_p0, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p1, tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p2, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* prc_p3, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p4, tyEnum_TEvalMode__sQljSFf0fjnsNV1fpgXakg mode_p5) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_2;
	tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew* c_1;
	RootObj* colontmpD_;
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA oldLocals_1;
	tyObject_TStackFrame__a20zU43j9cYHpYOOr1c2hZQ* tos_1;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD__2;
	tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A colontmpD__3;
	tySet_tyEnum_TransformFlag__CzUOfRCXpoYcP43GAlt9cnA T2_;
	tyEnum_TEvalMode__sQljSFf0fjnsNV1fpgXakg oldMode_1;
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA T3_;
	NI start_1;
	tyObject_TStackFrame__a20zU43j9cYHpYOOr1c2hZQ* T12_;
	NI T13_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	n_2 = NIM_NIL;
	c_1 = NIM_NIL;
	nimZeroMem((void*)(&oldLocals_1), sizeof(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA));
	tos_1 = NIM_NIL;
	nimZeroMem((void*)(&colontmpD__3), sizeof(tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A));
	T2_ = 0;
	n_2 = transformExpr__transf_u3516(g_p2, idgen_p1, module_p0, n_p4, T2_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	setupGlobalCtx__vm_u14200(module_p0, g_p2, idgen_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD_ = eqdup___ast_u4951((*g_p2).vm, NIM_TRUE);
	c_1 = (*((tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew**) (&(colontmpD_))));
	oldMode_1 = (*c_1).mode;
	eqcopy___pureZcollectionsZintsets_u250((&oldLocals_1), (&(*c_1).locals));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	(*c_1).mode = mode_p5;
	nimZeroMem((void*)(&T3_), sizeof(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA));
	initIntSet__pureZcollectionsZintsets_u598((&T3_));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	eqsink___pureZcollectionsZintsets_u236((&(*c_1).locals), (&T3_));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	(*c_1).cannotEval = NIM_FALSE;
	start_1 = genExpr__vmgen_u3448(c_1, n_2, !((mode_p5 == ((tyEnum_TEvalMode__sQljSFf0fjnsNV1fpgXakg)4))));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	eqsink___pureZcollectionsZintsets_u236((&(*c_1).locals), (&oldLocals_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	eqwasMoved___pureZcollectionsZintsets_u227((&oldLocals_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		if (!(*c_1).cannotEval) goto LA6_;
		result = errorNode__vm_u12981(idgen_p1, prc_p3, n_2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		eqdestroy___vmdef_u1706(colontmpD__3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___vmprofiler_u19(tos_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___pureZcollectionsZintsets_u230((&oldLocals_1));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___vmdef_u2206(c_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3252(n_2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		goto BeforeRet_;
	}
LA6_: ;
	{
		if (!(((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA) ((NU64)((NU64)((NU64)((*c_1).code.p->data[start_1]) >> (NU64)(0ULL & (64 - 1))) & 255ULL))) == ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)0))) goto LA10_;
		result = newNodeI__ast_u4091(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)1), (*n_2).info);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		eqdestroy___vmdef_u1706(colontmpD__3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___vmprofiler_u19(tos_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___pureZcollectionsZintsets_u230((&oldLocals_1));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___vmdef_u2206(c_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3252(n_2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		goto BeforeRet_;
	}
LA10_: ;
	T12_ = NIM_NIL;
	T12_ = (tyObject_TStackFrame__a20zU43j9cYHpYOOr1c2hZQ*) nimNewObj(sizeof(tyObject_TStackFrame__a20zU43j9cYHpYOOr1c2hZQ), NIM_ALIGNOF(tyObject_TStackFrame__a20zU43j9cYHpYOOr1c2hZQ));
	colontmpD__2 = eqdup___ast_u4580(prc_p3);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	(*T12_).prc = colontmpD__2;
	(*T12_).comesFrom = ((NI)0);
	(*T12_).next = ((tyObject_TStackFrame__a20zU43j9cYHpYOOr1c2hZQ*) NIM_NIL);
	tos_1 = T12_;
	T13_ = (*(*c_1).prc).regInfo.len;
	newSeq__vm_u2972((&(*tos_1).slots), (T13_));
	rawExecute__vm_u879(c_1, start_1, tos_1, (&colontmpD__3));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	result = regToNode__vm_u542(colontmpD__3);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		if (!((*result).info.col < ((NI16)0))) goto LA16_;
		(*result).info = (*n_2).info;
	}
LA16_: ;
	(*c_1).mode = oldMode_1;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___vmdef_u1706(colontmpD__3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___vmprofiler_u19(tos_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___pureZcollectionsZintsets_u230((&oldLocals_1));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___vmdef_u2206(c_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3252(n_2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, evalConstExpr__vm_u14280)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module_p0, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p1, tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p2, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p3) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	result = evalConstExprAux__vm_u14217(module_p0, idgen_p1, g_p2, ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL), e_p3, ((tyEnum_TEvalMode__sQljSFf0fjnsNV1fpgXakg)1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, evalStaticExpr__vm_u14286)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module_p0, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p1, tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p2, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p3, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* prc_p4) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	result = evalConstExprAux__vm_u14217(module_p0, idgen_p1, g_p2, prc_p4, e_p3, ((tyEnum_TEvalMode__sQljSFf0fjnsNV1fpgXakg)3));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, setupCompileTimeVar__vm_u14299)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module_p0, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p1, tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p2, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p3) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_ = NIM_NIL;
	colontmpD_ = evalConstExprAux__vm_u14217(module_p0, idgen_p1, g_p2, ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL), n_p3, ((tyEnum_TEvalMode__sQljSFf0fjnsNV1fpgXakg)4));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	(void)(colontmpD_);
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3252(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, evalStaticStmt__vm_u14293)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module_p0, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p1, tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p2, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p3, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* prc_p4) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_ = NIM_NIL;
	colontmpD_ = evalConstExprAux__vm_u14217(module_p0, idgen_p1, g_p2, prc_p4, e_p3, ((tyEnum_TEvalMode__sQljSFf0fjnsNV1fpgXakg)4));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	(void)(colontmpD_);
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3252(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ*, setupEvalGen__vm_u14207)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module_p1, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p2) {
	tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ* result;
	RootObj* colontmpD_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	setupGlobalCtx__vm_u14200(module_p1, graph_p0, idgen_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	colontmpD_ = eqdup___ast_u4951((*graph_p0).vm, NIM_TRUE);
	result = &(*((tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew**) (&(colontmpD_))))->Sup;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, execute__vm_u12939)(tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew* c_p0, NI start_p1) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
	tyObject_TStackFrame__a20zU43j9cYHpYOOr1c2hZQ* tos_1;
	tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A colontmpD_;
	tyObject_TStackFrame__a20zU43j9cYHpYOOr1c2hZQ* T2_;
	NI T3_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	tos_1 = NIM_NIL;
	nimZeroMem((void*)(&colontmpD_), sizeof(tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A));
	T2_ = NIM_NIL;
	T2_ = (tyObject_TStackFrame__a20zU43j9cYHpYOOr1c2hZQ*) nimNewObj(sizeof(tyObject_TStackFrame__a20zU43j9cYHpYOOr1c2hZQ), NIM_ALIGNOF(tyObject_TStackFrame__a20zU43j9cYHpYOOr1c2hZQ));
	(*T2_).prc = ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL);
	(*T2_).comesFrom = ((NI)0);
	(*T2_).next = ((tyObject_TStackFrame__a20zU43j9cYHpYOOr1c2hZQ*) NIM_NIL);
	tos_1 = T2_;
	T3_ = (*(*c_p0).prc).regInfo.len;
	newSeq__vm_u2972((&(*tos_1).slots), (T3_));
	rawExecute__vm_u879(c_p0, start_p1, tos_1, (&colontmpD_));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	result = regToNode__vm_u542(colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___vmdef_u1706(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___vmprofiler_u19(tos_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, evalStmt__vm_u12990)(tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_2;
	tySet_tyEnum_TransformFlag__CzUOfRCXpoYcP43GAlt9cnA T2_;
	NI start_1;
NIM_BOOL oldNimErrFin11_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	n_2 = NIM_NIL;
	T2_ = 0;
	n_2 = transformExpr__transf_u3516((*c_p0).graph, (*c_p0).Sup.idgen, (*c_p0).module, n_p1, T2_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	start_1 = genStmt__vmgen_u3440(c_p0, n_2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		if (!(*c_p0).cannotEval) goto LA5_;
		(*c_p0).cannotEval = NIM_FALSE;
		eqdestroy___ast_u3252(n_2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		goto BeforeRet_;
	}
LA5_: ;
	{
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD_;
		if (!!((((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA) ((NU64)((NU64)((NU64)((*c_p0).code.p->data[start_1]) >> (NU64)(0ULL & (64 - 1))) & 255ULL))) == ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)0)))) goto LA9_;
		colontmpD_ = NIM_NIL;
		colontmpD_ = execute__vm_u12939(c_p0, start_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
		(void)(colontmpD_);
		{
			LA11_:;
		}
		{
			oldNimErrFin11_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3252(colontmpD_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin11_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA9_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3252(n_2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, interpreterCode__vm_u14212)(tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
	tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew* c_2;
	tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ* colontmpD_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	c_2 = NIM_NIL;
	colontmpD_ = eqdup___cgen_u30982(c_p0, NIM_TRUE);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	c_2 = (*((tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew**) (&(colontmpD_))));
	{
		if (!((*c_2).oldErrorCount == (*(*c_2).config).errorCounter)) goto LA4_;
		evalStmt__vm_u12990(c_2, n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		result = newNodeI__ast_u4091(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)1), (*n_p1).info);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA2_;
LA4_: ;
	{
		eqcopy___ast_u3255(&result, n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA2_: ;
	(*c_2).oldErrorCount = (*(*c_2).config).errorCounter;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___vmdef_u2206(c_2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
